# Copyright 2005-2016 Canonical Limited.  All rights reserved.

import os
import sys

from testresources import TestLoader

from benchmark.testing.options import Options
from benchmark.testing.runner import TestRunner


class TestProgram(object):
    """A test program with the same API as unittest.TestProgram.

    Maybe one day we'll be able to inherit from it, for now we just
    have to accept that "TestProgram is an abomination" [0].

    [0] http://bugs.python.org/msg231442
    """

    def __init__(self, argv):
        self.parseArgs(argv)
        self.runTests()

    def parseArgs(self, argv):
        """Parse command line options."""
        self.options = Options()
        self.options.update(argv[1:])
        self.createTests()

    def createTests(self):
        """Create the benchmarks to run."""
        self.testLoader = TestLoader()
        self.testLoader.testMethodPrefix = "benchmark_"
        benchmarks = self.options.benchmarks
        if not benchmarks:
            benchmarks = ["benchmark"]
        suite = self.testLoader.suiteClass()
        for path in benchmarks:
            if os.path.isdir(path):
                start_dir = path
                pattern = "benchmark_*.py"
            else:
                start_dir = os.path.dirname(path)
                pattern = os.path.basename(path)
            benchmark = self.testLoader.discover(
                start_dir, pattern=pattern, top_level_dir="."
            )
            suite.addTest(benchmark)

        for benchmark in suite:
            for name, manager in benchmark.resources:
                manager.options = self.options
        self.test = suite

    def runTests(self):
        """Collect and run the benchmarks."""
        # Reset test run information
        runner = TestRunner(
            subunit=self.options.subunit, failfast=self.options.exitfirst
        )
        if self.options.list_benchmarks:
            self.test.sortTests()
            runner.list(self.test)
            code = 0
        else:
            result = runner.run(self.test)
            code = not result.wasSuccessful()
        sys.exit(code)


def main(argv):
    """Run the system tests."""
    TestProgram(argv)
