# Copyright 2005-2016 Canonical Limited.  All rights reserved.

from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter, Namespace


class Options(Namespace):
    """Available benchmark options."""

    def __init__(self):
        super(Namespace, self).__init__()
        self._parser = self._build_parser()
        self.update(())

    def update(self, args):
        """Update the options by parsing the given command line arguments."""
        self._parser.parse_args(args=args, namespace=self)

    def _build_parser(self):
        """Parse command line arguments to get benchmark run options."""
        parser = ArgumentParser(formatter_class=ArgumentDefaultsHelpFormatter)

        parser.add_argument(
            "benchmarks",
            metavar="BENCHMARKS",
            nargs="*",
            help="Optional list of specific benchmarks to run, either files "
            "or directories.",
        )
        parser.add_argument(
            "--build-area",
            metavar="PATH",
            default="./build/benchmarks",
            help="Directory where to build SQL dumps for benchmark data. "
            "Once created, these dumps will be re-used to speed up "
            "database setup.",
        )
        parser.add_argument(
            "-x",
            "--exitfirst",
            action="store_true",
            default=False,
            help="Stop running tests at the first failure.",
        )
        parser.add_argument(
            "-l",
            "--list",
            dest="list_benchmarks",
            action="store_true",
            help="Just list what benchmarks would be run, don't actually run " "them.",
        )
        parser.add_argument(
            "-c",
            "--force-create",
            action="store_true",
            default=False,
            help="Force creating data from scratch. This is useful if you "
            "change a benchmark dataset definition and you want to "
            "re-create everything.",
        )
        parser.add_argument(
            "--subunit",
            action="store",
            metavar="PATH",
            help="Optional file where subunit V2 output will be written.",
        )
        parser.add_argument(
            "--no-dumps",
            action="store_true",
            default=False,
            help="Don't produce or use dumps for speeding up benchmark setup. "
            "This flag should typically be turned on for Jenkins, where "
            "you want to ensure completely fresh runs.",
        )

        return parser
