import os

import transaction

from fixtures import TempDir

from canonical.landscape.testing.model import ModelTest
from canonical.landscape.model.main.account import get_account_by_name

from benchmark.testing.tests.data import DummyBenchmarkData


class BenchmarkDataTest(ModelTest):
    def setUp(self):
        super(BenchmarkDataTest, self).setUp()
        self.build_area_dir = self.useFixture(TempDir())
        self.benchmark_data = DummyBenchmarkData(self.zstorm)

    def test_ensure_no_dump(self):
        """
        If no cached dump is available yet, the data is created from scratch,
        and a dump is generated.
        """
        self.benchmark_data.ensure(self.build_area_dir.path)
        account = get_account_by_name("account")
        self.assertEqual("Account", account.title)

        main_store = self.get_main_store()
        result = main_store.execute("SELECT max(version) FROM patch")
        patch_level = result.get_one()[0]
        dump_dir = self.build_area_dir.join("dummy-{}".format(patch_level))
        self.assertTrue(os.path.exists(dump_dir))

    def test_ensure_with_dump(self):
        """
        If cached dump is available, the data is created by restoring it.
        """
        # Build the data from scratch, this will create the dump too.
        self.benchmark_data.ensure(self.build_area_dir.path)
        account = get_account_by_name("account")
        account_id = account.id

        # Clear the freshly created data
        account.remove()
        transaction.commit()

        # Build the data again, this time the dump will be used and objects
        # will get the same database ID as the first run.
        self.benchmark_data.ensure(self.build_area_dir.path)
        account = get_account_by_name("account")
        self.assertEqual(account_id, account.id)
