from twisted.python import log


class BrokerConnections(object):
    """A class for handling connections to multiple brokers.

    When a broker is connected, connected_callback will be called if
    it hasn't been called before. Further brokers that are connected
    will be stored, but not used.

    When the currently connected broker is disconnected,
    disconnected_callback will be called. If there are other connected
    brokers available, connected_callback will be called with one of
    those brokers.
    """

    def __init__(self, connected_callback, disconnected_callback):
        self._connections = {}
        self._current_broker_host = None
        self._connected_callback = connected_callback
        self._disconnected_callback = disconnected_callback

    def connected(self, broker_host, xxx_todo_changeme):
        """Handle a newly connected broker."""
        (client, channel) = xxx_todo_changeme
        log.msg("Connected to AMQP broker: {}".format(broker_host))
        self._connections[broker_host] = client, channel
        # We signal that a new broker has connected only if
        # connected_callback hasn't been called already, in order to
        # keep the current connection in use.
        if self._current_broker_host is None:
            self._connect_broker(broker_host)

    def disconnected(self, broker_host):
        """Handle a disconnected broker."""
        log.msg("Disconnected from AMQP broker: {}".format(broker_host))
        del self._connections[broker_host]
        if self._current_broker_host != broker_host:
            # If we get here, it means that an unused broker was
            # disconnected, so there's no need to do anything.
            return
        self._current_broker_host = None
        self._disconnected_callback()
        if not self._connections:
            log.msg("No AMQP brokers are available, wating for one to connect")
            return
        new_broker_host = list(self._connections.keys())[0]
        self._connect_broker(new_broker_host)

    def _connect_broker(self, broker_host):
        """Use the given host as the currently connected broker."""
        log.msg("Notifying about AMQP broker connection: {}".format(broker_host))
        self._current_broker_host = broker_host
        self._connected_callback(self._connections[broker_host])
