# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
A simple registry for job handlers used by L{canonical.amqp.job.handler}.
"""
from venusian import Scanner

from canonical.lib.text import lower_class
from canonical.amqp.job.runner import EchoJobRunner


class JobRegistry(object):
    """Registry holding available L{JobRunner}s.

    @param transactor: If passed, the L{Transactor} used by the jobs.
    @param echo: If C{True} support an 'echo' job for monitoring.
    """

    def __init__(self, transactor=None, echo=False):
        self._transactor = transactor
        self._runners = {}
        if echo:
            self.add(EchoJobRunner)

    def get(self, name):
        """Return the list of registered job runner for the given name.

        @param name: The name of the L{JobRunner} to get.
        """
        runner_class = self._runners.get(name)
        if runner_class is not None:
            return runner_class(transactor=self._transactor)

    def add(self, runner_class):
        """Register the given L{ActionHandler}."""
        name = getattr(runner_class, "name", None)
        if name is None:
            name = lower_class(runner_class, suffix="JobRunner")
        self._runners[name] = runner_class

    def reset(self):
        """Reset the registered job runners."""
        self._runners.clear()

    def scan(self, modules):
        """Scan the 'jobs' modules and register L{JobHandler}s.

        By default only the modules or packages named 'jobs' and
        located under the given root will be scanned.

        @param module: If given, scan only this module, used for testing.
        """
        scanner = Scanner(registry=self)

        for module in modules:
            scanner.scan(module, categories=["job"], ignore=[".tests"])
