# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from venusian import attach

from twisted.internet.defer import maybeDeferred


def job(runner_class):
    """Decorator to use to mark a job runner.

    When invoking L{ActionRegistry.scan} the classes marked with this decorator
    will be added to the registry.

    @param handler_class: The L{ActionHandler} class to register.
    """

    def callback(scanner, name, runner_class):
        scanner.registry.add(runner_class)

    attach(runner_class, callback, category="job")
    return runner_class


class JobRunner(object):
    """Handle requests for jobs of a specific type."""

    def __init__(self, transactor=None):
        self.transactor = transactor

    def __call__(self, **kwargs):
        """Call the C{run} method."""
        return maybeDeferred(self.run, **kwargs)

    def run(self, **kwargs):
        """Run the job.

        @return: A 2-tuple of the form C{(result, notifications)}, the
            requester of the job will be notified with the C{result} item,
            while all subscribers of this job's namespace (possibly including
            the requester) will be notified with the C{notifications} item. The
            return value can also be a C{Deferred} firing with a binary tuple
            of the just described form.
        """
        raise NotImplementedError("the run method must be implemented")


class EchoJobRunner(JobRunner):
    """An echo test job to check the availability of the job handler."""

    def run(self, **kwargs):
        return kwargs, None
