# Copyright 2005-2013 Canonical Limited.  All rights reserved.

import os

from zope.configuration.exceptions import ConfigurationError
from zope.contentprovider.interfaces import IContentProvider
from zope.security.checker import defineChecker, Checker, CheckerPublic
from zope.component.zcml import adapter

from z3c.pt.pagetemplate import ViewPageTemplate

from canonical.content.provider import (
    ContentProvider,
    TemplateContentProvider,
    ForwardContentProviderAdapter,
)


def provider(
    _context,
    name,
    for_=None,
    layer=None,
    view=None,
    class_=None,
    attribute=None,
    template=None,
    content=None,
    forward=None,
    empty=False,
    permission=CheckerPublic,
):

    if not (class_ or template or content or forward or empty):
        raise ConfigurationError(
            "Must provide 'class', 'template', 'forward'," " 'content', or 'empty'."
        )

    if empty and (class_ or attribute or template or content or forward):
        raise ConfigurationError(
            "Can't provide 'empty' with 'class', "
            "'attribute', 'template', 'content'"
            " or 'forward'"
        )

    if forward and (class_ or attribute or template or content):
        raise ConfigurationError(
            "Can't provide 'forward' with 'class', "
            "'attribute', 'template' or 'content'"
        )

    if attribute:
        if template:
            raise ConfigurationError("Can't provide 'attribute' and " "'template'.")
        if not class_:
            raise ConfigurationError("Can't provide 'attribute' without " "'class'.")

    if forward:
        factory = ForwardContentProviderAdapter(forward)
        adapter(
            _context,
            factory=(factory,),
            provides=IContentProvider,
            for_=(for_, layer, view),
            permission=permission,
            name=name,
        )
        return

    class_dict = {}

    if template:
        template_filename = os.path.abspath(str(_context.path(template)))
        if not os.path.isfile(template_filename):
            raise ConfigurationError("No such file", template_filename)

        class_dict["template_filename"] = template_filename

        if class_:
            if issubclass(class_, TemplateContentProvider):
                bases = (class_,)
            else:
                bases = (class_, TemplateContentProvider)
        else:
            bases = (TemplateContentProvider,)

    elif class_:
        bases = (class_, ContentProvider)
        if attribute:
            class_dict["render"] = getattr(class_, attribute)

    elif content:
        bases = (TemplateContentProvider,)
        class_dict["template"] = ViewPageTemplate(content)

    elif empty:
        bases = (ContentProvider,)

    factory = type("ZCMLContentProvider", bases, class_dict)

    get_permissions = {"view": permission}
    for attr in IContentProvider:
        get_permissions[attr] = permission

    defineChecker(factory, Checker(get_permissions))

    adapter(
        _context,
        factory=(factory,),
        provides=IContentProvider,
        for_=(for_, layer, view),
        permission=permission,
        name=name,
    )
