# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.configuration.fields import (
    GlobalObject,
    GlobalInterface,
    Path,
    PythonIdentifier,
)
from zope.security.zcml import Permission
from zope.schema import TextLine
from zope.interface import Interface


class IProviderDirective(Interface):

    name = TextLine(
        title="Content provider name",
        description="Name for the registered content provider.",
        required=True,
    )

    for_ = GlobalObject(
        title="Target",
        description="Interface or class this provider is for",
        required=False,
    )

    layer = GlobalInterface(
        title="Request layer",
        description="Request layer this provider is for",
        required=False,
    )

    view = GlobalObject(
        title="View",
        description="View interface or view class this provider is for",
        required=False,
    )

    class_ = GlobalObject(
        title="Class",
        description="Class that provides attributes used by the provider",
        required=False,
    )

    attribute = PythonIdentifier(
        title="Attribute",
        description="Name of the provider attribute to render the page.",
        required=False,
    )

    template = Path(
        title="Template",
        description="Filename of template rendered by the content provider.",
        required=False,
    )

    content = TextLine(
        title="Content",
        description="Inline TALES expression providing the rendered content.",
        required=False,
    )

    forward = TextLine(
        title="Forward content provider name",
        description="Name for the content provider to forward to.",
        required=False,
    )

    empty = TextLine(
        title="Empty content provider",
        description="If true the content provider will render to ''.",
        required=False,
    )

    permission = Permission(
        title="Permission",
        description="Permission needed to use the provider.",
        required=False,
    )
