# Copyright 2005-2022 Canonical Limited. All rights reserved.

import sys

from zope.browserpage import ViewPageTemplateFile
from zope.publisher.browser import BrowserView, BrowserPage


__all__ = ["BrowserView", "BrowserPage", "TemplateBrowserPage"]


class TemplateBrowserPageMeta(type):
    def __new__(cls, name, bases, dict):
        cls = type.__new__(cls, name, bases, dict)
        if cls.template is None and cls.template_filename is not None:
            filename_prefix = sys._getframe(1).f_globals
            cls.template = ViewPageTemplateFile(cls.template_filename, filename_prefix)
        return cls


class TemplateBrowserPage(BrowserPage, metaclass=TemplateBrowserPageMeta):
    """View which renders a template."""

    template_filename = None
    template = None

    def __call__(self, *args, **kwargs):
        return self.template(*args, **kwargs)
