# Copyright 2005-2013 Canonical Limited.  All rights reserved.

import datetime
import gc
import os


MEMORY_DUMP_SIGNAL = 44


def gc_dump(dump_dir):
    """Dump memory information using GC.

    @param dump_dir: The directory to write dump file in.
    """
    try:
        tstamp = datetime.datetime.utcnow().strftime("%Y%m%d%H%M%S")
        fname = os.path.join(dump_dir, "gcdump-%s.txt" % (tstamp,))
        with open(fname, "w") as fh:
            # count
            count = gc.get_count()
            fh.write("gc.get_count():\n%s\n" % (count,))

            # garbage
            fh.write("gc.garbage:\n")
            c = 0
            for x in gc.garbage:
                c += 1
                try:
                    line = repr(x)
                except Exception as e:
                    line = "Error str'ing an object: " + str(e)
                fh.write(line + "\n")
        m = "GC count is %s and %d garbage items written to: %s" % (count, c, fname)
        return m
    except Exception as e:
        return "Error while trying to dump GC: %s" % (e,)
