# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from functools import wraps
import logging
import transaction

from canonical.event.subscriber import subscriber
from canonical.landscape.model.events import GlobalMaintenanceEvent


def global_maintenance(call_fun):
    """
    Handle exceptions from the decorated method and subscribe it to
    global maintenance events.
    """

    @subscriber(GlobalMaintenanceEvent)
    @wraps(call_fun)
    def new_fun(*args, **kwargs):
        try:
            result = call_fun(*args, **kwargs)
            transaction.commit()
            return result

        except Exception:
            logger = logging.getLogger("maintenance-script")
            logger.exception("Exception trapped by global_maintenance")

            transaction.abort()

    return new_fun
