import urllib

from canonical.landscape.environment import get_raw_config
from canonical.lib.text import password_decode

__all__ = ["AMQP_CONFIG"]


def get_amqp_config():
    config_parser = get_raw_config()
    host = config_parser.get("broker", "host", fallback="localhost")
    port = config_parser.getint("broker", "port", fallback=5672)
    user = config_parser.get("broker", "user", fallback="guest")
    password = password_decode(
        config_parser.get("broker", "password", fallback="guest")
    )
    vhost = config_parser.get("broker", "hostagent_virtual_host", fallback="/")
    # / is the default vhost for RabbitMQ and needs to be escaped as %2F
    # so we override the `safe` parameter's default of "/"
    quoted_vhost = urllib.parse.quote(vhost, safe="")
    amqp_url = f"amqp://{user}:{password}@{host}:{port}/{quoted_vhost}"

    return {
        "host": host,
        "port": port,
        "user": user,
        "password": password,
        "vhost": vhost,
        "amqp_url": amqp_url,
    }


AMQP_CONFIG = get_amqp_config()
