// Copyright 2005-2013 Canonical Limited.  All rights reserved.

YUI.add("landscape.account.alerts", function(Y) {

Y.namespace("landscape.account");

/**
 * Widget for updating the alerts table on the account dashboard inline.
 * It listens to the landscape:alerts event and redraws the table with
 * the alerts listed in the event.
 *
 * @class AlertList
 * @extends Widget
 * @constructor
 */
var AlertList = function(config) {
    AlertList.superclass.constructor.apply(this, arguments);
};

AlertList.NAME = "alert-list";

AlertList.ATTRS = {};

Y.extend(AlertList, Y.Widget, {

    bindUI: function() {
        Y.on("landscape:alerts", Y.bind(this._updateAlertsList, this));
    },

    /**
     * Redraw the alerts table to contain the given alerts.
     *
     * The note saying how many alerts are outstanding and the table with the
     * alerts are drawn in the same way as they are drawn server-side in
     * canonical/landscape/ui/account/account.pt
     */
    _updateAlertsList: function(alerts) {
        var contentBox = this.get("contentBox"),
            countSpan = contentBox.one("p span"),
            currentTable = contentBox.one("table");

        var count = alerts.length;
        switch (count) {
        case 0:
            countSpan.set("text", "There are no outstanding alerts.");
            currentTable.set("innerHTML",  "");
            return;
        case 1:
            countSpan.set("text", "There is 1 outstanding alert:");
            break;
        default:
            countSpan.set("text", "There are " + count + " outstanding alerts:");
        }
        var table = Y.Node.create([
            "<table class='inline-listing'>",
            "  <thead>",
            "    <tr><th>Description</th></tr>",
            "  </thead>",
            "  <tbody></tbody>",
            "</table>"].join(""));
        var tbody = table.one("tbody");
        for (var i = 0; i < alerts.length; i++) {
            var row = Y.Node.create("<tr><td><a /></td></tr>");
            var ref = row.one("a");
            ref.set("text", alerts[i].title);
            ref.setAttribute("href", alerts[i].href);
            tbody.append(row);
        }
        currentTable.replace(table);
    }
});

Y.landscape.account.AlertList = AlertList;

}, "0.1", {"requires": ["node",
                        "base",
                        "widget"]});
