// Copyright 2005-2013 Canonical Limited.  All rights reserved.

YUI.add("landscape.account.computers", function(Y) {

Y.namespace("landscape.account");

var FormJob = Y.landscape.job.FormJob;

/**
 * Page for removing selected computers.
 *
 * @class RemoveComputersForm
 * @extends Widget
 * @constructor
 */
var RemoveComputersForm = function(config) {
    RemoveComputersForm.superclass.constructor.apply(this, arguments);
};

RemoveComputersForm.NAME = "account-computers-remove";

RemoveComputersForm.ATTRS = {

    /**
     * Base Account URL for the computers used by this widget.
     *
     * @attribute accountUrl
     * @type String
     */
    accountUrl: {
        value: ""
    },

    /**
     * @attribute computerCount
     * @description The number of computers in the current selection
     */

    computerCount: {
        value: null
    },

    /**
     * @attribute io
     * @description The Y.IO instance used to post the form, for testing.
     * @type Y.IO
     *
     */
    io: {
        value: Y.io,
        cloneDefaultValue: false,
    }
};

Y.extend(RemoveComputersForm, Y.Widget, {

    CONTENT_TEMPLATE: [
        "<div>",
        "  <h2>Remove computer</h2>",
        "  <div class='column-content'>",
        "    <p>",
        "      Removing this computer will delete all associated data ",
        "      and free up one license slot for another computer ",
        "      to be  registered.",
        "    </p>",
        "    <form action='remove-computers'>",
        "      <input class='button' name='remove' type='submit' value='Remove'>",
        "    </form>",
        "  </div>",
        "</div>"].join(""),

    bindUI: function() {
        var io = this.get("io"),
            contentBox = this.get("contentBox"),
            form = contentBox.one("form");

        form.plug(FormJob, {io: io});
        form.on("job:success", this._onSuccess, this);
        form.on("job:failure", this._onFailure, this);
    },

    renderUI: function() {
        var computerCount = this.get("computerCount");
        var contentBox = this.get("contentBox");

        contentBox.one("input").on("click", this._onSubmit, this);

        if (computerCount > 1) {

            var message = [
                "Removing these computers will delete all associated data ",
                "and free up ", computerCount, " license slots for ",
                "other computers."].join(" ");

            contentBox.one("h2").set("text", "Remove computers");
            contentBox.one(".column-content p").set("text", message);
        }
    },

    _onSubmit: function(e) {
        Y.one(document.body).addClass("waiting");
        var submit = this.get("contentBox").one("input");
        submit.set("value", "Removing...");
    },

    _onSuccess: function(e) {
        var computerCount = this.get("computerCount");
        var word = (computerCount == 1) ? "computer": "computers";

        this._redirectWithNote(
            {type: "info",
             message: "Successfully removed selected " + word + "."});
    },

    _onFailure: function(e) {
        var computerCount = this.get("computerCount");
        var word = (computerCount == 1) ? "computer": "computers";

        e.preventDefault();

        this._redirectWithNote(
            {type: "error",
             message: "Failed to remove selected " + word + "."});
    },

     /**
      * Redirect to a clean computer selection.
      */
    _redirectWithNote: function(note) {
        var redirectUrl = this.get("accountUrl") + "/computers/update";
        var formMarkup = [
            "<form id='redirect-form' method='POST'",
            "      action='" + redirectUrl + "'>",
            "   <input type='hidden' name='select_none'",
            "           value='1'/>",
            "   <input type='hidden' name='notes." + note.type + "'",
            "          value='" + note.message + "'/>",
            "</form>"].join("");
        var form = Y.Node.create(formMarkup);
        form.appendTo(this.get("contentBox"));
        form.submit();
    }
});

Y.landscape.account.RemoveComputersForm = RemoveComputersForm;

}, "0.1", {"requires": ["node",
                        "base",
                        "widget",
                        "io-form",
                        "landscape.job.creation"]});
