// Copyright 2005-2014 Canonical Limited.  All rights reserved.

YUI.add('landscape.notifications.datasource', function (Y) {

Y.namespace("landscape.notifications");

/**
 * Provides a DataSource implementation which can be used to retrieve data sent
 * by the Landscape server via notifications. For example it can be used to
 * get the result of a job that has completed.
 */

var DataSource = function() {
    DataSource.superclass.constructor.apply(this, arguments);
};

DataSource.NAME = "dataSourceNotifications";

DataSource.ATTRS = {
    /**
     * The transport to use to get notifications.
     */
    transport: {
        value: Y.landscape.notifications.transport,
        cloneDefaultValue: false
    }
};

Y.extend(DataSource, Y.DataSource.Local, {

    /* Handle 'request' events */
    _defRequestFn: function(event) {
        var action = this.get("source"),
            transport = this.get("transport"),
            deferred = transport.setHandler(action);
        deferred.addCallback(Y.bind(this._successHandler, this, event));
        deferred.addErrback(Y.bind(this._failureHandler, this, event));
    },

    /* Handle successful jobs */
    _successHandler: function(event, result) {
        var payload = event.details[0];

        delete Y.DataSource.Local.transactions[event.tId];

        payload.data = result;
        this.fire("data", payload);
    },

    /* Handle failed jobs */
    _failureHandler: function(event, result) {
        var payload = event.details[0];

        delete Y.DataSource.Local.transactions[event.tId];

        payload.error = result;
        this.fire("data", payload);
    }

});

Y.landscape.notifications.DataSource = DataSource;


}, "0.1", {"requires": ["datasource-local", "landscape.notifications.transport"]});
