// Copyright 2005-2013 Canonical Limited.  All rights reserved.

YUI.add("landscape.page.menu", function(Y) {

Y.namespace("landscape.page");

var loadMenu = function() {
    
    var base = Y.config.landscape.base,
        menuDefaults = {autoSubmenuDisplay: false,
                        submenuHideDelay: 200000},
        parentClass = ".parent-menuitem";

    var accountsMenu = Y.one("#accounts-menu"),
        systemMenu = Y.one("#system-menu"),
        notificationsMenu = Y.one("#notifications-menu");

    if (!Y.Lang.isNull(accountsMenu)) {
        Y.use("node-menunav", function(Y) {
            accountsMenu.plug(Y.Plugin.NodeMenuNav, menuDefaults);
            var selectedItems = accountsMenu.all(
                ".accounts-menu li.selected");
            if (selectedItems.size() > 1) {
                // If we have more than one item selected, it means we're in an
                // account but not at account-level, so unmark the first item
                // (the account name) as selected.
                selectedItems.item(0).removeClass("selected");
            } else if (selectedItems.size() === 1) {
                // If we only have one element selected, we're in the
                // account navigation, so let's mark the account with an image.
                var accountName = selectedItems.item(0);

                // Support providers may not have an account
                if (!Y.Lang.isNull(accountName)) {
                    // Add the 'account-selected' class to make the title bold
                    // and add the marker image.
                    accountName.addClass("account-selected");
                }

            }

            var parentMenus = accountsMenu.all(parentClass);
            parentMenus.each(function(parentMenu) {
                var menu = parentMenu.one(".yui3-menu"),
                    menuLabel = parentMenu.one(".yui3-menu-label");
                    menu.setStyle("minWidth", menuLabel.get("offsetWidth"));
            });
        });
    }

    if (!Y.Lang.isNull(systemMenu)) {
        Y.use("node-menunav", function(Y) {
            systemMenu.plug(Y.Plugin.NodeMenuNav, menuDefaults);
        });
    }

    var destroyNote = function(evt) {
        // Called when the menu is clicked so that no notes stay in front of
        // the menu.
        Y.one("#inner-notes").empty();
    };

    if (!Y.Lang.isNull(notificationsMenu)) {
        Y.use("node-menunav", "anim", "anim-color",
              "landscape.ui.menu", "landscape.notifications.transport",
	      function(Y) {
            notificationsMenu.plug(Y.Plugin.NodeMenuNav, menuDefaults);
            notificationsMenu.on("click", destroyNote);
            var alertsMenu = notificationsMenu.one(".yui3-menu"),
                activeAlerts = notificationsMenu.one(".yui3-menu-label :first-child"),
                transport = Y.landscape.notifications.transport;
            if (!Y.Lang.isNull(alertsMenu)) {
                alertsMenu.plug(Y.landscape.ui.MenuItemsPlugin);
                var bgColor, bgColorNode = activeAlerts;
                // Animating to a "transparent" background throws one exception
                // per animation frame, forever.  This is not good.  Instead we
                // walk up the DOM to find the first ancestor element without a
                // transparent background.
                while ((bgColor = bgColorNode.getStyle(
                            "backgroundColor")) === "transparent") {
                    bgColorNode = bgColorNode.get("parentNode");
                }
                var staticItems = alertsMenu.items.get("items"),
                    doc = Y.config.doc,
                    title = doc.title,
                    animate = false,
                    anim = new Y.Anim(
                        {from: {backgroundColor: "#98240c"},
                         to: {backgroundColor: bgColor},
                         node: activeAlerts,
                         duration: 3,
                         easing: Y.Easing.elasticOut});
                var activeRulesCallback = function(result) {
                    activeAlerts.set("text", result.length);
                    if (animate) {
                        anim.run();
                    } else {
                        // We never animate on the first pass because that's
                        // when the page gets loaded. But then always animate.
                        animate = true;
                    }
                    if (result.length) {
                        doc.title = "(" + result.length + ") - " + title;
                    } else {
                        doc.title = title;
                    }
                    alertsMenu.items.set("items", result.concat(staticItems));
                    Y.fire("landscape:alerts", result);
                };
                transport.setHandler("get-active-rules")
                    .addCallback(activeRulesCallback);
                Y.on("notification:account_rules_changed", function(event) {
                        transport.sendAction(
                            {base: event.result,
                             action: "get-active-rules"}).addCallback(activeRulesCallback);
                });
            }
        });
    }
};

Y.landscape.page.loadMenu = loadMenu;

Y.on("domready", loadMenu);

}, "0.1", {"requires": ["node", "get"]});
