// Copyright 2005-2013 Canonical Limited.  All rights reserved.

YUI.add("landscape.role.membership", function(Y) {

Y.namespace("landscape.role");

/**
 * This widget synchronizes the hidden input elements in the
 * role membership matrix with user's clicks.
 *
 * @class RoleMembership
 * @extends Widget
 * @constructor
 */

var RoleMembership = function(config) {
    RoleMembership.superclass.constructor.apply(this, arguments);
};

RoleMembership.NAME = "role-membership";

RoleMembership.ATTRS = {};


Y.extend(RoleMembership, Y.Widget, {

    initializer: function() {
        var contentBox = this.get("contentBox");
        this._table = contentBox.one("table");
        this._save = contentBox.one("#save");
        this._changed = 0;
    },

    bindUI: function() {
        this._table.delegate("click", this._onFlagClick, ".flag", this);
    },

    /*
     * Updates the CSS classes and hidden input values to reflect
     * the user's change.
     */
    _onFlagClick: function(evt) {
        var span = evt.currentTarget.one("span");

        if (!span.hasClass("changed")) {
            span.addClass("changed");
            this._changed += 1;
        } else {
            span.removeClass("changed");
            this._changed -= 1;
        }

        this._flipFlag(span);

        if (this._changed > 0) {
            this._save.set("disabled", false);
        } else {
            this._save.set("disabled", true);
        }
    },

    /*
     * Flip the value of a flag cell in the matrix.
     */
    _flipFlag: function(span) {
        var input = span.next("input"),
            value = input.get("value");

        if (span.hasClass("on")) {
            span.replaceClass("on", "off");
            input.set("value", value.replace(":on", ":off"));
        } else {
            span.replaceClass("off", "on");
            input.set("value", value.replace(":off", ":on"));
        }
    },

});

Y.landscape.role.RoleMembership = RoleMembership;

}, "0.1", {"requires": ["node",
                        "base",
                        "widget"]});
