// Copyright 2005-2013 Canonical Limited.  All rights reserved.

YUI.add("landscape.selection.deletesavedsearch", function(Y) {

Y.namespace("landscape.selection");

var DeleteSavedSearch = function(config) {
    DeleteSavedSearch.superclass.constructor.apply(this, arguments);
};

DeleteSavedSearch.NAME = "DeleteSavedSearch";

DeleteSavedSearch.ATTRS = {

    /**
     * @attribute notes
     * @description A notes reference to display messages.
     * @type landscape.notes.Notes
     */
    notes: {value: null},

    /**
     * @attribute source
     * @description A PageDataSource to make xhr calls.
     * @type PageDataSource
     */
    source: {value: null},

    /**
     * @attribute document
     * @description The DOM document object, used for testing.
     * type Y.config.doc
     */
    document: {
        value: Y.config.doc
    },
};

Y.extend(DeleteSavedSearch, Y.Widget, {

    initializer: function(config) {

        /**
         * Create an overlay to hold the form. Centralize it within the
         * '#sidebar-content-area' div.
         */
        this._overlay = new Y.landscape.ui.Dialog({
            contentBox: "#delete-search-overlay",
            visible: false,
            width: "70%",
            align: {node: "#tight-content",
                    points: [Y.WidgetPositionAlign.TC,
                             Y.WidgetPositionAlign.TC]}
        });
    },

    renderUI: function() {

        var contentBox = this.get("contentBox");

        // Remove field helpers so it's properly displayed in the overlay.
        this._removeFieldHelpers(contentBox);

        /**
          * Replace the overlay body with the delete form and un-hide it.
          * It will actually only show up in the page when the containing
          * Overlay widget is visible.
          */
        this._overlay.set("bodyContent", contentBox);
        this._overlay.render("#content");
        contentBox.show();
    },

    bindUI: function() {
        /**
         * Intercept click events for #delete-search-button input field.
         */
        var contentBox = this.get("contentBox");
        Y.one("#delete-search-button").on("click", function(evt) {
            evt.preventDefault();
            this._overlay.show();
        }, this);

        /**
         * Intercept click events for #form.actions.delete button.
         */
        Y.one("input[name='form.actions.delete']").on("click", function(evt) {
            evt.preventDefault();
            this._onClick(contentBox);
        }, this);
    },

    /**
     * zope.formlib "display forms" renders its widgets with extra elements
     * that are not used by this widget.
     * Since they are not used, they must be stripped.
     */
    _removeFieldHelpers : function(contentBox) {
        contentBox.all("label").remove();
        contentBox.all("div.form-hint").remove();
    },

    /**
     * Fires the xhr call.
     */
    _onClick: function(contentBox) {
        var source = this.get("source");
        var base = "../../../saved-searches"; // SavedSearchManagement route

        var deferred = source.sendAction(
            {form: contentBox.one("form"), action: "delete-saved-search",
             base: base});

        deferred.addCallback(Y.bind(this._handleSuccess, this));
        deferred.addErrback(Y.bind(this._handleFailure, this));
    },

     /**
      * Redirect to a clean computer selection.
      */
    _handleSuccess: function(result) {
        var formMarkup = ["",
                          "<form id='update-selection-form' method='POST'",
                          "      action='../../update'>",
                          "   <input type='hidden' name='select_none'",
                          "           value='1'/>",
                          "   <input type='hidden' name='notes.info'",
                          "          value='Search successfully deleted.'/>",
                          "</form>"].join("");
        var form = Y.Node.create(formMarkup);
        form.appendTo(this.get("contentBox"));
        form.submit();
    },

    /**
     * Display a note if something bad happens.
     */
    _handleFailure: function(result) {
        var errors = Y.JSON.parse(result.message);
        var error_message = errors.global_errors[0];
        this.get("notes").addNote("error", error_message);
    }

});

Y.landscape.selection.DeleteSavedSearch = DeleteSavedSearch;

}, "0.1", {"requires": ["node", "base", "widget", "json-parse",
                        "landscape.notes", "landscape.ui.dialog"]});
