# Copyright 2005-2015 Canonical Limited.  All rights reserved.

import os

from zope.cachedescriptors.property import Lazy
from zope.viewlet.manager import ViewletManagerBase

from z3c.pt.pagetemplate import ViewPageTemplateFile

from canonical.landscape.javascript.testing.request import get_base_dir


class ScriptViewletManager(ViewletManagerBase):
    """Custom script viewlet manager for rendering Javascript HTML test pages.

    This viewlet manager will render only the scripts needed to run the
    Javascript test module at hand.
    """

    template = ViewPageTemplateFile("script.pt")

    def render(self):
        return self.template()

    @Lazy
    def base_dir(self):
        """Get the base dir for the Landscape code in this branch."""
        return get_base_dir(self.request)

    @Lazy
    def modules(self):
        """Get the Javascript modules we need to include as dependencies."""
        modules = self.request["HTTP_X_JAVASCRIPT_TESTING_MODULES"]
        return modules.split(",")

    @Lazy
    def test_module(self):
        """Get the path to the test module containing the Javascript tests."""
        base_path = self.request["HTTP_X_JAVASCRIPT_TESTING_BASE_PATH"]
        return os.path.basename(base_path) + ".js"
