# Copyright 2005-2015 Canonical Limited.  All rights reserved.

import os

from landscape.lib.fs import create_file

from canonical.lib.timestamp import compare_modification_times

from canonical.landscape.ui.constants import STATIC_DIR
from canonical.landscape.ui.urlformat import read_asset
from canonical.landscape.javascript.testing.request import get_base_dir

_COMBO_PREFIX = "/combo?"


def static_url(context, request):
    """Transform a path to be relative to the test html file being generated.

    For example if we are generating a test html file with the path:

      canonical/landscape/javascript/foo/tests/test_bar.html

    we want all references to static assets be relative to that path, e.g.:

      <link href="../../../static/skin/hokan/favicon.ico" type="image/x-icon"/>

    will allow loading the test file from the browser with no errors.
    """
    path = context.replace(" ", "").replace("\n", "")  # For multi-line values

    # Concatenate assets loaded with the combo loader. If any of the
    # assets being concatenated has changed, we want to re-generate the combo.
    if path.startswith(_COMBO_PREFIX):
        parts = path[len(_COMBO_PREFIX) :].split("&")
        name = "_combo_"
        for part in parts:
            name += part.split(".")[0].replace("/", "_")
        # Assume that all parts have the same extension
        name += "." + parts[0].split(".")[1]
        combo = os.path.join(STATIC_DIR, "skin", "hokan", name)
        refresh = True
        if os.path.exists(combo):
            # Check modification times
            for part in parts:
                asset = os.path.join(STATIC_DIR, part)
                if compare_modification_times(asset, combo):
                    break
            else:
                # No part has changed, we don't need to refresh
                refresh = False
        if refresh:
            body = b""
            for part in parts:
                body += read_asset(part)
            create_file(combo, body)
        path = "/static/skin/hokan/" + name

    return get_base_dir(request) + path
