// Copyright 2005-2015 Canonical Limited.  All rights reserved.

YUI.add("landscape.ui.breadcrumbs", function(Y) {

Y.namespace("landscape.ui");

/**
* The Breadcrumbs widget renders a breadcrumb trail of sequential hyperlinks.
**/
var Breadcrumbs = Y.Base.create("breadcrumbs", Y.Widget, [], {

    BOUNDING_TEMPLATE: "<ul class='breadcrumbs'/>",
    CONTENT_TEMPLATE: null,

    ITEM_TEMPLATE: [
        "<li class='breadcrumbs-item breadcrumbs-{state}'>",
        "  <a{href}>{name}</a>",
        "</li>",
    ].join("\n"),

    renderUI: function() {
        var items = Y.clone(this.get("items"));
        this._uiSetItems(items);
    },

    bindUI: function() {
        this.after("itemsChange", this._afterItemsChange, this);
    },

    // Handle changes in the breadcrumb items.
    _afterItemsChange: function(evt) {
        this._uiSetItems(evt.newVal);
    },

    // Refresh content box with the given breadcrumbs items.
    _uiSetItems: function(items) {
        var contentBox = this.get("contentBox");

        contentBox.set("innerHTML", "");
        
        Y.Array.forEach(items, function(item) {
            var html = Y.Lang.sub(this.ITEM_TEMPLATE, {
                name: item.name,
                state: item.state,
                href: item.state === "disabled" ? "" : " href='" + item.url + "'",
            });

            contentBox.append(html);
        }, this);
    },

}, {ATTRS: {
    items: {value: null}
}});

Y.landscape.ui.Breadcrumbs = Breadcrumbs;
    
}, "0.1", {"requires": ["base", "widget", "handlebars"]});
