// Copyright 2005-2015 Canonical Limited.  All rights reserved.

YUI.add("landscape.ui.expandablelink", function(Y) {

Y.namespace("landscape.ui");

/**
 * A clickable link toggling display of a content element. The widget can
 * optionally change link text for expanded or hidden states.
 *
 * @class ExpandableLink
 * @extends Widget
 **/

var ExpandableLink = Y.Base.create("expandablelink", Y.Widget, [], {

    initializer: function() {
        this._linkSelector = "." + this.getClassName("link");
    },

    renderUI: function() {
        // Initialize the text of the link
        this._uiSetLinkText(this._getLinkText());        
    },

    bindUI: function() {
        var contentBox = this.get("contentBox");
        contentBox.delegate(
            "click", this._onLinkClick, this._linkSelector, this);
        this.after("visibleChange", this._afterVisibleChange, this);
    },

    /**
     * Handle clicks on the link, toggling the content's expanded state.
     */
    _onLinkClick: function(e) {
        e.preventDefault();
        if (this.get("visible")) {
            this.hide();
        } else {
            this.show();
        }
    },

    /**
     * Refresh the link content after show or hide changes visibilty.
     */
    _afterVisibleChange: function(e) {
        this._uiSetLinkText(this._getLinkText());
    },

    /**
     * Set the actual content of the link DOM node
     */
    _uiSetLinkText: function(text) {
        // Set the text of the link to the given value
        var contentBox = this.get("contentBox"),
            link = contentBox.one(this._linkSelector);
        link.setContent(text);
    },

    /**
     * Return the link text based on the current visibility state.
     */
    _getLinkText: function() {
        var linkContentExpanded = this.get("linkContentExpanded"),
            linkCOntentHidden = this.get("linkContentHidden");

        return this.get("visible") ? linkContentExpanded : linkCOntentHidden;
    },

}, {

HTML_PARSER: {
    // The default value for the hidden/expanded link content attributes
    // is whatever we find in the DOM we're progressively enhancing.
    linkContentHidden: function(srcNode) {
        return srcNode.one(".yui3-expandablelink-link").get("text");
     },
    linkContentExpanded: function(srcNode) {
        return srcNode.one(".yui3-expandablelink-link").get("text");
     },
},

ATTRS: {
    // Optional content to set for the link when the content is hidden.
    linkContentHidden: {value: null },
    // Optional content to set for the link when the content is expanded.
    linkContentExpanded: {value: null },
}});

Y.landscape.ui.ExpandableLink = ExpandableLink;

}, "0.1", {"requires": ["node",
                        "base",
                        "widget",
                        "event"]});
