// Copyright 2005-2015 Canonical Limited.  All rights reserved.

YUI.add("landscape.ui.expandablelist", function(Y) {

Y.namespace("landscape.ui");

/**
 * A list with expandable items.
 *
 * @class ExpandableList
 * @extends Widget
 **/

var ExpandableList = Y.Base.create("expandablelist", Y.Widget, [], {

    STATE_DISABLED: "disabled",
    STATE_EXPANDED: "expanded",
    STATE_EXPANDABLE: "expandable",
    STATE_HIDDEN: "hidden",

    bindUI: function() {
        var toggleSelector = this.get("toggleSelector"),
            contentBox = this.get("contentBox"),
            selector = (
                "." + this._getClass(this.STATE_EXPANDABLE) +
                    " " + toggleSelector);
        contentBox.delegate("click", this._onClick, selector, this);
    },

    /**
     * Return the number of items in the list.
     */
    size: function() {
        return this.get("contentBox").all("> li").size();
    },

    /**
     * Expand the element at the specified index.
     */
    expandAt: function(index) {
        var item = this._getItem(index);
        item.addClass(this._getClass(this.STATE_EXPANDED));
    },

    /**
     * Collapse the element at the specified index.
     */
    collapseAt: function(index) {
        var item = this._getItem(index);
        item.removeClass(this._getClass(this.STATE_EXPANDED));
    },

    /**
     * Enable the element at the specified index.
     */
    enableAt: function(index) {
        var item = this._getItem(index);
        item.removeClass(this._getClass(this.STATE_DISABLED));
    },

    /**
     * Disable the element at the specified index.
     */
    disableAt: function(index) {
        var item = this._getItem(index);
        item.addClass(this._getClass(this.STATE_DISABLED));
    },

    /**
     * Show the element at the specified index.
     */
    showAt: function(index) {
        var item = this._getItem(index);
        item.removeClass(this._getClass(this.STATE_HIDDEN));
    },

    /**
     * Hide the element at the specified index.
     */
    hideAt: function(index) {
        var item = this._getItem(index);
        item.addClass(this._getClass(this.STATE_HIDDEN));
    },

    /**
     * Enable or disable the expandable state of an element.
     */
    setExpandableAt: function(index, value) {
        var item = this._getItem(index);
        item.toggleClass(this._getClass(this.STATE_EXPANDABLE), value);
    },

    /**
     * Return the <li> node with the given index.
     */
    _getItem: function(index) {
        var contentBox = this.get("contentBox");
        return contentBox.all("> li").item(index);
    },

    /**
     * Get the CSS class for the specified state
     */
    _getClass: function(state) {
        return this.get("classPrefix") + "-" + state;
    },

    /*
     * Whether the element at the specified index is in the specified state.
     */
    _isInState: function(index, state) {
        return this._getItem(index).hasClass(this.getClass(state));
    },

    /**
     * Handle clicks on an item's toggle element, toggling the expanded state.
     */
    _onClick: function(e) {
        e.target.ancestor("li").toggleClass(
            this._getClass(this.STATE_EXPANDED));
    },

}, {ATTRS: {
    // Prefix for CSS classes.
    classPrefix: {value: "expandablelist"},
    // Selector of the element inside each list element to bind as toggle for
    // expansion via click.
    toggleSelector: {value: ".expandablelist-toggle"}
}});

Y.landscape.ui.ExpandableList = ExpandableList;

}, "0.1", {"requires": ["node",
                        "base",
                        "widget",
                        "event"]});
