// Copyright 2005-2013 Canonical Limited.  All rights reserved.

YUI.add("landscape.ui.fileinput", function(Y) {

Y.namespace("landscape.ui");

/**
 * This module provides progressive enhancement for input elements of type file
 * (for file uploads).
 * It wraps the input element in a container, and adds a button and message line.
 * The original input should be hidden with CSS.
 *
 * @module landscape.ui.fileinput
 *
 **/

/**
 * Provide a file upload widget that can be styled, wrapping the original
 * input element.
 * All file inputs inside the provided srcNode are replaced.
 *
 * @class FileInput
 * @extends Widget
 **/

var FileInput = Y.Base.create("fileinput", Y.Widget, [], {

    CONTENT_TEMPLATE: null,

    bindUI: function() {
        var contentBox = this.get("contentBox");
        contentBox.delegate(
            "click", this._onButtonInputClick,
            ".file-upload input[type='button']", this);
        contentBox.delegate(
            "change", this._onFileInputChange,
            ".file-upload input[type='file']", this);
    },

    // When the button is clicked, simulate a click on the input element,
    // so the file select window is displayed.
    _onButtonInputClick: function(event) {
        var buttonInput = event.target,
            fileInput = buttonInput.get("parentNode")
            .one("input[type='file']");
        fileInput.simulate("click");
    },

    // When a file is selected for upload, show the name in the message line.
    _onFileInputChange: function(event) {
        var input = event.target,
            messageRow = input.get("parentNode").one(".file-message"),
            // Chrome includes a fake path before the file name
            filePath = input.get("value").replace("C:\\fakepath\\", "");
        if (filePath) {
            messageRow.set("text", filePath);
        }
    },
}, {});

Y.landscape.ui.FileInput = FileInput;


}, "0.1", {"requires": ["node",
                        "base",
                        "widget",
                        "event",
                        "node-event-simulate"]});
