// Copyright 2005-2013 Canonical Limited.  All rights reserved.

YUI.add("landscape.ui.hierarchicalcheckbox", function(Y) {

Y.namespace("landscape.ui");


/**
 * This widget shows a hierarchical group of checkboxes, ensuring that if a
 * parent checkbox is ticked, its children become ticked as well.
 *
 * @class HierarchicalCheckbox
 * @extends Widget
 * @constructor
 */
var HierarchicalCheckbox = function(config) {
    HierarchicalCheckbox.superclass.constructor.apply(this, arguments);
};

HierarchicalCheckbox.NAME = "HierarchicalCheckbox";
HierarchicalCheckbox.ATTRS = {};

Y.extend(HierarchicalCheckbox, Y.Widget, {

    initializer: function(config) {
    },

    renderUI: function() {

    },

    syncUI: function() {

    },

    bindUI: function() {
        var boundingBox = this.get("boundingBox");

        var rootAccessGroup = boundingBox.one("ul.statictree-root label input");
        rootAccessGroup.on("click", this._handleCheckBoxes);

        var subAccessGroup = boundingBox.all("ul.statictree label input");
        if (!Y.Lang.isNull(subAccessGroup)) {
            subAccessGroup.on("click", this._handleCheckBoxes);
        }
    },
   
    // This callback method is bound to all checkboxes in the tree and gets a
    // list of all the clicked level's children checkboxes. It proceeds to 
    // select and disable all children checkboxes. If they were previously
    // checked and disabled, it reverts them to their unselected, active state.
    _handleCheckBoxes: function(e) {
        var all_inputs = e.target.get("parentNode").get("parentNode").all("input");
        if (!Y.Lang.isNull(all_inputs)) {
            if (e.target.get("checked")) {
                all_inputs.each(function(input) {
                    input.set("checked", true);
                    input.set("disabled", true);
                });
                e.target.set("disabled", false);
            } else {
                all_inputs.each(function(input) {
                    input.set("checked", false);
                    input.set("disabled", false);
                });
            }
        }
    }

});

Y.landscape.ui.HierarchicalCheckbox = HierarchicalCheckbox;

}, "0.1", {"requires" : ["widget"]});
