// Copyright 2005-2013 Canonical Limited.  All rights reserved.

YUI.add("landscape.ui.sprite", function(Y) {

Y.namespace("landscape.ui.sprite");


/**
 * This module provides the Sprite widget.
 *
 * @module landscape.ui.sprite
 */


// Configuration properties
var BOUNDING_BOX = "boundingBox",
    NODE = "node",
    ICON = "icon",
    IMAGE_ID = "imageId",
    IMAGE = "image",
    TITLE = "title",
    CSS_CLASSES = "cssClasses";

/**
 * A helper function to generate a CSS class name from a filename
 * according to the conventions in use by Landscape (see
 * c.l.ui.spriteformat).
 */
var classNameFromFilename = function(filename) {
    var basename = filename.split("/").pop();
    return "sprite-" + basename.split(".").shift();
};

var formatFilename = function(filename) {
    var classes = [];
    var className = classNameFromFilename(filename);
    var size = className.split("-").pop();

    classes.push(className);
    if (size == "14x14") {
        classes.push("smaller-" + ICON);
    }
    if (size == "16x16") {
        classes.push("small-" + ICON);
    }
    if (size == "32x32") {
        classes.push("large-" + ICON);
    }
    classes.push(ICON);
    return classes;
};


/**
 * The Sprite widget is just a helper to ensure rendering sprites in
 * Javascript is consistent across our UI.
 *
 * @class Sprite
 * @extends Widget
 * @constructor
 */
var Sprite = function() {
    Sprite.superclass.constructor.apply(this, arguments);
};

Sprite.NAME = "Sprite";

Sprite.ATTRS = Y.mix({
    /**
     * Node representing the sprite.
     *
     * @attribute node
     * @type Node
     */
    node: {
        valueFn: function() {
            return this.get(BOUNDING_BOX);
        }
    }
}, Y.landscape.ui.Image.ATTRS);


Y.extend(Sprite, Y.landscape.ui.Image, {
    /**
     * Render stuff that's specific to this widget.
     *
     * @method _renderUI
     * @protected
     */
    _renderUI: function() {
        this._imageSet(this.get(NODE), null, this.get(IMAGE));
    },

    _imageChange: function(prevVal, newVal) {
        this._imageSet(this.get(NODE), prevVal, newVal);
    },

    // Given previous and current images (previous might be null),
    // compute the CSS classes for each of them and adjust the node to
    // have the CSS classes needed to display the current image.
    _imageSet: function(node, previous, current) {
        var previousClasses = [];
        var currentClasses = [];
        if (! Y.Lang.isNull(previous)) {
            previousClasses = formatFilename(previous);
        }
        if (! Y.Lang.isNull(current)) {
            currentClasses = formatFilename(current);
        }
        this._cssClassesSet(node, previousClasses, currentClasses);

    }
});

Y.landscape.ui.Sprite = Sprite;
Y.landscape.ui.sprite.classNameFromFilename = classNameFromFilename;
Y.landscape.ui.sprite.formatFilename = formatFilename;

}, "0.1", {"requires": ["event", "node", "widget", "landscape.ui.image"]});
