// Copyright 2005-2014 Canonical Limited.  All rights reserved.

YUI.add("landscape.upgrade.schedule", function(Y) {

Y.namespace("landscape.upgrade");

/**
 * This module provides progressive enhanchment for UpgradeProfile scheduling
 * widget.
 *
 * @module landscape.upgrade.schedule
 */

/**
 * This class wraps the scheduling widget, enabling and disabling options based
 * on the schedule type.
 *
 * Selecting a schedule type will enable its options and disable ones for the
 * other type.
 *
 * @class WeeklySchedule
 * @extends Widget
 */

var WeeklySchedule = Y.Base.create("weeklyschedule", Y.Widget, [], {

    renderUI: function() {
        var contentBox = this.get("contentBox"),
            hourly = contentBox.one(".schedule-frequency-hourly").get("checked"),
            weekly = contentBox.one(".schedule-frequency-weekly").get("checked");
        if (hourly || weekly) {
            this._toggleHourly(hourly);
        }
    },

    bindUI: function() {
        var contentBox = this.get("contentBox");
        contentBox.all(
            ".schedule-frequency-hourly, .schedule-frequency-weekly").on(
                "click", this._onClick, this);
    },

    _onClick: function(evt) {
        var node = evt.target,
            hourly = node.hasClass("schedule-frequency-hourly");
        this._toggleHourly(hourly);
    },

    // Toggle disabled state for options based on the schedule type.
    _toggleHourly: function(hourly) {
        var contentBox = this.get("contentBox");
        contentBox.all(".schedule-options-hourly").set("disabled", !hourly);
        contentBox.all(".schedule-options-weekly").set("disabled", hourly);
    },

},{});

Y.landscape.upgrade.WeeklySchedule = WeeklySchedule;

}, "0.1", {"requires": ["node",
                        "base",
                        "widget"]});
