// Copyright 2005-2013 Canonical Limited.  All rights reserved.

YUI.add("landscape.util.date", function(Y) {

Y.namespace("landscape.util");


/**
 * This module provides date utilities.
 *
 * @module landscape.util.date
 */


var FEB = 2,
    APR = 4,
    JUN = 6,
    SEP = 9,
    NOV = 11;


function isLeapYear(year) {
    return (year % 4 === 0 && year % 100 !== 0) || (year % 400 === 0);
}


function isShortMonth(month) {
    return (month == APR || month == JUN || month == SEP || month == NOV);
}

function getDaysInMonth(year, month) {
    if (month == FEB) {
        return isLeapYear(year) ? 29 : 28;
    } else {
        return isShortMonth(month) ? 30 : 31;
    }
}


/**
 * Convert date values into a Date instance.  Returns null if the date values
 * don't represent a valid date.
 *
 * @function createDate
 */
function createDate(year, month, day, hour, minute, second) {
    if ((year < 1900 || year > 9999) ||
        (month < 1 || month > 12) ||
        (day < 1 || day > getDaysInMonth(year, month)) ||
        (hour < 0 || hour > 23) ||
        (minute < 0 || minute > 59) ||
        (second < 0 || second > 59)) {
        return null;
    }
    return new Date(year, month-1, day, hour, minute, second, 0);
}

Y.landscape.util.createDate = createDate;


}, "0.1", {"requires": ["event"]});
