// Copyright 2005-2013 Canonical Limited.  All rights reserved.

YUI.add("landscape.util.text", function(Y) {

Y.namespace("landscape.util");

/**
 * Input mask to convert to a valid slug. Modified from a snippet found on
 * the web.
 */
var stringToSlug = function(str) {
    str = str.toLowerCase();
    // remove accents, swap ñ for n, etc
    var from = "àáäâãèéëêìíïîòóöôõùúüûñç·/_,:;";
    var to   = "aaaaaeeeeiiiiooooouuuunc------";
    for (var i=0, l=from.length ; i<l ; i++) {
        str = str.replace(new RegExp(from.charAt(i), 'g'), to.charAt(i));
    }
    str = str.replace(/[^a-z0-9 -]/g, "")
        .replace(/\s+/g, "-");

    return str;
};

Y.landscape.util.stringToSlug = stringToSlug;


/**
 * Call Number.toFixed using the precision that was passed.
 */
var toUsefulFixed = function(value, precision) {
    var stringValue = value.toFixed(precision);
    return stringValue;
};

/**
 * Format a number into a condensed fashion, adding unit suffix and choosing
 * how many floating digits to show.
 *
 */
var formatValue = function(value, precision) {
    if (Y.Lang.isUndefined(precision)) {
        precision = 1;
    }
    var absValue = Math.abs(value);
    if (absValue > 1000000000000) {
        return toUsefulFixed(value / 1000000000000, precision) + "T";
    } else if (absValue > 1000000000) {
        return toUsefulFixed(value / 1000000000, precision) + "G";
    } else if (absValue > 1000000) {
        return toUsefulFixed(value / 1000000, precision) + "M";
    } else if (absValue > 1000) {
        return toUsefulFixed(value / 1000, precision) + "k";
    } else if (absValue < 1 && absValue > 0) {
        return value.toFixed(2);
    }
    return toUsefulFixed(value, precision);
};

Y.landscape.util.formatValue = formatValue;

/** 
 * Remove trailing zeros.
 * The idea here is to loop over all the Y column numbers and remove
 * the trailing zeros but only if all numbers ends with zero in the
 * axis ends with zero.
 * If the number has a unit, save it so it can be used later when
 * the graph if finally adjusted.
 */

var handleTrailingZeros = function(numbers) {
    var MAX_ZEROS = 5;
    var minZeros = MAX_ZEROS;
    var units = [];
    var collectedNumbers = [];
    Y.Array.each(numbers, function(number) {
        // Try to match a unit at the end of the number in the first place.
        if (!Y.Lang.isNull(number.match(/[a-zA-Z]$/))) {
            units.push(number[number.length - 1]);
            number = number.slice(0, number.length - 1);
        } else {
            // No problem, just push an empty string to book the slot in the
            // array and avoid complicated logic later.
            units.push("");
        }
        // Save this number so it's easier handle unit in the last pass.
        collectedNumbers.push(number);
        // For each number, get a count of trailing zeros and if it's less than
        // the current one, update the count so it can be computed as the
        // minimum amount of zeros to remove from each number.
        var match = number.match(/(0+)$/);
        if (!Y.Lang.isNull(match) && match[0].length < minZeros) {
            minZeros = match[0].length;
        }
    });

    var newNumbers = [];
    Y.Array.each(collectedNumbers, function(number, index) {
        var correctNumber = number;
        var numberParts = number.split(".").length;
        var endsWithZero = !Y.Lang.isNull(number.match(/(0+)$/));
        if (numberParts > 1 && endsWithZero) {
            // Update each number by removing trailing zeros using the value
            // computed above.
            correctNumber = number.slice(0, number.length - minZeros);
            if (correctNumber[correctNumber.length - 1] == ".") {
                // Special case when all the zeros were dropped and the number
                // ended up as "1." or "2.".
                correctNumber = correctNumber.slice(0, correctNumber.length - 1);
            }
        }
        newNumbers.push(correctNumber + units[index]);
    });
    return newNumbers;
};

Y.landscape.util.removeCommonTrailingZeros = handleTrailingZeros;

var BYTES_CONVERSION = {
    decimal: {
        step: 1000,
        units: ["k","M","G","T","P","E","Z","Y"]
    },
    binary: {
        step: 1024,
        units: ["KiB","MiB","GiB","TiB"]
    }
};

/**
 * Convert bytes into a human-readable string.
 *
 * The following bytesConversion can be specified:
 * 
 * decimal: '1G' = 1000^3
 * binary: '1GiB' = 1024^3
 */
var bytesToString = function(value, bytesConversion) {
    var i = -1,
        conversion = BYTES_CONVERSION[bytesConversion || "decimal"];
    do {
        value = value / conversion.step;
        i++;
    } while (value >= conversion.step);
    
    return value.toFixed(0) + conversion.units[i];
};

Y.landscape.util.bytesToString = bytesToString;
 
var NUMBER_WORDS = [
    "zero", "one", "two", "three", "four", "five", "six", "seven", "eight",
    "nine", "ten", "eleven", "twelve", "thirteen", "fourteen", "fifteen",
    "sixteen", "seventeen", "eighteen", "nineteen"];

/**
 * Return the passed number as a word, if it's between 0 and 19. Otherwise the
 * number is just converted to string.
 */
var numberToWord = function(n) {
    var word = NUMBER_WORDS[n];
    if (word === undefined) {
        return n.toString();
    }
    return word;
};

Y.landscape.util.numberToWord = numberToWord;

}, "0.1", {"requires": ["base"]});
