// Copyright 2005-2013 Canonical Limited.  All rights reserved.

YUI.add("landscape.util.validation", function(Y) {

Y.namespace("landscape.util");

/*
 * This module provides a set of validation functions that can be used
 * to check that a value meets certain constraints.
 *
 * Each function takes the value to be validated as its only parameter
 * and returns an error string in case the validation fails.
 */


var ALPHANUMERIC = "^[a-zA-Z0-9_]*$";

var LOWER_ALPHANUMERIC = "^[a-z0-9_]*$";

var IP = "^(?:(?:25[0-5]|2[0-4][0-9]|[1]?[0-9][0-9]?)\\.){3}" +
         "(?:25[0-5]|2[0-4][0-9]|[1]?[0-9][0-9]?)$";

var CIDR = "^(?:(?:25[0-5]|2[0-4][0-9]|[1]?[0-9][0-9]?)\\.){3}" +
           "(?:25[0-5]|2[0-4][0-9]|[1]?[0-9][0-9]?)\/(?:3[0-2]|[12]?[0-9])$";

/* Email addresses -- especially the local part (the portion before the @) --
 * can contain just about anything, so we aren't too picky.
 */
var EMAIL = "^.+@.+\\.[^.]+$";

/*
 * Check that a required value is not empty.
 */
var required = function(value) {
    if (!value) {
        return "Required input is missing";
    }
};

Y.landscape.util.required = required;


/*
 * Check that a value is an alphanumeric string.
 */
var alphanumeric = function(value) {
    if (value.match(ALPHANUMERIC) === null) {
        return "Please use only alphanumeric characters";
    }
};

Y.landscape.util.alphanumeric = alphanumeric;

/*
 * Check that a value is a lowercase alphanumeric string.
 */
var lowercase_alphanumeric = function(value) {
    if (value.match(LOWER_ALPHANUMERIC) === null) {
        return "Use only lowercase alphanumeric and _";
    }
};

Y.landscape.util.lowercase_alphanumeric = lowercase_alphanumeric;


/*
 * Check that a value is a valid IPv4 address.
 */
var ip = function(value) {
    if (value.match(IP) === null) {
        return "Please enter a valid IPv4 address";
    }
};

Y.landscape.util.ip = ip;


/*
 * Check that a value is a valid IPv4 CIDR.
 */
var cidr = function(value) {
    if (value.match(CIDR) === null) {
        return "Please enter a valid IPv4 CIDR";
    }
};

Y.landscape.util.cidr = cidr;


/*
 * Check that a value is not an invalid email address.
 */
var email = function(value) {
    if (value.match(EMAIL) === null) {
        return "Please enter a valid address";
    }
};

Y.landscape.util.email = email;


}, "0.1", {"requires": []});
