import PropTypes from 'prop-types';
import React from 'react';

import { ValidatedCountryDropDown } from './country';
import { isEUCountry } from './eu';
import { ValidatedLabeledInput } from './components';


export class AccountCountry extends React.Component  {

    constructor(props) {
        super(props);
        this.onVATChange = this.onVATChange.bind(this);
        this.onVATBlur = this.onVATBlur.bind(this);
        this.onCountryChange = this.onCountryChange.bind(this);
    }
    
    onVATChange(event) {
        this.props.onVATChange(event.target.value);
    }

    onVATBlur() {
        this.props.onVATBlur();
    }
    
    onCountryChange(event) {
        this.props.onCountryChange(event.target.value);
    }
    
    render() {
        let vatValue = this.props.accountVAT || '';
        let renderVAT = (this.props.isBusinessAccount &&
                         isEUCountry(this.props.selectedCountry));
        let vatElement = (renderVAT &&
                          <ValidatedLabeledInput type="text"
                              name="VATNumber"
                              labelText="VAT number"
                              onChange={this.onVATChange}
                              onBlur={this.onVATBlur}
                              placeholder="VAT number"
                              value={vatValue}
                              isOK={this.props.isVATOK}
                              errorMessage={this.props.vatErrorMessage}/>);
        
        return (
            <div>
                <ValidatedCountryDropDown
                    name={this.props.name}
                    data-stripe={this.props.stripeData}
                    value={this.props.selectedCountry}
                    onChange={this.onCountryChange}
                    isOK={this.props.isCountryOK}
                    errorMessage={this.props.countryErrorMessage}
                />
                {vatElement}
            </div>
        );
    }
}

AccountCountry.propTypes = {
    name: PropTypes.string.isRequired,
    stripeData: PropTypes.string.isRequired,
    isBusinessAccount: PropTypes.bool,
    accountVAT: PropTypes.string,
    selectedCountry: PropTypes.string,
    onCountryChange: PropTypes.func,
    onVATChange: PropTypes.func,
    onVATBlur: PropTypes.func,
    isVATOK: PropTypes.bool,
    vatErrorMessage: PropTypes.string,
    isCountryOK: PropTypes.bool,
    countryErrorMessage: PropTypes.string
};
