import PropTypes from 'prop-types';
import React from 'react';

import { AccountCountry } from './account-country';
import { LabeledInput, ValidatedLabeledInput } from './components';
import { ValidatedCountryDropDown, hasMandatoryState } from './country';


export class BillingAddress extends React.Component {

    constructor(props) {
        super(props);
        this.handleCountryChange = this.handleCountryChange.bind(this);
        this.handleNameChange = this.handleNameChange.bind(this);
        this.handleAddress1Change = this.handleAddress1Change.bind(this);
        this.handleAddress2Change = this.handleAddress2Change.bind(this);
        this.handleStateChange = this.handleStateChange.bind(this);
        this.handleCityChange = this.handleCityChange.bind(this);
        this.handleZipChange = this.handleZipChange.bind(this);
    }

    handleCountryChange(e) {
        this.props.onChange({billingCountry: e.target.value});
    }

    handleNameChange(e) {
        this.props.onChange({billingName: e.target.value});
    }

    handleAddress1Change(e) {
        this.props.onChange({billingAddress1: e.target.value});
    }

    handleAddress2Change(e) {
        this.props.onChange({billingAddress2: e.target.value});
    }

    handleStateChange(e) {
        this.props.onChange({billingState: e.target.value});
    }

    handleCityChange(e) {
        this.props.onChange({billingCity: e.target.value});
    }

    handleZipChange(e) {
        this.props.onChange({billingZip: e.target.value});
    }

    render () {
        return (
            <div className="p-payment__section" id="billing-address">
                <h3>Billing address</h3>
                <ValidatedCountryDropDown data-stripe="address-country"
                    name="billing-country"
                    value={this.props.billingCountry}
                    onChange={this.handleCountryChange}
                    isOK={this.props.billingCountryOK}
                    errorMessage="'Country' is required."
                />
                <ValidatedLabeledInput name="billing-name"
                    labelText="Full name"
                    type="text"
                    data-stripe="name"
                    placeholder="e.g. John Smith"
                    value={this.props.billingName}
                    onChange={this.handleNameChange}
                    isOK={this.props.billingNameOK}
                    errorMessage="'Full name' is required."
                />
                <ValidatedLabeledInput name="billing-address1"
                    labelText="Address line 1"
                    type="text"
                    data-stripe="address-line1"
                    autoComplete="billing address-line1"
                    placeholder="e.g. 20 Ingram Street"
                    value={this.props.billingAddress1}
                    onChange={this.handleAddress1Change}
                    isOK={this.props.billingAddress1OK}
                    errorMessage="'Address line 1' is required."
                />
                <LabeledInput name="billing-address2"
                    labelText="Address line 2"
                    type="text"
                    data-stripe="address-line2"
                    autoComplete="billing address-line2"
                    placeholder="Optional"
                    value={this.props.billingAddress2}
                    onChange={this.handleAddress2Change}
                />
                {hasMandatoryState(this.props.billingCountry) ?
                    <ValidatedLabeledInput name="billing-state"
                        labelText="County / State"
                        type="text"
                        data-stripe="address-state"
                        autoComplete="billing address-level1"
                        placeholder="e.g. Essex"
                        value={this.props.billingState}
                        onChange={this.handleStateChange}
                        isOK={this.props.billingStateOK}
                        errorMessage="'County / State' is required."
                    />
                    :
                    <LabeledInput name="billing-state"
                        labelText="County / State"
                        type="text"
                        data-stripe="address-state"
                        autoComplete="billing address-level1"
                        placeholder="e.g. Essex"
                        value={this.props.billingState}
                        onChange={this.handleStateChange}
                    />
                }
                <div className="l-col-half">
                    <ValidatedLabeledInput name="billing-city"
                        labelText="Town / City"
                        type="text"
                        data-stripe="address-city"
                        autoComplete="billing address-level2"
                        placeholder="e.g. London"
                        value={this.props.billingCity}
                        onChange={this.handleCityChange}
                        isOK={this.props.billingCityOK}
                        errorMessage="'Town / City' is required."
                    />
                </div>
                <div className="l-col-half"> 
                    <ValidatedLabeledInput name="billing-zip"
                        labelText="Postcode / Zip"
                        type="text"
                        data-stripe="address-zip"
                        autoComplete="billing postal-code"
                        placeholder="e.g. E1 6DU"
                        value={this.props.billingZip}
                        onChange={this.handleZipChange}
                        isOK={this.props.billingZipOK}
                        errorMessage="'Postcode / Zip' is required."
                    />
                </div>
            </div>);
    }
}

BillingAddress.propTypes = {
    onChange: PropTypes.func.isRequired,
    billingCountry: PropTypes.string,
    billingCountryOK: PropTypes.bool,
    billingName: PropTypes.string,
    billingNameOK: PropTypes.bool,
    billingAddress1: PropTypes.string,
    billingAddress1OK: PropTypes.bool,
    billingAddress2: PropTypes.string,
    billingState: PropTypes.string,
    billingStateOK: PropTypes.bool,
    billingCity: PropTypes.string,
    billingCityOK: PropTypes.bool,
    billingZip: PropTypes.string,
    billingZipOK: PropTypes.bool,
};    

export class AddressCheckbox extends React.Component {

    constructor(props) {
        super(props);
        this.handleChange = this.handleChange.bind(this);
    }

    // This will trigger hiding/showing the BillingAddress component in SignupForm
    handleChange( event ) {
        this.props.onChange(event.target.checked);
    }

    render () {
        return (
            <div className="p-payment__section">
                <label>
                    <input type="checkbox" name="same-address" checked={this.props.sameAddress} onChange={this.handleChange} />
                    <span className="checkbox">
                  Credit or debit card address is the same as above
                    </span>
                </label>
            </div>);
    }
}

AddressCheckbox.propTypes = {
    onChange: PropTypes.func.isRequired,
    sameAddress: PropTypes.bool.isRequired,
};

export class AccountAddress extends React.Component {

    constructor(props) {
        super(props);
        this.handleCountryChange = this.handleCountryChange.bind(this);
        this.handleVATChange = this.handleVATChange.bind(this);
        this.handleVATBlur = this.handleVATBlur.bind(this);
        this.handleNameChange = this.handleNameChange.bind(this);
        this.handleAddress1Change = this.handleAddress1Change.bind(this);
        this.handleAddress2Change = this.handleAddress2Change.bind(this);
        this.handleStateChange = this.handleStateChange.bind(this);
        this.handleCityChange = this.handleCityChange.bind(this);
        this.handleZipChange = this.handleZipChange.bind(this);
    }

    handleCountryChange(country) {
        this.props.onChange({accountCountry: country});
    }

    handleVATChange(vatNumber) {
        this.props.onChange({accountVAT: vatNumber});
    }

    handleVATBlur() {
        this.props.onVATBlur();
    }

    handleNameChange(e) {
        this.props.onChange({accountName: e.target.value});
    }

    handleAddress1Change(e) {
        this.props.onChange({accountAddress1: e.target.value});
    }

    handleAddress2Change(e) {
        this.props.onChange({accountAddress2: e.target.value});
    }

    handleStateChange(e) {
        this.props.onChange({accountState: e.target.value});
    }

    handleCityChange(e) {
        this.props.onChange({accountCity: e.target.value});
    }

    handleZipChange(e) {
        this.props.onChange({accountZip: e.target.value});
    }

    render () {
        var stripeCountry = '';
        var stripeName = '';
        var stripeAddressLine1 = '';
        var stripeAddressLine2 = '';
        var stripeState = '';
        var stripeCity = '';
        var stripeZip = '';

        // If the BillingAddress component is not visible, this component must provide
        // the fields that stripe needs to assign to the customer
        if (this.props.isStripeAddress) {
            stripeCountry = "address-country";
            stripeName = "name";
            stripeAddressLine1 = "address-line1";
            stripeAddressLine2 = "address-line2";
            stripeState = "address-state";
            stripeCity = "address-city";
            stripeZip = "address-zip";
        }


        return (
            <div className="p-payment__section" id="account-address">
                <h3>Name and address</h3>
                <AccountCountry name="account-country"
                    stripeData={stripeCountry}
                    selectedCountry={this.props.accountCountry}
                    onVATChange={this.handleVATChange}
                    onVATBlur={this.handleVATBlur}
                    onCountryChange={this.handleCountryChange}
                    isBusinessAccount={this.props.isBusinessAccount}
                    accountVAT={this.props.accountVAT}
                    isVATOK={this.props.accountVATOK}
                    vatErrorMessage={this.props.accountVATErrorMessage}
                    isCountryOK={this.props.accountCountryOK}
                    countryErrorMessage="'Country' is required."
                />
                <ValidatedLabeledInput type="text"
                    name="account-name"
                    labelText="Full name"
                    value={this.props.accountName}
                    data-stripe={stripeName}
                    onChange={this.handleNameChange}
                    placeholder="e.g. John Smith"
                    isOK={this.props.accountNameOK}
                    errorMessage="'Full name' is required."
                />
                <ValidatedLabeledInput type="text"
                    name="account-address1"
                    labelText="Address line 1"
                    value={this.props.accountAddress1}
                    data-stripe={stripeAddressLine1}
                    onChange={this.handleAddress1Change}
                    autoComplete="account address-line1"
                    placeholder="e.g. 20 Ingram Street"
                    isOK={this.props.accountAddress1OK}
                    errorMessage="'Address line 1' is required."
                />
                <LabeledInput type="text"
                    name="account-address2"
                    labelText="Address line 2"
                    value={this.props.accountAddress2}
                    data-stripe={stripeAddressLine2}
                    onChange={this.handleAddress2Change}
                    autoComplete="account address-line2"
                    placeholder="Optional"
                />
                {hasMandatoryState(this.props.accountCountry) ?
                    <ValidatedLabeledInput type="text"
                        name="account-state"
                        labelText="County / State"
                        value={this.props.accountState}
                        data-stripe={stripeState}
                        onChange={this.handleStateChange}
                        autoComplete="account address-level1"
                        placeholder="e.g. Essex"
                        isOK={this.props.accountStateOK}
                        errorMessage="'County / State' is required."
                    />
                    :
                    <LabeledInput type="text"
                        name="account-state"
                        labelText="County / State"
                        value={this.props.accountState}
                        data-stripe={stripeState}
                        onChange={this.handleStateChange}
                        autoComplete="account address-level1"
                        placeholder="e.g. Essex"
                    />
                }
                <div className="l-col-half">
                    <ValidatedLabeledInput type="text"
                        name="account-city"
                        labelText="Town / City"
                        value={this.props.accountCity}
                        data-stripe={stripeCity}
                        onChange={this.handleCityChange}
                        autoComplete="account address-level2"
                        placeholder="e.g. London"
                        isOK={this.props.accountCityOK}
                        errorMessage="'Town / City' is required."
                    />
                </div>
                <div className="l-col-half">
                    <ValidatedLabeledInput type="text"
                        name="account-zip"
                        labelText="Postcode / Zip"
                        value={this.props.accountZip}
                        data-stripe={stripeZip}
                        onChange={this.handleZipChange}
                        autoComplete="account postal-code"
                        placeholder="e.g. E1 6DU"
                        isOK={this.props.accountZipOK}
                        errorMessage="'Postcode / Zip' is required."
                    />
                </div>
            </div>);
    }
}

AccountAddress.propTypes = {
    isStripeAddress: PropTypes.bool.isRequired,
    onChange: PropTypes.func.isRequired,
    isBusinessAccount: PropTypes.bool.isRequired,
    accountCountry: PropTypes.string,
    accountCountryOK: PropTypes.bool,
    accountVAT: PropTypes.string,
    onVATBlur: PropTypes.func,
    accountVATOK: PropTypes.bool,
    accountVATErrorMessage: PropTypes.string,
    accountName: PropTypes.string,
    accountNameOK: PropTypes.bool,
    accountAddress1: PropTypes.string,
    accountAddress1OK: PropTypes.bool,
    accountAddress2: PropTypes.string,
    accountState: PropTypes.string,
    accountStateOK: PropTypes.bool,
    accountCity: PropTypes.string,
    accountCityOK: PropTypes.bool,
    accountZip: PropTypes.string,
    accountZipOK: PropTypes.bool,
};

