import PropTypes from 'prop-types';
import React from 'react';
import Modal from 'react-modal';


function pad(n) {
    return n<10 ? "0"+n : n;
}

function formatExpiryDate(exp_month, exp_year) {
    return pad(exp_month) + "/" + exp_year;
}

export function CreditCardDetails(props) {
    let address = (props.displayAddress &&
                   <address className="p-payment__details-address">
                       <span>{props.card.address_line1}</span>
                       <span>{props.card.address_city} {props.card.address_zip}</span>
                       <span>{props.card.address_country}</span>
                   </address>);
    let buttons = (props.displayAddress && props.buttons);
    return (
        <div>
            <div className="p-payment__card" >
                <p className="p-payment__card-number">
                    <span>XXXX</span><span>XXXX</span><span>XXXX</span><span>{props.card.last4}</span>
                </p>
                <p className="p-payment__card-name">{props.card.name}</p>
                <div className="p-payment__card-type"></div>
            </div>
            <div className="p-payment__details">
                <p className="p-payment__details-card"><strong>{props.card.brand} - {props.card.last4}</strong></p>
                <p className="p-payment__details-exp">Expires: {formatExpiryDate(props.card.exp_month, props.card.exp_year)}</p>
                {address}
            </div>
            {buttons}
        </div>);
}

export const cardPropType = PropTypes.shape({
    name:  PropTypes.string.isRequired,
    address_line1:  PropTypes.string.isRequired,
    address_line2:  PropTypes.string,
    address_city:  PropTypes.string.isRequired,
    address_state:  PropTypes.string.isRequired,
    address_zip:  PropTypes.string.isRequired,
    address_country:  PropTypes.string.isRequired,
    country:  PropTypes.string,
    exp_month:  PropTypes.number.isRequired,
    exp_year:  PropTypes.number.isRequired,
    last4:  PropTypes.string.isRequired,
    object:  PropTypes.string,
    brand:  PropTypes.string.isRequired,
    funding:  PropTypes.string
});

CreditCardDetails.propTypes = {
    card: cardPropType,
    displayAddress: PropTypes.bool,
    buttons: PropTypes.node
};


export class RemoveCardConfirmation extends React.Component {

    constructor(props) {
        super(props);
        this.state = {
            modalIsOpen: false,
            amSubmitting: false,
        };
        this.handleRemoveCardClick = this.handleRemoveCardClick.bind(this);
        this.handleConfirmRemoveCardClick = this.handleConfirmRemoveCardClick.bind(this);
        this.closeModal = this.closeModal.bind(this);
    }

    handleRemoveCardClick() {
        this.setState({modalIsOpen: true});
    }

    handleConfirmRemoveCardClick() {
        /* We don't need to close the modal, since we'll be unmounted once removeCard is done */
        this.setState({amSubmitting: true});
        this.props.removeCard();
    }

    closeModal() {
        /* We only close the modal dialog if we're not in the middle of submitting */
        this.setState((prevState) => ({
            modalIsOpen: prevState.amSubmitting
        }));
    }

    render () {
        let modalStyles = {
            content: {
                height: '150px',
                width: '515px',
                margin: 'auto',
                overflow: 'hidden',
            }};
        return (
            <div style={{display: 'inline'}}>
                <a className="p-payment__remove-link" onClick={this.handleRemoveCardClick}>Remove card</a>
                <Modal isOpen={this.state.modalIsOpen}
                    onRequestClose={this.closeModal}
                    contentLabel="Confirm removal"
                    style={modalStyles} >
                    <p>Are you sure you want to remove this card from your Landscape account?</p>
                    <div className="buttons">
                        <button disabled={this.state.amSubmitting} onClick={this.closeModal}>Cancel</button>
                        <button disabled={this.state.amSubmitting} className="primary"
                            onClick={this.handleConfirmRemoveCardClick}>Remove</button>
                    </div>
                </Modal>
            </div>
        );
    }
}

RemoveCardConfirmation.propTypes = {
    removeCard: PropTypes.func.isRequired,
};


export function MissingCreditCard() {
    return (
        <div>
            <div className="buttons">
                <form method="GET" action="create">
                    <button className="primary p-payment__add-button" type="submit">Add payment method</button>
                </form>
            </div>
            <span>Please add a payment method to continue using Landscape.</span>
        </div>);
}

MissingCreditCard.propTypes = {};

export function CreditCardError() {
    return (
        <div className="wrapper">
            <div className="p-payment__card">
                <div className="p-payment__card-type"></div>
            </div>
            <div className="p-error__details">
                <p>
              Your payment details aren&#39;t available at the moment, please try again later.
                </p>
            </div>
        </div>);
}

CreditCardError.propTypes = {};
