import PropTypes from 'prop-types';
import React from 'react';
import { CardNumberElement, CardExpiryElement, CardCvcElement } from 'react-stripe-elements';

export class CreditCardForm extends React.Component {

    constructor(props) {
        super(props);
        this.state = {
            cvcClass: "",
            cvcError: null,
            cvcOK: false,
            expiryClass: "",
            expiryError: null,
            expiryOK: false,
            cardClass: "",
            cardError: null,
            cardOK: false,
        };
        this.onCardChange = this.onCardChange.bind(this);
        this.onExpiryChange = this.onExpiryChange.bind(this);
        this.onCvcChange = this.onCvcChange.bind(this);
        this.onChange = this.onChange.bind(this);
    }

    onChange() {
        this.props.onOKChange && this.props.onOKChange(!(
            this.state.cvcError ||
            this.state.cardError ||
            this.state.expiryError));
    }

    onCardChange(event) {
        this.setState({
            cardClass: (event.complete?  "has-success":
                event.error?  "has-error": ""),
            cardError: (event.error || {}).message,
            cardOK: event.complete,
        });
        this.onChange();
    }

    onExpiryChange(event) {
        this.setState({
            expiryClass: (event.complete? "has-success":
                event.error? "has-error": ""),
            expiryError: (event.error || {}).message,
            expiryOK: event.complete,
        });
        this.onChange();
    }

    onCvcChange(event) {
        this.setState({
            cvcClass: (event.complete? "has-success":
                event.error? "has-error": ""),
            cvcError: (event.error || {}).message,
            cvcOK: event.complete,
        });
        this.onChange();
    }

    render () {
        return (
            <div className="p-payment__section">
                <h3>Payment information</h3>
                {this.props.showWarning &&
                  <p className="p-payment__notification">Don&#39;t worry, you won&#39;t be charged until your trial has expired</p>}
                <label id="card-number-label" className={this.state.cardClass}>
                    Card number
                    <CardNumberElement onChange={this.onCardChange}/>
                </label>
                {this.state.cardError &&
                    <div className="p-payment__details-error">
                        <span>Error:&nbsp;</span>{this.state.cardError}
                    </div>
                }
                <span className="l-col-two-thirds">
                    <label id="card-expiry-label" className={this.state.expiryClass}>
                        Expiry
                        <CardExpiryElement onChange={this.onExpiryChange}/>
                    </label>
                </span>
                <span className="l-col-third">
                    <label id="card-cvc-label" className={this.state.cvcClass}>
                        Security number
                        <CardCvcElement onChange={this.onCvcChange}/>
                    </label>
                </span>
                {this.state.expiryError &&
                    <div className="p-payment__details-error">
                        <span>Error:&nbsp;</span>{this.state.expiryError}
                    </div>
                }
                {this.state.cvcError &&
                    <div className="p-payment__details-error">
                        <span>Error:&nbsp;</span>{this.state.cvcError}
                    </div>
                }
            </div>);
    }
}

CreditCardForm.propTypes = {
    showWarning: PropTypes.bool,
    onOKChange: PropTypes.func,
};
