import PropTypes from 'prop-types';
import React from 'react';

import { AccountAddress, AddressCheckbox, BillingAddress } from './address';
import { AccountType } from './account-type';
import { getFieldState, ModalInterstitial } from './components';
import { getCountryState, getStateState } from './country';
import { CreditCardDetails, cardPropType } from './credit-card-details';
import { isValidVATIN } from './vat';
import { delayDecorator } from './utility';


export class EditBillingDetailsForm extends React.Component {

    constructor(props) {
        super(props);
        this.state = {
            accountCountry: props.shippingAddress.country,
            accountVAT: props.accountVAT,
            accountType: props.accountType,
            accountName: props.shippingAddress.name,
            accountAddress1: props.shippingAddress.address1,
            accountAddress2: props.shippingAddress.address2,
            accountState: props.shippingAddress.state,
            accountCity: props.shippingAddress.city,
            accountZip: props.shippingAddress.zip,
            billingCountry: props.card.address_country,
            billingName: props.card.name,
            billingAddress1: props.card.address_line1,
            billingAddress2: props.card.address_line2,
            billingState: props.card.address_state,
            billingCity: props.card.address_city,
            billingZip: props.card.address_zip,
            sameAddress: false,
        };
        this.handleAccountTypeChange = this.handleAccountTypeChange.bind(this);
        this.handleAccountAddressChange = this.handleAccountAddressChange.bind(this);
        this.handleAddressCheckboxChange = this.handleAddressCheckboxChange.bind(this);
        this.handleBillingAddressChange = this.handleBillingAddressChange.bind(this);
        this.handleAccountVATBlur = this.handleAccountVATBlur.bind(this);
        this.onCancel = this.onCancel.bind(this);
        this.onSubmit = this.onSubmit.bind(this);
        this.simpleAddressFields = [
            "billingName",
            "billingAddress1",
            "billingCity",
            "billingZip",
            "accountName",
            "accountAddress1",
            "accountCity",
            "accountZip",
        ];

    }

    handleAccountTypeChange(value) {
        this.setState({accountType: value});
    }


    _generateAccountAddressStateUpdate(items, state) {
        let stateUpdate = {};
        for (let key in items) {
            // AccountAddress is only allowed to update account address fields
            if (key.startsWith("account")) {
                stateUpdate[key] = items[key];
                if (this.simpleAddressFields.includes(key)) {
                    stateUpdate[key + "OK"] = getFieldState(items[key]);
                } else if (key === "accountState") {
                    stateUpdate["accountStateOK"] = getStateState(items[key], this.state.accountCountry);
                } else if (key === "accountCountry") {
                    let [isVATOK, errorMessage] = isValidVATIN(state.accountVAT, items[key]);
                    stateUpdate["accountCountryOK"] = getCountryState(items[key]);
                    stateUpdate["accountVATOK"] = isVATOK;
                    stateUpdate["accountVATErrorMessage"] = errorMessage;
                    if (this.state.accountStateOK !== undefined) {
                        stateUpdate["accountStateOK"] = getStateState(this.state.accountState, items[key]);
                    }
                }
            }
        }
        return stateUpdate;
    }
    
    handleAccountAddressChange(items) {
        this.setState(this._generateAccountAddressStateUpdate(items, this.state));
    }

    handleAddressCheckboxChange(value) {
        this.setState({sameAddress: value});
    }

    _generateBillingAddressStateUpdate(items) {
        let stateUpdate = {};
        for (let key in items) {
            // BillingAddress is only allowed to update billing address fields
            if (key.startsWith("billing")) {
                stateUpdate[key] = items[key];
                if (this.simpleAddressFields.includes(key)) {
                    stateUpdate[key + "OK"] = getFieldState(items[key]);
                } else if (key === "billingState") {
                    stateUpdate["billingStateOK"] = getStateState(items[key], this.state.billingCountry);
                } else if (key === "billingCountry") {
                    stateUpdate["billingCountryOK"] = getCountryState(items[key]);
                    if (this.state.billingStateOK !== undefined) {
                        stateUpdate["billingStateOK"] = getStateState(this.state.billingState, items[key]);
                    }
                }
            }
        }
        return stateUpdate;
    }
    
    handleBillingAddressChange(items) {
        this.setState(this._generateBillingAddressStateUpdate(items, this.state));
    }

    handleAccountVATBlur() {
        const [isVATOK, errorMessage] = isValidVATIN(this.state.accountVAT, this.state.accountCountry);
        this.setState({accountVATOK: isVATOK, accountVATErrorMessage: errorMessage});
    }

    onCancel() {
        window.location.replace("./");
    }

    _getSubmitData() {
        let form = new FormData();
        form.set("accountCountry", this.state["accountCountry"]);
        form.set("accountVAT", this.state["accountVAT"]);
        form.set("accountType", this.state["accountType"]);
        form.set("accountName", this.state["accountName"]);
        form.set("accountAddress1", this.state["accountAddress1"]);
        form.set("accountAddress2", this.state["accountAddress2"]);
        form.set("accountState", this.state["accountState"]);
        form.set("accountCity", this.state["accountCity"]);
        form.set("accountZip", this.state["accountZip"]);
        if (this.state.sameAddress) {
            form.set("billingCountry", this.state["accountCountry"]);
            form.set("billingName", this.state["accountName"]);
            form.set("billingAddress1", this.state["accountAddress1"]);
            form.set("billingAddress2", this.state["accountAddress2"]);
            form.set("billingState", this.state["accountState"]);
            form.set("billingCity", this.state["accountCity"]);
            form.set("billingZip", this.state["accountZip"]);
        } else {
            form.set("billingCountry", this.state["billingCountry"]);
            form.set("billingName", this.state["billingName"]);
            form.set("billingAddress1", this.state["billingAddress1"]);
            form.set("billingAddress2", this.state["billingAddress2"]);
            form.set("billingState", this.state["billingState"]);
            form.set("billingCity", this.state["billingCity"]);
            form.set("billingZip", this.state["billingZip"]);
        }
        form.set("form-security-token", this.props.formToken);
        return form;
    }

    isSubmittable(state) {
        const accountFields = [
            state.accountNameOK,
            state.accountAddress1OK,
            state.accountCityOK,
            state.accountStateOK,
            state.accountZipOK,
            state.accountCountryOK,
        ];
        const billingFields = [
            state.billingNameOK,
            state.billingAddress1OK,
            state.billingCityOK,
            state.billingStateOK,
            state.billingZipOK,
            state.billingCountryOK,
        ];
        let mustHaveFields = (( state.sameAddress ) ? accountFields : [...accountFields, ...billingFields]);
        if (state.accountVATOK !== undefined) {
            // undefined VAT is fine
            mustHaveFields.push(state.accountVATOK);
        }
        return mustHaveFields.every(field => Boolean(field));
    }

    // Click handler when submitting
    refreshFieldValidity(state) {
        let stateUpdate = {sameAddress: state.sameAddress};
        let billingChanges = {};
        let accountChanges = {};
        // Coerce empty fields to the empty string
        this.simpleAddressFields.map(key => {
            let map;
            if (key.startsWith("billing")) {
                map = billingChanges;
            } else if (key.startsWith("account")) {
                map = accountChanges;
            } else {
                throw "unexpected key";
            }
            map[key] = state[key] || "";
        });
        billingChanges["billingState"] = this.state["billingState"] || "";
        billingChanges["billingCountry"] = state["billingCountry"] || "";
        accountChanges["accountState"] = this.state["accountState"] || "";
        accountChanges["accountCountry"] = state["accountCountry"] || "";
        billingChanges = this._generateBillingAddressStateUpdate(billingChanges);
        accountChanges = this._generateAccountAddressStateUpdate(accountChanges, state);
        return Object.assign(stateUpdate, billingChanges, accountChanges);
    }


    onSubmit(event) {
        event.preventDefault();
        let state = this.refreshFieldValidity(this.state);
        this.setState(state);
        if (!this.isSubmittable(state)) {
            return;
        }
        this.setState({amSubmitting: true});
        let form = this._getSubmitData();
        let fetchConfig = {
            credentials: 'same-origin',
            method: 'POST',
            body: form,
        };
        fetch('./edit', fetchConfig).then((response) => {
            if (!response.ok) {
                this.setState({amSubmitting: false});
                throw new Error('Failure to edit billing details.');
            }
            window.location.replace(response.url);
        }).catch((error) => {
            this.setState({amSubmitting: false});
            throw new Error('Failure to edit billing details: ' + error.message);
        });
    }

    render() {
        return (
            <div className="p-payment">
                <ModalInterstitial isOpen={this.state.amSubmitting} />
                <h2 className="p-payment__title">
                    Payment details &nbsp;&nbsp;
                    <small className="p-payment__tagline">
                        <i className="p-icon--padlock p-icon--title"></i> 128-bit SSL encrypted payment
                    </small>
                </h2>
                <form method="POST" onSubmit={this.onSubmit} >
                    <CreditCardDetails card={this.props.card} displayAddress={false} />
                    <AccountType type={this.state.accountType} onChange={this.handleAccountTypeChange} className='u-clearfix' />
                    <AccountAddress isStripeAddress={this.state.sameAddress}
                        isBusinessAccount={this.state.accountType == "business"}
                        accountName={this.state.accountName}
                        accountNameOK={this.state.accountNameOK}
                        accountCountry={this.state.accountCountry}
                        accountCountryOK={this.state.accountCountryOK}
                        accountVAT={this.state.accountVAT}
                        accountVATOK={this.state.accountVATOK}
                        accountVATErrorMessage={this.state.accountVATErrorMessage}
                        accountAddress1={this.state.accountAddress1}
                        accountAddress1OK={this.state.accountAddress1OK}
                        accountAddress2={this.state.accountAddress2}
                        accountState={this.state.accountState}
                        accountStateOK={this.state.accountStateOK}
                        accountCity={this.state.accountCity}
                        accountCityOK={this.state.accountCityOK}
                        accountZip={this.state.accountZip}
                        accountZipOK={this.state.accountZipOK}
                        onChange={this.handleAccountAddressChange}
                        onVATBlur={delayDecorator(this.handleAccountVATBlur)}
                    />
                    <AddressCheckbox sameAddress={this.state.sameAddress}
                        onChange={this.handleAddressCheckboxChange} />
                    {this.state.sameAddress || (
                        <BillingAddress billingName={this.state.billingName}
                            billingNameOK={this.state.billingNameOK}
                            billingCountry={this.state.billingCountry}
                            billingCountryOK={this.state.billingCountryOK}
                            billingAddress1={this.state.billingAddress1}
                            billingAddress1OK={this.state.billingAddress1OK}
                            billingAddress2={this.state.billingAddress2}
                            billingState={this.state.billingState}
                            billingStateOK={this.state.billingStateOK}
                            billingCity={this.state.billingCity}
                            billingCityOK={this.state.billingCityOK}
                            billingZip={this.state.billingZip}
                            billingZipOK={this.state.billingZipOK}
                            onChange={this.handleBillingAddressChange}  />)}
                    <div className="buttons">
                        <button disabled={this.state.amSubmitting} type="button" onClick={this.onCancel}>Cancel</button>
                        <button disabled={this.state.amSubmitting} className="primary p-payment__button" type="submit">Update payment details</button>
                    </div>
                </form>
            </div>);
    }
}

EditBillingDetailsForm.propTypes = {
    formToken: PropTypes.string.isRequired,
    card: cardPropType,
    accountVAT: PropTypes.string.isRequired,
    accountType: PropTypes.string.isRequired,
    shippingAddress: PropTypes.shape({
        country: PropTypes.string.isRequired,
        name: PropTypes.string.isRequired,
        address1: PropTypes.string.isRequired,
        address2: PropTypes.string.isRequired,
        city: PropTypes.string.isRequired,
        state: PropTypes.string.isRequired,
        zip: PropTypes.string.isRequired,
    }).isRequired
};
