import PropTypes from 'prop-types';
import React from 'react';

import { formatMoney, formatNumber } from 'accounting';


export function Receipts(props) {
    return(
        <div id="receipt-list">
            <h3>Receipts</h3>
            { props.payments.length > 0 ? <ReceiptList payments={props.payments} /> : <NoReceipts />}
        </div>
    );
}

const paymentPropType = PropTypes.shape({
    end_date: PropTypes.string.isRequired,
    url: PropTypes.string.isRequired,
    usage: PropTypes.number.isRequired,
    amount: PropTypes.number.isRequired
});

export const paymentsPropType = PropTypes.arrayOf(paymentPropType).isRequired;

Receipts.propTypes = {
    payments: paymentsPropType,
};


export function ReceiptList(props) {
    let receipt_list = props.payments;
    let paymentDetailF = function (payment, i) {
        return (
            <tr key={i}>
                <td><a href={payment.url}>{payment.end_date}</a></td>
                <td>{formatNumber(payment.usage)}</td>
                <td>{formatMoney(payment.amount / 10000)}</td>
            </tr>);
    };
    const receipts_rows = receipt_list.map(paymentDetailF);

    return (
        <div>
            <table id="receipts">
                <thead>
                    <tr>
                        <th>Name</th>
                        <th>Usage (managed hours)</th>
                        <th>Amount</th>
                    </tr>
                </thead>
                <tbody>
                    {receipts_rows}
                </tbody>
            </table>
        </div>);
}

ReceiptList.propTypes = {
    payments: PropTypes.arrayOf(paymentPropType).isRequired
};


export function NoReceipts() {
    return (
        <div>
            <span>You have no receipts for your Landscape usage yet.</span>
        </div>);
}
