import { getEUCountryName, isEUCountry } from './eu';


function isValidVATINForm(value) {
    // The value has a form that complies with the EU rules for
    // VATIN.
    const re = /^[A-Z]{2}[a-zA-Z0-9]{2,13}$/;
    let ok = re.test(value);
    return [ok, ((ok) ? undefined : 'An EU VAT number should start with a' +
                 ' 2 character country code and then have a further 2 to ' + 
                 '13 characters.')];
}

function isValidVATINCountryPrefix(value, countryCode) {
    // Most countries use ISO 3166-1-alpha-2 country codes as
    // their VATIN prefix.
    let prefix = countryCode;
    
    if (countryCode == 'AT') {
        // Austrian VAT numbers start with ATU. That's still ISO
        // 3166-alpha-2 compliant, we just happen to know they
        // have to have the U, so we'll do that random bit of
        // extra validation.
        prefix = 'ATU';
    }
    
    if (countryCode == 'GR') {
        // Greece uses the ISO 639-1 prefix "EL".
        prefix = 'EL';
    }

    // Note the special VATIN prefix 'EU' is used by companies
    // with no legal entity registered in the EU, but whom are
    // registered for VAT within the EU.
    let ok = (!value || value == '' || value.startsWith(prefix) || value.startsWith('EU'));
    return [ok, ((ok) ? undefined : 'VAT numbers for ' + getEUCountryName(countryCode) +
                 ' should start with "' + prefix + '".')];
}

export function isValidVATIN(value, countryCode) {
    if (!value || value.length == 0 || !isEUCountry(countryCode)) {
        return [undefined, undefined];
    }

    let [formOK, formMessage] = isValidVATINForm(value);
    let [codeOK, codeMessage] = isValidVATINCountryPrefix(value, countryCode);
    
    if (!formOK && !codeOK) {
        return [false, formMessage + ' ' + codeMessage];
    }
    if (!formOK || !codeOK) {
        return [false, formMessage || codeMessage];
    }
    return [true, undefined];
}
