from canonical.landscape.model.main.tag import get_tags
from canonical.lib.arguments import coerce_arguments
from canonical.message.handler import FunctionHandler
from landscape.lib.tag import is_valid_tag
from landscape.message_schemas import COMPUTER_TAGS


@coerce_arguments(message=COMPUTER_TAGS)
def handle_tags(message_api, type, message):
    """
    The message contains tags from the client config file. This handler adds
    any new tags to the computer. Note tags are not deleted.
    """

    tags_text = message.get("tags")
    if not tags_text:
        return

    tag_names = [tag.strip() for tag in tags_text.split(",")]
    tag_objects = get_tags([name for name in tag_names if is_valid_tag(name)])

    computer = message_api.computer
    current_tags = set(computer.get_tags())
    for tag_object in tag_objects:
        if tag_object not in current_tags:
            computer.add_tag(tag_object)


tags_handler = FunctionHandler(handle_tags)
