# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from landscape.message_schemas import TEST

from canonical.lib.arguments import coerce_arguments
from canonical.message.handler import FunctionHandler
from canonical.landscape.message.interfaces import ConsistencyError

from canonical.landscape.security.interfaces import (
    IComputerRequest,
    IPendingComputerRequest,
)


@coerce_arguments(message=TEST)
def handle_test(message_api, _type, message):
    """Message handler for tests."""
    body = {}
    if type(message) is not dict:
        body["error"] = "Invalid message format"
    else:
        if "greeting" in message:
            if IComputerRequest.providedBy(message_api.request):
                body["greeting"] = "Hello registered computer!"
            elif IPendingComputerRequest.providedBy(message_api.request):
                body["greeting"] = "Hello pending computer!"
            else:
                body["greeting"] = "Hello anonymous computer!"
        if "echo" in message:
            body["echo"] = message["echo"]
        if "sequence" in message:
            try:
                body["sequence"] = message["sequence"] + 1
            except TypeError:
                pass
        if "consistency-error" in message:
            if IComputerRequest.providedBy(message_api.request):
                raise ConsistencyError("Just testing.", "test")
    if body:
        message_api.send("test", body)


test_handler = FunctionHandler(handle_test)
