# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.interface import Interface

from canonical.message.interfaces import IMessageSystem


class ConsistencyError(Exception):
    """
    Raise this in message handlers to indicate to the message system
    that the computer should be resynchronised.

    @param message: the error message.

    @param scope: the scope of the error message.  This value is used when
        requesting a resynchronisation of data from the client to control which
        data is to be resynchronised.  It is important that any new values to
        be passed into this variable are also added to the clients
        resynchronisation handlers.
    """

    def __init__(self, message, scope):
        super(ConsistencyError, self).__init__(message)
        self.scope = scope


class ILoadShaperFactory(Interface):
    """Interface for L{LoadShaper} factories."""

    def get_load_shaper(get_load_average):
        """Create a L{LoadShaper}.

        @param get_load_average: A callable taking no arguments that returns
            the current load average for the monitored resource.
        """


class ILandscapeMessageSystem(IMessageSystem):
    """Message system used by Landscape."""
