# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import object
from canonical.landscape.model.access.management import AccessControlManagement


# Map of stock roles names and macro-permissions associated to them.  These are
# created upon account creation and are modifiable.
STOCK_ROLES = {
    "Auditor": [
        "ViewComputer",
        "ViewScript",
        "ViewPackageProfile",
        "ViewUpgradeProfile",
    ],
    "SupportAnalyst": [
        "ManageComputer",
        "ViewScript",
        "ViewPackageProfile",
        "ViewUpgradeProfile",
    ],
}

STOCK_ROLE_DESCRIPTION = "Predefined {} role"


class StockRoleManager(object):
    def create_stock_roles(self, account):
        """Create predefined roles for an L{Account}."""
        management = AccessControlManagement(account)

        for name, permissions in STOCK_ROLES.items():
            description = STOCK_ROLE_DESCRIPTION.format(name)
            role = management.create_role(name, description)
            role.add_permissions(permissions)
            role.add_access_contexts([account.access_context.name])
