# Copyright 2017 Canonical Limited.  All rights reserved.

import logging

import transaction

from canonical.landscape.model.billing.pastdue import (
    get_cutoff,
    iter_past_due_account_ids,
)
from canonical.landscape.model.main.account import get_account_by_id


GRACE_PERIOD_DAYS = 60


def disable_accounts(dryrun=False):
    """Disable Accounts that are past-due."""
    byreason = {}

    # Get past-due accounts.
    reason = "past-due for {} days".format(GRACE_PERIOD_DAYS)
    cutoff = get_cutoff(GRACE_PERIOD_DAYS)
    pastdue_ids = iter_past_due_account_ids(cutoff=cutoff)
    byreason[reason] = list(pastdue_ids)

    for reason, ids in list(byreason.items()):
        for account_id in ids:
            _disable_account(account_id, reason, dryrun=dryrun)


def _disable_account(account_id, reason, dryrun):
    account = get_account_by_id(account_id)
    if account.is_disabled:
        return

    name = account.name
    if dryrun:
        logging.info("account {!r} would have been disabled".format(name))
        return

    with transaction.manager as manager:
        logging.info("Disabling account {!r}".format(name))
        try:
            account.disable(reason)
        except Exception:
            logging.exception("Error disabling account {!r}".format(name))
            manager.abort()
