# Copyright 2005-2013 Canonical Limited.  All rights reserved.

__all__ = [
    "MaximumAccountAdministratorsError",
    "RepeatedInvitationError",
    "IllegalInvitationError",
    "PersonAlreadyInAccountError",
    "InvalidInvitationError",
]

__clearlist__ = __all__


class IllegalInvitationError(Exception):
    """
    Raised when a person tries to invite wihtout the proper permissions.
    """


class MaximumAccountAdministratorsError(IllegalInvitationError):
    """
    Raised when activating an invitation when the account is already at or
    over the limit of administrators.

    @see: L{AccountInvitation.activate}
    """


class RepeatedInvitationError(Exception):
    """Raised when an existing administrator is invited to an account.

    @see: L{create_invitation}
    """


class PersonAlreadyInAccountError(Exception):
    """
    Raised when a person tries to accept an invitation for an account he
    is already in.

    @see: L{AccountInvitation.activate}
    """


class InvalidInvitationError(Exception):
    """
    Raised when a person tries to accept an invitation that is not longer
    valid.

    @see: L{AccountInvitation.activate}
    """
