# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.interface import Interface
from zope.schema import Text, TextLine, List, Choice, Bool


__all__ = ["ICustomGraph", "ISavedSearch"]

__clearlist__ = __all__


class ICustomGraph(Interface):

    title = TextLine(title="Title", description="Title for the graph", required=True)

    code = Text(
        title="Code",
        description=(
            "Script code that should print a numeric value to "
            "standard output. Will be run every 5 minutes."
        ),
        required=True,
        default="#!/bin/bash\n",
    )

    username = TextLine(
        title="Run as user",
        description="Default user to run the script as.",
        required=True,
    )

    y_axis_title = TextLine(
        title="Y-axis title",
        description="Title for the vertical axis on the graph.",
        required=True,
    )

    all_computers = Bool(
        required=False,
        title="All computers",
        description=("If enabled, this will monitor all computers in this " "account."),
    )

    tags = List(
        required=False,
        title="Tags",
        description="The graph will run on computers with these tags.",
        value_type=Choice(vocabulary="account-tags"),
    )

    def add_computer(computer):
        """Associate a computer with this Custom Graph."""

    def get_computers():
        """Get a list of computers associated with this Custom Graph."""


class ISavedSearch(Interface):

    title = TextLine(
        title="Title",
        description="A human readable name for the saved search",
        required=True,
    )

    name = TextLine(
        title="Search Name",
        description="The search name to be associated with this search. E.g.:"
        " natty-security-upgrades. If empty, one will be automatically"
        " generated.",
        required=False,
    )

    search = TextLine(
        title="Search",
        description="The search parameters used in this search",
        required=True,
    )
