# Copyright 2005-2022 Canonical Limited. All rights reserved.

from canonical.landscape.model.entity.helper import (
    register_account_entity_type,
    register_account_entity_permissions,
)
from canonical.landscape.model.account.computergroup import (
    register_profile_info_type,
    profile_info_types,
)
from canonical.landscape.environment import get_config_name
from canonical.landscape.model.alert.rule import Rule
from canonical.landscape.model.account.customgraph import CustomGraph
from canonical.landscape.model.package.profile import PackageProfile
from canonical.landscape.model.package.autoupgrade import UpgradeProfile
from canonical.landscape.model.repository.profile import RepositoryProfile
from canonical.landscape.model.computer.removal import RemovalProfile
from canonical.landscape.model.repository.distribution import Distribution
from canonical.landscape.model.computer.twin import AccountComputerTwin
from canonical.landscape.model.billing.payment import Payment


def register_profile_info_types():
    """Register all the model L{ComputerGroupHelper} types."""
    if profile_info_types:
        return

    register_profile_info_type(1, Rule)
    register_profile_info_type(2, CustomGraph)
    register_profile_info_type(3, PackageProfile)
    register_profile_info_type(4, UpgradeProfile)
    register_profile_info_type(5, RepositoryProfile)
    register_profile_info_type(6, RemovalProfile)


def register_account_entity_types():
    """Register all AccountEntity types."""
    # Repository management
    register_account_entity_type(1, Distribution)
    register_account_entity_permissions(1, "view", ["ViewDistribution"])

    # Computers
    register_account_entity_type(2, AccountComputerTwin)
    register_account_entity_permissions(2, "view", ["ViewComputer"])
    register_account_entity_permissions(
        2, "edit", ["ApproveActivity", "CancelActivity"]
    )

    # Billing
    # -- Entity 5 was Invoice
    register_account_entity_type(6, Payment)
    register_account_entity_permissions(6, "view", ["ViewBilling"])
    # -- Entity 7 was Receipt

    # Indexes >= 1000 are reserved for testing
    if get_config_name() == "default":
        from canonical.landscape.model.activity.testing import StubEntity

        register_account_entity_type(1000, StubEntity)
        register_account_entity_permissions(1000, "view", ["ViewStub"])
        register_account_entity_permissions(1000, "edit", ["EditStub"])
