# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from datetime import timedelta
import logging

import transaction

from canonical.lib.timestamp import utctoday

from canonical.landscape.model.main.store import get_main_store
from canonical.landscape.model.main.account import get_account_by_id, Account
from canonical.landscape.model.account.collection import AccountCollection


NUMBER_OF_DAYS_TO_KEEP_ACCOUNTS = 90


def remove_expired_accounts(dry_run=False):
    """
    Remove L{Accounts} that expired L{NUMBER_OF_DAYS_TO_KEEP_ACCOUNTS} days or
    more ago.

    @param dry_run: True if we should only identify and list the accounts
        that are to be removed.
    """
    expiration_date = utctoday() - timedelta(days=NUMBER_OF_DAYS_TO_KEEP_ACCOUNTS)

    collection = AccountCollection(
        get_main_store(), expired=True, expiration_date=expiration_date
    )

    account_ids = list(collection.find().values(Account.id))

    for account_id in account_ids:
        account = get_account_by_id(account_id)
        name = account.name
        if not dry_run:
            with transaction.manager as manager:
                logging.info("Removing account %s" % name)
                try:
                    account.remove()
                except Exception:
                    logging.exception("Error removing account %s" % name)
                    manager.abort()
        else:
            logging.info("Did NOT remove account %s" % name)
