# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Search logic to find L{SavedSearch}es."""
from builtins import object
from canonical.search.engine import SearchCriteriaError

__all__ = ["SavedSearchCriteria"]


class SavedSearchCriteria(object):
    """
    Search criteria matches C{SavedSearch}es with a matching search name.

    @param search_name: The name of the saved search.
    @param account: The account in which the search will be performed.
    """

    criteria_prefix = "search"
    search_help = {
        "terms": ["search:<name>"],
        "descriptions": ["Computers meeting the terms of the <name> saved search."],
    }

    def __init__(self, search_name, account):
        self._search_name = search_name
        self._account = account

    def get_where_clause(self):
        """
        Get a where clause to find L{SavedSearch}es that matches the search
        name.

        @return: A Storm expression that will match L{SavedSearch}es.
        """
        from canonical.landscape.model.account.savedsearch import SavedSearchManagement
        from canonical.landscape.model.computer.search import ComputerSearch

        management = SavedSearchManagement(self._account)
        saved_search = management.get_saved_search_by_name(self._search_name)
        if not saved_search:
            raise SearchCriteriaError("Invalid search name: %s" % self._search_name)
        search = ComputerSearch(self._account)
        criteria = search.get_search_criteria(saved_search.search)

        return criteria.get_where_clause()

    def to_string(self):
        """Convert this criteria to a string."""
        return "%s:%s" % (self.criteria_prefix, self._search_name)
