# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.component import getUtility

from storm.zope.interfaces import IZStorm


__all__ = ["get_account_stores", "get_account_store_by_name"]


def get_account_stores():
    """Returns stores that begin with 'account-'.

    Given that the resource_database_key is a numeric value that is
    appended onto the string 'account-' this means that 'account-'
    should not be used to name any non-account databases.
    """
    zstorm = getUtility(IZStorm)
    for name, uri in sorted(zstorm.get_default_uris().items()):
        if name.startswith("account-"):
            yield (name, zstorm.get(name))


def get_account_store_by_name(store_name):
    """
    Return the account store named C{store_name}, if it exists.
    """
    for name, store in get_account_stores():
        if name == store_name:
            return store
