# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.event.subscriber import subscriber
from canonical.landscape.model.events import (
    AddComputerEvent,
    AddTagsEvent,
    RemoveTagsEvent,
)
from canonical.landscape.model.main.interfaces import IAccount
from canonical.landscape.model.account.customgraph import CustomGraph
from canonical.landscape.model.account.computergroup import ComputerGroup


@subscriber(IAccount, AddComputerEvent)
def add_computer_to_account_handler(account, event):
    """
    Event handler is invoked when a L{Computer} is added to an L{Account}.
    """
    graphs = account.store.find(
        CustomGraph,
        CustomGraph.account_id == account.id,
        CustomGraph.computer_group_id == ComputerGroup.id,
        ComputerGroup.all_computers == True,
    )
    for graph in graphs:
        graph.add_computers_with_ids([event.computer.id])


@subscriber(IAccount, AddTagsEvent)
def add_tag_to_computers_handler(account, event):
    """Event handler is invoked when L{Tag}s are added to L{Computer}s."""
    account.computer_group.synchronize_with_added_tags(
        event.tag_ids, event.computer_ids, CustomGraph
    )


@subscriber(IAccount, RemoveTagsEvent)
def remove_tag_from_computers_handler(account, event):
    """Event handler is invoked when L{Tag}s are removed from L{Computer}s."""
    account.computer_group.synchronize_with_removed_tags(
        event.tag_ids, event.computer_ids, CustomGraph
    )
