# Copyright 2005-2013 Canonical Limited.  All rights reserved.

__clearlist__ = ["ActionError"]

from collections import namedtuple

ActionErrorReason = namedtuple("ActionErrorReason", "message param code")


class ActionError(Exception):
    """Raised upon action errors.

    It's possible to pass the first reason for the error in the
    constructor, add further reasons with C{add_reason}.

    @param param: The action parameter the error refers to, if any.
    @param code: A machine-parsable error code.
    @param message: A human-readable error message.
    """

    def __init__(self, message=None, param=None, code=None):
        super(ActionError, self).__init__(self, message)
        self._reasons = []
        if message is not None:
            self.add_reason(message=message, param=param, code=code)

    def add_reason(self, message=None, param=None, code=None):
        """Add a reason for the error.

        @param param: The action parameter the error reason refers to, if any.
        @param code: A machine-parsable error code.
        @param message: A human-readable error message.
        """
        self._reasons.append(ActionErrorReason(message, param, code))

    def get_reasons(self):
        """Get all error reasons."""
        return self._reasons
