# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import object
from venusian import Scanner

from zope.interface import implementer
from zope.component import getUtility

from canonical.lib.text import lower_class
from canonical.security.protect import protect_names, PUBLIC

from canonical.landscape.model.action.interfaces import IActionRegistry


@implementer(IActionRegistry)
class ActionRegistry(object):
    """Register L{ActionHandler}s."""

    def __init__(self):
        self._handlers = {}

    def get(self, action, context=None, person=None, uuid=None):
        """Return the L{ActionHandler} for the given action."""
        handler = self._handlers[action]
        return handler(context=context, person=person, uuid=uuid)

    def add(self, handler_class):
        """Register the given L{ActionHandler}."""

        # This is needed in order for ActionPage to be able to access
        # the schema attribute for parameter validation.
        protect_names(handler_class, ["schema"], get_permission=PUBLIC)
        if handler_class.permission is not None:
            permission = "landscape.%s" % handler_class.permission
        else:
            permission = PUBLIC
        protect_names(handler_class, ["handle"], get_permission=permission)

        action = lower_class(handler_class, suffix="ActionHandler")
        self._handlers[action] = handler_class

    def reset(self):
        """Reset the registered action handlers."""
        self._handlers.clear()

    def scan(self, modules):
        """Scan the given modules and register L{ActionHandler}s.

        @param modules: A list of modules to scan.
        """
        scanner = Scanner(registry=self)

        for module in modules:
            scanner.scan(module, categories=["action"], ignore=[".tests"])


def get_action_handler(action, context=None, person=None, uuid=None):
    """Return the L{ActionHandler} for the given action."""
    # XXX We should use the regular Zope registry with queryMultiAdapter
    registry = getUtility(IActionRegistry)
    return registry.get(action, context=context, person=person, uuid=uuid)
