# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from future import standard_library

standard_library.install_aliases()
import csv
from io import StringIO

from zope.security import proxy

from canonical.lib.timestamp import format_datetime

from canonical.landscape.model.activity.parent import ActivityParent


__all__ = ["get_csv"]

__clearlist__ = ["get_csv"]


def get_csv(activities):
    io = StringIO()
    fields = [
        "id",
        "type",
        "summary",
        "creation_time",
        "account_id",
        "parent_id",
        "creator",
        "computer_id",
        "access_group",
    ]
    writer = csv.DictWriter(io, fields)
    writer.writeheader()
    for activity in activities:
        email = activity.creator.email if activity.creator else None

        if activity.access_context == activity.account.access_context:
            access_group = None
        else:
            access_group = activity.access_context.name

        if hasattr(activity.info, "computer"):
            computer_id = activity.info.computer.id
        else:
            computer_id = None

        if proxy.isinstance(activity, ActivityParent):
            parent_id = None
        else:
            parent_id = activity.parent_id

        row = {
            "id": activity.id,
            "type": activity.info.__class__.__name__,
            "summary": activity.info.get_summary(),
            "creation_time": format_datetime(activity.creation_time),
            "account_id": activity.account_id,
            "parent_id": parent_id,
            "creator": email,
            "computer_id": computer_id,
            "access_group": access_group,
        }
        writer.writerow(row)
    return io.getvalue()
