# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from twisted.internet.defer import inlineCallbacks, returnValue

from storm.twisted.transact import transact

from canonical.amqp.job.runner import job, JobRunner

from canonical.landscape.model.main.account import get_account_by_id
from canonical.landscape.model.activity.parent import get_parent_activity


@job
class ActivityUpdateParentJobRunner(JobRunner):
    """Update the progress and status of a parent activity."""

    @inlineCallbacks
    def run(self, account_id, activity_id):
        yield self._update_activity(account_id, activity_id)
        returnValue((None, None))

    @transact
    def _update_activity(self, account_id, activity_id):
        account = get_account_by_id(account_id)
        activity = get_parent_activity(account, activity_id)
        # Access private APIs of ActivityParent here because this job is
        # essentially an asynchronous implementation of the ActivityParent
        # internals and can be essentially considered part of the class.
        activity._update_after_child_progress_change()
        activity._update_after_child_status_change()
