# Copyright 2005-2022 Canonical Limited.  All rights reserved.

from canonical.landscape.environment import get_config_name

from canonical.landscape.model.activity.activity import (
    register_activity_info_type,
    activity_info_types,
)
from canonical.landscape.model.activity.parent import (
    register_activity_parent_info_type,
    activity_parent_info_types,
)

from canonical.landscape.model.activity.resynchronize import ResynchronizeRequest
from canonical.landscape.model.activity.snap import (
    HoldSnaps,
    InstallSnaps,
    RefreshSnaps,
    RemoveSnaps,
    UnholdSnaps,
)

from canonical.landscape.model.activity.group import ActivityGroup

from canonical.landscape.model.users.activities import (
    CreateUserRequest,
    EditUserRequest,
    DeleteUserRequest,
    CreateGroupRequest,
    AddGroupMemberRequest,
    RemoveGroupMemberRequest,
    LockUserRequest,
    UnlockUserRequest,
)

from canonical.landscape.model.package.activities import (
    ChangePackagesRequest,
    UpgradeAllPackagesRequest,
    ReleaseUpgradeRequest,
    ChangePackageProfilesRequest,
    ChangeUpgradeProfilesRequest,
)

from canonical.landscape.model.repository.activities import (
    ChangeRepositoryProfilesRequest,
    SyncPocketRequest,
)

from canonical.landscape.model.activity.activities import (
    ExecuteScriptRequest,
    SignalProcessRequest,
)

from canonical.landscape.model.activity.shutdown import RestartRequest, ShutdownRequest

from canonical.landscape.model.computer.activities import (
    DeleteChildComputerActivity,
    StartChildComputerActivity,
    StopChildComputerActivity,
)


def register_activity_info_types():
    """Register all the ActivityParentInfo and ActivityInfo types."""
    # Check if activities were already registered, needed for tests that might
    # call this code more than once
    if activity_info_types or activity_parent_info_types:
        return

    # System activities
    # 1 was used for MultiOperation but is unused now
    # 2 was used for ComputerOperation but is unused now
    # 3 was used for ResynchronizeNotice but is unused now
    register_activity_info_type(4, ResynchronizeRequest)
    register_activity_parent_info_type(6, ActivityGroup)

    # User activities (100-199)
    register_activity_info_type(100, CreateUserRequest)
    register_activity_info_type(101, EditUserRequest)
    register_activity_info_type(102, DeleteUserRequest)
    register_activity_info_type(103, CreateGroupRequest)
    # 104 is reserved for DeleteGroupRequest
    register_activity_info_type(105, AddGroupMemberRequest)
    register_activity_info_type(106, RemoveGroupMemberRequest)
    register_activity_info_type(107, LockUserRequest)
    register_activity_info_type(108, UnlockUserRequest)
    # 109 was used for GenericUser but is unused now
    # 110 is reserved for EditGroupRequest
    # 111 was used for UserActivityGroup but is unused now

    # Package activities (200-299)
    # 200 is unused
    register_activity_info_type(201, ChangePackagesRequest)
    register_activity_info_type(204, UpgradeAllPackagesRequest)
    register_activity_info_type(207, ReleaseUpgradeRequest)
    # 208 , 209  and 210 have been removed
    # register_activity_info_type(208, CreatePackageLockRequest)
    # register_activity_info_type(209, RemovePackageLockRequest)
    # register_activity_info_type(210, ChangePackageLocksRequest)
    register_activity_info_type(211, ChangePackageProfilesRequest)
    register_activity_info_type(212, ChangeRepositoryProfilesRequest)
    # 213 was used for ChangePackageHoldsRequest but is unused now
    register_activity_info_type(214, ChangeUpgradeProfilesRequest)
    # 215 was used for OpenStackChangePackagesRequest

    # Active process activities (300-399)
    register_activity_info_type(300, SignalProcessRequest)

    # 400 was used for TextMessageNotice

    # Script activities (500-599)
    register_activity_info_type(500, ExecuteScriptRequest)

    # Power management activities (600-699)
    register_activity_info_type(600, RestartRequest)
    register_activity_info_type(601, ShutdownRequest)
    # 602 was used for HAClusterEnableRequest
    # 603 was used for HAClusterDisableRequest
    # 604 was used for DisableNovaComputeUnitRequest
    # 605 was used for EnableNovaComputeUnitRequest

    # Accept/reject activities (700-799)
    # 700 was used for RejectComputerNotice
    # 701 was used for AcceptComputerRequest

    # Repository management activities (800-899)
    register_activity_info_type(800, SyncPocketRequest)

    # Snap management activities (900-999)
    register_activity_info_type(900, InstallSnaps)
    register_activity_info_type(901, RemoveSnaps)
    register_activity_info_type(902, RefreshSnaps)
    register_activity_info_type(903, HoldSnaps)
    register_activity_info_type(904, UnholdSnaps)
    # Do not reuse 1000-1036 info_types. They are retired audit activities.

    # GRPC child computer management activities (1100-1199)
    register_activity_info_type(1100, StartChildComputerActivity)
    register_activity_info_type(1101, StopChildComputerActivity)
    register_activity_info_type(1102, DeleteChildComputerActivity)

    # Sample activities (8000-max(int))
    if get_config_name() in ("default", "selenium"):
        from canonical.landscape.model.activity.testing import (
            StubInfo,
            StubInfoLeaf,
            StubRequest,
            StoredStubRequest,
            StubRevertableRequest,
            StubReappliableRequest,
            StubExpandableRequest,
            StubChildInfo,
        )

        register_activity_parent_info_type(9990, StubInfo)
        register_activity_info_type(9991, StubInfoLeaf)
        register_activity_info_type(9992, StubRequest)
        register_activity_info_type(9993, StoredStubRequest)
        register_activity_info_type(9994, StubRevertableRequest)
        register_activity_info_type(9995, StubReappliableRequest)
        register_activity_info_type(9996, StubExpandableRequest)
        register_activity_info_type(9997, StubChildInfo)

        from canonical.landscape.model.sandbox.activities import SingleInfo, MultiInfo

        register_activity_info_type(10001, SingleInfo)
        register_activity_parent_info_type(10002, MultiInfo)

        from canonical.landscape.model.activity.tests.test_snap import FrobnicateSnaps

        register_activity_info_type(10003, FrobnicateSnaps)
