# Copyright 2005-2022 Canonical Limited. All rights reserved.

from canonical.security.protect import requires, requires_advisor

from canonical.landscape.model.activity.computer import ComputerRequest

__all__ = ["RestartRequest", "ShutdownRequest"]

__clearlist__ = ["RestartRequest", "ShutdownRequest"]

__requires_prefix__ = "landscape."


@requires_advisor
class RestartRequest(ComputerRequest):
    """Restart a computer."""

    @requires("ViewActivity")
    def get_summary(self):
        return "Restart computer"

    def _started(self):
        """Send a restart message."""
        message_store = self.computer.get_message_store()
        message_store.add(
            {"type": "shutdown", "reboot": True, "operation-id": self.activity.id}
        )


@requires_advisor
class ShutdownRequest(ComputerRequest):
    """Shutdown a computer."""

    @requires("ViewActivity")
    def get_summary(self):
        return "Shutdown computer"

    def _started(self):
        """Send a C{shutdown} message."""
        message_store = self.computer.get_message_store()
        message_store.add(
            {"type": "shutdown", "reboot": False, "operation-id": self.activity.id}
        )
