# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import object
from storm.locals import Unicode

from zope.interface import implementer


from canonical.landscape.model.activity.activity import ActivityInfo
from canonical.landscape.model.activity.parent import ActivityParentInfo
from canonical.landscape.model.activity.interfaces import (
    IRevertableRequest,
    IReappliableRequest,
    IExpandableRequest,
)
from canonical.landscape.model.activity.computer import ComputerRequest
from canonical.landscape.model.entity.data import AccountEntityData
from canonical.landscape.model.entity.helper import get_account_entity_type


class StubEntity(object):
    """A stub account entity not saved in the db."""

    _name_count = 0

    @classmethod
    def name(cls):
        """Generate a deterministic unique name for the entity."""
        cls._name_count += 1
        return "StubEntity-{}".format(cls._name_count)

    @classmethod
    def get_entity_type(cls):
        return get_account_entity_type(cls)


class StubInfoLeaf(ActivityInfo):

    _summary = "Stub info!"
    name = "Stub Info"

    def __init__(self, activity, summary=None):
        super(StubInfoLeaf, self).__init__(activity)
        if summary is not None:
            self._summary = summary

        # Link the child activity to a fake entity
        account = activity.account
        entity_type = StubEntity.get_entity_type()
        entity_name = StubEntity.name()
        entity_data = AccountEntityData(account, entity_type, entity_name)
        activity.entity_data = entity_data

    def get_summary(self):
        return self._summary


class StubInfo(ActivityParentInfo):

    id = None
    _summary = "Stub info!"
    name = "Stub Info"

    def __init__(self, activity, summary=None):
        super(StubInfo, self).__init__(activity)
        if summary is not None:
            self._summary = summary

    def get_summary(self):
        return self._summary


class StubChildInfo(ActivityInfo):
    """An ActivityChild linked to an entity.

    XXX We should eventually replace all StubInfoLeaf with this, since
    activities should always have related entities.
    """

    def get_summary(self):
        return "Stub child info"


class StubRequest(ComputerRequest):
    def get_summary(self):
        return "Stub request!"


class StoredStubRequest(ComputerRequest):

    __storm_table__ = "stored_stub_request"

    summary = Unicode("message")

    def __init__(self, activity, computer, summary=None):
        self.summary = summary or "Stub request!"
        # Call the base class constructor last, so that our own custom
        # attributes are fully initialized, because Storm could end up
        # causing a flush mid-initialization.
        super(StoredStubRequest, self).__init__(activity, computer)

    def get_summary(self):
        return self.summary


@implementer(IRevertableRequest)
class StubRevertableRequest(StubRequest):
    def revert(self, parent):
        super(StubRevertableRequest, self).revert(parent)
        return parent.add(StubRevertableRequest, computer=self.computer)


@implementer(IReappliableRequest)
class StubReappliableRequest(StoredStubRequest):

    reapply_arguments = {}


@implementer(IExpandableRequest)
class StubExpandableRequest(StoredStubRequest):
    def has_expanded_content(self):
        return True
