# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import object
from zope.security import proxy

from canonical.landscape.environment import get_config_name

from canonical.landscape.model.configuration import is_standalone
from canonical.landscape.model.alert.rule import (
    register_rule_info_type,
    unregister_rule_info_types,
)
from canonical.landscape.model.alert.computer import ComputerRuleInfo
from canonical.landscape.model.account.alerts import (
    PendingComputersAlert,
    StandaloneOverflowAlert,
    StandaloneSystemEmailAlert,
    LicenseExpiryAlert,
    StandaloneScriptAlert,
)
from canonical.landscape.model.computer.alerts import (
    ComputerOfflineAlert,
    ComputerRebootAlert,
    ComputerDuplicateAlert,
)
from canonical.landscape.model.package.alerts import (
    EsmDisabledAlert,
    PackageUpgradesAlert,
    SecurityUpgradesAlert,
    PackageProfilesAlert,
    PackageReporterAlert,
)
from canonical.landscape.model.activity.alerts import UnapprovedActivitiesAlert
from canonical.landscape.model.billing.alerts import FailedBillingAlert


class AlertRulePolicy(object):
    def create_rules_for_account(self, account):

        # Account-based rules.
        account.create_rule(PendingComputersAlert)
        account.create_rule(LicenseExpiryAlert)

        if is_standalone():
            account.create_rule(StandaloneOverflowAlert)
            account.create_rule(StandaloneScriptAlert)
            account.create_rule(StandaloneSystemEmailAlert)
        else:
            if account.is_self_service:
                account.create_rule(FailedBillingAlert)

        # Computer-based rules.
        rule = account.create_rule(PackageUpgradesAlert)
        rule.enable_for_all_computers()
        rule = account.create_rule(PackageProfilesAlert)
        rule.enable_for_all_computers()
        rule = account.create_rule(SecurityUpgradesAlert)
        rule.enable_for_all_computers()
        rule = account.create_rule(PackageReporterAlert)
        rule.enable_for_all_computers()
        rule = account.create_rule(EsmDisabledAlert)
        rule.enable_for_all_computers()
        rule = account.create_rule(UnapprovedActivitiesAlert)
        rule.enable_for_all_computers()
        rule = account.create_rule(ComputerOfflineAlert)
        rule.enable_for_all_computers()
        rule = account.create_rule(ComputerRebootAlert)
        rule.enable_for_all_computers()
        rule = account.create_rule(ComputerDuplicateAlert)
        rule.enable_for_all_computers()

    def create_rules_for_computer(self, computer):
        if computer.get_tags():
            raise RuntimeError("Implement support for tags here!")
        for rule in computer.account.get_rules():
            if proxy.isinstance(rule.info, ComputerRuleInfo) and rule.all_computers:
                rule.add_computers_with_ids([computer.id])

    def drop_rules(self):
        """Unregister all the L{RuleInfo} types, useful for tests."""
        unregister_rule_info_types()


def register_rule_info_types():
    """Register the L{RuleInfo} types known by Landscape."""

    if get_config_name() in ("default", "selenium"):
        from canonical.landscape.testing.alerts import (
            SampleAccountAlert,
            SampleStoredAccountAlert,
            SampleComputerAlert,
            SampleStoredComputerAlert,
        )

        # Sample rules for testing purposes (0-99) -->
        register_rule_info_type(0, SampleAccountAlert)
        register_rule_info_type(1, SampleStoredAccountAlert)
        register_rule_info_type(2, SampleComputerAlert)
        register_rule_info_type(3, SampleStoredComputerAlert)

    # Package management rules (100-199)
    register_rule_info_type(100, PackageUpgradesAlert)
    register_rule_info_type(101, SecurityUpgradesAlert)
    register_rule_info_type(102, PackageProfilesAlert)
    register_rule_info_type(103, PackageReporterAlert)
    register_rule_info_type(104, EsmDisabledAlert)

    # Account management rules (200-299)
    register_rule_info_type(200, PendingComputersAlert)
    register_rule_info_type(201, StandaloneOverflowAlert)
    register_rule_info_type(202, LicenseExpiryAlert)
    # 203 was the removed PendingJujuModelsAlert
    register_rule_info_type(204, StandaloneSystemEmailAlert)
    register_rule_info_type(205, FailedBillingAlert)

    # Activity rules (300-399)
    register_rule_info_type(300, UnapprovedActivitiesAlert)

    # Monitoring rules (400-499)
    register_rule_info_type(400, ComputerOfflineAlert)
    register_rule_info_type(401, ComputerRebootAlert)
    register_rule_info_type(402, ComputerDuplicateAlert)

    # Standalone rules (500-599)
    register_rule_info_type(500, StandaloneScriptAlert)
