# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.component import getUtility

from canonical.event.subscriber import subscriber

from canonical.amqp.message.interfaces import IDispatcher
from canonical.landscape.model.events import (
    RuleChangedEvent,
    AccountRulesChangedEvent,
    AddTagsEvent,
    RemoveTagsEvent,
)
from canonical.landscape.model.main.interfaces import IAccount
from canonical.landscape.model.alert.rule import Rule


def notify_account_rules_changed(account):
    dispatcher = getUtility(IDispatcher)
    dispatcher.send_notification(
        "/account/%s" % account.name,
        None,
        "account_rules_changed",
        "landscape.account.%d" % account.id,
    )


@subscriber(RuleChangedEvent)
def rule_changed_subscriber(event):
    notify_account_rules_changed(event.object.account)


@subscriber(IAccount, AccountRulesChangedEvent)
def account_rules_changed_subscriber(account, event):
    notify_account_rules_changed(account)


@subscriber(IAccount, AddTagsEvent)
def add_rule_states(account, event):
    """Event handler is invoked when L{Tag}s are added to L{Computer}s."""
    account.computer_group.synchronize_with_added_tags(
        event.tag_ids, event.computer_ids, Rule
    )


@subscriber(IAccount, RemoveTagsEvent)
def remove_rule_states(account, event):
    """Event handler is invoked when L{Tag}s are removed from L{Computer}s."""
    account.computer_group.synchronize_with_removed_tags(
        event.tag_ids, event.computer_ids, Rule
    )
