# Copyright 2005-2022 Canonical Limited. All rights reserved.

from canonical.security.protect import requires, requires_advisor, PRIVATE

from canonical.landscape.mail.template import load_template

from canonical.landscape.model.billing.payment import Payment
from canonical.landscape.model.configuration import get_root_url
from canonical.landscape.model.alert.account import AccountRuleInfo
from canonical.landscape.model.alert.mail import AlertEmailViewBase


__all__ = ["FailedBillingAlert"]

__clearlist__ = __all__

__requires_prefix__ = "landscape."


@requires_advisor
class FailedBillingAlert(AccountRuleInfo):

    requires("ViewAlertRule", PRIVATE, ["title"])

    title = "Alert when billing fails"

    rule_requires = "landscape.ManageBilling"

    @requires("ViewAlertRule")
    def get_summary(self):
        return "Billing failed"

    def check(self):
        state_data = self.get_state_data()
        if state_data:
            self.state.activate()
        else:
            self.state.deactivate()

    def get_state_data(self):
        from canonical.landscape.model.billing.management import BillingManagement

        management = BillingManagement(self.rule.account)
        failed_payments = management.get_outstanding_payments().find(
            Payment.status.is_in(["failed", "incomplete"])
        )
        return failed_payments.count()

    def get_resolution_url(self):
        if self.state.active:
            return "{}account/{}/billing".format(get_root_url(), self.rule.account.name)


class FailedBillingEmailView(AlertEmailViewBase):

    _content_template = load_template(__file__, "failed-billing-alert.msg")

    def __init__(self, context, person):
        super(FailedBillingEmailView, self).__init__(context, person)
        self.url = context.get_resolution_url()
