# Copyright 2005-2016 Canonical Limited.  All rights reserved.

"""Billing-related collections."""
from storm.expr import Desc

from canonical.landscape.model.entity.collection import AccountEntityCollection
from canonical.landscape.model.billing.payment import Payment


class PaymentCollection(AccountEntityCollection):
    """A collection of Payments."""

    model_class = Payment

    def with_statuses(self, statuses):
        """Filter Payments by status."""
        return self._filter_by(statuses=statuses)

    def with_receipt_uri(self, value):
        """Filter only Payments with or without a receipt URI."""
        return self._filter_by(with_receipt_uri=value)

    def with_num_attempts(self, value):
        """Filter only Payments with the number of attempts."""
        return self._filter_by(num_attempts=value)

    def with_next_action(self, value):
        """Filter only Payments with a next action."""
        return self._filter_by(with_next_action=value)

    def _get_result(
        self,
        store,
        statuses=None,
        with_receipt_uri=None,
        num_attempts=None,
        with_next_action=None,
        **kwargs
    ):
        result = super(PaymentCollection, self)._get_result(store, **kwargs)

        where = []
        if statuses is not None:
            where.append(Payment.status.is_in(statuses))
        if with_receipt_uri is not None:
            if with_receipt_uri:
                where.append(Payment.receipt_uri != None)
            else:
                where.append(Payment.receipt_uri == None)
        if with_next_action is not None:
            if with_next_action:
                where.append(Payment.stripe_next_action != None)
            else:
                where.append(Payment.stripe_next_action == None)
        if num_attempts is not None:
            where.append(Payment.num_attempts >= num_attempts)

        return result.find(*where).order_by(Desc(Payment.period_end_date))
