# Copyright 2017 Canonical Limited.  All rights reserved.

import datetime

from canonical.landscape.model.account.store import get_account_stores
from canonical.landscape.model.billing.collection import PaymentCollection
from canonical.landscape.model.billing.payment import Payment


def get_cutoff(grace=None, today=None):
    """Return a cutoff date for the give "current" date and grace period."""
    if grace is None:
        grace = 0
    else:
        grace = max(0, grace)
    if today is None:
        today = datetime.date.today()
    return today - datetime.timedelta(days=grace)


def iter_past_due_account_ids(account=None, cutoff=None):
    """Yield the ID of each past-due account."""
    if account is None:
        stores = get_account_stores()
    else:
        stores = [(account.id, account.store)]
    for _, store in stores:
        for payment in _get_past_due_payments(store, cutoff):
            yield payment.account_id


def _get_past_due_payments(store, cutoff=None):
    if cutoff is None:
        cutoff = get_cutoff()
    if isinstance(cutoff, datetime.date):
        cutoff = datetime.datetime.combine(cutoff, datetime.time())

    payments = PaymentCollection(store, account=None, statuses=["failed"])
    return payments.find().find(Payment.first_failure < cutoff)
