# Copyright 2005-2016 Canonical Limited.  All rights reserved.

"""Helper functions around receipts for payments."""

from zope.component import getUtility

from canonical.lib.timestamp import format_date
from canonical.landscape.mail.interfaces import ILandscapeMailer
from canonical.landscape.mail.mail import format_address
from canonical.landscape.model.access.role import get_persons_with_account_permission


SUBJECT = "Landscape SAAS receipt from Canonical"

BODY_TEMPLATE = """
Attached is a receipt for Landscape SAAS usage.

Account:         {account_title} ({account_name})
Billing period:  {period_start} - {period_end}
"""


def email_pdf_receipt(payment, pdf_filename):
    """
    Email a PDF receipt for a payment to all billing managers in the account.
    """
    account = payment.account
    persons = get_persons_with_account_permission(account, "ManageBilling")
    if not persons:
        return
    recipients = [format_address(person.name, person.email) for person in persons]
    context = {
        "account_title": account.title,
        "account_name": account.name,
        "period_start": format_date(payment.period_start_date),
        "period_end": format_date(payment.period_end_date),
    }
    body = BODY_TEMPLATE.format(**context)
    getUtility(ILandscapeMailer).send(
        recipients, SUBJECT, body, attachments=[(pdf_filename, "application/pdf")]
    )
