# Copyright 2005-2016 Canonical Limited.  All rights reserved.

"""VAT percentages applied per country."""

from storm.locals import Storm, Int, AutoReload, Unicode, Float
from storm.expr import Update
from storm.databases.postgres import Returning

from canonical.landscape.model.main.store import get_main_store


class VATRate(Storm):
    """VAT percentage applied in a country.

    @param country_code: the Country code, in ISO 3166-1 2-letter format.
    @param rate: the VAT percentage.
    """

    __storm_table__ = "vat_rate"

    id = Int(primary=True, allow_none=False, default=AutoReload)
    country_code = Unicode(allow_none=False)
    rate = Float(allow_none=False)

    def __init__(self, country_code, rate):
        self.country_code = country_code.upper()
        self.rate = rate


def add_vat_rate(country_code, rate):
    """Add a VAT rate for a country."""
    store = get_main_store()
    return store.add(VATRate(country_code, rate))


def get_country_vat_rate(country_code):
    """Return the VAT rate for a country, or None if not present."""
    store = get_main_store()
    return store.find(VATRate.rate, VATRate.country_code == country_code).one()


def update_country_vat_rate(country_code, rate):
    """Update the rate for a country.

    @return: a boolean indicating whether the country was found and updated.
    """
    store = get_main_store()
    update = Update({VATRate.rate: rate}, where=(VATRate.country_code == country_code))
    result = store.execute(Returning(update, VATRate.id))
    return bool(result.rowcount)


def get_country_vat_rates():
    """Return a dict mapping country codes to VAT rates."""
    store = get_main_store()
    return dict(store.find((VATRate.country_code, VATRate.rate)))
