# Copyright 2005-2016 Canonical Limited.  All rights reserved.

from canonical.landscape.model.account.computergroup import (
    ComputerGroup,
    ComputerGroupItem,
)
from canonical.landscape.model.account.customgraph import CustomGraph
from canonical.landscape.model.alert.rule import Rule
from canonical.landscape.model.package.profile import PackageProfile
from canonical.landscape.model.package.autoupgrade import UpgradeProfile
from canonical.landscape.model.computer.removal import RemovalProfile
from canonical.landscape.model.repository.profile import RepositoryProfile


def update_computer_groups_access_context(account, computer_ids, access_context_id):
    """Update all computer-related entities after access context change.

    This should be called after computers have been moved to a new access
    context to update group membership for for related entities such as
    profiles, and trigger necessary updates.
    """
    store = account.store

    # Find all computer groups linked to the computers that have been
    # updated.
    computer_groups = store.find(
        ComputerGroup,
        ComputerGroupItem.computer_group_id == ComputerGroup.id,
        ComputerGroupItem.computer_id.is_in(computer_ids),
    )
    info_objects = {computer_group.info for computer_group in computer_groups}

    # Find all computer groups that have entities linked to it and that are
    # in the same access context.
    entity_types = (
        Rule,
        CustomGraph,
        PackageProfile,
        UpgradeProfile,
        RemovalProfile,
        RepositoryProfile,
    )
    for entity_type in entity_types:
        result = store.find(
            ComputerGroup,
            ComputerGroup.id == entity_type.computer_group_id,
            entity_type.access_context_id == access_context_id,
        )
        info_objects.update(info_type.info for info_type in result)

    for info in info_objects:
        info.update_access_context(computer_ids, access_context_id)
