# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.landscape.model.action.handler import ActionHandler, action
from canonical.landscape.model.computer.management import ComputerManagement


@action
class DeleteChildComputersActionHandler(ActionHandler):
    permission = "RemoveComputer"

    def handle(self, computer_ids=None):
        if computer_ids is None:
            computer_ids = list(self.context.get_selected_computer_ids())
        management = ComputerManagement(self.context, self.person)
        activity_parent = management.delete_child_computers(self.person, computer_ids)

        return activity_parent.get_state()


@action
class RemoveComputersActionHandler(ActionHandler):
    permission = "RemoveComputer"

    def handle(self, computer_ids=None):
        selection = self.context.selection
        if computer_ids is None:
            computer_ids = list(selection.get_selected_computer_ids())
        self.send_job(
            account_id=self.context.account.id,
            person_id=self.person.id,
            computer_ids=computer_ids,
        )


@action
class StartChildComputersActionHandler(ActionHandler):
    permission = "RestartComputer"

    def handle(self, computer_ids=None):
        if computer_ids is None:
            computer_ids = list(self.context.get_selected_computer_ids())
        management = ComputerManagement(self.context, self.person)
        activity_parent = management.start_child_computers(self.person, computer_ids)

        return activity_parent.get_state()


@action
class StopChildComputersActionHandler(ActionHandler):
    permission = "ShutdownComputer"

    def handle(self, computer_ids=None):
        if computer_ids is None:
            computer_ids = list(self.context.get_selected_computer_ids())
        management = ComputerManagement(self.context, self.person)
        activity_parent = management.stop_child_computers(self.person, computer_ids)

        return activity_parent.get_state()
