# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import object
from zope.interface import implementer
from zope.security import proxy

from canonical.landscape.model.computer.interfaces import IComputerAware
from canonical.landscape.model.main.store import get_main_store


__all__ = ["ComputerHelper"]


@implementer(IComputerAware)
class ComputerHelper(object):
    """Helper implements L{IComputerAware} and includes a C{computer} property.

    @param computer: Either a L{Computer} or a L{Computer.id}.
    """

    _computer = None
    computer_id = None

    def __init__(self, computer=None):
        if computer:
            if proxy.isinstance(computer, (int, int)):
                self.computer_id = computer
            else:
                self.computer = computer

    def _get_computer(self):
        store = get_main_store()
        computer_id = self.computer_id
        # A computer is optional, so it may be the case that we return None
        # here.
        if (computer_id is not None and not self._computer) or (
            self._computer and self._computer.id != computer_id
        ):
            from canonical.landscape.model.main.computer import Computer

            self._computer = store.get(Computer, computer_id)
        return self._computer

    def _set_computer(self, computer):
        if computer is None:
            self.computer_id = None
        else:
            self.computer_id = computer.id
        self._computer = computer

    computer = property(_get_computer, _set_computer)

    @property
    def store(self):
        return proxy.removeSecurityProxy(self.computer).store
