# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.interface import Interface
from zope.schema import Object, Int, TextLine

from canonical.lib.validators import validator

from canonical.landscape.model.main.interfaces import IComputer


__all__ = ["IComputerAware", "IComputerManagement", "IRemovalProfile"]


__clearlist__ = __all__


class IComputerAware(Interface):

    computer = Object(
        title="Computer",
        description="The computer that's associated with this resource.",
        required=True,
        readonly=False,
        schema=IComputer,
    )


class IComputerManagement(Interface):
    def restart(deliver_after=None):
        """Restart selected L{Computer}s.

        @param deliver_after: Optionally, the earliest time to allow delivery
            of this request to selected L{Computer}s.
        """

    def shutdown(deliver_after=None):
        """Shutdown selected L{Computer}s.

        @param deliver_after: Optionally, the earliest time to allow delivery
            of this request to selected L{Computer}s.
        """


class IRemovalProfile(Interface):

    title = TextLine(
        title="Title", description=("Title of the removal profile."), required=True
    )

    days_without_exchange = Int(
        title="Days without exchange",
        description=(
            "Number of days a computer is allowed without contacting "
            "Landscape before it is automatically removed. Number must be "
            "greater than or equal to 1."
        ),
        required=True,
        constraint=validator(
            lambda days: int(days) > 0,
            "Days without exchange must be a number greater than or equal " "to 1.",
        ),
    )
