# Copyright 2005-2016 Canonical Limited.  All rights reserved.

from canonical.landscape.model.entity.collection import AccountEntityCollection
from canonical.landscape.model.entity.data import remove_entity_data_by_ids
from canonical.landscape.model.activity.collection import ActivityChildCollection
from canonical.landscape.model.activity.parent import (
    get_parent_ids_for_entities,
    update_parent_activities_after_changed_children,
)


def remove_entities(account, entity_class, entity_ids):
    """Remove entities of a specified type by IDs.

    It takes care of removing related AccountEntityData and Activities, and
    updating parents of removed activities (or removing them if they're left
    without children).
    """
    collection = AccountEntityCollection(account.store, account=account, ids=entity_ids)
    # XXX inject the class to search for since we're using the generic
    # collection. Eventually methods like this might be grouped in a management
    # class that deals with a specific entity class, and use its specific
    # collection.
    collection.model_class = entity_class

    # Materialize IDs for related AccountEntityData before removing the
    # objects.
    data_ids = set(collection.find().values(entity_class.data_id))

    # Remove related activities and update parents
    parent_activity_ids = set(
        get_parent_ids_for_entities(account.store, entity_class, entity_ids)
    )
    activity_collection = ActivityChildCollection(
        account.store, account=account, entity_class=entity_class, entity_ids=entity_ids
    )
    activity_collection.remove()
    update_parent_activities_after_changed_children(account, parent_activity_ids)

    # Remove entities and related data
    collection.remove()
    remove_entity_data_by_ids(account.store, data_ids)
