# Copyright 2005-2016 Canonical Limited.  All rights reserved.

import storm

from fixtures import Fixture

from zope.component import getUtility

from canonical.security.interfaces import IRoleRegistry

from canonical.landscape.model.entity.helper import (
    register_account_entity_type,
    register_account_entity_permissions,
    unregister_account_entity_type,
    unregister_account_entity_permissions,
    AccountEntity,
)


class StubEntity1(AccountEntity):

    __storm_table__ = "stub_entity_1"


class StubEntity2(AccountEntity):

    __storm_table__ = "stub_entity_2"


class StubEntityFixture(Fixture):

    entity_classes = (StubEntity1, StubEntity2)

    def __init__(self, store):
        self.store = store
        self.role_registry = getUtility(IRoleRegistry)

    def setUp(self):
        super(StubEntityFixture, self).setUp()
        owner = self.role_registry.get("Owner")

        for n, entity_class in enumerate(self.entity_classes, 1):
            self.store.execute(
                "CREATE TABLE {} (id SERIAL, data_id INT)".format(
                    entity_class.__storm_table__
                )
            )
            index = 1000 + n
            register_account_entity_type(index, entity_class)
            register_account_entity_permissions(index, "view", ["ViewStub{}".format(n)])
            register_account_entity_permissions(index, "edit", ["EditStub{}".format(n)])

            self.role_registry.grant(owner, "landscape.ViewStub{}".format(n))
            self.role_registry.grant(owner, "landscape.EditStub{}".format(n))

        self.store.commit()

    def cleanUp(self):
        owner = self.role_registry.get("Owner")
        for n, entity_class in enumerate(self.entity_classes, 1):

            self.store.execute("DROP TABLE {}".format(entity_class.__storm_table__))

            unregister_account_entity_type(entity_class)
            unregister_account_entity_permissions(1000 + n, "view")
            unregister_account_entity_permissions(1000 + n, "edit")

            self.role_registry.revoke(owner, "landscape.ViewStub{}".format(n))
            self.role_registry.revoke(owner, "landscape.EditStub{}".format(n))

        self.store.commit()

        super(StubEntityFixture, self).cleanUp()
