# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import object
from zope.component.interfaces import ObjectEvent


class ProcessStarting(object):
    """Sent upon process startup."""


class ResynchronizeEvent(object):
    """Representation of a computer that is being resynchronized.

    This object is to be broadcast with the Zope Component Event system.

    @ivar computer: The L{Computer} being resynchronized.
    @ivar scopes: The scope of the resyncronisation.

    """

    def __init__(self, computer, scopes=None):
        self.computer = computer
        self.scopes = scopes

    def is_in_scope(self, scope):
        return self.scopes is None or scope in self.scopes


class MaintenanceEvent(ObjectEvent):
    """Sent to indicate that than object should perform maintenance."""


class GlobalMaintenanceEvent(object):
    """Sent to indicate that Landscape should perform maintenance."""


class SchemaMaintenanceEvent(object):
    """Sent to indicate that Landscape should do schema maintenance."""


class AddTagsEvent(ObjectEvent):
    """Broadcast when tags are added to computers."""

    def __init__(self, account, tag_ids, computer_ids):
        super(AddTagsEvent, self).__init__(account)
        self.tag_ids = tag_ids
        self.computer_ids = computer_ids


class RemoveTagsEvent(ObjectEvent):
    """Broadcast when tags are removed from computers."""

    def __init__(self, account, tag_ids, computer_ids):
        super(RemoveTagsEvent, self).__init__(account)
        self.tag_ids = tag_ids
        self.computer_ids = computer_ids


class AddComputerEvent(ObjectEvent):
    """Broadcast when computer added to account."""

    def __init__(self, account, computer):
        super(AddComputerEvent, self).__init__(account)
        self.computer = computer


class AccountRulesChangedEvent(ObjectEvent):
    """
    Broadcast when something happens to an account that might have triggered
    changes to alert rules.
    """


class NewUserEvent(ObjectEvent):
    """Broadcast when new user is created."""


class RuleChangedEvent(ObjectEvent):
    """Broadcast when an alert rule is changed."""
