# Copyright 2005-2022 Canonical Limited. All rights reserved.

from storm.locals import Unicode, DateTime, Int, AutoReload, Store, Update, Select
from storm.expr import Column

from canonical.lib.timestamp import utcnow

from canonical.security.protect import requires, requires_advisor, PRIVATE

from canonical.landscape.model.script.script import Length

__all__ = ["Attachment"]


__requires_prefix__ = "landscape."


@requires_advisor
class Attachment(object):
    """A file attachment for an article in the knowledge base."""

    __storm_table__ = "attachment"

    id = Int(primary=True, default=AutoReload)
    filename = Unicode(allow_none=False)
    creation_time = DateTime(allow_none=False)
    article_id = Int(allow_none=False)

    requires("ViewKnowledgeBase", PRIVATE, ["id", "creation_time", "article"])

    requires("ViewKnowledgeBase", "EditKnowledgeBase", ["filename"])

    def __init__(self, filename):
        self.filename = filename
        self.creation_time = utcnow()

    @requires("ViewKnowledgeBase")
    def get_data(self):
        store = Store.of(self)
        result = store.execute(
            Select(Column("data"), Attachment.id == self.id, Attachment)
        )

        return result.get_one()[0].tobytes()

    @requires("EditKnowledgeBase")
    def set_data(self, data):
        store = Store.of(self)
        store.execute(Update({"data": data}, Attachment.id == self.id, Attachment))

    @requires("ViewKnowledgeBase")
    def get_size(self):
        store = Store.of(self)
        result = store.execute(
            Select(Length([Column("data")]), Attachment.id == self.id, Attachment)
        )
        return result.get_one()[0]
