# Copyright 2005-2022 Canonical Limited. All rights reserved.

from zope.interface import implementer

from storm.locals import Unicode, Int, AutoReload

from canonical.security.protect import requires, requires_advisor, PRIVATE

from canonical.landscape.model.knowledge.store import get_knowledge_store
from canonical.landscape.model.knowledge.interfaces import ICategory


__all__ = ["Category", "ArticleCategoryLink", "get_categories", "get_category_by_id"]

__clearlist__ = ["Category"]


__requires_prefix__ = "landscape."


@requires_advisor
@implementer(ICategory)
class Category(object):
    """A category for use by articles in the knowledge base."""

    __storm_table__ = "category"

    requires("ViewKnowledgeBase", PRIVATE, ["id"])
    requires("ViewKnowledgeBase", "EditKnowledgeBase", ["title"])

    id = Int(primary=True, allow_none=False, default=AutoReload)
    title = Unicode(allow_none=False)

    def __init__(self, title):
        self.title = title


class ArticleCategoryLink(object):
    """Link between a category and an article."""

    __storm_table__ = "article_category"
    __storm_primary__ = "category_id", "article_id"

    category_id = Int(allow_none=False)
    article_id = Int(allow_none=False)


def get_categories():
    store = get_knowledge_store()
    result = store.find(Category)
    result.order_by(Category.title)
    return result


def get_category_by_id(category_id):
    store = get_knowledge_store()
    return store.get(Category, category_id)
