# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.interface import Interface
from zope.schema import TextLine, Text, Set, Choice, Bool


__all__ = ["IKnowledgeBase", "IArticle", "ICategory"]

__clearlist__ = __all__


class IKnowledgeBase(Interface):
    """A marker interface for the knowledge base landing page."""


class IArticle(Interface):
    """The interface used to build the form for editing articles."""

    title = TextLine(title="Title", description="Title of the article.", required=True)

    body = Text(title="Body", description="Main content of the article.", required=True)

    published = Bool(
        title="Published",
        description="Whether the article is published to users or not.",
        required=False,
    )

    categories = Set(
        required=False,
        title="Categories",
        description="Categories the article is associated with.",
        value_type=Choice(vocabulary="kb_categories"),
    )


class ICategory(Interface):
    """Interface implemented by a category of articles."""
