# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.landscape.global_maintenance import global_maintenance
from canonical.landscape.model.knowledge.store import get_knowledge_store
from canonical.landscape.model.knowledge.article import Article, ArticleView


@global_maintenance
def maintain_knowledge_base(event):
    """
    Update the times_viewed column of the article table, and clean all rows in
    article_view once handled.
    """
    store = get_knowledge_store()
    result = store.execute(
        "SELECT article_id, COUNT(client_id) FROM (SELECT DISTINCT client_id,"
        "article_id FROM article_view) AS tmp GROUP BY article_id"
    )
    article_views = dict(result.get_all())
    for article in store.find(Article, Article.id.is_in(article_views)):
        article.times_viewed += article_views[article.id]
    store.find(ArticleView).remove()
