# Copyright 2005-2022 Canonical Limited. All rights reserved.

from storm.locals import Int, Bool, DateTime

from canonical.lib.timestamp import utcnow

from canonical.security.protect import requires, requires_advisor, PRIVATE


__all__ = ["ArticleVote"]


__requires_prefix__ = "landscape."


@requires_advisor
class ArticleVote(object):
    """Represent a vote from a person on an article."""

    __storm_table__ = "article_vote"
    __storm_primary__ = "person_id", "article_id"

    requires("VoteKnowledgeBase", PRIVATE, ["helpful"])

    requires(PRIVATE, PRIVATE, ["person_id", "article_id"])

    person_id = Int(allow_none=False)
    article_id = Int(allow_none=False)
    helpful = Bool(allow_none=False)
    vote_time = DateTime(allow_none=False)

    def __init__(self, person, article, helpful):
        self.person_id = person.id
        self.article_id = article.id
        self.helpful = helpful
        self.vote_time = utcnow()
