# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.security.interfaces import Unauthorized

__all__ = [
    "UnknownPersonsError",
    "UnknownAccessContextsError",
    "UnknownAccessContextError",
    "AcceptanceUnauthorized",
]

__clearlist__ = [
    "UnknownPersonsError",
    "UnknownAccessContextsError",
    "UnknownAccessContextError",
    "AcceptanceUnauthorized",
]


class UnknownPersonsError(Exception):
    """Raised when one or more person emails are unknown."""

    def __init__(self, emails, account=None):
        message = "Unknown persons emails"
        if account:
            message += " for account '%s'" % account.name
        message += ": %s" % ", ".join(emails)
        super(UnknownPersonsError, self).__init__(message)
        self.emails = emails
        self.account = account


class UnknownAccessContextsError(Exception):
    """Raised when one or more access context names or titles are unknown."""

    def __init__(self, names=(), titles=(), account=None):
        message = "Unknown access groups"
        if account:
            message += " for account '%s'" % account.name
        message += ": %s" % ", ".join(names + titles)
        super(UnknownAccessContextsError, self).__init__(message)
        self.names = names
        self.titles = titles
        self.account = account


class UnknownAccessContextError(Exception):
    """Raised when an access context name is unknown or not accessible."""

    def __init__(self, name):
        message = "Unknown access group name '%s'" % name
        super(UnknownAccessContextError, self).__init__(message)


class AcceptanceUnauthorized(Unauthorized):
    """Raised when a person doesn't have access to accept pending computers."""
