# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from storm.twisted.transact import transact

from canonical.amqp.job.runner import JobRunner, job
from canonical.landscape.model.main.account import get_account_by_id
from canonical.landscape.model.main.person import get_person_by_id


@job
class GetActiveRulesJobRunner(JobRunner):
    """Get the active rules for an account."""

    def run(self, account_id, person_id):
        """
        @param account_id: The L{Account.id} we refer to.
        @param person_id: The L{Person.id} we refer to.
        """
        return self._get_active_rules(account_id, person_id)

    @transact
    def _get_active_rules(self, account_id, person_id):
        account = get_account_by_id(account_id)
        person = get_person_by_id(person_id)
        result = []
        for rule in account.get_rules(active=True, person=person):
            info = rule.info
            result.append(
                {
                    "title": info.get_summary(),
                    "href": "/account/%s/alert/%d/resolve" % (account.name, rule.id),
                }
            )
        return result, None
