# Copyright 2005-2013 Canonical Limited.  All rights reserved.

import zope.schema
import zope.schema.interfaces
from zope.formlib.textwidgets import TextWidget

from canonical.lib.mail import is_email_address

__all__ = ["IEmailAddress", "InvalidEmailAddress", "EmailAddress"]

__clearlist__ = ["EmailAddress"]


class IEmailAddress(zope.schema.interfaces.ITextLine):
    """A valid email address field from the RFC 2822 specification."""


class InvalidEmailAddress(zope.schema.ValidationError):
    """Invalid email address."""

    def __init__(self, email):
        super(InvalidEmailAddress, self).__init__(
            "'%s' is not a valid e-mail address." % email
        )


class StripTextWidget(TextWidget):
    """
    Used to strip whitespace from form fields
    """

    def _getFormInput(self):
        value = super(StripTextWidget, self)._getFormInput()
        return value.strip()


@zope.interface.implementer(IEmailAddress)
class EmailAddress(zope.schema.TextLine):
    """A valid email address."""

    custom_widget = StripTextWidget

    def constraint(self, value):
        # Email addresses can never contain a newline, or a carriage-return
        return "\n" not in value and "\r" not in value

    def _validate(self, value):
        super(EmailAddress, self)._validate(value)
        if not is_email_address(value):
            raise InvalidEmailAddress(value)
