# Copyright 2005-2022 Canonical Limited. All rights reserved.

from canonical.security.protect import requires, requires_advisor, PRIVATE

from canonical.landscape.model.monitoring.graph import MonitoringGraph, GraphExporter

from canonical.landscape.model.resource.customgraph import (
    CustomGraphDataPoint,
    CustomGraphData,
)


__requires_prefix__ = "landscape."

__all__ = ["CustomGraphGraph", "CustomGraphExporter"]

__clearlist__ = ["CustomGraphGraph", "CustomGraphExporter"]


class CustomGraphGraph(MonitoringGraph):

    monitoring_class = CustomGraphDataPoint
    monitoring_field = CustomGraphDataPoint.value
    computer_id_field = CustomGraphData.computer_id

    def __init__(self, selection, custom_graph, start, stop, large, tzinfo):
        super(CustomGraphGraph, self).__init__(selection, start, stop, large, tzinfo)
        self._custom_graph = custom_graph

    @property
    def title(self):
        return self._custom_graph.title

    @property
    def label(self):
        return self._custom_graph.y_axis_title

    def get_filter(self, ids):
        return [
            CustomGraphData.computer_id.is_in(ids),
            CustomGraphData.id == CustomGraphDataPoint.custom_graph_data_id,
            CustomGraphData.custom_graph_id == self._custom_graph.id,
        ]


@requires_advisor
class CustomGraphExporter(GraphExporter):

    requires("ViewCustomGraph", PRIVATE, ["graph"])

    @property
    def graph(self):
        return self._graph._custom_graph
