from __future__ import division

# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from past.utils import old_div
from decimal import Decimal

from canonical.landscape.model.monitoring.graph import MonitoringGraph, GraphExporter
from canonical.landscape.model.resource.memoryinfo import MemoryInfo


__all__ = ["UsedMemoryGraph", "UsedMemoryDataExporter"]

__clearlist__ = ["UsedMemoryGraph", "UsedMemoryDataExporter"]


class UsedMemoryGraph(MonitoringGraph):

    title = "Used memory"
    label = "Percent"

    monitoring_class = MemoryInfo
    monitoring_field = MemoryInfo.free_memory

    def __init__(self, selection, start, stop, large, tzinfo):
        super(UsedMemoryGraph, self).__init__(selection, start, stop, large, tzinfo)
        self._total_memory = dict(
            (computer.id, computer.total_memory)
            for computer in selection.get_selected()
        )

    def transform_value(self, computer_id, value, raw=False):
        total_memory = self._total_memory[computer_id]
        if not total_memory:
            return 0
        if raw:
            return total_memory - value
        else:
            return float(old_div((total_memory - value), Decimal(total_memory)) * 100)


class UsedMemoryDataExporter(GraphExporter):

    unit = "MiB"
