# Copyright 2005-2022 Canonical Limited. All rights reserved.

from canonical.security.protect import requires, requires_advisor

from canonical.landscape.model.monitoring.graph import MonitoringGraph, GraphExporter
from canonical.landscape.model.resource.network import NetworkTraffic, INBOUND


__all__ = ["NetworkTrafficGraph", "NetworkTrafficExporter"]

__clearlist__ = ["NetworkTrafficGraph", "NetworkTrafficExporter"]


class NetworkTrafficGraph(MonitoringGraph):

    label = "Bits/s"

    monitoring_class = NetworkTraffic

    def __init__(self, selection, interface, direction, start, stop, large, tzinfo):
        super(NetworkTrafficGraph, self).__init__(selection, start, stop, large, tzinfo)
        self._interface = interface
        self._direction = direction

    def get_filter(self, ids):
        return [
            self.monitoring_class.computer_id.is_in(ids),
            self.monitoring_class.interface == self._interface.encode(),
        ]

    @property
    def monitoring_field(self):
        return (
            NetworkTraffic.bytes_in
            if self._direction == INBOUND
            else NetworkTraffic.bytes_out
        )

    @property
    def title(self):
        direction = "Inbound" if self._direction == INBOUND else "Outbound"
        return "{} network traffic for {}".format(direction, self._interface)

    def transform_value(self, computer_id, value, raw=False):
        return (value // 30) * 8


@requires_advisor
class NetworkTrafficExporter(GraphExporter):

    unit = "B"

    @requires("zope.View")
    def get_network_interface(self):
        """Retrieve the interface currently inspected, and the direction."""
        return "%s_%s" % (self._graph._interface, self._graph._direction)
