from __future__ import division

# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from past.utils import old_div
from decimal import Decimal

from canonical.landscape.model.monitoring.graph import MonitoringGraph, GraphExporter
from canonical.landscape.model.resource.memoryinfo import MemoryInfo


__all__ = ["UsedSwapGraph", "UsedSwapDataExporter"]

__clearlist__ = ["UsedSwapGraph", "UsedSwapDataExporter"]


class UsedSwapGraph(MonitoringGraph):

    title = "Used swap"
    label = "Percent"

    monitoring_class = MemoryInfo
    monitoring_field = MemoryInfo.free_swap

    def __init__(self, selection, start, stop, large, tzinfo):
        super(UsedSwapGraph, self).__init__(selection, start, stop, large, tzinfo)
        self._total_swap = dict(
            (computer.id, computer.total_swap) for computer in selection.get_selected()
        )

    def transform_value(self, computer_id, value, raw=False):
        total_swap = self._total_swap[computer_id]
        if not total_swap:
            return 0
        if raw:
            return total_swap - value
        else:
            return float(old_div((total_swap - value), Decimal(total_swap)) * 100)


class UsedSwapDataExporter(GraphExporter):

    unit = "MiB"
