# Copyright 2005-2022 Canonical Limited. All rights reserved.

from canonical.security.protect import requires, requires_advisor, PRIVATE

from canonical.landscape.model.monitoring.graph import MonitoringGraph, GraphExporter
from canonical.landscape.model.resource.temperature import Temperature, ThermalZone


__all__ = ["TemperatureGraph", "TemperatureDataExporter"]

__clearlist__ = ["TemperatureGraph", "TemperatureDataExporter"]


class TemperatureGraph(MonitoringGraph):

    label = "Celsius"

    monitoring_class = Temperature
    monitoring_field = Temperature.temperature
    computer_id_field = ThermalZone.computer_id

    def __init__(self, selection, thermal_zone, start, stop, large, tzinfo):
        super(TemperatureGraph, self).__init__(selection, start, stop, large, tzinfo)
        self._thermal_zone = thermal_zone

    def get_filter(self, ids):
        return [
            self.monitoring_class.thermal_zone_id == ThermalZone.id,
            ThermalZone.name == self._thermal_zone,
            ThermalZone.computer_id.is_in(ids),
        ]

    @property
    def title(self):
        return "Temperatures for %s" % self._thermal_zone


@requires_advisor
class TemperatureDataExporter(GraphExporter):

    requires("landscape.ViewPersonResource", PRIVATE, ["thermal_zone"])

    unit = "\N{DEGREE CELSIUS}"

    @property
    def thermal_zone(self):
        return self._graph._thermal_zone
