# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from datetime import datetime

from storm.twisted.transact import transact

from canonical.amqp.job.runner import job, JobRunner

from canonical.landscape.model.main.account import get_account_by_id
from canonical.landscape.model.activity.parent import get_parent_activity
from canonical.landscape.model.selection.selection import ComputerSelection
from canonical.landscape.model.package.management import PackageManagement


@job
class PopulateChangePackagesActivityJobRunner(JobRunner):
    """
    Continue a package activity created previously, handling another batch of
    computers.
    """

    def run(
        self,
        account_id,
        activity_id,
        person_id,
        computer_changes,
        deliver_after,
        batch_size,
    ):
        return self._populate_activity(
            account_id,
            activity_id,
            person_id,
            computer_changes,
            deliver_after,
            batch_size,
        )

    @transact
    def _populate_activity(
        self,
        account_id,
        activity_id,
        person_id,
        computer_changes,
        deliver_after,
        batch_size,
    ):
        account = get_account_by_id(account_id)
        parent = get_parent_activity(account, activity_id)
        if deliver_after is not None:
            deliver_after = datetime.strptime(deliver_after, "%Y-%m-%dT%H:%M:%SZ")

        selection = ComputerSelection(account)
        selection.select_computers(
            computer_change[0] for computer_change in computer_changes
        )
        execution = PackageManagement(selection)
        parent.alter()
        execution.run_change_packages_batch(
            parent, computer_changes, batch_size=batch_size, deliver_after=deliver_after
        )
        return None, None
