# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from storm.locals import Int, Unicode, DateTime, AutoReload, Reference

from canonical.landscape.model.account.helper import AccountHelper
from canonical.landscape.model.error import DuplicateModelError
from canonical.landscape.model.gpg.key import GPGKey


class DuplicateAPTSourceError(DuplicateModelError):
    """
    Raised when an APT source with the same name already exists in the account.
    """

    model_name = "APT source"


class UnknownAPTSourceError(Exception):
    """Raised when an APT source couldn't be found."""


class APTSource(AccountHelper):

    __storm_table__ = "apt_source"

    id = Int(primary=True, allow_none=False, default=AutoReload)
    account_id = Int(allow_none=False)
    name = Unicode(allow_none=False)
    line = Unicode(allow_none=False)
    creation_time = DateTime(default=AutoReload)
    gpg_key_id = Int()
    access_context_id = Int(allow_none=False)

    gpg_key = Reference(gpg_key_id, GPGKey.id)

    def __init__(self, account, name, line, gpg_key=None, access_context=None):
        super(APTSource, self).__init__(account)
        self.name = name
        self.line = line
        self.gpg_key = gpg_key
        if access_context is None:
            access_context = self.account.access_context
        self.access_context_id = access_context.id

    def _get_access_context(self):
        return self.account.get_access_context(self.access_context_id)

    def _set_access_context(self, access_context):
        self.access_context_id = access_context.id

    access_context = property(_get_access_context, _set_access_context)

    def get_state(self):
        """Return a dict with information about the L{APTSource}."""
        access_context = self.account.get_access_context(self.access_context_id)
        return {
            "id": self.id,
            "access_group": access_context.name,
            "name": self.name,
            "line": self.line,
            "gpg_key": self.gpg_key.get_state() if self.gpg_key else None,
        }

    def remove(self):
        self.account.store.remove(self)
