# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import object
import os

from zope.component import getUtility
from storm.locals import Int, Unicode, AutoReload, DateTime

from canonical.landscape.interfaces import IFileBasedConfiguration
from canonical.landscape.model.account.store import get_account_stores


class Upload(object):
    """A single package upload waiting to be processed.

    @param pocket: The L{Pocket} the upload is targeted to.
    @param changes: The name of the .changes file that was uploaded.
    """

    __storm_table__ = "upload"

    id = Int(primary=True, allow_none=False, default=AutoReload)
    distribution_id = Int(allow_none=False)
    pocket_id = Int(allow_none=False)
    changes = Unicode(allow_none=False)
    creation_time = DateTime(default=AutoReload)

    def __init__(self, pocket, changes):
        # We need to link the distribution explicitly in order to express the
        # constraint UNIQUE(distribution_id, changes)
        self.distribution = pocket.series.distribution
        self.pocket = pocket
        self.changes = changes

    def get_changes_path(self):
        """Return the path to the associated .changes file."""
        config = getUtility(IFileBasedConfiguration)
        repodir = config.get("landscape", "repository-path")
        return os.path.join(
            repodir,
            self.distribution.account.name,
            self.distribution.name,
            "incoming",
            self.changes,
        )

    @property
    def account(self):
        return self.distribution.account


def get_uploads():
    """Get all available L{Upload}s."""
    uploads = []
    for name, store in get_account_stores():
        result = store.find(Upload)
        uploads.extend(result.order_by(Upload.creation_time))
    return uploads


def remove_upload(account, upload_id):
    """Remove the L{Upload} in the specified L{Account}."""
    account.store.find(Upload, Upload.id == upload_id).remove()
