# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from storm.locals import Int, DateTime, Unicode

from canonical.landscape.model.computer.helper import ComputerHelper


__all__ = ["CephUsage", "CephUsageManagement"]


class CephUsage(ComputerHelper):

    __storm_table__ = "ceph_usage"
    __storm_primary__ = "computer_id", "timestamp", "ring_uuid"

    computer_id = Int(allow_none=False)
    timestamp = DateTime(allow_none=False)
    ring_uuid = Unicode(allow_none=False)
    total = Int(allow_none=False)
    available = Int(allow_none=False)
    used = Int(allow_none=False)

    def __init__(self, computer, timestamp, ring_uuid, total, available, used):
        super(CephUsage, self).__init__(computer)
        self.timestamp = timestamp
        self.ring_uuid = ring_uuid
        self.total = total
        self.available = available
        self.used = used


class CephUsageManagement(ComputerHelper):
    """
    A helper class to associate a C{CephUsage} object to a computer.
    """

    def create_ceph_usage(self, timestamp, ring_uuid, total, available, used):
        ceph_usage = CephUsage(
            self.computer, timestamp, ring_uuid, total, available, used
        )
        self.store.add(ceph_usage)
        return ceph_usage

    def get_ceph_usages(self):
        """Return L{CephUsage}s sorted by timestamp."""
        result = self.store.find(CephUsage, CephUsage.computer_id == self.computer.id)
        return result.order_by(CephUsage.timestamp)
