# Copyright 2005-2022 Canonical Limited. All rights reserved.

from zope.interface import implementer

from storm.locals import Int, Float, DateTime

from canonical.security.protect import requires, requires_advisor

from canonical.landscape.model.computer.helper import ComputerHelper
from canonical.landscape.model.resource.interfaces import ICPUUsage


__all__ = ["CPUUsage", "CPUUsageManagement"]


__requires_prefix__ = "landscape."


@requires_advisor
@implementer(ICPUUsage)
class CPUUsage(ComputerHelper):

    __storm_table__ = "cpu_usage"
    __storm_primary__ = "computer_id", "timestamp"

    requires("ViewCPUUsage", "EditCPUUsage", ["timestamp", "cpu_usage"])

    computer_id = Int(allow_none=False)
    timestamp = DateTime(allow_none=False)
    cpu_usage = Float(allow_none=False)

    def __init__(self, computer, timestamp, cpu_usage):
        super(CPUUsage, self).__init__(computer)
        self.timestamp = timestamp
        self.cpu_usage = cpu_usage


@requires_advisor
class CPUUsageManagement(ComputerHelper):
    """
    A helper class to associate a C{CPUUsage} object to a computer.
    """

    @requires("CreateCPUUsage")
    def create_cpu_usage(self, timestamp, cpu_usage):
        cpu_usage = CPUUsage(self.computer, timestamp, cpu_usage)
        self.store.add(cpu_usage)
        return cpu_usage

    @requires("ViewCPUUsage")
    def get_cpu_usage(self, start=None, stop=None):
        """
        Returns an iterable that yields C{(timestamp, cpu_usage)} 2-tuples.
        """
        where = []
        if start is not None:
            where.append(CPUUsage.timestamp >= start)
        if stop is not None:
            where.append(CPUUsage.timestamp <= stop)
        results = self.store.find(
            CPUUsage, CPUUsage.computer_id == self.computer.id, *where
        )
        results.order_by(CPUUsage.timestamp)
        return results.values(CPUUsage.timestamp, CPUUsage.cpu_usage)
