# Copyright 2005-2022 Canonical Limited. All rights reserved.

from storm.locals import Int, Unicode, DateTime

from canonical.security.protect import requires, requires_advisor, PRIVATE

from canonical.landscape.model.computer.helper import ComputerHelper


__all__ = ["HistoricProcess"]


__requires_prefix__ = "landscape."


@requires_advisor
class HistoricProcess(ComputerHelper):
    """Data for a single running process."""

    __storm_table__ = "historic_process"

    requires("ViewHistoricProcess", PRIVATE, ["id"])
    requires(
        "ViewHistoricProcess",
        "EditHistoricProcess",
        ["pid", "uid", "gid", "name", "exit_code", "start_time", "stop_time"],
    )

    id = Int(primary=True, allow_none=False)
    computer_id = Int(allow_none=False)
    pid = Int(allow_none=False)
    uid = Int(allow_none=False)
    gid = Int(allow_none=False)
    name = Unicode(allow_none=False)
    exit_code = Int(allow_none=False)
    start_time = DateTime(allow_none=False)
    stop_time = DateTime(allow_none=False)

    def __init__(self, computer, pid, uid, gid, name, exit_code, start_time, stop_time):
        super(HistoricProcess, self).__init__(computer)
        self.pid = pid
        self.uid = uid
        self.gid = gid
        self.name = name
        self.exit_code = exit_code
        self.start_time = start_time
        self.stop_time = stop_time
