# Copyright 2005-2022 Canonical Limited. All rights reserved.

from storm.locals import Int

from canonical.security.protect import requires, requires_advisor, PRIVATE

from canonical.storm.variables import BytesStr

from canonical.landscape.model.computer.helper import ComputerHelper


__all__ = ["KeystoneToken", "KeystoneTokenManagement"]


__requires_prefix__ = "landscape."


@requires_advisor
class KeystoneToken(ComputerHelper):
    """
    Stores a keystone token associated with a computer.
    """

    __storm_table__ = "keystone_token"

    requires("ViewKeystoneToken", PRIVATE, ["computer_id"])
    requires("ViewKeystoneToken", "EditKeystoneToken", ["token"])

    computer_id = Int(primary=True)
    token = BytesStr()

    def __init__(self, computer, token):
        super(KeystoneToken, self).__init__(computer)
        self.token = token


@requires_advisor
class KeystoneTokenManagement(ComputerHelper):
    @requires("SetKeystoneToken")
    def set_keystone_token(self, token):
        """
        Create or update a keystone token on the computer.
        """
        existing_token = self.get_keystone_token()
        if existing_token is not None:
            existing_token.token = token
        else:
            self.store.add(KeystoneToken(self.computer, token))

    @requires("ViewKeystoneToken")
    def get_keystone_token(self):
        """
        Get the keystone token associated with the computer, or None if there
        isn't one.
        """
        return self.store.find(KeystoneToken, computer_id=self.computer.id).one()
