# Copyright 2005-2022 Canonical Limited. All rights reserved.

from zope.interface import implementer

from storm.locals import Int, Float, DateTime

from canonical.security.protect import requires, requires_advisor

from canonical.landscape.model.computer.helper import ComputerHelper
from canonical.landscape.model.resource.interfaces import ILoadAverage


__all__ = ["LoadAverage"]


__requires_prefix__ = "landscape."


@requires_advisor
@implementer(ILoadAverage)
class LoadAverage(ComputerHelper):
    """Resource captures load average and running/total processes."""

    __storm_table__ = "load_average"
    __storm_primary__ = "computer_id", "timestamp"

    requires("ViewLoadAverage", "EditLoadAverage", ["timestamp", "load_average"])

    computer_id = Int(allow_none=False)
    timestamp = DateTime(allow_none=False)
    load_average = Float(allow_none=False)

    def __init__(self, computer, timestamp, load_average):
        super(LoadAverage, self).__init__(computer)
        self.timestamp = timestamp
        self.load_average = load_average
