# Copyright 2005-2022 Canonical Limited. All rights reserved.

from zope.interface import implementer

from storm.locals import Int, DateTime

from canonical.security.protect import requires, requires_advisor

from canonical.landscape.model.computer.helper import ComputerHelper
from canonical.landscape.model.resource.interfaces import IMemoryInfo


__all__ = ["MemoryInfo"]


__requires_prefix__ = "landscape."


@requires_advisor
@implementer(IMemoryInfo)
class MemoryInfo(ComputerHelper):
    """Resource captures timestamp, free memory kbytes and free swap kbytes."""

    __storm_table__ = "memory_info"
    __storm_primary__ = "computer_id", "timestamp"

    requires(
        "ViewMemoryInfo", "EditMemoryInfo", ["timestamp", "free_memory", "free_swap"]
    )

    computer_id = Int(allow_none=False)
    timestamp = DateTime(allow_none=False)
    free_memory = Int(allow_none=False)
    free_swap = Int(allow_none=False)

    def __init__(self, computer, timestamp, free_memory, free_swap):
        super(MemoryInfo, self).__init__(computer)
        self.timestamp = timestamp
        self.free_memory = free_memory
        self.free_swap = free_swap
