# Copyright 2005-2022 Canonical Limited. All rights reserved.

from zope.interface import implementer

from storm.locals import Int, Unicode

from canonical.security.protect import requires, requires_advisor, PRIVATE

from canonical.landscape.model.computer.helper import ComputerHelper
from canonical.landscape.model.resource.interfaces import IProcessor


__all__ = ["Processor"]

__requires_prefix__ = "landscape."


@requires_advisor
@implementer(IProcessor)
class Processor(ComputerHelper):
    """Manage data for a single processor in a computer."""

    __storm_table__ = "processor"

    requires("ViewProcessor", PRIVATE, ["id"])
    requires(
        "ViewProcessor",
        "EditProcessor",
        ["processor_id", "cache_size", "model", "vendor"],
    )

    id = Int(primary=True, allow_none=False)
    computer_id = Int(allow_none=False)
    processor_id = Int(allow_none=False)
    cache_size = Int(allow_none=False)
    model = Unicode(allow_none=False)
    vendor = Unicode(allow_none=False)

    def __init__(self, computer, processor_id, model, vendor, cache_size):
        super(Processor, self).__init__(computer)
        self.processor_id = processor_id
        self.vendor = vendor
        self.model = model
        self.cache_size = cache_size
