# Copyright 2005-2022 Canonical Limited. All rights reserved.

import re

from zope.interface import implementer
from zope.schema import ValidationError, TextLine
from zope.schema.interfaces import ITextLine


__all__ = ["Username"]

__clearlist__ = ["Username"]


valid_username_re = re.compile(r"\A[a-zA-Z0-9_@\.][a-zA-Z0-9_@\-\.]+\$?$")


def is_valid_username(username):
    """Validate a username.

    adduser: To avoid problems, the username should consist only of
    letters, digits, underscores, periods, at signs and dashes, and not start
    with a dash (as defined by IEEE Std 1003.1-2001). For compatibility with
    Samba machine accounts $ is also supported at the end of the username.
    """
    return bool(valid_username_re.match(username))


class IUsername(ITextLine):
    """A valid username.

    Note that valid Linux usernames are not POSIX compliant (because they can
    have the $ at the end).
    """


class InvalidUsername(ValidationError):
    """Invalid username."""


@implementer(IUsername)
class Username(TextLine):
    """A valid username.

    This needs to be a Unicode capable schema item, but usernames can't be
    Unicode.
    """

    def _validate(self, value):
        super(Username, self)._validate(value)
        if not is_valid_username(value):
            raise InvalidUsername(value)
