# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.component import getUtility

from storm.zope.interfaces import IZStorm

from canonical.landscape.model.computer.twin import ComputerTwin


__all__ = ["get_resource_stores", "get_resource_stores_for_computer_ids"]


def get_resource_stores():
    """Returns stores that begin with C{resource-}.

    Given that the resource_database_key is a numeric value that is appended
    onto the string C{resource-} this means that C{resource-} should not be
    used to name any non-resource databases.
    """
    zstorm = getUtility(IZStorm)
    for name, uri in sorted(zstorm.get_default_uris().items()):
        if name.startswith("resource-"):
            yield (name, zstorm.get(name))


def get_resource_stores_for_computer_ids(computer_ids):
    """Returns an index of resource stores mapped to C{Computer.id}s.

    Only entries for stores which match contain ids are returned.

    @note: This function is optimised with the assumption that the given
        computer_ids are actually valid IDs of existing L{Computer}s.
    """
    stores = list(get_resource_stores())
    if len(stores) == 1:
        # If there is only one store, don't bother querying
        return {stores[0][1]: computer_ids}
    index = {}
    for name, store in get_resource_stores():
        result = store.find(ComputerTwin, ComputerTwin.id.is_in(computer_ids))
        ids = list(result.values(ComputerTwin.id))
        # Don't include empty results
        if ids:
            index[store] = ids
    return index
