# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from storm.locals import Int, DateTime, Unicode

from canonical.landscape.model.computer.helper import ComputerHelper


__all__ = ["SwiftUsage", "SwiftUsageManagement"]


class SwiftUsage(ComputerHelper):
    """
    Model for a  usage data point for a Swift device in a computer.
    """

    __storm_table__ = "swift_usage"
    __storm_primary__ = "computer_id", "timestamp", "device"

    computer_id = Int(allow_none=False)
    timestamp = DateTime(allow_none=False)
    device = Unicode(allow_none=False)
    total = Int(allow_none=False)
    available = Int(allow_none=False)
    used = Int(allow_none=False)

    def __init__(self, computer, timestamp, device, total, available, used):
        super(SwiftUsage, self).__init__(computer)
        self.timestamp = timestamp
        self.device = device
        self.total = total
        self.available = available
        self.used = used


class SwiftUsageManagement(ComputerHelper):
    """
    A helper class to associate a C{SwiftUsage} object to a computer.
    """

    def create_swift_usage(self, timestamp, device, total, available, used):
        """
        Create a usage data point for a Swift device in the computer.
        """
        swift_usage = SwiftUsage(
            self.computer, timestamp, device, total, available, used
        )
        self.store.add(swift_usage)
        return swift_usage

    def get_swift_usages(self):
        """Return L{SwiftUsage}s sorted by timestamp."""
        result = self.store.find(SwiftUsage, SwiftUsage.computer_id == self.computer.id)
        return result.order_by(SwiftUsage.timestamp)
