# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.interface import implementer
from zope.authentication.interfaces import IAuthentication
from zope.component.interfaces import IComponentLookup

from canonical.root import Root

from canonical.landscape.security.authentication import LandscapeAuthentication
from canonical.landscape.model.root.interfaces import ILandscapeRoot


__all__ = ["LandscapeRoot", "create_root"]
__clearlist__ = ["create_root"]


@implementer(ILandscapeRoot)
class LandscapeRoot(Root):
    pass


def create_root():
    """Create a L{LandscapeRoot} object to be used as root Zope site."""
    root = LandscapeRoot()
    sm = root.getSiteManager()

    # The Zope publication tries to lookup the authentication utility
    # against the root site's registry, so we register it here.
    #
    # See the zope.app.publication.zopepublication module and the
    # ZopePublication._maybePlacefullyAuthenticate method in particular.
    sm.registerUtility(LandscapeAuthentication(), IAuthentication)

    # Instances of PluggableAuthentication pass themselves as context when
    # looking up plugin utilities, so we need to register our site manager
    # as IComponentLookup for it.
    #
    # See:
    #  zope.pluggableauth.authentication.PluggableAuthentication._plugin
    #  zope.component.hooks.getSiteManager
    sm.registerAdapter(lambda _: sm, (IAuthentication,), IComponentLookup)

    sm.registerUtility(root, ILandscapeRoot)

    return root


landscape_root = create_root()
