# Copyright 2005-2022 Canonical Limited. All rights reserved.

from zope.interface import implementer

from canonical.security.protect import requires, requires_advisor, PUBLIC

from canonical.landscape.model.root.interfaces import ILogin
from canonical.landscape.model.main.person import get_person_by_identity


__all__ = ["Login"]

__clearlist__ = ["Login"]


@requires_advisor
@implementer(ILogin)
class Login(object):
    @requires(PUBLIC)
    def get_person_id_by_identity(self, identity):
        person = get_person_by_identity(identity)
        if person is not None:
            return person.id

    @requires(PUBLIC)
    def update_login_data(self, identity, host):
        person = get_person_by_identity(identity)
        if person is not None:
            person.update_login_data(host)

    @requires(PUBLIC)
    def get_default_account_name(self, identity):
        """Return the name of the Person's default account.

        If L{Person} is part of no accounts, return None.

        @param identity: The identity of the L{Person}.
        """
        person = get_person_by_identity(identity)
        if person is None:
            return None
        account = person.get_default_account()
        return account.name if account else None

    @requires(PUBLIC)
    def accounts_are_expired(self, identity):
        """Return whether the L{Person}'s accounts are all expired.

        @param identity: The identity of the L{Person}.
        """
        person = get_person_by_identity(identity)
        if person is None:
            return False
        accounts = list(person.accounts)
        if len(accounts) == 0:
            return False
        for account in accounts:
            if not account.has_expired():
                return False
        return True
