# Copyright 2005-2013 Canonical Limited.  All rights reserved.

__all__ = [
    "UnknownScriptError",
    "UnknownScriptAttachmentError",
    "DuplicateScriptAttachmentError",
    "TooManyScriptAttachmentsError",
    "ScriptAttachmentSizeError",
    "ScriptEncodingError",
]

__clearlist__ = __all__


class UnknownScriptError(Exception):
    def __init__(self, script_id):
        super(UnknownScriptError, self).__init__(
            "script_id '%d' does not exist." % script_id
        )


class UnknownScriptAttachmentError(Exception):
    def __init__(self, script_id, attachment_filename):
        super(UnknownScriptAttachmentError, self).__init__(
            "script attachment with filename '%s' does not exist for script "
            "'%s'." % (attachment_filename, script_id)
        )


class DuplicateScriptAttachmentError(Exception):
    def __init__(self, script_id, filename):
        super(DuplicateScriptAttachmentError, self).__init__(
            "an attachment with a name of '%s' already exists for "
            "script '%d'" % (filename, script_id)
        )


class TooManyScriptAttachmentsError(Exception):
    def __init__(self, script_id, max_files):
        super(TooManyScriptAttachmentsError, self).__init__(
            "script '%d' already has the maximum number of attachments "
            "permitted by this account (%d)" % (script_id, max_files)
        )


class ScriptAttachmentSizeError(Exception):
    def __init__(self, script_id, max_size):
        super(ScriptAttachmentSizeError, self).__init__(
            "adding an attachment to script '%d' would exeed the total size "
            "for attachment permitted by this account (%d)" % (script_id, max_size)
        )


class ScriptEncodingError(Exception):
    def __init__(self):
        super(ScriptEncodingError, self).__init__(
            "Script body could not be read - is it utf-8 encoded text?"
        )
