# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.interface import Interface
from zope.schema import Int, TextLine, Text, Bool

__all__ = ["IScript", "IScriptExecution", "MAX_TIME_LIMIT", "MIN_TIME_LIMIT"]

__clearlist__ = __all__

MAX_TIME_LIMIT = 2147483647  # The maximum value of a PostgreSQL INT.
MIN_TIME_LIMIT = 0


class IScript(Interface):

    title = TextLine(title="Title", description="Title for the script.", required=True)

    code = Text(
        title="Code",
        description=(
            "Code to run, which will be written to a file "
            "before being run.  Please note, the output "
            "returned may be truncated."
        ),
        required=True,
        default="#!/bin/bash\n",
    )

    username = TextLine(
        title="Run as user",
        description="Default user to run the script as.",
        required=False,
    )

    time_limit = Int(
        title="Time limit (seconds)",
        description="Amount of time to wait for the process to end.",
        default=300,
        max=MAX_TIME_LIMIT,
        min=MIN_TIME_LIMIT,
        required=True,
    )

    def get_code():
        """Get the script contents including interpreter."""

    def set_code():
        """Set the script contents including interpreter."""


class IScriptExecution(Interface):

    username = TextLine(
        title="Run as user",
        description=(
            "The user to run the script as. You can choose an "
            "arbitrary user or select one from the set of known "
            "users."
        ),
        required=True,
    )

    save_script = Bool(
        title="Save script",
        description="Save this script in your script library.",
        required=False,
    )
