# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from datetime import datetime

from storm.twisted.transact import transact

from canonical.amqp.job.runner import job, JobRunner

from canonical.landscape.model.main.account import get_account_by_id
from canonical.landscape.model.main.person import get_person_by_id
from canonical.landscape.model.activity.parent import get_parent_activity
from canonical.landscape.model.selection.selection import ComputerSelection
from canonical.landscape.model.script.script import ScriptExecution


@job
class PopulateScriptActivityJobRunner(JobRunner):
    """
    Continue a script activity created previously, handling another batch of
    computers.
    """

    def run(
        self,
        account_id,
        activity_id,
        person_id,
        computer_ids,
        title,
        interpreter,
        code,
        username,
        time_limit,
        deliver_after,
        batch_size,
    ):
        return self._populate_activity(
            account_id,
            activity_id,
            person_id,
            computer_ids,
            title,
            interpreter,
            code,
            username,
            time_limit,
            deliver_after,
            batch_size,
        )

    @transact
    def _populate_activity(
        self,
        account_id,
        activity_id,
        person_id,
        computer_ids,
        title,
        interpreter,
        code,
        username,
        time_limit,
        deliver_after,
        batch_size,
    ):
        account = get_account_by_id(account_id)
        parent = get_parent_activity(account, activity_id)
        person = get_person_by_id(person_id)
        if deliver_after is not None:
            deliver_after = datetime.strptime(deliver_after, "%Y-%m-%dT%H:%M:%SZ")

        selection = ComputerSelection(account)
        selection.select_computers(computer_ids)

        execution = ScriptExecution(selection)
        parent.alter()
        execution.run_execute_batch(
            person,
            title,
            interpreter,
            code,
            username,
            time_limit,
            deliver_after,
            batch_size,
            parent,
        )
        return None, None
