# Copyright 2005-2016 Canonical Limited.  All rights reserved.

"""Generic model search criteria."""

from storm.expr import Eq

from canonical.lib.undef import Undef
from canonical.search.engine import CriteriaBase


class ModelIDCriteria(CriteriaBase):
    """Criteria that matches model instances by ID."""

    criteria_prefix = "id"
    criteria_attribute = "_id"

    _model = Undef()

    _term = Undef()

    @classmethod
    def get_search_help(cls):
        return {
            "terms": ["id:<id>"],
            "descriptions": ["{} with the exact specified ID.".format(cls._term)],
        }

    def __init__(self, id):
        self._id = id

    def get_where_clause(self):
        """Find the model instance with the given id.

        @return: A Storm expression that will match the specified id.
        """
        return Eq(self._model.id, self._id)
