# Copyright 2005-2022 Canonical Limited. All rights reserved.

import csv
from io import StringIO

from zope.interface import implementer

from canonical.security.protect import requires, requires_advisor, PRIVATE

from canonical.landscape.model.main.interfaces import IAccessDelegateAware


__all__ = ["SelectionAsCSV"]
__clearlist__ = ["SelectionAsCSV"]


@requires_advisor
@implementer(IAccessDelegateAware)
class SelectionAsCSV(object):

    requires("landscape.ViewPersonResource", PRIVATE, ["get_csv_data"])

    def __init__(self, selection):
        self.selection = selection

    @property
    def access_delegate(self):
        return self.selection.account

    def get_csv_data(self):
        """
        Return data from the currently selected computers in the
        ComputerSelection.
        """
        column_headers = (
            "Id",
            "Name",
            "Hostname",
            "Last Ping Time",
            "Reboot",
            "Tags",
            "Access Group",
            "Clone Id",
        )
        csv_data = [column_headers]

        computers = self.selection.get_selected()
        for computer in computers:
            hostname = computer.hostname

            if computer.last_ping_time:
                last_activity = computer.last_ping_time.isoformat()
            else:
                last_activity = ""

            reboot_required = "Y" if computer.reboot_required_flag else "N"
            tags = sorted(tag.name for tag in computer.get_tags())
            csv_data.append(
                (
                    computer.id,
                    computer.title,
                    hostname,
                    last_activity,
                    reboot_required,
                    " ".join(tags),
                    computer.access_context.name,
                    computer.clone_id,
                )
            )

        output = StringIO()
        writer = csv.writer(output)
        writer.writerows(csv_data)
        return output.getvalue()
