# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.interface import Interface
from zope.schema import Object, Text

from canonical.landscape.model.main.interfaces import IAccount

__all__ = ["IComputerSelection"]

__clearlist__ = __all__


class IComputerSelection(Interface):
    """
    Selection keeps track of filtering criteria and selected computers.

    The computer selection is one of the central concepts in the
    Landscape user interface.  Users choose filtering criteria, such
    as tags and/or search criteria, which determine the set of computers from
    which they can select.  They then select computers from the set of
    selectable computers to perform operations on, such as adding
    users or installing security updates.
    """

    account = Object(
        title="Account",
        schema=IAccount,
        description="The account from which computers may be selected.",
        required=True,
        readonly=False,
    )

    permission = Text(
        title="Permission",
        description="The permission required to operate on the selection.",
        required=False,
        readonly=False,
    )

    def clear():
        """Clear filtering criteria and unselect any selected computers."""

    def __iter__():
        """Iterate over the set of selected computers."""

    def get_available():
        """Get a list of all available computers."""

    def get_available_count():
        """Return the number of available computers."""

    def get_available_ids():
        """Return the ids of all available computers."""

    def get_selected():
        """Get a list of all selected computers."""

    def get_selected_count():
        """Return the number of selected computers."""

    def get_selected_computer_ids():
        """Get a list of selected computer IDs."""

    def is_selected(computer):
        """Returns True if the given computer (object or id) is selected."""

    def select_computers(computers):
        """Mark the given computers (objects or ids) as selected."""

    def unselect_computers(computers):
        """Remove the given computers (object or ids) from the selected set."""

    def clear_selected_computers():
        """Clear the set of selected computers."""

    def include_computers(computers):
        """Update the included computers to include the given computers."""

    def get_included_computer_ids():
        """Return the set of included computer ids."""

    def discard_included_computers(computers):
        """Remove the given computers from the included computers set."""

    def clear_included_computers():
        """Clear the set of included computers."""

    def include_tags(tags):
        """Include computers with the given tags in this computer set."""

    def include_access_groups(access_groups):
        """
        Include computers with the given access groups in this computer set.
        """

    def set_search_criteria(search_criteria):
        """Include computers with the search criteria in this computer set."""

    def set_saved_search_criteria(search_name):
        """Include computers matching the saved search name."""

    def get_included_tags():
        """Return the set of included tags."""

    def get_included_access_groups():
        """Return the set of included access groups."""

    def get_search_criteria():
        """Return the included search criteria."""

    def discard_included_tags(tags):
        """Remove the given tags from the include tags set."""

    def discard_included_access_groups(access_groups):
        """
        Remove the given access groups from the include access groups set.
        """

    def clear_included_tags():
        """Clear the set of included tags."""

    def clear_included_access_groups():
        """Clear the set of included access groups."""

    def clear_search_criteria():
        """Clear the search criteria."""

    def create_activity_group(**kwargs):
        """Create an ActivityGroup activity."""

    def get_search_name():
        """Return the name of the saved search included in the selection."""

    def set_saved_search_name(search_name):
        """Set the name of the saved search to be included in the selection."""

    def clear_search_name():
        """Clear the search name."""

    def get_computers_by_ids(computer_ids):
        """Return computer ids."""
