# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.event import subscribers as zope_subscribers
from zope.component import provideUtility

from canonical.lib.config import Config

from canonical.event.subscriber import dispatch

from canonical.landscape.interfaces import IFileBasedConfiguration
from canonical.landscape.environment import get_modules
from canonical.security.role import RoleRegistry
from canonical.landscape.security.roles import setup_roles
from canonical.landscape.security.grants import setup_grants
from canonical.landscape.model.configuration import SystemConfiguration
from canonical.landscape.model.alert.policy import register_rule_info_types
from canonical.landscape.model.activity.register import register_activity_info_types
from canonical.landscape.model.account.register import (
    register_profile_info_types,
    register_account_entity_types,
)
from canonical.landscape.prometheus.metrics import PrometheusMetrics


def setup():
    """Bootstrap and control the model setup and components."""
    provideUtility(Config(), IFileBasedConfiguration)
    provideUtility(RoleRegistry())
    provideUtility(SystemConfiguration())
    provideUtility(PrometheusMetrics())

    setup_roles()
    setup_grants()

    register_rule_info_types()
    register_activity_info_types()
    register_profile_info_types()
    register_account_entity_types()
    # This will import the modules that declare that event subscribers,
    # hence triggering the registration in the ZCA.
    zope_subscribers.append(dispatch)
    get_modules(["model/*/subscriber.py"])
