# Copyright 2005-2022 Canonical Limited. All rights reserved.

from zope.component import getUtility

from storm.locals import Storm
from storm.zope.interfaces import IZStorm

from canonical.security.protect import requires, requires_advisor, PUBLIC


__all__ = ["StoreHolder"]


class LazyStore(object):
    def __get__(self, obj, cls=None):
        if obj is not None:
            zstorm = getUtility(IZStorm)
            obj.store = zstorm.get(obj.get_store_name())
            return obj.store
        return self


@requires_advisor
class StoreHolder(Storm):

    store = LazyStore()

    def get_store_name(self):
        raise NotImplementedError

    def reset_store(self):
        self.__dict__.pop("store", None)

    def __storm_invalidated__(self):
        self.reset_store()

    @requires(PUBLIC)
    def commit_store(self):
        self.store.commit()

    @requires(PUBLIC)
    def rollback_store(self):
        self.store.rollback()
