# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from storm.expr import Func, NamedFunc, SQLRaw, Cast


__all__ = [
    "AgeFromNow",
    "Now",
    "Avg",
    "Mod",
    "DatePart",
    "Timezone",
    "utc_timestamp_as_integer",
    "Concat",
    "Floor",
    "Today",
]


class AgeFromNow(Func):
    def __init__(self, time):
        Func.__init__(self, "AGE", Now, time)


Now = Func("TIMEZONE", "UTC", Func("NOW"))
Today = Func("DATE", Now)


class Concat(NamedFunc):
    """Concatenate strings."""

    name = "concat"


class Floor(NamedFunc):
    """Largest integer not greater than the argument."""

    name = "floor"


class Avg(NamedFunc):
    """
    The database average aggregate function.
    """

    name = "AVG"


class Mod(NamedFunc):
    """
    The basic module operator. This is used instead of storm module support
    because it doesn't escape '%' properly.
    """

    name = "mod"


class DatePart(Func):
    """
    Return the date part of a timestamp, default to change to epoch.
    """

    def __init__(self, field, part="epoch"):
        Func.__init__(self, "date_part", SQLRaw("'%s'" % part), field)


class Timezone(NamedFunc):
    name = "timezone"


def utc_timestamp_as_integer(field):
    """
    Take a timestamp field and apply functions to make it return an integer
    epoch value.
    """
    return Cast(DatePart(Timezone(SQLRaw("'UTC'"), field)), "INTEGER")
