# Copyright 2005-2017 Canonical Limited.  All rights reserved.

from functools import wraps
from zope.component import getUtility

from canonical.landscape.prometheus.interfaces import IPrometheusMetrics


def http_metrics(func):
    """Wrap a function to track prometheus HTTP request metrics."""

    @wraps(func)
    def wrapper(*args, **kwargs):
        page = args[0]
        request = page.request
        response = func(*args, **kwargs)
        metric = getUtility(IPrometheusMetrics).get("landscape_http_requests")
        revision = getattr(page, "http_metrics_revision", "")
        metric.labels(
            revision=revision,
            code=request.response.getStatus(),
            method=request.method,
            path=request.getURL(path_only=True),
        ).inc()
        return response

    return wrapper
