--
-- PostgreSQL database dump
--

-- Dumped from database version 12.15 (Ubuntu 12.15-0ubuntu0.20.04.1)
-- Dumped by pg_dump version 12.15 (Ubuntu 12.15-0ubuntu0.20.04.1)

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET xmloption = content;
SET client_min_messages = warning;
SET row_security = off;

--
-- Name: plpython3u; Type: PROCEDURAL LANGUAGE; Schema: -; Owner: -
--

CREATE OR REPLACE PROCEDURAL LANGUAGE plpython3u;


--
-- Name: ltree; Type: EXTENSION; Schema: -; Owner: -
--

CREATE EXTENSION IF NOT EXISTS ltree WITH SCHEMA public;


--
-- Name: EXTENSION ltree; Type: COMMENT; Schema: -; Owner: -
--

COMMENT ON EXTENSION ltree IS 'data type for hierarchical tree-like structures';


--
-- Name: get_tag(text); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION public.get_tag(tag_name text) RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
    tag_record RECORD;
BEGIN
    LOOP
        SELECT INTO tag_record * FROM tag WHERE tag.name = tag_name;

        IF FOUND THEN
            RETURN tag_record.id;
        END IF;

        BEGIN
            INSERT INTO tag (name) VALUES (tag_name);
        EXCEPTION
            WHEN unique_violation THEN
                NULL; -- do nothing
        END;
    END LOOP;
END;
$$;


SET default_tablespace = '';

SET default_table_access_method = heap;

--
-- Name: access_context; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.access_context (
    id integer NOT NULL,
    parent_id integer,
    root_id integer NOT NULL,
    name text NOT NULL,
    description text,
    CONSTRAINT access_context_check CHECK ((id <> parent_id))
);


--
-- Name: access_context_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.access_context_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: access_context_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.access_context_id_seq OWNED BY public.access_context.id;


--
-- Name: account; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.account (
    id integer NOT NULL,
    access_context_id integer NOT NULL,
    name character varying(60) NOT NULL,
    registration_password text,
    title text NOT NULL,
    database_key integer DEFAULT 1,
    max_people_count integer DEFAULT 5 NOT NULL,
    salesforce_account_key text,
    max_attachment_size integer DEFAULT 1048576 NOT NULL,
    creation_time timestamp without time zone DEFAULT timezone('UTC'::text, now()) NOT NULL,
    managed_hours_start_time timestamp without time zone DEFAULT timezone('UTC'::text, now()) NOT NULL,
    stripe_customer_id text,
    vat_number text,
    vat_country character(2),
    marketing_emails boolean DEFAULT false,
    is_business boolean,
    disabled_reason text
);


--
-- Name: account_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.account_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: account_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.account_id_seq OWNED BY public.account.id;


--
-- Name: account_invitation; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.account_invitation (
    id integer NOT NULL,
    secure_id text NOT NULL,
    account_id integer NOT NULL,
    salesforce_key text,
    name text NOT NULL,
    email text NOT NULL,
    creation_time timestamp without time zone NOT NULL
);


--
-- Name: account_invitation_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.account_invitation_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: account_invitation_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.account_invitation_id_seq OWNED BY public.account_invitation.id;


--
-- Name: api_credentials; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.api_credentials (
    access_key_id bytea NOT NULL,
    access_secret_key bytea NOT NULL,
    person_id integer NOT NULL,
    account_id integer,
    creation_time timestamp without time zone DEFAULT timezone('UTC'::text, now()) NOT NULL
);


--
-- Name: pending_computer; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.pending_computer (
    id integer NOT NULL,
    secure_id bytea NOT NULL,
    account_id integer NOT NULL,
    creation_time timestamp without time zone NOT NULL,
    title text NOT NULL,
    description text,
    hostname text,
    client_tags text,
    vm_info text,
    container_info text,
    access_group text,
    juju_model_uuid text,
    juju_machine_id text,
    clone_id integer,
    ubuntu_pro_info text,
    CONSTRAINT juju_model_uuid_and_machine_id CHECK ((((juju_model_uuid IS NULL) AND (juju_machine_id IS NULL)) OR ((juju_model_uuid IS NOT NULL) AND (juju_machine_id IS NOT NULL))))
);


--
-- Name: pending_computer_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.pending_computer_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: pending_computer_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.pending_computer_id_seq OWNED BY public.pending_computer.id;


--
-- Name: computer; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.computer (
    id integer NOT NULL,
    access_context_id integer NOT NULL,
    account_id integer NOT NULL,
    distribution_id integer,
    current_api bytea,
    current_version bytea,
    secure_id bytea NOT NULL,
    insecure_id integer DEFAULT nextval('public.pending_computer_id_seq'::regclass) NOT NULL,
    title text NOT NULL,
    comment text DEFAULT ''::text NOT NULL,
    hostname text,
    total_memory integer,
    total_swap integer,
    resource_database_key integer NOT NULL,
    accepted_message_types_hash bytea,
    accept_time timestamp without time zone DEFAULT timezone('UTC'::text, now()) NOT NULL,
    vm_info text,
    container_info text,
    juju_model_uuid text,
    juju_machine_id text,
    clone_id integer,
    ubuntu_pro_info text,
    CONSTRAINT juju_model_uuid_and_machine_id CHECK ((((juju_model_uuid IS NULL) AND (juju_machine_id IS NULL)) OR ((juju_model_uuid IS NOT NULL) AND (juju_machine_id IS NOT NULL))))
);


--
-- Name: computer_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.computer_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: computer_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.computer_id_seq OWNED BY public.computer.id;


--
-- Name: computer_license; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.computer_license (
    computer_id integer NOT NULL,
    license_id integer NOT NULL
);


--
-- Name: computer_message_type; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.computer_message_type (
    computer_id integer NOT NULL,
    message_type_id integer NOT NULL
);


--
-- Name: computer_relationship; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.computer_relationship (
    computer_id integer NOT NULL,
    parent_id integer,
    tree public.ltree NOT NULL
);


--
-- Name: computer_selection_data; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.computer_selection_data (
    person_id integer NOT NULL,
    account_id integer NOT NULL,
    selected_computer_ids integer[]
);


--
-- Name: computer_status; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.computer_status (
    computer_id integer NOT NULL,
    next_expected_sequence integer,
    next_exchange_token bytea,
    consecutive_errors integer DEFAULT 0 NOT NULL,
    last_exchange_time timestamp without time zone,
    soft_lock_time timestamp without time zone,
    is_inconsistent boolean DEFAULT false NOT NULL,
    reboot_required_flag boolean DEFAULT false NOT NULL,
    update_manager_prompt text DEFAULT 'normal'::text NOT NULL,
    last_exchange_duration real DEFAULT 0 NOT NULL,
    last_exchange_size real DEFAULT 0 NOT NULL,
    ignored_count integer DEFAULT 0 NOT NULL,
    processed_count integer DEFAULT 0 NOT NULL,
    dropped_count integer DEFAULT 0 NOT NULL,
    remaining_count integer DEFAULT 0 NOT NULL
);


--
-- Name: computer_tag; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.computer_tag (
    computer_id integer NOT NULL,
    tag_id integer NOT NULL
);


--
-- Name: computer_utilisation; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.computer_utilisation (
    computer_id integer,
    managed_hours integer DEFAULT 0 NOT NULL,
    next_managed_hour_time timestamp without time zone DEFAULT timezone('UTC'::text, now()) NOT NULL,
    account_id integer NOT NULL,
    computer_type integer
);


--
-- Name: distributed_lock; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.distributed_lock (
    id integer NOT NULL,
    name text NOT NULL,
    hostname text NOT NULL,
    creation_time timestamp without time zone DEFAULT timezone('UTC'::text, now()) NOT NULL
);


--
-- Name: distributed_lock_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.distributed_lock_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: distributed_lock_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.distributed_lock_id_seq OWNED BY public.distributed_lock.id;


--
-- Name: distribution; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.distribution (
    id integer NOT NULL,
    description text NOT NULL,
    distributor text,
    release text,
    code_name text,
    meta_release_id integer
);


--
-- Name: distribution_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.distribution_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: distribution_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.distribution_id_seq OWNED BY public.distribution.id;


--
-- Name: enabled_feature; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.enabled_feature (
    name text NOT NULL
);


--
-- Name: installed_snap; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.installed_snap (
    computer_id integer NOT NULL,
    snap_id text NOT NULL,
    version text,
    revision text,
    tracking_channel text,
    held_until timestamp,
    confinement text
);


--
-- Name: invitation_role; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.invitation_role (
    invitation_id integer NOT NULL,
    role_key integer NOT NULL
);


--
-- Name: lds_available_release; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.lds_available_release (
    release text NOT NULL
);


--
-- Name: lds_license; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.lds_license (
    id integer NOT NULL,
    account_id integer NOT NULL,
    apt_key text NOT NULL,
    contents text NOT NULL
);


--
-- Name: lds_license_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.lds_license_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: lds_license_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.lds_license_id_seq OWNED BY public.lds_license.id;


--
-- Name: lds_release; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.lds_release (
    account_id integer NOT NULL,
    release text
);


--
-- Name: lds_script_execution_log; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.lds_script_execution_log (
    id integer NOT NULL,
    name text NOT NULL,
    run_interval integer NOT NULL,
    run_timeout integer NOT NULL,
    start_time timestamp without time zone,
    end_time timestamp without time zone,
    success boolean
);


--
-- Name: lds_script_execution_log_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.lds_script_execution_log_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: lds_script_execution_log_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.lds_script_execution_log_id_seq OWNED BY public.lds_script_execution_log.id;


--
-- Name: license; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.license (
    id integer NOT NULL,
    account_id integer NOT NULL,
    expiration_date date,
    role_key integer NOT NULL,
    license_key bytea,
    seats integer DEFAULT 0 NOT NULL,
    salesforce_asset_key text
);


--
-- Name: license_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.license_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: license_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.license_id_seq OWNED BY public.license.id;


--
-- Name: license_lds_license; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.license_lds_license (
    lds_license_id integer NOT NULL,
    license_id integer NOT NULL
);


--
-- Name: message_type; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.message_type (
    id integer NOT NULL,
    name text NOT NULL
);


--
-- Name: message_type_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.message_type_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: message_type_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.message_type_id_seq OWNED BY public.message_type.id;


--
-- Name: meta_release; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.meta_release (
    id integer NOT NULL,
    code_name text NOT NULL,
    name text,
    version text,
    date timestamp without time zone,
    supported boolean DEFAULT false NOT NULL,
    upgrade_tool_tarball_url text,
    upgrade_tool_signature_url text,
    lts boolean DEFAULT false NOT NULL,
    upgrade_id integer
);


--
-- Name: meta_release_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.meta_release_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: meta_release_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.meta_release_id_seq OWNED BY public.meta_release.id;


--
-- Name: password_recovery; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.password_recovery (
    person_id integer NOT NULL,
    secure_id text NOT NULL,
    creation_time timestamp without time zone DEFAULT timezone('UTC'::text, now()) NOT NULL
);


--
-- Name: person; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.person (
    id integer NOT NULL,
    name text NOT NULL,
    email text NOT NULL,
    password bytea,
    timezone text DEFAULT 'UTC'::text NOT NULL,
    identity text,
    last_login_time timestamp without time zone,
    last_login_host text
);


--
-- Name: person_access; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.person_access (
    person_id integer NOT NULL,
    role_key integer NOT NULL,
    access_context_id integer
);


--
-- Name: person_account; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.person_account (
    person_id integer NOT NULL,
    account_id integer NOT NULL
);


--
-- Name: person_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.person_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: person_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.person_id_seq OWNED BY public.person.id;


--
-- Name: ping_server; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.ping_server (
    id integer NOT NULL,
    startup_time timestamp without time zone DEFAULT timezone('UTC'::text, now()) NOT NULL,
    last_update_time timestamp without time zone
);


--
-- Name: ping_server_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.ping_server_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: ping_server_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.ping_server_id_seq OWNED BY public.ping_server.id;


--
-- Name: ping_time; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.ping_time (
    computer_id integer NOT NULL,
    last_ping_time timestamp without time zone
);


--
-- Name: removed_account_name; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.removed_account_name (
    id integer NOT NULL,
    name character varying(60) NOT NULL,
    creation_time timestamp without time zone DEFAULT timezone('UTC'::text, now()) NOT NULL
);


--
-- Name: removed_account_name_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.removed_account_name_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: removed_account_name_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.removed_account_name_id_seq OWNED BY public.removed_account_name.id;


--
-- Name: role; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.role (
    id integer NOT NULL,
    account_id integer NOT NULL,
    name text NOT NULL,
    description text
);


--
-- Name: role_access_context; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.role_access_context (
    role_id integer NOT NULL,
    access_context_id integer NOT NULL
);


--
-- Name: role_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.role_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: role_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.role_id_seq OWNED BY public.role.id;


--
-- Name: role_permission; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.role_permission (
    role_id integer NOT NULL,
    permission text NOT NULL
);


--
-- Name: role_person; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.role_person (
    role_id integer NOT NULL,
    person_id integer NOT NULL
);


--
-- Name: salesforce_activated_asset; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.salesforce_activated_asset (
    asset_id text NOT NULL,
    account_id integer NOT NULL,
    creation_time timestamp without time zone DEFAULT timezone('UTC'::text, now()) NOT NULL,
    notification_time timestamp without time zone
);


--
-- Name: salesforce_user; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.salesforce_user (
    id integer NOT NULL,
    account_id integer NOT NULL,
    person_id integer NOT NULL,
    salesforce_key text
);


--
-- Name: salesforce_user_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.salesforce_user_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: salesforce_user_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.salesforce_user_id_seq OWNED BY public.salesforce_user.id;


--
-- Name: server_identity; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.server_identity (
    id integer DEFAULT 1 NOT NULL,
    uuid text NOT NULL
);


--
-- Name: snap; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.snap (
    id text NOT NULL,
    name text,
    publisher_id integer,
    summary text
);


--
-- Name: snap_publisher; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.snap_publisher (
    id integer NOT NULL,
    username text,
    validation text
);


--
-- Name: snap_publisher_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.snap_publisher_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: snap_publisher_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.snap_publisher_id_seq OWNED BY public.snap_publisher.id;


--
-- Name: system_configuration; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.system_configuration (
    key text NOT NULL,
    value json NOT NULL
);


--
-- Name: tag; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.tag (
    id integer NOT NULL,
    name text NOT NULL
);


--
-- Name: tag_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.tag_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: tag_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.tag_id_seq OWNED BY public.tag.id;


--
-- Name: trial_account; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.trial_account (
    id integer NOT NULL,
    secure_id text,
    account_id integer,
    creator_id integer,
    company_name text NOT NULL,
    daytime_phone text,
    company_size character varying(20),
    country text,
    region text,
    mailing_list_optin boolean DEFAULT false NOT NULL,
    city text,
    registration_comments text
);


--
-- Name: trial_account_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.trial_account_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: trial_account_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.trial_account_id_seq OWNED BY public.trial_account.id;


--
-- Name: utility_cost; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.utility_cost (
    id integer NOT NULL,
    computer_type integer NOT NULL,
    valid_since date NOT NULL,
    hourly_cost integer NOT NULL,
    CONSTRAINT utility_cost_hourly_cost_check CHECK ((hourly_cost > 0))
);


--
-- Name: utility_cost_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.utility_cost_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: utility_cost_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.utility_cost_id_seq OWNED BY public.utility_cost.id;


--
-- Name: utility_credit; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.utility_credit (
    id integer NOT NULL,
    account_id integer NOT NULL,
    creation_date date DEFAULT ('now'::text)::date NOT NULL,
    amount integer NOT NULL,
    expiration_date date DEFAULT (('now'::text)::date + '65 days'::interval day) NOT NULL,
    initial_amount integer NOT NULL,
    CONSTRAINT utility_credit_amount_check CHECK ((amount > 0)),
    CONSTRAINT utility_credit_intial_amount_check CHECK ((initial_amount >= amount))
);


--
-- Name: utility_credit_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.utility_credit_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: utility_credit_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.utility_credit_id_seq OWNED BY public.utility_credit.id;


--
-- Name: vat_rate; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.vat_rate (
    id integer NOT NULL,
    country_code character(2) NOT NULL,
    rate numeric(5,3) NOT NULL
);


--
-- Name: vat_rate_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.vat_rate_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: vat_rate_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.vat_rate_id_seq OWNED BY public.vat_rate.id;


--
-- Name: access_context id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.access_context ALTER COLUMN id SET DEFAULT nextval('public.access_context_id_seq'::regclass);


--
-- Name: access_context root_id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.access_context ALTER COLUMN root_id SET DEFAULT currval('public.access_context_id_seq'::regclass);


--
-- Name: account id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.account ALTER COLUMN id SET DEFAULT nextval('public.account_id_seq'::regclass);


--
-- Name: account_invitation id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.account_invitation ALTER COLUMN id SET DEFAULT nextval('public.account_invitation_id_seq'::regclass);


--
-- Name: computer id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer ALTER COLUMN id SET DEFAULT nextval('public.computer_id_seq'::regclass);


--
-- Name: distributed_lock id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.distributed_lock ALTER COLUMN id SET DEFAULT nextval('public.distributed_lock_id_seq'::regclass);


--
-- Name: distribution id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.distribution ALTER COLUMN id SET DEFAULT nextval('public.distribution_id_seq'::regclass);


--
-- Name: lds_license id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.lds_license ALTER COLUMN id SET DEFAULT nextval('public.lds_license_id_seq'::regclass);


--
-- Name: lds_script_execution_log id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.lds_script_execution_log ALTER COLUMN id SET DEFAULT nextval('public.lds_script_execution_log_id_seq'::regclass);


--
-- Name: license id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.license ALTER COLUMN id SET DEFAULT nextval('public.license_id_seq'::regclass);


--
-- Name: message_type id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.message_type ALTER COLUMN id SET DEFAULT nextval('public.message_type_id_seq'::regclass);


--
-- Name: meta_release id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.meta_release ALTER COLUMN id SET DEFAULT nextval('public.meta_release_id_seq'::regclass);


--
-- Name: pending_computer id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.pending_computer ALTER COLUMN id SET DEFAULT nextval('public.pending_computer_id_seq'::regclass);


--
-- Name: person id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.person ALTER COLUMN id SET DEFAULT nextval('public.person_id_seq'::regclass);


--
-- Name: ping_server id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.ping_server ALTER COLUMN id SET DEFAULT nextval('public.ping_server_id_seq'::regclass);


--
-- Name: removed_account_name id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.removed_account_name ALTER COLUMN id SET DEFAULT nextval('public.removed_account_name_id_seq'::regclass);


--
-- Name: role id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.role ALTER COLUMN id SET DEFAULT nextval('public.role_id_seq'::regclass);


--
-- Name: salesforce_user id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.salesforce_user ALTER COLUMN id SET DEFAULT nextval('public.salesforce_user_id_seq'::regclass);


--
-- Name: snap_publisher id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.snap_publisher ALTER COLUMN id SET DEFAULT nextval('public.snap_publisher_id_seq'::regclass);


--
-- Name: tag id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.tag ALTER COLUMN id SET DEFAULT nextval('public.tag_id_seq'::regclass);


--
-- Name: trial_account id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.trial_account ALTER COLUMN id SET DEFAULT nextval('public.trial_account_id_seq'::regclass);


--
-- Name: utility_cost id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.utility_cost ALTER COLUMN id SET DEFAULT nextval('public.utility_cost_id_seq'::regclass);


--
-- Name: utility_credit id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.utility_credit ALTER COLUMN id SET DEFAULT nextval('public.utility_credit_id_seq'::regclass);


--
-- Name: vat_rate id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.vat_rate ALTER COLUMN id SET DEFAULT nextval('public.vat_rate_id_seq'::regclass);


--
-- Name: access_context access_context_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.access_context
    ADD CONSTRAINT access_context_pkey PRIMARY KEY (id);


--
-- Name: access_context access_context_root_id_name_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.access_context
    ADD CONSTRAINT access_context_root_id_name_key UNIQUE (root_id, name);


--
-- Name: account_invitation account_invitation_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.account_invitation
    ADD CONSTRAINT account_invitation_pkey PRIMARY KEY (id);


--
-- Name: account_invitation account_invitation_salesforce_key_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.account_invitation
    ADD CONSTRAINT account_invitation_salesforce_key_key UNIQUE (salesforce_key);


--
-- Name: account_invitation account_invitation_secure_id_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.account_invitation
    ADD CONSTRAINT account_invitation_secure_id_key UNIQUE (secure_id);


--
-- Name: account account_name_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.account
    ADD CONSTRAINT account_name_key UNIQUE (name);


--
-- Name: account account_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.account
    ADD CONSTRAINT account_pkey PRIMARY KEY (id);


--
-- Name: account account_salesforce_account_key_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.account
    ADD CONSTRAINT account_salesforce_account_key_key UNIQUE (salesforce_account_key);


--
-- Name: api_credentials api_credentials_account_id_person_id_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.api_credentials
    ADD CONSTRAINT api_credentials_account_id_person_id_key UNIQUE (account_id, person_id);


--
-- Name: api_credentials api_credentials_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.api_credentials
    ADD CONSTRAINT api_credentials_pkey PRIMARY KEY (access_key_id);


--
-- Name: computer computer_insecure_id_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer
    ADD CONSTRAINT computer_insecure_id_key UNIQUE (insecure_id);


--
-- Name: computer_license computer_license_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_license
    ADD CONSTRAINT computer_license_pkey PRIMARY KEY (computer_id, license_id);


--
-- Name: computer_message_type computer_message_type_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_message_type
    ADD CONSTRAINT computer_message_type_pkey PRIMARY KEY (computer_id, message_type_id);


--
-- Name: computer computer_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer
    ADD CONSTRAINT computer_pkey PRIMARY KEY (id);


--
-- Name: computer_relationship computer_relationship_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_relationship
    ADD CONSTRAINT computer_relationship_pkey PRIMARY KEY (computer_id);


--
-- Name: computer computer_secure_id_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer
    ADD CONSTRAINT computer_secure_id_key UNIQUE (secure_id);


--
-- Name: computer_selection_data computer_selection_data_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_selection_data
    ADD CONSTRAINT computer_selection_data_pkey PRIMARY KEY (person_id, account_id);


--
-- Name: computer_status computer_status_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_status
    ADD CONSTRAINT computer_status_pkey PRIMARY KEY (computer_id);


--
-- Name: computer_tag computer_tag_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_tag
    ADD CONSTRAINT computer_tag_pkey PRIMARY KEY (computer_id, tag_id);


--
-- Name: computer_utilisation computer_utilisation_computer_id_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_utilisation
    ADD CONSTRAINT computer_utilisation_computer_id_key UNIQUE (computer_id);


--
-- Name: distributed_lock distributed_lock_name_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.distributed_lock
    ADD CONSTRAINT distributed_lock_name_key UNIQUE (name);


--
-- Name: distributed_lock distributed_lock_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.distributed_lock
    ADD CONSTRAINT distributed_lock_pkey PRIMARY KEY (id);


--
-- Name: distribution distribution_description_distributor_release_code_name_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.distribution
    ADD CONSTRAINT distribution_description_distributor_release_code_name_key UNIQUE (description, distributor, release, code_name);


--
-- Name: distribution distribution_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.distribution
    ADD CONSTRAINT distribution_pkey PRIMARY KEY (id);


--
-- Name: enabled_feature enabled_feature_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.enabled_feature
    ADD CONSTRAINT enabled_feature_pkey PRIMARY KEY (name);


--
-- Name: installed_snap installed_snap_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.installed_snap
    ADD CONSTRAINT installed_snap_pkey PRIMARY KEY (computer_id, snap_id);


--
-- Name: invitation_role invitation_role_invitation_id_role_key_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.invitation_role
    ADD CONSTRAINT invitation_role_invitation_id_role_key_key UNIQUE (invitation_id, role_key);


--
-- Name: lds_available_release lds_available_release_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.lds_available_release
    ADD CONSTRAINT lds_available_release_pkey PRIMARY KEY (release);


--
-- Name: lds_license lds_license_account_id_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.lds_license
    ADD CONSTRAINT lds_license_account_id_key UNIQUE (account_id);


--
-- Name: lds_license lds_license_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.lds_license
    ADD CONSTRAINT lds_license_pkey PRIMARY KEY (id);


--
-- Name: lds_release lds_release_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.lds_release
    ADD CONSTRAINT lds_release_pkey PRIMARY KEY (account_id);


--
-- Name: lds_script_execution_log lds_script_execution_log_name_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.lds_script_execution_log
    ADD CONSTRAINT lds_script_execution_log_name_key UNIQUE (name);


--
-- Name: lds_script_execution_log lds_script_execution_log_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.lds_script_execution_log
    ADD CONSTRAINT lds_script_execution_log_pkey PRIMARY KEY (id);


--
-- Name: license license_account_id_license_key_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.license
    ADD CONSTRAINT license_account_id_license_key_key UNIQUE (account_id, license_key);


--
-- Name: license_lds_license license_lds_license_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.license_lds_license
    ADD CONSTRAINT license_lds_license_pkey PRIMARY KEY (lds_license_id, license_id);


--
-- Name: license license_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.license
    ADD CONSTRAINT license_pkey PRIMARY KEY (id);


--
-- Name: message_type message_type_name_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.message_type
    ADD CONSTRAINT message_type_name_key UNIQUE (name);


--
-- Name: message_type message_type_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.message_type
    ADD CONSTRAINT message_type_pkey PRIMARY KEY (id);


--
-- Name: meta_release meta_release_code_name_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.meta_release
    ADD CONSTRAINT meta_release_code_name_key UNIQUE (code_name);


--
-- Name: meta_release meta_release_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.meta_release
    ADD CONSTRAINT meta_release_pkey PRIMARY KEY (id);


--
-- Name: password_recovery password_recovery_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.password_recovery
    ADD CONSTRAINT password_recovery_pkey PRIMARY KEY (secure_id);


--
-- Name: pending_computer pending_computer_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.pending_computer
    ADD CONSTRAINT pending_computer_pkey PRIMARY KEY (id);


--
-- Name: pending_computer pending_computer_secure_id_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.pending_computer
    ADD CONSTRAINT pending_computer_secure_id_key UNIQUE (secure_id);


--
-- Name: person_access person_access_person_id_role_key_access_context_id_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.person_access
    ADD CONSTRAINT person_access_person_id_role_key_access_context_id_key UNIQUE (person_id, role_key, access_context_id);


--
-- Name: person_account person_account_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.person_account
    ADD CONSTRAINT person_account_pkey PRIMARY KEY (person_id, account_id);


--
-- Name: person person_identity_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.person
    ADD CONSTRAINT person_identity_key UNIQUE (identity);


--
-- Name: person person_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.person
    ADD CONSTRAINT person_pkey PRIMARY KEY (id);


--
-- Name: ping_server ping_server_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.ping_server
    ADD CONSTRAINT ping_server_pkey PRIMARY KEY (id);


--
-- Name: ping_time ping_time_computer_id_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.ping_time
    ADD CONSTRAINT ping_time_computer_id_key UNIQUE (computer_id);


--
-- Name: removed_account_name removed_account_name_name_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.removed_account_name
    ADD CONSTRAINT removed_account_name_name_key UNIQUE (name);


--
-- Name: removed_account_name removed_account_name_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.removed_account_name
    ADD CONSTRAINT removed_account_name_pkey PRIMARY KEY (id);


--
-- Name: role_access_context role_access_context_role_id_access_context_id_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.role_access_context
    ADD CONSTRAINT role_access_context_role_id_access_context_id_key UNIQUE (role_id, access_context_id);


--
-- Name: role role_account_id_name_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.role
    ADD CONSTRAINT role_account_id_name_key UNIQUE (account_id, name);


--
-- Name: role_permission role_permission_role_id_permission_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.role_permission
    ADD CONSTRAINT role_permission_role_id_permission_key UNIQUE (role_id, permission);


--
-- Name: role_person role_person_role_id_person_id_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.role_person
    ADD CONSTRAINT role_person_role_id_person_id_key UNIQUE (role_id, person_id);


--
-- Name: role role_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.role
    ADD CONSTRAINT role_pkey PRIMARY KEY (id);


--
-- Name: salesforce_activated_asset salesforce_activated_asset_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.salesforce_activated_asset
    ADD CONSTRAINT salesforce_activated_asset_pkey PRIMARY KEY (asset_id);


--
-- Name: salesforce_user salesforce_user_account_id_person_id_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.salesforce_user
    ADD CONSTRAINT salesforce_user_account_id_person_id_key UNIQUE (account_id, person_id);


--
-- Name: salesforce_user salesforce_user_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.salesforce_user
    ADD CONSTRAINT salesforce_user_pkey PRIMARY KEY (id);


--
-- Name: salesforce_user salesforce_user_salesforce_key_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.salesforce_user
    ADD CONSTRAINT salesforce_user_salesforce_key_key UNIQUE (salesforce_key);


--
-- Name: server_identity server_identity_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.server_identity
    ADD CONSTRAINT server_identity_pkey PRIMARY KEY (id);


--
-- Name: snap snap_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.snap
    ADD CONSTRAINT snap_pkey PRIMARY KEY (id);


--
-- Name: snap_publisher snap_publisher_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.snap_publisher
    ADD CONSTRAINT snap_publisher_pkey PRIMARY KEY (id);


--
-- Name: system_configuration system_configuration_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.system_configuration
    ADD CONSTRAINT system_configuration_pkey PRIMARY KEY (key);


--
-- Name: tag tag_name_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.tag
    ADD CONSTRAINT tag_name_key UNIQUE (name);


--
-- Name: tag tag_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.tag
    ADD CONSTRAINT tag_pkey PRIMARY KEY (id);


--
-- Name: trial_account trial_account_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.trial_account
    ADD CONSTRAINT trial_account_pkey PRIMARY KEY (id);


--
-- Name: trial_account trial_account_secure_id_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.trial_account
    ADD CONSTRAINT trial_account_secure_id_key UNIQUE (secure_id);


--
-- Name: utility_cost utility_cost_computer_type_valid_since_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.utility_cost
    ADD CONSTRAINT utility_cost_computer_type_valid_since_key UNIQUE (computer_type, valid_since);


--
-- Name: utility_cost utility_cost_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.utility_cost
    ADD CONSTRAINT utility_cost_pkey PRIMARY KEY (id);


--
-- Name: utility_credit utility_credit_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.utility_credit
    ADD CONSTRAINT utility_credit_pkey PRIMARY KEY (id);


--
-- Name: vat_rate vat_rate_country_code_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.vat_rate
    ADD CONSTRAINT vat_rate_country_code_key UNIQUE (country_code);


--
-- Name: vat_rate vat_rate_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.vat_rate
    ADD CONSTRAINT vat_rate_pkey PRIMARY KEY (id);


--
-- Name: account_access_context_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX account_access_context_id_idx ON public.account USING btree (access_context_id);


--
-- Name: account_invitation_account_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX account_invitation_account_id_idx ON public.account_invitation USING btree (account_id);


--
-- Name: computer_access_context_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX computer_access_context_id_idx ON public.computer USING btree (access_context_id);


--
-- Name: computer_account_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX computer_account_id_idx ON public.computer USING btree (account_id);


--
-- Name: computer_clone_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX computer_clone_id_idx ON public.computer USING btree (clone_id);


--
-- Name: computer_hostname_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX computer_hostname_idx ON public.computer USING btree (hostname);


--
-- Name: computer_status_consecutive_errors_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX computer_status_consecutive_errors_idx ON public.computer_status USING btree (consecutive_errors) WHERE (consecutive_errors >= 1);


--
-- Name: computer_utilisation_account_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX computer_utilisation_account_id_idx ON public.computer_utilisation USING btree (account_id);


--
-- Name: computer_utilisation_computer_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX computer_utilisation_computer_id_idx ON public.computer_utilisation USING btree (computer_id);


--
-- Name: lds_license_account_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX lds_license_account_id_idx ON public.lds_license USING btree (account_id);


--
-- Name: license_account_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX license_account_id_idx ON public.license USING btree (account_id);


--
-- Name: license_lds_license_license_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX license_lds_license_license_id_idx ON public.license_lds_license USING btree (license_id);


--
-- Name: password_recovery_person_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX password_recovery_person_id_idx ON public.password_recovery USING btree (person_id);


--
-- Name: pending_computer_account_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX pending_computer_account_id_idx ON public.pending_computer USING btree (account_id);


--
-- Name: pending_computer_clone_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX pending_computer_clone_id_idx ON public.pending_computer USING btree (clone_id);


--
-- Name: person_access_access_context_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX person_access_access_context_id_idx ON public.person_access USING btree (access_context_id);


--
-- Name: person_access_person_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX person_access_person_id_idx ON public.person_access USING btree (person_id);


--
-- Name: person_account_account_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX person_account_account_id_idx ON public.person_account USING btree (account_id);


--
-- Name: salesforce_user_person_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX salesforce_user_person_id_idx ON public.salesforce_user USING btree (person_id);


--
-- Name: snap_name_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX snap_name_idx ON public.snap USING btree (name);


--
-- Name: trial_account_account_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE UNIQUE INDEX trial_account_account_id_idx ON public.trial_account USING btree (account_id);


--
-- Name: vat_rate_country_code_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX vat_rate_country_code_idx ON public.vat_rate USING btree (country_code);


--
-- Name: access_context access_context_parent_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.access_context
    ADD CONSTRAINT access_context_parent_id_fkey FOREIGN KEY (parent_id) REFERENCES public.access_context(id) ON DELETE CASCADE;


--
-- Name: access_context access_context_root_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.access_context
    ADD CONSTRAINT access_context_root_id_fkey FOREIGN KEY (root_id) REFERENCES public.access_context(id);


--
-- Name: account account_access_context_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.account
    ADD CONSTRAINT account_access_context_id_fkey FOREIGN KEY (access_context_id) REFERENCES public.access_context(id);


--
-- Name: account_invitation account_invitation_account_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.account_invitation
    ADD CONSTRAINT account_invitation_account_id_fkey FOREIGN KEY (account_id) REFERENCES public.account(id) ON DELETE CASCADE;


--
-- Name: api_credentials api_credentials_account_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.api_credentials
    ADD CONSTRAINT api_credentials_account_id_fkey FOREIGN KEY (account_id) REFERENCES public.account(id) ON DELETE CASCADE;


--
-- Name: api_credentials api_credentials_person_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.api_credentials
    ADD CONSTRAINT api_credentials_person_id_fkey FOREIGN KEY (person_id) REFERENCES public.person(id) ON DELETE CASCADE;


--
-- Name: computer computer_access_context_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer
    ADD CONSTRAINT computer_access_context_id_fkey FOREIGN KEY (access_context_id) REFERENCES public.access_context(id);


--
-- Name: computer computer_account_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer
    ADD CONSTRAINT computer_account_id_fkey FOREIGN KEY (account_id) REFERENCES public.account(id);


--
-- Name: computer computer_clone_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer
    ADD CONSTRAINT computer_clone_id_fkey FOREIGN KEY (clone_id) REFERENCES public.computer(id) ON DELETE SET NULL;


--
-- Name: computer computer_distribution_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer
    ADD CONSTRAINT computer_distribution_id_fkey FOREIGN KEY (distribution_id) REFERENCES public.distribution(id);


--
-- Name: computer_license computer_license_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_license
    ADD CONSTRAINT computer_license_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer(id) ON DELETE CASCADE;


--
-- Name: computer_license computer_license_license_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_license
    ADD CONSTRAINT computer_license_license_id_fkey FOREIGN KEY (license_id) REFERENCES public.license(id) ON DELETE CASCADE;


--
-- Name: computer_message_type computer_message_type_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_message_type
    ADD CONSTRAINT computer_message_type_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer(id) ON DELETE CASCADE;


--
-- Name: computer_message_type computer_message_type_message_type_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_message_type
    ADD CONSTRAINT computer_message_type_message_type_id_fkey FOREIGN KEY (message_type_id) REFERENCES public.message_type(id) ON DELETE CASCADE;


--
-- Name: computer_relationship computer_relationship_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_relationship
    ADD CONSTRAINT computer_relationship_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer(id) ON DELETE CASCADE;


--
-- Name: computer_relationship computer_relationship_parent_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_relationship
    ADD CONSTRAINT computer_relationship_parent_id_fkey FOREIGN KEY (parent_id) REFERENCES public.computer(id) ON DELETE CASCADE;


--
-- Name: computer_selection_data computer_selection_data_account_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_selection_data
    ADD CONSTRAINT computer_selection_data_account_id_fkey FOREIGN KEY (account_id) REFERENCES public.account(id) ON DELETE CASCADE;


--
-- Name: computer_selection_data computer_selection_data_person_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_selection_data
    ADD CONSTRAINT computer_selection_data_person_id_fkey FOREIGN KEY (person_id) REFERENCES public.person(id) ON DELETE CASCADE;


--
-- Name: computer_status computer_status_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_status
    ADD CONSTRAINT computer_status_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer(id) ON DELETE CASCADE;


--
-- Name: computer_tag computer_tag_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_tag
    ADD CONSTRAINT computer_tag_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer(id) ON DELETE CASCADE;


--
-- Name: computer_tag computer_tag_tag_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_tag
    ADD CONSTRAINT computer_tag_tag_id_fkey FOREIGN KEY (tag_id) REFERENCES public.tag(id) ON DELETE CASCADE;


--
-- Name: computer_utilisation computer_utilisation_account_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_utilisation
    ADD CONSTRAINT computer_utilisation_account_id_fkey FOREIGN KEY (account_id) REFERENCES public.account(id) ON DELETE CASCADE;


--
-- Name: computer_utilisation computer_utilisation_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_utilisation
    ADD CONSTRAINT computer_utilisation_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer(id) ON DELETE SET NULL;


--
-- Name: distribution distribution_meta_release_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.distribution
    ADD CONSTRAINT distribution_meta_release_id_fkey FOREIGN KEY (meta_release_id) REFERENCES public.meta_release(id);


--
-- Name: installed_snap installed_snap_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.installed_snap
    ADD CONSTRAINT installed_snap_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer(id) ON DELETE CASCADE;


--
-- Name: installed_snap installed_snap_snap_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.installed_snap
    ADD CONSTRAINT installed_snap_snap_id_fkey FOREIGN KEY (snap_id) REFERENCES public.snap(id) ON DELETE CASCADE;


--
-- Name: invitation_role invitation_role_invitation_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.invitation_role
    ADD CONSTRAINT invitation_role_invitation_id_fkey FOREIGN KEY (invitation_id) REFERENCES public.account_invitation(id) ON DELETE CASCADE;


--
-- Name: lds_license lds_license_account_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.lds_license
    ADD CONSTRAINT lds_license_account_id_fkey FOREIGN KEY (account_id) REFERENCES public.account(id) ON DELETE CASCADE;


--
-- Name: lds_release lds_release_account_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.lds_release
    ADD CONSTRAINT lds_release_account_id_fkey FOREIGN KEY (account_id) REFERENCES public.account(id) ON DELETE CASCADE;


--
-- Name: license license_account_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.license
    ADD CONSTRAINT license_account_id_fkey FOREIGN KEY (account_id) REFERENCES public.account(id) ON DELETE CASCADE;


--
-- Name: license_lds_license license_lds_license_lds_license_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.license_lds_license
    ADD CONSTRAINT license_lds_license_lds_license_id_fkey FOREIGN KEY (lds_license_id) REFERENCES public.lds_license(id) ON DELETE CASCADE;


--
-- Name: license_lds_license license_lds_license_license_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.license_lds_license
    ADD CONSTRAINT license_lds_license_license_id_fkey FOREIGN KEY (license_id) REFERENCES public.license(id) ON DELETE CASCADE;


--
-- Name: meta_release meta_release_upgrade_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.meta_release
    ADD CONSTRAINT meta_release_upgrade_id_fkey FOREIGN KEY (upgrade_id) REFERENCES public.meta_release(id);


--
-- Name: password_recovery password_recovery_person_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.password_recovery
    ADD CONSTRAINT password_recovery_person_id_fkey FOREIGN KEY (person_id) REFERENCES public.person(id) ON DELETE CASCADE;


--
-- Name: pending_computer pending_computer_account_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.pending_computer
    ADD CONSTRAINT pending_computer_account_id_fkey FOREIGN KEY (account_id) REFERENCES public.account(id) ON DELETE CASCADE;


--
-- Name: pending_computer pending_computer_clone_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.pending_computer
    ADD CONSTRAINT pending_computer_clone_id_fkey FOREIGN KEY (clone_id) REFERENCES public.computer(id) ON DELETE SET NULL;


--
-- Name: person_access person_access_access_context_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.person_access
    ADD CONSTRAINT person_access_access_context_id_fkey FOREIGN KEY (access_context_id) REFERENCES public.access_context(id) ON DELETE CASCADE;


--
-- Name: person_access person_access_person_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.person_access
    ADD CONSTRAINT person_access_person_id_fkey FOREIGN KEY (person_id) REFERENCES public.person(id) ON DELETE CASCADE;


--
-- Name: person_account person_account_account_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.person_account
    ADD CONSTRAINT person_account_account_id_fkey FOREIGN KEY (account_id) REFERENCES public.account(id) ON DELETE CASCADE;


--
-- Name: person_account person_account_person_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.person_account
    ADD CONSTRAINT person_account_person_id_fkey FOREIGN KEY (person_id) REFERENCES public.person(id) ON DELETE CASCADE;


--
-- Name: ping_time ping_time_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.ping_time
    ADD CONSTRAINT ping_time_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer(id) ON DELETE CASCADE;


--
-- Name: role_access_context role_access_context_access_context_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.role_access_context
    ADD CONSTRAINT role_access_context_access_context_id_fkey FOREIGN KEY (access_context_id) REFERENCES public.access_context(id) ON DELETE CASCADE;


--
-- Name: role_access_context role_access_context_role_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.role_access_context
    ADD CONSTRAINT role_access_context_role_id_fkey FOREIGN KEY (role_id) REFERENCES public.role(id) ON DELETE CASCADE;


--
-- Name: role role_account_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.role
    ADD CONSTRAINT role_account_id_fkey FOREIGN KEY (account_id) REFERENCES public.account(id) ON DELETE CASCADE;


--
-- Name: role_permission role_permission_role_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.role_permission
    ADD CONSTRAINT role_permission_role_id_fkey FOREIGN KEY (role_id) REFERENCES public.role(id) ON DELETE CASCADE;


--
-- Name: role_person role_person_person_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.role_person
    ADD CONSTRAINT role_person_person_id_fkey FOREIGN KEY (person_id) REFERENCES public.person(id) ON DELETE CASCADE;


--
-- Name: role_person role_person_role_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.role_person
    ADD CONSTRAINT role_person_role_id_fkey FOREIGN KEY (role_id) REFERENCES public.role(id) ON DELETE CASCADE;


--
-- Name: salesforce_activated_asset salesforce_activated_asset_account_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.salesforce_activated_asset
    ADD CONSTRAINT salesforce_activated_asset_account_id_fkey FOREIGN KEY (account_id) REFERENCES public.account(id) ON DELETE CASCADE;


--
-- Name: salesforce_user salesforce_user_account_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.salesforce_user
    ADD CONSTRAINT salesforce_user_account_id_fkey FOREIGN KEY (account_id) REFERENCES public.account(id) ON DELETE CASCADE;


--
-- Name: salesforce_user salesforce_user_person_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.salesforce_user
    ADD CONSTRAINT salesforce_user_person_id_fkey FOREIGN KEY (person_id) REFERENCES public.person(id) ON DELETE CASCADE;


--
-- Name: snap snap_publisher_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.snap
    ADD CONSTRAINT snap_publisher_id_fkey FOREIGN KEY (publisher_id) REFERENCES public.snap_publisher(id) ON DELETE CASCADE;


--
-- Name: trial_account trial_account_account_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.trial_account
    ADD CONSTRAINT trial_account_account_id_fkey FOREIGN KEY (account_id) REFERENCES public.account(id) ON DELETE SET NULL;


--
-- Name: trial_account trial_account_creator_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.trial_account
    ADD CONSTRAINT trial_account_creator_id_fkey FOREIGN KEY (creator_id) REFERENCES public.person(id) ON DELETE CASCADE;


--
-- Name: utility_credit utility_credit_account_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.utility_credit
    ADD CONSTRAINT utility_credit_account_id_fkey FOREIGN KEY (account_id) REFERENCES public.account(id) ON DELETE CASCADE;


--
-- Name: TABLE access_context; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.access_context TO landscape;


--
-- Name: SEQUENCE access_context_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.access_context_id_seq TO landscape;


--
-- Name: TABLE account; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.account TO landscape;


--
-- Name: SEQUENCE account_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.account_id_seq TO landscape;


--
-- Name: TABLE account_invitation; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.account_invitation TO landscape;


--
-- Name: SEQUENCE account_invitation_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.account_invitation_id_seq TO landscape;


--
-- Name: TABLE api_credentials; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.api_credentials TO landscape;


--
-- Name: TABLE pending_computer; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.pending_computer TO landscape;


--
-- Name: SEQUENCE pending_computer_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.pending_computer_id_seq TO landscape;


--
-- Name: TABLE computer; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.computer TO landscape;


--
-- Name: SEQUENCE computer_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.computer_id_seq TO landscape;


--
-- Name: TABLE computer_license; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.computer_license TO landscape;


--
-- Name: TABLE computer_message_type; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.computer_message_type TO landscape;


--
-- Name: TABLE computer_relationship; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.computer_relationship TO landscape;


--
-- Name: TABLE computer_selection_data; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.computer_selection_data TO landscape;


--
-- Name: TABLE computer_status; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.computer_status TO landscape;


--
-- Name: TABLE computer_tag; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.computer_tag TO landscape;


--
-- Name: TABLE computer_utilisation; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.computer_utilisation TO landscape;


--
-- Name: TABLE distributed_lock; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.distributed_lock TO landscape;


--
-- Name: SEQUENCE distributed_lock_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.distributed_lock_id_seq TO landscape;


--
-- Name: TABLE distribution; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.distribution TO landscape;


--
-- Name: SEQUENCE distribution_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.distribution_id_seq TO landscape;


--
-- Name: TABLE enabled_feature; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.enabled_feature TO landscape;


--
-- Name: TABLE installed_snap; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.installed_snap TO landscape;


--
-- Name: TABLE invitation_role; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.invitation_role TO landscape;


--
-- Name: TABLE lds_available_release; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.lds_available_release TO landscape;


--
-- Name: TABLE lds_license; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.lds_license TO landscape;


--
-- Name: SEQUENCE lds_license_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.lds_license_id_seq TO landscape;


--
-- Name: TABLE lds_release; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,UPDATE ON TABLE public.lds_release TO landscape;


--
-- Name: TABLE lds_script_execution_log; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.lds_script_execution_log TO landscape;


--
-- Name: SEQUENCE lds_script_execution_log_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.lds_script_execution_log_id_seq TO landscape;


--
-- Name: TABLE license; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.license TO landscape;


--
-- Name: SEQUENCE license_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.license_id_seq TO landscape;


--
-- Name: TABLE license_lds_license; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.license_lds_license TO landscape;


--
-- Name: TABLE message_type; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT ON TABLE public.message_type TO landscape;


--
-- Name: SEQUENCE message_type_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.message_type_id_seq TO landscape;


--
-- Name: TABLE meta_release; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.meta_release TO landscape;


--
-- Name: SEQUENCE meta_release_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.meta_release_id_seq TO landscape;


--
-- Name: TABLE password_recovery; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.password_recovery TO landscape;


--
-- Name: TABLE person; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.person TO landscape;


--
-- Name: TABLE person_access; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.person_access TO landscape;


--
-- Name: TABLE person_account; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.person_account TO landscape;


--
-- Name: SEQUENCE person_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.person_id_seq TO landscape;


--
-- Name: TABLE ping_server; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.ping_server TO landscape;


--
-- Name: SEQUENCE ping_server_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.ping_server_id_seq TO landscape;


--
-- Name: TABLE ping_time; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.ping_time TO landscape;


--
-- Name: TABLE removed_account_name; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT ON TABLE public.removed_account_name TO landscape;


--
-- Name: SEQUENCE removed_account_name_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.removed_account_name_id_seq TO landscape;


--
-- Name: TABLE role; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.role TO landscape;


--
-- Name: TABLE role_access_context; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.role_access_context TO landscape;


--
-- Name: SEQUENCE role_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.role_id_seq TO landscape;


--
-- Name: TABLE role_permission; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.role_permission TO landscape;


--
-- Name: TABLE role_person; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.role_person TO landscape;


--
-- Name: TABLE salesforce_activated_asset; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.salesforce_activated_asset TO landscape;


--
-- Name: TABLE salesforce_user; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.salesforce_user TO landscape;


--
-- Name: SEQUENCE salesforce_user_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.salesforce_user_id_seq TO landscape;


--
-- Name: TABLE server_identity; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.server_identity TO landscape;


--
-- Name: TABLE snap; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.snap TO landscape;


--
-- Name: TABLE snap_publisher; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.snap_publisher TO landscape;


--
-- Name: SEQUENCE snap_publisher_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.snap_publisher_id_seq TO landscape;


--
-- Name: TABLE system_configuration; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.system_configuration TO landscape;


--
-- Name: TABLE tag; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT ON TABLE public.tag TO landscape;


--
-- Name: SEQUENCE tag_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.tag_id_seq TO landscape;


--
-- Name: TABLE trial_account; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.trial_account TO landscape;


--
-- Name: SEQUENCE trial_account_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.trial_account_id_seq TO landscape;


--
-- Name: TABLE utility_cost; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.utility_cost TO landscape;


--
-- Name: SEQUENCE utility_cost_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.utility_cost_id_seq TO landscape;


--
-- Name: TABLE utility_credit; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.utility_credit TO landscape;


--
-- Name: SEQUENCE utility_credit_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.utility_credit_id_seq TO landscape;


--
-- Name: TABLE vat_rate; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.vat_rate TO landscape;


--
-- Name: SEQUENCE vat_rate_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.vat_rate_id_seq TO landscape;


--
-- PostgreSQL database dump complete
--

