--
-- PostgreSQL database dump
--

-- Dumped from database version 12.15 (Ubuntu 12.15-0ubuntu0.20.04.1)
-- Dumped by pg_dump version 12.15 (Ubuntu 12.15-0ubuntu0.20.04.1)

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET xmloption = content;
SET client_min_messages = warning;
SET row_security = off;

--
-- Name: plpython3u; Type: PROCEDURAL LANGUAGE; Schema: -; Owner: -
--

CREATE OR REPLACE PROCEDURAL LANGUAGE plpython3u;


--
-- Name: debversion; Type: EXTENSION; Schema: -; Owner: -
--

CREATE EXTENSION IF NOT EXISTS debversion WITH SCHEMA public;


--
-- Name: EXTENSION debversion; Type: COMMENT; Schema: -; Owner: -
--

COMMENT ON EXTENSION debversion IS 'A Debian version number data type';


--
-- Name: pg_trgm; Type: EXTENSION; Schema: -; Owner: -
--

CREATE EXTENSION IF NOT EXISTS pg_trgm WITH SCHEMA public;


--
-- Name: EXTENSION pg_trgm; Type: COMMENT; Schema: -; Owner: -
--

COMMENT ON EXTENSION pg_trgm IS 'text similarity measurement and index searching based on trigrams';


--
-- Name: text_as_grams(text); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION public.text_as_grams(i_txt text) RETURNS text
    LANGUAGE plpython3u
    AS $$

import re

WORD_SPLIT_PATTERN = re.compile(r"\s+", re.UNICODE)

def get_word_grams(text, unique=True):
    '''
    This function operates on a single word, returning trigrams for that
    word.

    Text grams are non-semantic, non-phonological word components determined
    solely by the positions of letters in a word. The most common form used is
    word "trigrams", where a word of three letters or more can generate a word
    part for every sequential block of three letters.

    This is intended to be used with PostgreSQL's full text search in order to
    provide substring search support. As such, keep in mind that PostgreSQL
    will process all n-grams with its to_tsvector function. This could include
    changes from stemming or exclusion due to matching a stop word.

    @param unique: a boolean that is used to determine if the calculated
        trigrams should include dupicates or not. Defaults to removing the
        duplicates.
    '''
    gram_length = 3
    text_length = len(text)
    if 0 < text_length <= gram_length:
        return [text]

    grams = []
    offset = gram_length - 1
    for index in range(text_length - offset):
        gram = text[index:index+gram_length]
        if unique and gram in grams:
            continue
        grams.append(gram)
    return grams

def get_text_grams(text, unique=True):
    '''
    This function operates on multiple words and can be used against multi-word
    text in, returning all the trigrams for the words present.

    For information on the parameters, see the docstring for C{get_word_grams}.
    '''
    grams = []
    words = WORD_SPLIT_PATTERN.split(text)
    for word in words:
        grams.extend(get_word_grams(word, unique=unique))
    return grams


def get_text_grams_as_text(text, unique=True, separator=u" ",
                           include_original=False):
    '''Return text grams as text, instead of as a list.
    '''
    grams = get_text_grams(text, unique=unique)
    if include_original:
        grams.append(text)
    return separator.join(grams)

return get_text_grams_as_text(i_txt)

$$;


--
-- Name: update_package_tsvector(); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION public.update_package_tsvector() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
    IF TG_OP = 'INSERT' THEN
        IF (NEW.name_search_vector IS NULL) THEN
            NEW.name_search_vector :=
                SETWEIGHT(TO_TSVECTOR('simple',
                                      COALESCE(text_as_grams(NEW.name), '')),
                          'A');
        END IF;
        IF (NEW.text_search_vector IS NULL) THEN
            NEW.text_search_vector :=
                SETWEIGHT(TO_TSVECTOR('public.landscape_english',
                                      COALESCE(NEW.summary, '')), 'B') ||
                SETWEIGHT(TO_TSVECTOR('public.landscape_english',
                                      COALESCE(NEW.description, '')), 'C');
        END IF;
    END IF;

    IF TG_OP = 'UPDATE' THEN
        IF (NEW.name_search_vector = OLD.name_search_vector AND
            NOT NEW.name = OLD.name) THEN
            NEW.name_search_vector :=
                SETWEIGHT(TO_TSVECTOR('simple',
                                      COALESCE(text_as_grams(NEW.name), '')),
                          'A');
        END IF;
        IF (NEW.text_search_vector = OLD.text_search_vector AND
            (NOT (NEW.summary = OLD.summary
                  AND NEW.description = OLD.description))) THEN
            NEW.text_search_vector :=
                SETWEIGHT(TO_TSVECTOR('public.landscape_english',
                                      COALESCE(NEW.summary, '')), 'B') ||
                SETWEIGHT(TO_TSVECTOR('public.landscape_english',
                                      COALESCE(NEW.description, '')), 'C');
        END IF;
    END IF;
    RETURN NEW;
END
$$;


--
-- Name: landscape_english; Type: TEXT SEARCH CONFIGURATION; Schema: public; Owner: -
--

CREATE TEXT SEARCH CONFIGURATION public.landscape_english (
    PARSER = pg_catalog."default" );

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR asciiword WITH english_stem;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR word WITH english_stem;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR numword WITH simple;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR email WITH simple;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR url WITH simple;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR host WITH simple;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR sfloat WITH simple;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR version WITH simple;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR hword_numpart WITH simple;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR hword_part WITH english_stem;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR hword_asciipart WITH english_stem;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR numhword WITH simple;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR asciihword WITH english_stem;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR hword WITH english_stem;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR url_path WITH simple;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR file WITH simple;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR "float" WITH simple;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR "int" WITH simple;

ALTER TEXT SEARCH CONFIGURATION public.landscape_english
    ADD MAPPING FOR uint WITH simple;


SET default_tablespace = '';

SET default_table_access_method = heap;

--
-- Name: cve; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.cve (
    usn_id integer NOT NULL,
    id character varying(30) NOT NULL
);


--
-- Name: name; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.name (
    id integer NOT NULL,
    name text NOT NULL
);


--
-- Name: name_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.name_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: name_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.name_id_seq OWNED BY public.name.id;


--
-- Name: package; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.package (
    id integer NOT NULL,
    hash bytea NOT NULL,
    type integer NOT NULL,
    name text NOT NULL,
    version public.debversion NOT NULL,
    section text,
    summary text,
    description text,
    size bigint,
    installed_size bigint,
    usn_id integer,
    name_search_vector tsvector,
    text_search_vector tsvector,
    creation_time timestamp without time zone DEFAULT timezone('UTC'::text, now()) NOT NULL
);


--
-- Name: package_binary; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.package_binary (
    package_id integer NOT NULL,
    data bytea NOT NULL
);


--
-- Name: package_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.package_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: package_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.package_id_seq OWNED BY public.package.id;


--
-- Name: package_lock; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.package_lock (
    id integer NOT NULL,
    value text NOT NULL
);


--
-- Name: package_lock_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.package_lock_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: package_lock_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.package_lock_id_seq OWNED BY public.package_lock.id;


--
-- Name: usn; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.usn (
    id integer NOT NULL,
    summary text NOT NULL,
    release_time timestamp without time zone
);


--
-- Name: name id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.name ALTER COLUMN id SET DEFAULT nextval('public.name_id_seq'::regclass);


--
-- Name: package id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.package ALTER COLUMN id SET DEFAULT nextval('public.package_id_seq'::regclass);


--
-- Name: package_lock id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.package_lock ALTER COLUMN id SET DEFAULT nextval('public.package_lock_id_seq'::regclass);


--
-- Name: cve cve_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.cve
    ADD CONSTRAINT cve_pkey PRIMARY KEY (usn_id, id);


--
-- Name: name name_name_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.name
    ADD CONSTRAINT name_name_key UNIQUE (name);


--
-- Name: name name_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.name
    ADD CONSTRAINT name_pkey PRIMARY KEY (id);


--
-- Name: package_binary package_binary_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.package_binary
    ADD CONSTRAINT package_binary_pkey PRIMARY KEY (package_id);


--
-- Name: package package_hash_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.package
    ADD CONSTRAINT package_hash_key UNIQUE (hash);


--
-- Name: package_lock package_lock_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.package_lock
    ADD CONSTRAINT package_lock_pkey PRIMARY KEY (id);


--
-- Name: package_lock package_lock_value_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.package_lock
    ADD CONSTRAINT package_lock_value_key UNIQUE (value);


--
-- Name: package package_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.package
    ADD CONSTRAINT package_pkey PRIMARY KEY (id);


--
-- Name: usn usn_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.usn
    ADD CONSTRAINT usn_pkey PRIMARY KEY (id);


--
-- Name: name_search_vector_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX name_search_vector_idx ON public.package USING gin (name_search_vector);


--
-- Name: name_trgm; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX name_trgm ON public.package USING gin (name public.gin_trgm_ops);


--
-- Name: package_name_version_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX package_name_version_idx ON public.package USING btree (name, version);


--
-- Name: package_usn_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX package_usn_id_idx ON public.package USING btree (usn_id);


--
-- Name: text_search_vector_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX text_search_vector_idx ON public.package USING gin (text_search_vector);


--
-- Name: package package_inserted; Type: TRIGGER; Schema: public; Owner: -
--

CREATE TRIGGER package_inserted BEFORE INSERT OR UPDATE ON public.package FOR EACH ROW EXECUTE FUNCTION public.update_package_tsvector();


--
-- Name: cve cve_usn_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.cve
    ADD CONSTRAINT cve_usn_id_fkey FOREIGN KEY (usn_id) REFERENCES public.usn(id) ON DELETE CASCADE;


--
-- Name: package_binary package_binary_package_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.package_binary
    ADD CONSTRAINT package_binary_package_id_fkey FOREIGN KEY (package_id) REFERENCES public.package(id) ON DELETE CASCADE;


--
-- Name: package package_usn_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.package
    ADD CONSTRAINT package_usn_id_fkey FOREIGN KEY (usn_id) REFERENCES public.usn(id) ON DELETE SET NULL;


--
-- Name: TABLE cve; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.cve TO landscape;


--
-- Name: TABLE name; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT ON TABLE public.name TO landscape;


--
-- Name: SEQUENCE name_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.name_id_seq TO landscape;


--
-- Name: TABLE package; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.package TO landscape;


--
-- Name: TABLE package_binary; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.package_binary TO landscape;


--
-- Name: SEQUENCE package_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.package_id_seq TO landscape;


--
-- Name: TABLE package_lock; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.package_lock TO landscape;


--
-- Name: SEQUENCE package_lock_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.package_lock_id_seq TO landscape;


--
-- Name: TABLE usn; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.usn TO landscape;


--
-- PostgreSQL database dump complete
--

