# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Add support for performing full text search against articles in the knowledge
base.
"""
from __future__ import print_function

command_create_configuration = """
    CREATE TEXT SEARCH CONFIGURATION
        public.landscape_english (COPY = pg_catalog.english)
    """

command_set_default_configuration = """
    SET default_text_search_config = 'public.landscape_english';
    """

command_set_ascii_mapper = """
    ALTER TEXT SEARCH CONFIGURATION public.landscape_english
       ALTER MAPPING FOR asciiword WITH english_stem;
    """

command_add_new_field = """
    ALTER TABLE article ADD COLUMN text_search tsvector
    """

command_coalesce_title_and_body = """
    UPDATE article SET text_search =
        to_tsvector(
            'public.landscape_english',
            title || ' ' || body);
    """

command_create_index = """
    CREATE INDEX text_search_idx ON article USING gin(text_search);
    """

command_create_trigger = """
    CREATE TRIGGER text_search_update_trigger BEFORE INSERT OR UPDATE
    ON article FOR EACH ROW EXECUTE PROCEDURE
    tsvector_update_trigger(
        text_search, 'public.landscape_english', title, body);
    """


def apply(store):
    print("Creating a text search configuration for the knowledge base.")
    store.execute(command_create_configuration)
    print("Setting the new configuration as the default one.")
    store.execute(command_set_default_configuration)
    print("Setting the ASCII knowledge base text search to use stemming.")
    store.execute(command_set_ascii_mapper)
    print("Adding a text search vector field to the article table.")
    store.execute(command_add_new_field)
    print("Setting up article title and body to be used for text search.")
    store.execute(command_coalesce_title_and_body)
    print("Creating an index for the text search field.")
    store.execute(command_create_index)
    print("Creating a trigger for updating the text search vector.")
    store.execute(command_create_trigger)
