# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Update the TrialAccount.company_size column to be a ranged selection
list.
"""
from __future__ import print_function

from canonical.landscape.model.main.account import TrialAccount

statements = [
    """
ALTER TABLE trial_account ALTER COLUMN company_size TYPE VARCHAR(20)
""",
    """
ALTER TABLE trial_account ADD COLUMN desktops VARCHAR(20)
""",
    """
ALTER TABLE trial_account ADD COLUMN servers VARCHAR(20)
""",
    """
ALTER TABLE trial_account ADD COLUMN first_name TEXT
""",
    """
ALTER TABLE trial_account ADD COLUMN last_name TEXT
""",
    """
ALTER TABLE trial_account ADD COLUMN support BOOLEAN NOT NULL DEFAULT FALSE
""",
    """
ALTER TABLE trial_account ADD COLUMN city TEXT
""",
]


def lookup_new_company_size(current_size):
    current_size = int(current_size)
    if current_size >= 1 and current_size <= 49:
        return "1-49"
    elif current_size >= 50 and current_size <= 99:
        return "50-99"
    elif current_size >= 100 and current_size <= 249:
        return "100-249"
    elif current_size >= 250 and current_size <= 499:
        return "250-499"
    elif current_size >= 500 and current_size <= 999:
        return "500-999"
    elif current_size >= 1000 and current_size <= 4999:
        return "1,000-4,999"
    elif current_size >= 5000 and current_size <= 9999:
        return "5,000-9,999"
    elif current_size >= 10000 and current_size <= 24999:
        return "10,000-24,999"
    elif current_size >= 25000 and current_size <= 49999:
        return "25,000-49,999"
    elif current_size >= 50000 and current_size <= 99999:
        return "50,000-99,999"
    elif current_size >= 100000:
        return "100,000+"


def apply(store):
    print(__doc__)
    for statement in statements:
        store.execute(statement)

    for trial_account in store.find(TrialAccount):
        trial_account.company_size = lookup_new_company_size(trial_account.company_size)
