# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Remove unknown package ids from the computer_packages table.
WARNING: This could take several minutes.
"""
from __future__ import print_function

from storm.expr import Insert

from canonical.landscape.model.configuration import is_standalone
from canonical.landscape.model.package.store import get_package_store


def apply(store):
    # only run this on LDS, as it would be very slow for huge deployments
    if not is_standalone():
        return

    print(__doc__)

    result = get_package_store().execute("SELECT id FROM package")
    package_ids = [row[0] for row in result]

    # import package ids from the package database in a temporary table, will
    # be dropped automatically at the end of the transaction.
    store.execute(
        "CREATE TEMPORARY TABLE temp_package (id integer primary key) " "ON COMMIT DROP"
    )
    insert = Insert(["id"], values=package_ids, table="temp_package")
    store.execute(insert)

    # update each column with the intersection between arrays
    store.execute(
        """
        WITH package_ids AS (SELECT array_agg(id) AS all_ids FROM temp_package)
        UPDATE computer_packages
        SET available = available & all_ids,
            available_upgrades = available_upgrades & all_ids,
            installed = installed & all_ids,
            held = held & all_ids
        FROM package_ids
        """
    )
