# Copyright 2005-2014 Canonical Limited.  All rights reserved.

"""
Add update_computer_packages stored procedure.
"""
from __future__ import print_function

STATEMENTS = [
    """
CREATE FUNCTION update_computer_packages(
  computer_id INT, available INT[], available_upgrades INT[],
  installed INT[], held INT[], not_available INT[],
  not_available_upgrades INT[], not_installed INT[], not_held INT[],
  reset BOOL)
RETURNS BOOL AS
$$
  def update_set(s, add, remove):
    '''Add/remove elements to/from a set and return resultin elements'''
    s.difference_update(remove)
    s.update(add)
    return list(s)

  if reset:
    packages = {
      "available": set(),
      "available_upgrades": set(),
      "installed": set(),
      "held": set()}
  else:
    # get current packages
    packages_plan = plpy.prepare('''
      SELECT available, available_upgrades, installed, held
      FROM computer_packages
      WHERE computer_id = $1''', ["int"])
    packages = plpy.execute(packages_plan, [computer_id])[0]
    packages = dict((key, set(value)) for key, value in packages.iteritems())

  params = [
    update_set(packages["available"], available, not_available),
    update_set(
      packages["available_upgrades"], available_upgrades,
      not_available_upgrades),
    update_set(packages["installed"], installed, not_installed),
    update_set(packages["held"], held, not_held),
    computer_id]

  update_packages_plan = plpy.prepare('''
      UPDATE computer_packages
      SET available = $1, available_upgrades = $2, installed = $3, held = $4
      WHERE computer_id = $5''',
     ["int[]", "int[]", "int[]", "int[]", "int"])
  plpy.execute(update_packages_plan, params)

  return True
$$
LANGUAGE plpythonu
""",
    """
GRANT EXECUTE
    ON FUNCTION update_computer_packages(
      INT, INT[], INT[], INT[], INT[], INT[], INT[], INT[], INT[], BOOL)
    TO landscape
""",
    """
DROP FUNCTION change_array(INT[], INT[], INT[])
""",
]


def apply(store):
    print(__doc__)

    for statement in STATEMENTS:
        store.execute(statement)
