# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Add license_key to all Licenses."""
from __future__ import print_function
from canonical.landscape.application import is_standalone
import os


def make_secure_id():
    """Generate a 64 character unique ID."""
    s = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
    l = len(s)
    return "".join([s[ord(c) % l] for c in os.urandom(64)])


def apply(store):

    print(__doc__)
    store.execute("ALTER TABLE license " "ADD COLUMN license_key BYTEA DEFAULT ''")
    if is_standalone():
        print(
            "Not assigning license_keys in account database because "
            "standalone install detected."
        )
    else:
        license_ids = store.execute("SELECT license.id FROM license").get_all()
        for license_id in license_ids:
            store.execute(
                "UPDATE license SET license_key = ? " "WHERE license.id = ?",
                (make_secure_id(), license_id),
            )
    store.execute("ALTER TABLE license " "ADD UNIQUE(license_key)")
