# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Add LDS License Mapping."""
from __future__ import print_function

LDS_FEATURES_ROLE_KEY = 10002

statements = [
    """
CREATE TABLE license_lds_license (
    lds_license_id INTEGER NOT NULL REFERENCES lds_license ON DELETE CASCADE,
    license_id INTEGER NOT NULL REFERENCES license ON DELETE CASCADE,
    PRIMARY KEY (lds_license_id, license_id))
""",
    """
GRANT SELECT, INSERT, DELETE
    ON TABLE license_lds_license TO landscape, landscape_maintenance
""",
    """
CREATE INDEX license_lds_license_license_id_idx ON
    license_lds_license(license_id)
""",
]


def apply(store):
    print(__doc__)

    for statement in statements:
        store.execute(statement)

    licenses = store.execute(
        "SELECT lds_license.id, license.id from lds_license, license WHERE "
        "  lds_license.license_id = license.id AND license.role_key = ?",
        (LDS_FEATURES_ROLE_KEY,),
    ).get_all()

    for lds_license_id, license_id in licenses:
        store.execute(
            "INSERT INTO license_lds_license VALUES (?, ?)",
            (lds_license_id, license_id),
        )

    store.execute("ALTER TABLE lds_license DROP COLUMN license_id")
