# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Move computer status fields to a new computer_status table.
"""
from __future__ import print_function


def apply(store):
    print(__doc__)

    store.execute(
        "CREATE TABLE computer_status ( "
        "computer_id integer NOT NULL PRIMARY KEY "
        "REFERENCES computer(id) ON DELETE CASCADE, "
        "next_expected_sequence INTEGER, "
        "consecutive_errors INTEGER DEFAULT 0 NOT NULL, "
        "last_exchange_time TIMESTAMP, "
        "soft_lock_time TIMESTAMP, "
        "is_inconsistent BOOLEAN DEFAULT FALSE NOT NULL, "
        "reboot_required_flag boolean DEFAULT FALSE NOT NULL "
        ")"
    )

    store.execute(
        "CREATE INDEX computer_status_consecutive_errors_idx "
        "ON computer_status (consecutive_errors) "
        "WHERE consecutive_errors >= 1 "
    )

    store.execute(
        "GRANT SELECT, INSERT, DELETE, UPDATE "
        "ON TABLE computer_status TO landscape, "
        "landscape_maintenance"
    )

    store.execute(
        "INSERT INTO computer_status ( "
        "computer_id, next_expected_sequence, consecutive_errors, "
        "last_exchange_time, soft_lock_time, is_inconsistent, "
        "reboot_required_flag) "
        "SELECT id, next_expected_sequence, consecutive_errors, "
        "last_exchange_time, soft_lock_time, is_inconsistent, "
        "reboot_required_flag FROM computer"
    )

    store.execute("DROP INDEX computer_consecutive_errors_idx")

    store.execute(
        "ALTER TABLE computer "
        "DROP COLUMN next_expected_sequence, "
        "DROP COLUMN consecutive_errors, "
        "DROP COLUMN last_exchange_time, "
        "DROP COLUMN soft_lock_time, "
        "DROP COLUMN is_inconsistent, "
        "DROP COLUMN reboot_required_flag"
    )
