# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Create ec2_region table and fill with initial 6 known regions.
Will allow dynamic updates in the future w/ dev/maintenance
"""
from __future__ import print_function

statements = [
    # Create the new table
    """
CREATE TABLE ec2_region (
    id SERIAL NOT NULL PRIMARY KEY,
    name TEXT NOT NULL UNIQUE,
    title TEXT NOT NULL UNIQUE,
    url TEXT NOT NULL UNIQUE)
""",
    """
GRANT SELECT, INSERT, DELETE, UPDATE
    ON TABLE ec2_region TO landscape_maintenance
""",
    """
GRANT SELECT, INSERT, UPDATE
    ON TABLE ec2_region TO landscape
""",
    """
GRANT SELECT, UPDATE
    ON TABLE ec2_region_id_seq TO landscape, landscape_maintenance
""",
    # Stuff known initial ec2_region data into table. Need to provide
    # addtional functionality to dev/maintenance to update amazon region data
    """
INSERT INTO ec2_region (name, title, url) VALUES
('us-east-1', 'Amazon US East', 'https://ec2.us-east-1.amazonaws.com'),
('us-west-1', 'Amazon US West (N. California)',
    'https://ec2.us-west-1.amazonaws.com'),
('us-west-2', 'Amazon US West (Oregon)',
    'https://ec2.us-west-2.amazonaws.com'),
('eu-west-1', 'Amazon Europe','https://ec2.eu-west-1.amazonaws.com'),
('ap-southeast-1', 'Amazon Asia Pacific (Singapore)',
    'https://ec2.ap-southeast-1.amazonaws.com'),
('ap-northeast-1', 'Amazon Asia Pacific (Tokyo)',
    'https://ec2.ap-northeast-1.amazonaws.com'),
('sa-east-1', 'Amazon South America (Sao Paulo)',
    'https://ec2.sa-east-1.amazonaws.com')
""",
    """
ALTER TABLE ec2_current_image
    ADD COLUMN region_id INTEGER REFERENCES ec2_region
    ON DELETE CASCADE
""",
    """
UPDATE ec2_current_image SET region_id=ec2_region.id FROM ec2_region
WHERE ec2_current_image.region = ec2_region.url
""",
    # Drop old region TEXT column to be replaced by region_id
    """
ALTER TABLE ec2_current_image
  DROP COLUMN region
""",
    """
ALTER TABLE ec2_current_image ALTER COLUMN region_id SET NOT NULL
""",
    # Setup UNIQUE contraint on new ec2_current_image.region_id column
    """
ALTER TABLE ec2_current_image
    ADD CONSTRAINT ec2_current_image_ubuntu_release_name_key
        UNIQUE (ubuntu_release_name, bits, region_id, image_type, hypervisor)
""",
]


def apply(store):
    print(__doc__)

    for statement in statements:
        store.execute(statement)
