# Copyright 2005-2014 Canonical Limited.  All rights reserved.

"""Drop extra indexes on resource tables."""
from __future__ import print_function

TABLES = [
    "ceph_usage",
    "cpu_usage",
    "load_average",
    "memory_info",
    "temperature",
    "custom_graph_data_point",
]

SUFFIXES = ["idx", "idx1", "key"]


def apply(store):
    print(__doc__)

    queries = _free_space_tables_queries(store) + _resource_tables_queries(store)
    for query in queries:
        store.execute(query, noresult=True)


def _find_partitioned_tables(store, table):
    """
    Return a list with partitioned tables for the specified table (including
    the master table itself).
    """
    tables = [table]
    result = store.execute(
        "SELECT tablename FROM pg_tables "
        "WHERE schemaname='public' AND tablename LIKE '%s_%%'" % table
    )
    tables.extend(row[0] for row in result.get_all())
    return tables


def _free_space_tables_queries(store):
    """Return queries to drop extra indexes on the free_space table."""
    queries = [
        "DROP INDEX IF EXISTS %(table)s_mount_info_id_%(suffix)s",
        "DROP INDEX IF EXISTS %(table)s_timestamp_%(suffix)s",
    ]

    tables = _find_partitioned_tables(store, "free_space")
    return [
        query % {"table": table, "suffix": suffix}
        for query in queries
        for table in tables
        for suffix in SUFFIXES
    ]


def _resource_tables_queries(store):
    """Return queries to drop extra indexes in resource tables."""
    queries = [
        "DROP INDEX IF EXISTS %(table)s_computer_id_%(suffix)s",
        "DROP INDEX IF EXISTS %(table)s_timestamp_%(suffix)s",
    ]

    tables = []
    for table in TABLES:
        tables.extend(_find_partitioned_tables(store, table))
    return [
        query % {"table": table, "suffix": suffix}
        for query in queries
        for table in tables
        for suffix in SUFFIXES
    ]
