# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Add uid and gid columns to existing opinfo tables.  Also drop NOT NULL
constraints from various add_user_opinfo columns.
"""
from __future__ import print_function


def apply(store):
    print(__doc__)
    add_uid_column(store)
    add_gid_column(store)
    drop_constraints(store)


def add_uid_column(store):
    """Add the C{uid} column to the required tables."""
    tables = (
        "generic_user_opinfo",
        "add_user_opinfo",
        "edit_user_opinfo",
        "delete_user_opinfo",
        "add_group_member_opinfo",
        "remove_group_member_opinfo",
    )

    for table in tables:
        store.execute("ALTER TABLE %s ADD COLUMN uid INTEGER" % table)

    for table in tables:
        result = store.execute("SELECT uid, username FROM computer_user")
        for uid, username in result:
            store.execute(
                "UPDATE %s SET uid = ? WHERE username = ?" % table, (uid, username)
            )

    for table in (
        "generic_user_opinfo",
        "edit_user_opinfo",
        "remove_group_member_opinfo",
    ):
        store.execute("ALTER TABLE %s ALTER COLUMN uid SET NOT NULL" % table)


def add_gid_column(store):
    """Add the C{gid} column to the required tables."""
    tables = (
        "create_group_opinfo",
        "add_group_member_opinfo",
        "remove_group_member_opinfo",
    )
    for table in tables:
        store.execute("ALTER TABLE %s ADD COLUMN gid INTEGER" % table)

    for table in tables:
        result = store.execute("SELECT gid, name FROM computer_group")
        for gid, groupname in result:
            store.execute(
                "UPDATE %s SET gid = ? WHERE groupname = ?" % table, (gid, groupname)
            )

    for table in ("remove_group_member_opinfo",):
        store.execute("ALTER TABLE %s ALTER COLUMN gid SET NOT NULL" % table)


def drop_constraints(store):
    """
    Drop NOT NULL constraints from the C{name}, C{passphrase} and
    C{require_password_reset} columns of the C{add_user_opinfo} table.
    """
    store.execute("ALTER TABLE add_user_opinfo " "    ALTER COLUMN name DROP NOT NULL")
    store.execute(
        "ALTER TABLE add_user_opinfo " "    ALTER COLUMN passphrase DROP NOT NULL"
    )
    store.execute(
        "ALTER TABLE add_user_opinfo "
        "    ALTER COLUMN require_password_reset DROP NOT NULL"
    )
