# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Add tables to store the new RBAC model."""
from __future__ import print_function


STATEMENTS = [
    """
CREATE TABLE role (
    id SERIAL NOT NULL PRIMARY KEY,
    account_id INTEGER NOT NULL REFERENCES account ON DELETE CASCADE,
    name TEXT NOT NULL,
    description TEXT,
    UNIQUE(account_id, name))
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE role TO landscape
""",
    """
GRANT SELECT, UPDATE
    ON TABLE role_id_seq TO landscape
""",
    """
CREATE TABLE role_permission (
    role_id INTEGER NOT NULL REFERENCES role ON DELETE CASCADE,
    permission TEXT NOT NULL,
    UNIQUE(role_id, permission))
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE role_permission TO landscape
""",
    """
CREATE TABLE role_access_context (
    role_id INTEGER NOT NULL REFERENCES role ON DELETE CASCADE,
    access_context_id INTEGER NOT NULL
        REFERENCES access_context ON DELETE CASCADE,
    UNIQUE(role_id, access_context_id))
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE role_access_context TO landscape
""",
    """
CREATE TABLE role_person (
    role_id INTEGER NOT NULL REFERENCES role ON DELETE CASCADE,
    person_id INTEGER NOT NULL REFERENCES person ON DELETE CASCADE,
    UNIQUE(role_id, person_id))
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE role_person TO landscape
""",
]


def apply(store):
    print(__doc__)

    for statement in STATEMENTS:
        store.execute(statement)
