# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Change access_control to better support hierarchies."""
from __future__ import print_function


STATEMENTS = [
    """
ALTER TABLE access_context ADD COLUMN root_access_context_id
     INTEGER REFERENCES access_context
""",
    """
ALTER TABLE access_context DROP CONSTRAINT %s
""",
    """
UPDATE access_context SET root_access_context_id = id
    WHERE access_context_id IS NULL
""",
    """
UPDATE access_context SET root_access_context_id = access_context_id
    WHERE access_context_id IS NOT NULL
""",
    """
ALTER TABLE access_context ADD CONSTRAINT
    access_context_root_access_context_id_key
    UNIQUE (root_access_context_id, title)
""",
]


def apply(store):
    print(__doc__)

    # The UNIQUE(access_context_id, title) constraint name is different
    # if the db has been created with Pg 8 or 9
    constraint = store.execute(
        "SELECT conname FROM pg_constraint, pg_class "
        "WHERE pg_constraint.conrelid=pg_class.oid AND "
        "pg_class.relname='access_context' "
        "AND conkey='{2,3}'"
    ).get_one()[0]
    statements = STATEMENTS[:]
    statements[1] = statements[1] % constraint

    for statement in statements:
        store.execute(statement)
