# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Add name field to access_context."""
from __future__ import print_function

from builtins import str
import re
import unicodedata


def slug_from_title(title, default, max_root_length, existing_check):
    # copied from from canonical.lib.text.slug_from_title, for future proof
    normalised_title = unicodedata.normalize("NFKD", title)
    normalised_title = normalised_title.encode("ascii", "ignore")
    slug = str(re.sub("[^\w\s-]", "", normalised_title).strip())
    slug = re.sub("[-\s]+", "-", slug.lower())
    if not slug:
        slug = default
    root = slug = slug[:max_root_length]
    counter = 0
    existing = existing_check(slug)
    while slug in existing:
        counter += 1
        slug = "%s%d" % (root, counter)
    return slug


def apply(store):
    print(__doc__)

    # first, add the name column
    store.execute("ALTER TABLE access_context ADD COLUMN name TEXT")
    store.execute(
        "ALTER TABLE access_context ADD UNIQUE (root_access_context_id, name)"
    )

    root_access_contexts = store.execute(
        "SELECT id FROM access_context WHERE access_context_id IS NULL"
    )
    for root_access_context in root_access_contexts:
        # create unique names from title within each account
        access_contexts = store.execute(
            "SELECT id, title FROM access_context " "WHERE root_access_context_id = ?",
            (root_access_context[0],),
        )

        names = set()

        def existing_check(slug):
            return (name for name in names if name.startswith(slug))

        for id, title in access_contexts:
            name = slug_from_title(title, "access-group-", 20, existing_check)
            names.add(name)
            store.execute("UPDATE access_context SET name = ? WHERE id = ?", (name, id))

    # name column has been filled, add constraint
    store.execute("ALTER TABLE access_context ALTER COLUMN name SET NOT NULL")
