# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Downgrade legacy RBAC admins into account members"""
from __future__ import print_function


def apply(store):
    print(__doc__)

    # Get the IDs of all restricted admins, grouped by access context ID
    result = store.execute(
        "SELECT access_context_id, ARRAY_AGG(person_id) FROM person_access"
        "    WHERE access_context_id  IN ("
        "        SELECT id FROM access_context"
        "        WHERE access_context_id IS NOT NULL)"
        "    GROUP BY access_context_id"
    )

    for row in result:
        access_context_id, person_ids = row

        # Get the title of the access context and the ID of its account
        parent_id, title, name = store.execute(
            "SELECT access_context_id, title, name FROM access_context " "WHERE id = ?",
            (access_context_id,),
        ).get_one()
        account_id = store.execute(
            "SELECT id FROM account WHERE access_context_id = ?", (parent_id,)
        ).get_one()[0]

        # Create a role, specific to the access context
        name = "Role_%s" % name
        description = "Administrator of access group '%s'" % title
        role_id = store.execute(
            "INSERT INTO role (account_id, name, description) VALUES (?, ?, ?)"
            "    RETURNING id",
            (account_id, name, description),
        ).get_one()[0]

        # Include the restricted admins in the role
        for person_id in person_ids:
            store.execute(
                "INSERT INTO role_person (role_id, person_id) VALUES (?, ?)",
                (role_id, person_id),
            )

        # Associate the access context with the role
        store.execute(
            "INSERT INTO role_access_context (role_id, access_context_id)"
            "    VALUES (?, ?)",
            (role_id, access_context_id),
        )

        # Grant permissions to manage computers
        for permission in ["ManageComputer", "ViewScript"]:
            store.execute(
                "INSERT INTO role_permission (role_id, permission)" "    VALUES (?, ?)",
                (role_id, permission),
            )

        # Update the low-level person_access table
        role_key = role_id + 100000  # copied from c.l.security.roles
        store.execute(
            "UPDATE person_access SET role_key = ?" "    WHERE access_context_id = ?",
            (role_key, access_context_id),
        )
