# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Add an ID column to trial_account."""
from __future__ import print_function

STATEMENTS = [
    """
ALTER TABLE trial_account ADD COLUMN id SERIAL NOT NULL PRIMARY KEY;
""",
    """
GRANT SELECT, UPDATE ON TABLE trial_account_id_seq TO landscape
""",
    """
ALTER TABLE trial_account ADD CONSTRAINT trial_account_account_id_fkey
    FOREIGN KEY (account_id) REFERENCES account(id) ON DELETE SET NULL
""",
    """
ALTER TABLE trial_account ADD COLUMN secure_id TEXT UNIQUE;
""",
    """
ALTER TABLE trial_account ADD COLUMN company_name TEXT;
""",
    """
ALTER TABLE trial_account DROP COLUMN name;
""",
    """
ALTER TABLE trial_account ALTER COLUMN creator_id DROP NOT NULL;
""",
]

DROP_DANGLING_ACCOUNT_FKEY_CONSTRAINT = """
ALTER TABLE trial_account DROP CONSTRAINT trial_account_account_id_fkey
"""


def apply(store):
    print(__doc__)
    result = store.execute(
        "SELECT COUNT(*) FROM information_schema.table_constraints "
        "    WHERE table_name='trial_account' AND "
        "          constraint_name='trial_account_account_id_fkey'"
    )
    if result.get_one()[0] > 0:
        store.execute(DROP_DANGLING_ACCOUNT_FKEY_CONSTRAINT)

    for statement in STATEMENTS:
        store.execute(statement)
