# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Add tables to store juju information."""
from __future__ import print_function

STATEMENTS = [
    """
CREATE TABLE juju_environment (
    id SERIAL NOT NULL PRIMARY KEY,
    account_id INTEGER NOT NULL REFERENCES account_twin ON DELETE CASCADE,
    name TEXT NOT NULL,
    uuid TEXT,
    creation_time TIMESTAMP NOT NULL DEFAULT (now() AT TIME ZONE 'UTC'),
    endpoint TEXT NOT NULL,
    username TEXT NOT NULL,
    password TEXT NOT NULL,
    UNIQUE (account_id, name))
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE juju_environment TO landscape, landscape_maintenance
""",
    """
GRANT SELECT, UPDATE
    ON TABLE juju_environment_id_seq TO landscape, landscape_maintenance
""",
    """
CREATE TABLE juju_service (
    id SERIAL NOT NULL PRIMARY KEY,
    juju_environment_id INTEGER NOT NULL REFERENCES juju_environment ON DELETE
        CASCADE,
    name TEXT NOT NULL,
    charm TEXT NOT NULL,
    UNIQUE (juju_environment_id, name))
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE juju_service TO landscape, landscape_maintenance
""",
    """
GRANT SELECT, UPDATE
    ON TABLE juju_service_id_seq TO landscape, landscape_maintenance
""",
    """
CREATE TABLE juju_unit (
    id SERIAL NOT NULL PRIMARY KEY,
    juju_service_id INTEGER NOT NULL REFERENCES juju_service ON DELETE CASCADE,
    name TEXT NOT NULL,
    computer_id INTEGER UNIQUE REFERENCES computer_twin ON DELETE CASCADE,
    UNIQUE (juju_service_id, name))
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE juju_unit TO landscape, landscape_maintenance
""",
    """
GRANT SELECT, UPDATE
    ON TABLE juju_unit_id_seq TO landscape, landscape_maintenance
""",
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)
