# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Add audit log tables for profile-related events."""
from __future__ import print_function

statements = [
    """
CREATE TABLE package_profile_created_notice (
    activity_id INTEGER PRIMARY KEY REFERENCES activity ON DELETE CASCADE,
    profile_name TEXT,
    constraint_count INTEGER,
    access_context TEXT)
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE package_profile_created_notice TO landscape, landscape_maintenance
""",
    """
CREATE TABLE package_profile_removed_notice (
    activity_id INTEGER PRIMARY KEY REFERENCES activity ON DELETE CASCADE,
    profile_name TEXT)
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE package_profile_removed_notice TO landscape, landscape_maintenance
""",
    """
CREATE TABLE package_profile_changed_notice (
    activity_id INTEGER PRIMARY KEY REFERENCES activity ON DELETE CASCADE,
    profile_name TEXT,
    tags_added TEXT[],
    tags_removed TEXT[],
    constraints_added TEXT[],
    constraints_removed TEXT[],
    associate_all_computers BOOL NOT NULL DEFAULT false,
    disassociate_all_computers BOOL NOT NULL DEFAULT false)
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE package_profile_changed_notice
    TO landscape, landscape_maintenance
""",
]


def apply(store):
    print(__doc__)
    for statement in statements:
        store.execute(statement)
