# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Allow provisioning activities to stay alive when provisioned systems are
deleted.
"""
from __future__ import print_function


STATEMENTS = [
    """
ALTER TABLE provision_system_request
ALTER COLUMN provisioned_system_id
DROP NOT NULL
""",
    """
ALTER TABLE terminate_system_request
ALTER COLUMN provisioned_system_id
DROP NOT NULL
""",
    """
ALTER TABLE provision_system_request
DROP CONSTRAINT IF EXISTS provision_system_request_cobbler_system_id_fkey
""",
    """
ALTER TABLE provision_system_request
DROP CONSTRAINT IF EXISTS provision_system_request_provisioned_system_id_fkey
""",
    """
ALTER TABLE provision_system_request
ADD CONSTRAINT provision_system_request_provisioned_system_id_fkey
FOREIGN KEY (provisioned_system_id)
REFERENCES provisioned_system (id)
ON DELETE SET NULL
""",
    """
ALTER TABLE terminate_system_request
DROP CONSTRAINT terminate_system_request_provisioned_system_id_fkey
""",
    """
ALTER TABLE terminate_system_request
ADD CONSTRAINT terminate_system_request_provisioned_system_id_fkey
FOREIGN KEY (provisioned_system_id)
REFERENCES provisioned_system (id)
ON DELETE SET NULL
""",
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)
