# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Add audit log tables for repository profile events."""
from __future__ import print_function

statements = [
    """
CREATE TABLE repository_profile_created_notice (
    activity_id INTEGER PRIMARY KEY REFERENCES activity ON DELETE CASCADE,
    profile_name TEXT,
    description TEXT,
    access_context TEXT)
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE repository_profile_created_notice
    TO landscape, landscape_maintenance
""",
    """
CREATE TABLE repository_profile_removed_notice (
    activity_id INTEGER PRIMARY KEY REFERENCES activity ON DELETE CASCADE,
    profile_name TEXT)
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE repository_profile_removed_notice
    TO landscape, landscape_maintenance
""",
    """
CREATE TABLE repository_profile_changed_notice (
    activity_id INTEGER PRIMARY KEY REFERENCES activity ON DELETE CASCADE,
    profile_name TEXT,
    former_name TEXT,
    former_description TEXT,
    tags_added TEXT[],
    tags_removed TEXT[],
    pockets_added TEXT[],
    pockets_removed TEXT[],
    apt_sources_added TEXT[],
    apt_sources_removed TEXT[],
    associate_all_computers BOOL NOT NULL DEFAULT false,
    disassociate_all_computers BOOL NOT NULL DEFAULT false)
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE repository_profile_changed_notice
    TO landscape, landscape_maintenance
""",
]


def apply(store):
    print(__doc__)
    for statement in statements:
        store.execute(statement)
