# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Add openstack_endpoints and openstack_token tables"""
from __future__ import print_function

statements = [
    """
CREATE TABLE openstack_endpoints (
    id SERIAL NOT NULL PRIMARY KEY,
    name TEXT, -- Can be null when it's auto-discovered
    account_id INTEGER NOT NULL REFERENCES account_twin ON DELETE CASCADE,
    access_context_id INTEGER NOT NULL,
    keystone_admin_endpoint TEXT,
    keystone_service_endpoint TEXT,
    admin_api_endpoint TEXT,
    api_endpoint TEXT,
    landscape_password TEXT
)
""",
    """
CREATE INDEX openstack_endpoints_account_id_idx
    ON openstack_endpoints (account_id)
""",
    """
GRANT SELECT, UPDATE
    ON TABLE openstack_endpoints_id_seq TO landscape, landscape_maintenance
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE openstack_endpoints TO landscape, landscape_maintenance
""",
    """
CREATE TABLE openstack_token (
    openstack_endpoints_id
        INTEGER NOT NULL PRIMARY KEY REFERENCES openstack_endpoints,
    landscape_token TEXT
)
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE openstack_token TO landscape, landscape_maintenance
""",
]


def apply(store):
    print(__doc__)
    for statement in statements:
        store.execute(statement)
