# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Unify account_rule_state and computer_rule_state tables."""
from __future__ import print_function


def apply(store):
    print(__doc__)

    # Rename computer_rule_state table to rule_state and update constraints.
    store.execute("ALTER TABLE computer_rule_state RENAME TO rule_state")
    store.execute("ALTER TABLE rule_state" "    ALTER COLUMN computer_id DROP NOT NULL")
    store.execute(
        "ALTER INDEX computer_rule_state_computer_id_idx"
        "    RENAME TO rule_state_computer_id_idx"
    )
    store.execute(
        "ALTER INDEX computer_rule_state_rule_id_idx"
        "    RENAME TO rule_state_rule_id_idx"
    )

    # Copy data from account_rule_state into the new rule_state table.
    result = store.execute(
        "SELECT rule_id, active, dismissed" "    FROM account_rule_state"
    )
    for row in result:
        store.execute(
            "INSERT INTO rule_state (rule_id, active, dismissed)"
            "    VALUES (?, ?, ?)",
            row,
        )

    # Delete the account_rule_state table now that all data has been migrated.
    store.execute("DROP TABLE account_rule_state")
