# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Add a UNIQUE constraint to rule_state for (rule_id, computer_id) and create
new rule_tag table.
"""
from __future__ import print_function


def apply(store):
    print(__doc__)

    # Add UNIQUE constraint to rule_state table.
    store.execute(
        """
ALTER TABLE rule_state
    ADD CONSTRAINT rule_state_rule_id_key UNIQUE (rule_id, computer_id)
"""
    )

    # Create rule_tag table.
    store.execute(
        """
CREATE TABLE rule_tag (
    rule_id INTEGER NOT NULL REFERENCES rule ON DELETE CASCADE,
    tag_id INTEGER NOT NULL,
    PRIMARY KEY (rule_id, tag_id))
"""
    )
    store.execute(
        """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE rule_tag TO landscape
"""
    )

    # Set 'all-computers' flag to true for existing computer-based rules.
    store.execute(
        """
ALTER TABLE rule
    ADD COLUMN all_computers BOOLEAN NOT NULL DEFAULT false
"""
    )
    store.execute(
        """
UPDATE rule SET all_computers=true WHERE info_type IN (100, 101, 300)
"""
    )
