"""
Delete orphan computer groups that has no matching holder.
"""
from __future__ import print_function

from builtins import zip
from builtins import range

STATEMENT_TMPL = """
DELETE FROM computer_group WHERE id IN (
    SELECT computer_group.id FROM computer_group LEFT OUTER JOIN %s ON (
        computer_group.id = %s.computer_group_id
    ) WHERE computer_group.info_type = %s AND %s.id IS NULL
)
"""


def apply(store):
    print(__doc__)
    # The mapping bellow reflects the info types in
    # canonical/landscape/model/account/register.py
    # Order is important.
    tables = (
        "rule",
        "custom_graph",
        "package_profile",
        "upgrade_profile",
        "repository_profile",
        "removal_profile",
    )
    for info_type, table in zip(list(range(1, 7)), tables):
        store.execute(STATEMENT_TMPL % (table, table, info_type, table))
