# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Remove rule subscriptions for disabled persons."""
from __future__ import print_function

from canonical.landscape.model.main import get_main_store


# This patch is based on queries generated by the following Python code:
#
#     from storm.expr import Join, And
#
#     from canonical.landscape.model.main import Account, Person, PersonAccess
#     from canonical.landscape.model.alert import Rule, RuleSubscription
#
#     person_account_ids = main.find(
#         (Person.id, Account.id),
#         PersonAccess.person_id == Person.id,
#         PersonAccess.role_key == 4,
#         PersonAccess.access_context_id == Account.access_context_id)
#
#     subscriptions = []
#     for person_id, account_id in person_account_ids:
#         table_store = store.using(
#             Join(RuleSubscription, Rule,
#                  RuleSubscription.rule_id == Rule.id))
#         rule_ids = table_store.find(
#             RuleSubscription.rule_id,
#             RuleSubscription.person_id == person_id,
#             RuleSubscription.rule_id == Rule.id,
#             Rule.account_id == account_id)
#         subscriptions.extend([(person_id, rule_id) for rule_id in rule_ids])
#
#     where = []
#     for person_id, rule_id in subscriptions:
#         where.append(Or(And(RuleSubscription.person_id == person_id,
#                             RuleSubscription.rule_id == rule_id)))
#     store.find(RuleSubscription, *where).remove()


def apply(store):
    print(__doc__)
    statement = """
SELECT person.id, account.id
    FROM account, person, person_access
    WHERE person_access.person_id = person.id
        AND person_access.role_key = 4
        AND person_access.access_context_id = account.access_context_id
"""
    person_account_ids = get_main_store().execute(statement)

    subscriptions = []
    for (person_id, account_id) in person_account_ids:
        statement = """
SELECT rule_subscription.rule_id
    FROM rule_subscription
    JOIN rule ON rule_subscription.rule_id = rule.id
    WHERE rule_subscription.person_id = %s
        AND rule_subscription.rule_id = rule.id
        AND rule.account_id = %s
""" % (
            person_id,
            account_id,
        )
        for (rule_id,) in store.execute(statement):
            subscriptions.append((person_id, rule_id))

    if subscriptions:
        statement = "DELETE FROM rule_subscription WHERE"
        where = []
        for person_id, rule_id in subscriptions:
            where.append(
                """
 (rule_subscription.person_id = %s AND rule_subscription.rule_id = %s)
"""
                % (person_id, rule_id)
            )
        statement = statement + " OR".join(where)
        store.execute(statement)
