"""
Move the access_context_id value from the computer_group table to each of its
 owners.
"""
from __future__ import print_function

STATEMENTS = [
    """
ALTER TABLE package_profile
    ADD COLUMN access_context_id INTEGER NOT NULL DEFAULT 0
""",
    """
ALTER TABLE removal_profile
    ADD COLUMN access_context_id INTEGER NOT NULL DEFAULT 0
""",
    """
ALTER TABLE custom_graph
    ADD COLUMN access_context_id INTEGER NOT NULL DEFAULT 0
""",
    """
ALTER TABLE rule
    ADD COLUMN access_context_id INTEGER
""",
    """
ALTER TABLE upgrade_profile
    ADD COLUMN access_context_id INTEGER NOT NULL DEFAULT 0
""",
    """
ALTER TABLE repository_profile
    ADD COLUMN access_context_id INTEGER NOT NULL DEFAULT 0
""",
]


INFO_TYPES = [
    (1, "rule"),
    (2, "custom_graph"),
    (3, "package_profile"),
    (4, "upgrade_profile"),
    (5, "repository_profile"),
    (6, "removal_profile"),
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)

    for info_type_id, info_type_table in INFO_TYPES:
        result = store.execute(
            "SELECT id, account_id, access_context_id FROM"
            " computer_group WHERE info_type = ?",
            (info_type_id,),
        )
        for computer_group_id, account_id, access_context_id in result:
            store.execute(
                "UPDATE %s SET access_context_id = ? WHERE"
                " account_id = ? AND computer_group_id = ?" % info_type_table,
                (access_context_id, account_id, computer_group_id),
            )
        store.execute(
            "ALTER TABLE %s ALTER COLUMN access_context_id"
            " DROP DEFAULT" % info_type_table
        )
    store.execute("ALTER TABLE computer_group DROP COLUMN access_context_id")
