"""
Add a removed column the to package_profile, removal_profile, custom_graph,
rule, upgrade_profile, repository_profile tables, and also change the
computer_group_id column to allow null values and set null on delete.
"""
from __future__ import print_function

TEMPLATE = """
ALTER TABLE %s
    ALTER COLUMN computer_group_id DROP NOT NULL,
    ADD COLUMN removed BOOLEAN NOT NULL DEFAULT FALSE,
    DROP CONSTRAINT %s_computer_group_id_fkey,
    ADD CONSTRAINT %s_computer_group_id_fkey
        FOREIGN KEY (computer_group_id)
            REFERENCES computer_group(id)
                ON DELETE SET NULL
"""


TABLES = (
    "package_profile",
    "upgrade_profile",
    "repository_profile",
    "rule",
    "custom_graph",
    "removal_profile",
)


def apply(store):
    print(__doc__)
    for table in TABLES:
        store.execute(TEMPLATE % (table, table, table))
