# Copyright 2005-2014 Canonical Limited.  All rights reserved.

"""
Drop the FINISHED activity status and remap SUCCEED, FAILED and CANCELED.
WARNING: This could take several minutes.
"""
from __future__ import print_function

# Convert activities with the FINISHED status to use SUCCEEDED
# and FAILED, according to their result_code.
STATEMENTS = [
    """
UPDATE activity SET status = 1006 WHERE status = 5 and result_code = 0
""",
    """
UPDATE activity SET status = 1005 WHERE status = 5 and result_code != 0
""",
]

# List of status values conversions (old, new)
CONVERSIONS = [
    (1006, 5),  # SUCCEEDED
    (1005, 6),  # FAILED
    (1004, 7),  # CANCELED
]

TABLES = ["activity", "computer_request_data", "activity_group"]


def apply(store):
    print(__doc__)

    for statement in STATEMENTS:
        store.execute(statement)

    # Secondly renumber the SUCCEEDED, FAILED and CANCELED statuses.
    for table in TABLES:
        for old, new in CONVERSIONS:
            store.execute(
                "UPDATE %s SET status = ? WHERE status = ?" % (table), (new, old)
            )
