# Copyright 2005-2014 Canonical Ltd. All rights reserved.

"""
Drop the provisioning tables and create maas tables.
"""
from __future__ import print_function


STATEMENTS = [
    """
ALTER TABLE juju_bootstrap_request
    DROP CONSTRAINT juju_bootstrap_request_provisioning_server_id_fkey
""",
    """
ALTER TABLE juju_bootstrap_request
    RENAME COLUMN provisioning_server_id TO maas_server_id
""",
    """
DROP TABLE provisioning_server
""",
    """
DROP TABLE provisioning_server_created_notice
""",
    """
DROP TABLE provisioning_server_removed_notice
""",
    """
DROP TABLE provisioning_server_changed_notice
""",
    """
DELETE FROM activity WHERE info_type IN (900, 901, 1019, 1020, 1021)
""",
    """
DELETE FROM activity WHERE id in
    (SELECT id FROM activity JOIN activity_group ON id = activity_id
     WHERE info_type = 6 AND basic_summary = 27)
""",
    """
CREATE TABLE maas_server (
    id SERIAL NOT NULL PRIMARY KEY,
    account_id INTEGER NOT NULL REFERENCES account_twin ON DELETE CASCADE,
    name TEXT NOT NULL,
    title TEXT NOT NULL,
    endpoint TEXT NOT NULL,
    credentials TEXT NOT NULL,
    creation_time TIMESTAMP NOT NULL DEFAULT (now() AT TIME ZONE 'UTC'),
    UNIQUE (account_id, name),
    UNIQUE (account_id, title))
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE maas_server TO landscape
""",
    """
GRANT SELECT, UPDATE
    ON TABLE maas_server_id_seq TO landscape
""",
    """
CREATE TABLE maas_server_created_notice (
    activity_id INTEGER PRIMARY KEY REFERENCES activity ON DELETE CASCADE,
    name TEXT NOT NULL,
    title TEXT NOT NULL,
    endpoint TEXT NOT NULL)
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE maas_server_created_notice TO landscape
""",
    """
CREATE TABLE maas_server_removed_notice (
    activity_id INTEGER PRIMARY KEY REFERENCES activity ON DELETE CASCADE,
    name TEXT NOT NULL)
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE maas_server_removed_notice TO landscape
""",
    """
CREATE TABLE maas_server_changed_notice (
    activity_id INTEGER PRIMARY KEY REFERENCES activity ON DELETE CASCADE,
    name TEXT NOT NULL,
    new_name TEXT,
    title TEXT,
    endpoint TEXT,
    credentials_changed BOOL NOT NULL DEFAULT FALSE)
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE maas_server_changed_notice TO landscape
""",
    """
ALTER TABLE juju_bootstrap_request
    ADD CONSTRAINT juju_bootstrap_request_maas_server_id_fkey
        FOREIGN KEY (maas_server_id) REFERENCES maas_server(id)
        ON DELETE CASCADE
""",
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)
