# Copyright 2005-2014 Canonical Ltd. All rights reserved.

"""
Add juju machine data
"""
from __future__ import print_function


def apply(store):
    print(__doc__)
    # Create new Juju machine rows by looking at the machine_id column of
    # the juju_unit table
    result = store.execute(
        "SELECT juju_environment_id, machine_id, array_agg(juju_unit.id) "
        "  FROM juju_unit "
        "  JOIN juju_service ON juju_unit.juju_service_id = juju_service.id "
        "  GROUP BY juju_environment_id, machine_id"
    )
    for environment_id, machine_id, unit_ids in result:
        if not machine_id:
            # Units of subordinate charms don't get a machine ID
            continue
        # Insert the Juju machine
        result = store.execute(
            "INSERT INTO "
            "    juju_machine (juju_environment_id, machine_id, status) "
            "    VALUES (?, ?, 'pending') RETURNING ID",
            (environment_id, machine_id),
        )
        juju_machine_id = result.get_one()[0]
        # Link associated units to the newly inserted Juju machine
        store.execute(
            "UPDATE juju_unit SET juju_machine_id = ? " "    WHERE id IN ?",
            (juju_machine_id, tuple(unit_ids)),
        )
