# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Create computer_group related tables."""
from __future__ import print_function

STATEMENTS = [
    """
CREATE TABLE computer_group (
    id SERIAL NOT NULL PRIMARY KEY,
    account_id INTEGER NOT NULL REFERENCES account_twin ON DELETE CASCADE,
    all_computers BOOL NOT NULL DEFAULT false)
""",
    """
GRANT SELECT, INSERT, DELETE, UPDATE
ON TABLE computer_group TO landscape, landscape_maintenance
""",
    """
GRANT SELECT, UPDATE, DELETE
    ON TABLE computer_group_id_seq TO landscape, landscape_maintenance
""",
    """
CREATE TABLE computer_group_tag (
    tag_id INTEGER NOT NULL,
    computer_group_id INTEGER NOT NULL REFERENCES computer_group
        ON DELETE CASCADE,
    PRIMARY KEY (tag_id, computer_group_id))
""",
    """
GRANT SELECT, INSERT, DELETE
    ON TABLE computer_group_tag TO landscape, landscape_maintenance
""",
    """
CREATE TABLE computer_group_item (
    computer_id INTEGER NOT NULL REFERENCES computer_twin ON DELETE CASCADE,
    computer_group_id INTEGER NOT NULL REFERENCES computer_group
        ON DELETE CASCADE,
    PRIMARY KEY (computer_id, computer_group_id))
""",
    """
GRANT SELECT, INSERT, DELETE
    ON TABLE computer_group_item TO landscape, landscape_maintenance
""",
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)

    from canonical.landscape.model.main import get_account_by_id
    from canonical.landscape.model.account.computergroup import (
        ComputerGroup,
        ComputerGroupTag,
        ComputerGroupItem,
    )

    # Modify custom graph tables
    store.execute(
        """
        ALTER TABLE custom_graph ADD computer_group_id INTEGER
            REFERENCES computer_group ON DELETE CASCADE
        """
    )
    graphs = store.execute(
        """
        SELECT id, all_computers, account_id FROM custom_graph
        """
    )
    for graph_id, all_computers, account_id in graphs:
        account = get_account_by_id(account_id)
        group = store.add(ComputerGroup(account))
        group.all_computers = all_computers
        store.execute(
            """
            UPDATE custom_graph SET computer_group_id = %s WHERE id = %s
            """,
            (group.id, graph_id),
        )
        computers = store.execute(
            """
            SELECT computer_id FROM custom_graph_computer
                WHERE custom_graph_id = %s
            """,
            (graph_id,),
        )
        for computer in computers:
            item = ComputerGroupItem()
            item.computer_id = computer[0]
            item.computer_group_id = group.id
            store.add(item)
        tags = store.execute(
            """
            SELECT tag_id FROM custom_graph_tag WHERE custom_graph_id = %s
            """,
            (graph_id,),
        )
        for tag in tags:
            group_tag = ComputerGroupTag()
            group_tag.tag_id = tag[0]
            group_tag.computer_group_id = group.id
            store.add(group_tag)
    store.execute(
        """
        ALTER TABLE custom_graph DROP COLUMN all_computers
        """
    )
    store.execute(
        """
        ALTER TABLE custom_graph ALTER COLUMN computer_group_id SET NOT NULL
        """
    )
    store.execute(
        """
        DROP TABLE custom_graph_tag
        """
    )
    store.execute(
        """
        DROP TABLE custom_graph_computer
        """
    )

    # Modify rule tables
    store.execute(
        """
        ALTER TABLE rule ADD computer_group_id INTEGER
            REFERENCES computer_group ON DELETE CASCADE
        """
    )
    rules = store.execute(
        """
        SELECT id, all_computers, account_id FROM rule
        """
    )
    for rule_id, all_computers, account_id in rules:
        account = get_account_by_id(account_id)
        group = store.add(ComputerGroup(account))
        group.all_computers = all_computers
        store.execute(
            """
            UPDATE rule SET computer_group_id = %s WHERE id = %s
            """,
            (group.id, rule_id),
        )
        tags = store.execute(
            """
            SELECT tag_id FROM rule_tag WHERE rule_id = %s
            """,
            (rule_id,),
        )
        for tag in tags:
            group_tag = ComputerGroupTag()
            group_tag.tag_id = tag[0]
            group_tag.computer_group_id = group.id
            store.add(group_tag)
        computers = store.execute(
            """
            SELECT computer_id FROM rule_state
                WHERE rule_id = %s AND computer_id is NOT NULL
            """,
            (rule_id,),
        )
        for computer in computers:
            item = ComputerGroupItem()
            item.computer_id = computer[0]
            item.computer_group_id = group.id
            store.add(item)
    store.execute(
        """
        ALTER TABLE rule DROP COLUMN all_computers
        """
    )
    store.execute(
        """
        ALTER TABLE rule ALTER COLUMN computer_group_id SET NOT NULL
        """
    )
    store.execute(
        """
        DROP TABLE rule_tag
        """
    )
