# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Add support for performing full text search on packages.
"""
from __future__ import print_function

command_create_configuration = """
    CREATE TEXT SEARCH CONFIGURATION
        public.landscape_english (COPY = pg_catalog.english)
    """

command_set_default_configuration = """
    SET default_text_search_config = 'public.landscape_english'
    """

command_set_ascii_mapper = """
    ALTER TEXT SEARCH CONFIGURATION public.landscape_english
       ALTER MAPPING FOR asciiword WITH english_stem
    """

command_add_name_search_vector = """
    ALTER TABLE package ADD COLUMN name_search_vector tsvector
    """

command_add_text_search_vector = """
    ALTER TABLE package ADD COLUMN text_search_vector tsvector
    """

command_create_name_search_vector_index = """
    CREATE INDEX name_search_vector_idx ON package
        USING gin(name_search_vector)
    """

command_create_text_search_vector_index = """
    CREATE INDEX text_search_vector_idx ON package
        USING gin(text_search_vector)
    """


def apply(store):
    print("Creating a text search configuration for packages.")
    store.execute(command_create_configuration)
    print("Setting the new configuration as the default one.")
    store.execute(command_set_default_configuration)
    print("Setting the ASCII package text search to use stemming.")
    store.execute(command_set_ascii_mapper)
    print("Adding two text search vector fields to the package table.")
    store.execute(command_add_name_search_vector)
    store.execute(command_add_text_search_vector)
    print("Creating indexes for the text search fields.")
    store.execute(command_create_name_search_vector_index)
    store.execute(command_create_text_search_vector_index)
