from __future__ import print_function

# Copyright 2005-2015 Canonical Ltd. All rights reserved.

from canonical.landscape.schema.patch_305 import __doc__

STATEMENTS = [
    # The two statements below fix #1414119. The cause of the bug is that there are
    # some computer activities which have non-NULL approval_time and at the same
    # time are in the UNAPPROVED state (1001). This shouldn't be possible according
    # to the code (since as soon as you approve an activity the approval_time is
    # set and the activity is transitioned to QUEUED), however it might be the
    # result of some old bug (there are currently 197 activities like that in
    # production, all created between 2008-06 and 2010-08). Most probably we had
    # this broken data since a good while, but since these were old activities
    # nobody looked at them for a long time, till recently James Troup discovered
    # one them while checking his activities because of #1414631. These
    # activities are in an inconsistent state and are also very old, we just set
    # their status to cancelled.
    """
UPDATE activity SET status=7 WHERE id IN (
    SELECT activity.parent_id FROM activity
        JOIN computer_request_data
            ON computer_request_data.activity_id = activity.id
        WHERE activity.parent_id IS NOT NULL
        AND activity.status = 1001
        AND computer_request_data.approval_time IS NOT NULL)
""",
    """
UPDATE activity SET status=7 WHERE id IN (
    SELECT activity.id FROM activity
        JOIN computer_request_data
            ON computer_request_data.activity_id = activity.id
        WHERE activity.parent_id IS NOT NULL
        AND activity.status = 1001
        AND computer_request_data.approval_time IS NOT NULL)
""",
    # The two statements below fix #1414631. The cause of that bug is that
    # production r846 was rolled out without patch 298, which was fixing the data
    # of the activity_group.status/activity.status columns to match some new which
    # was already present in r846. Similar queries where cowboyed on 21/01/2015,
    # but since patch 298 hadn't been applied yet on that date (it was applied only
    # on 22/01/2015), there were some uncaught cases left, see RT 78158 and the
    # SQL requests at:
    #
    # http://wiki.canonical.com/InformationInfrastructure/OSA/RequestLogging/LS/SQL
    #
    # which fixed the issue for activities created after the r846 rollout).
    #
    # The first query sets to SUCCEEDED (5) any parent activity whose children are
    # not in any state other than SUCCEEDED.
    #
    # The second query sets to FAILED (6) any parent activity with status
    # INPROGRESS or QUEUED that has at least one FAILED child.
    """
UPDATE activity SET status=5 WHERE id IN (
    SELECT parent.id FROM activity AS parent
    INNER JOIN activity AS child ON child.parent_id=parent.id
    WHERE parent.status != 5
    GROUP BY parent.id
    HAVING not(array_agg(child.status) && '{1, 2, 3, 4, 6, 7, 1001}'))
""",
    """
UPDATE activity SET status=6 WHERE id IN (
    SELECT parent.id FROM activity AS parent
    INNER JOIN activity AS child ON child.parent_id=parent.id
    WHERE parent.status = 1 or parent.status = 2
    GROUP BY parent.id
    HAVING array_agg(child.status) @> '{6}')
""",
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)
