from __future__ import print_function

# Copyright 2005-2015 Canonical Ltd. All rights reserved.

from builtins import zip
from canonical.landscape.schema.patch_316 import __doc__

INSERT_PARENTS = """
INSERT INTO activity (info_type, account_id)
  SELECT 6, account_id
  FROM activity WHERE info_type = 800
  RETURNING id
"""

GET_SYNC_POCKET_IDS = """
  SELECT id FROM activity WHERE info_type = 800
"""

UPDATE_CHILD = """
UPDATE activity SET parent_id = ? WHERE id = ?
"""

UPDATE_PARENT = """
UPDATE activity SET
    account_id=child.account_id,
    creation_time=child.creation_time,
    completion_time=child.completion_time,
    creator_id=child.creator_id,
    status=child.status
FROM (SELECT account_id, creation_time, completion_time, creator_id, status
      FROM activity WHERE id = ?) AS child
WHERE id = ?
"""

INSERT_PARENT_INFO = """
INSERT INTO activity_group (activity_id, basic_summary, summary)
VALUES (?, ?, ?)
"""

GET_NAMES = """
  SELECT pocket.name, series.name, distribution.name
  FROM sync_pocket_request
  JOIN pocket ON pocket.id = sync_pocket_request.pocket_id
  JOIN series ON series.id = pocket.series_id
  JOIN distribution ON distribution.id = series.distribution_id
  WHERE sync_pocket_request.activity_id = ?
"""

SUMMARY_TEMPLATE = "Sync pocket '%s' of series '%s' in distribution '%s'"


def apply(store):
    print(__doc__)

    # First, insert new parent activity rows, and get their IDs back.
    result = store.execute(INSERT_PARENTS)
    parent_ids = [row[0] for row in result.get_all()]

    # Get a list of all sync-pocket activities that need to be processed
    child_ids = [row[0] for row in store.execute(GET_SYNC_POCKET_IDS)]

    # For each sync-pocket activity pick a parent among the newly ones that
    # we created and update it accordingly, creating also the relevant
    # entry in activity_group.
    for parent_id, child_id in zip(parent_ids, child_ids):
        store.execute(UPDATE_CHILD, (parent_id, child_id))
        store.execute(UPDATE_PARENT, (child_id, parent_id))
        names = store.execute(GET_NAMES, (child_id,)).get_one()
        summary = SUMMARY_TEMPLATE % names
        store.execute(INSERT_PARENT_INFO, (parent_id, 34, summary))
