from __future__ import print_function

# Copyright 2005-2015 Canonical Ltd. All rights reserved.

from canonical.landscape.model.main.store import get_main_store
from canonical.landscape.schema.patch_319 import __doc__

# Info type code of resync activities, as from c.l.model.activity.registry.
RESYNC_INFO_TYPE = 4

# Info type code of activity groups, as from c.l.model.activity.registry.
GROUP_INFO_TYPE = 6

# Select IDs of resynch activities without parent
SELECT_NO_PARENTS = (
    """
SELECT id FROM activity WHERE info_type = %d and parent_id IS NULL
"""
    % RESYNC_INFO_TYPE
)

# Insert a new activity row for the parent, copying details from the child
INSERT_PARENT = (
    """
INSERT INTO activity (info_type, creator_id, creation_time, completion_time,
                      account_id, progress, status)
(SELECT %d, creator_id, creation_time, completion_time, account_id, progress,
        status
    FROM activity WHERE id = ?) RETURNING id
"""
    % GROUP_INFO_TYPE
)

# Insert a new activity_group row for the given parent activity ID
INSERT_PARENT_INFO = """
INSERT INTO activity_group (activity_id, basic_summary, summary, children_data)
VALUES (?, 6, ?, ?)
"""

# Update the child activity setting its parent ID to the associated parent
UPDATE_CHILD = """
UPDATE activity SET parent_id = ? WHERE id = ?
"""

# Select computer ID for the given activity
SELECT_COMPUTER_ID = """
SELECT computer_id FROM computer_request_data WHERE activity_id = ?
"""

# Select the title of the computer with the given ID
SELECT_COMPUTER_TITLE = """
SELECT title FROM computer WHERE id = ?
"""

# Activity group summary template (see ResynchronizeRequest.get_summary).
SUMMARY_TEMPLATE = "Resynchronize computer %s"


def apply(store):
    print(__doc__)
    main_store = get_main_store()
    rows_with_no_parents = store.execute(SELECT_NO_PARENTS)
    for row in rows_with_no_parents:
        child_id = row[0]
        parent_id = store.execute(INSERT_PARENT, (child_id,)).get_one()[0]
        computer_id = store.execute(SELECT_COMPUTER_ID, (child_id,)).get_one()[0]
        computer_title = main_store.execute(
            SELECT_COMPUTER_TITLE, (computer_id,)
        ).get_one()[0]
        summary = "Resynchronize computer %s" % computer_title
        store.execute(UPDATE_CHILD, (parent_id, child_id))
        store.execute(INSERT_PARENT_INFO, (parent_id, summary, [computer_id]))
