from __future__ import print_function

# Copyright 2005-2015 Canonical Ltd. All rights reserved.

from canonical.landscape.schema.patch_320 import __doc__

# Info type code of juju-destroy-environment activities, as from
# c.l.model.activity.registry.
JUJU_DESTROY_ENVIRONMENT_INFO_TYPE = 905

# Info type code of activity groups, as from c.l.model.activity.registry.
GROUP_INFO_TYPE = 6

# JUJU_DESTROY_ENVIRONMENT_SUMMARY
GROUP_BASIC_SUMMARY = 36

# Select IDs of destroy-environment activities without parent
SELECT_NO_PARENTS = (
    """
SELECT id FROM activity WHERE info_type = %d AND parent_id IS NULL
"""
    % JUJU_DESTROY_ENVIRONMENT_INFO_TYPE
)

# Insert a new activity row for the parent, copying details from the child
INSERT_PARENT = (
    """
INSERT INTO activity (info_type, creator_id, creation_time, completion_time,
                      account_id, progress, status)
(SELECT %d, creator_id, creation_time, completion_time, account_id, progress,
        status
    FROM activity WHERE id = ?) RETURNING id
"""
    % GROUP_INFO_TYPE
)

# Insert a new activity_group row for the given parent activity ID
INSERT_PARENT_INFO = (
    """
INSERT INTO activity_group (activity_id, basic_summary, summary, children_data)
VALUES (?, %d, ?, '{}')
"""
    % GROUP_BASIC_SUMMARY
)

# Update the child activity setting its parent ID to the associated parent
UPDATE_CHILD = """
UPDATE activity SET parent_id = ? WHERE id = ?
"""

# Activity group summary (see JujuDestroyEnvironmentRequest.get_summary).
SUMMARY = "Destroy Juju environment"


def apply(store):
    print(__doc__)
    rows_with_no_parents = store.execute(SELECT_NO_PARENTS)
    for row in rows_with_no_parents:
        child_id = row[0]
        parent_id = store.execute(INSERT_PARENT, (child_id,)).get_one()[0]
        store.execute(UPDATE_CHILD, (parent_id, child_id))
        store.execute(INSERT_PARENT_INFO, (parent_id, SUMMARY))
