from __future__ import print_function

# Copyright 2005-2015 Canonical Ltd. All rights reserved.

from canonical.landscape.schema.patch_335 import __doc__

# Map each possible status to the name of its count column in
# the activity table.
STATUS_COLUMNS = {
    1: "inprogress_count",
    2: "queued_count",
    3: "waiting_count",
    4: "blocked_count",
    5: "scheduled_count",
    6: "succeeded_count",
    7: "failed_count",
    8: "canceled_count",
    1001: "unapproved_count",
}

# For each (parent, status) pair compute how many children of that
# parent are in that status.
SELECT_STATUS_COUNTS = """
SELECT parent_id, status, count(id) FROM activity
   WHERE parent_id IS NOT NULL
   GROUP BY parent_id, status
"""


def apply(store):
    print(__doc__)

    # Build a dict mapping each parent ID to a dict which maps a status
    # to the number of children in that status.
    all_counts = {}
    result = store.execute(SELECT_STATUS_COUNTS)
    for parent_id, status, count in result.get_all():
        counts = all_counts.setdefault(parent_id, {})
        counts[status] = count

    # For each parent activity, update the count columns
    for parent_id, counts in all_counts.items():
        columns = []
        params = []
        for status, count in counts.items():
            columns.append("%s=?" % STATUS_COLUMNS[status])
            params.append(count)
        statement = "UPDATE activity SET %s WHERE id = ?" % ",".join(columns)
        params.append(parent_id)
        store.execute(statement, params)
