from __future__ import print_function

# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.landscape.schema.patch_346 import __doc__

from canonical.landscape.application import is_standalone
from canonical.landscape.model.main.store import get_main_store

# Info type code of StandaloneSystemEmaiAlert, as from c.l.model.alert.policy.
ALERT_INFO_TYPE = 204

# Since standalone LDS only supports a single account
SELECT_STANDALONE_ACCOUNT_ID = """SELECT id FROM account_twin"""

SELECT_GLOBAL_ACCESS_CONTEXT_ID = """
SELECT id FROM access_context WHERE parent_id is null and name='global';
"""

SELECT_EXISTING_RULE = """SELECT id FROM rule WHERE info_type = ?"""

INSERT_ALERT_RULE = """
INSERT INTO rule (account_id, access_context_id, info_type) VALUES (?, ?, ?)
RETURNING id
"""

INSERT_RULE_STATE = """INSERT INTO rule_state (rule_id) VALUES (?)"""


def apply(store):
    print(__doc__)

    if not is_standalone():
        return

    result = store.execute(SELECT_EXISTING_RULE, (ALERT_INFO_TYPE,))

    if result.rowcount > 0:
        # We already have the rule in the database
        return

    main_store = get_main_store()
    account = store.execute(SELECT_STANDALONE_ACCOUNT_ID).get_one()[0]
    access_context = main_store.execute(SELECT_GLOBAL_ACCESS_CONTEXT_ID).get_one()[0]
    result = store.execute(
        INSERT_ALERT_RULE,
        (
            account,
            access_context,
            ALERT_INFO_TYPE,
        ),
    )
    new_rule_id = result.get_one()[0]
    store.execute(INSERT_RULE_STATE, (new_rule_id,))
