# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Remove redundant ActivityGroup activities left over from the command/operation
migration.
"""
from __future__ import print_function

from canonical.landscape.model.activity.activity import Activity
from canonical.landscape.model.activity.group import ActivityGroup


def apply(store):
    print(__doc__)
    # Find non-top-level ActivityGroups.
    nested_activity_groups = store.find(
        (Activity.id, Activity.parent_id),
        Activity.info_type == ActivityGroup.info_type,
        Activity.parent_id != None,
    )

    # Reparent children of non-top-level ActivityGroups.
    for activity_id, parent_id in nested_activity_groups:
        child_activities = store.find(Activity, Activity.parent_id == activity_id)
        child_activities.set(parent_id=parent_id)

    # Remove non-top-level ActivityGroups.
    nested_activity_groups = store.find(
        Activity,
        Activity.info_type == ActivityGroup.info_type,
        Activity.parent_id != None,
    )
    nested_activity_groups.remove()
