from __future__ import print_function

# Copyright 2005-2015 Canonical Ltd. All rights reserved.

from collections import defaultdict

from canonical.landscape.schema.patch_369 import __doc__


def apply(store):
    print(__doc__)

    result = store.execute(
        """
        SELECT region.id, region.block_storage, maas_target_machine.maas_name,
          juju_service.name
        FROM region, juju_service, juju_unit, juju_machine, maas_target_machine
        WHERE juju_unit.juju_service_id = juju_service.id
          AND juju_unit.juju_machine_id = juju_machine.id
          AND maas_target_machine.juju_machine_id = juju_machine.machine_id
          AND region.juju_environment_id =
            maas_target_machine.juju_environment_id"""
    )

    # Map (region_id, machine_name) to a set of roles
    machine_to_roles = defaultdict(set)
    for region_id, block_storage, name, service_name in result:
        machine_roles = machine_to_roles[region_id, name]
        if service_name == "neutron-gateway":
            machine_roles.add("network")
        elif service_name == "nova-compute":
            machine_roles.add("compute")
        elif service_name in ("ceph", "ceph-osd", "swift-storage"):
            machine_roles.add("storage")
        elif service_name == "cinder" and block_storage == "iscsi":
            # Cinder is just API (admin service) if storage is not iSCSI
            machine_roles.add("storage")
        else:
            machine_roles.add("control")

    rows = [
        (region_id, host_name, sorted(roles))
        for ((region_id, host_name), roles) in machine_to_roles.items()
    ]
    for row in rows:
        # This doesn't use the bulk Insert functionality since it doesn't play
        # well with arrays.
        store.execute(
            "INSERT INTO region_machine (region_id, name, roles)" " VALUES (?, ?, ?)",
            row,
        )
