# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Clean up users with duplicate names and fix the constraints on the
computer_user table.
"""
from __future__ import print_function

from storm.expr import In
from canonical.landscape.model.resource import User


indexes = [
    """
ALTER TABLE computer_user DROP CONSTRAINT computer_user_computer_id_key;
""",
    """
ALTER TABLE computer_user ADD CONSTRAINT computer_user_computer_id_key UNIQUE
(computer_id, username)
""",
]


def apply(store):
    print(__doc__)

    query = store.execute("SELECT id, computer_id, username, uid FROM computer_user")

    computers = {}

    for id, computer_id, username, uid in query:
        computer = computers.setdefault(computer_id, {})
        usernames = computer.setdefault(username, [])
        usernames.append((uid, id))

    delete_ids = []

    for computer_id, users in computers.items():
        for username, user_keys in users.items():
            if len(user_keys) > 1:
                user_keys.sort()
                for uid, id in user_keys[1:]:
                    delete_ids.append(id)

    if delete_ids:
        print("Removing %d users with duplicate names" % len(delete_ids))
        result = store.find(User, In(User.id, delete_ids))
        result.remove()

    for index in indexes:
        store.execute(index)
