from __future__ import print_function

# Copyright 2005-2015 Canonical Ltd. All rights reserved.

from canonical.landscape.schema.patch_373 import __doc__

ADD_DATA_ID_COLUMN = """
ALTER TABLE distribution
    ADD COLUMN data_id INTEGER REFERENCES account_entity_data ON DELETE CASCADE
"""

SELECT_DISTRIBUTIONS = """
SELECT id, account_id, name, access_context_id, creation_time
    FROM distribution
"""

INSERT_ENTITY_DATA = """
INSERT INTO account_entity_data(
    account_id, name, access_context_id, creation_time, entity_type)
    VALUES(?, ?, ?, ?, 1) RETURNING id
"""

UPDATE_DISTRIBUTION = """
UPDATE distribution SET data_id = ? WHERE id = ?
"""

DROP_OLD_COLUMNS = [
    """
ALTER TABLE distribution DROP COLUMN account_id
""",
    """
ALTER TABLE distribution DROP COLUMN name
""",
    """
ALTER TABLE distribution DROP COLUMN access_context_id
""",
    """
ALTER TABLE distribution DROP COLUMN creation_time
""",
]

DROP_UNIQUE_NAME_CONSTRAINT = [
    """
ALTER TABLE account_entity_data
    DROP CONSTRAINT account_entity_data_account_id_entity_type_name_key
""",
    """
CREATE INDEX account_entity_data_account_id_entity_type_name ON
    account_entity_data(account_id, entity_type, name)
""",
]

ADD_NOT_NULL_DATA_ID = """
ALTER TABLE distribution
    ALTER COLUMN data_id SET NOT NULL
"""


def apply(store):
    print(__doc__)
    # Migrate data from distribution columns to account_entity columns,
    # inserting a new account_entity row for each distribution row
    # and linking the two via the distribution.entity_id.
    store.execute(ADD_DATA_ID_COLUMN)
    for row in store.execute(SELECT_DISTRIBUTIONS).get_all():
        distribution_id = row[0]
        entity_data = row[1:]
        data_id = store.execute(INSERT_ENTITY_DATA, entity_data).get_one()[0]
        store.execute(UPDATE_DISTRIBUTION, (data_id, distribution_id))
    for statement in DROP_OLD_COLUMNS + DROP_UNIQUE_NAME_CONSTRAINT:
        store.execute(statement)
    store.execute(ADD_NOT_NULL_DATA_ID)
