from __future__ import print_function

# Copyright 2005-2015 Canonical Ltd. All rights reserved.

from canonical.landscape.schema.patch_374 import __doc__

from canonical.landscape.model.main.store import get_main_store


ACCOUNT_COMPUTER_TWIN_ENTITY_TYPE = 2


def apply(store):
    print(__doc__)

    store.execute(
        "ALTER TABLE computer_twin"
        " ADD COLUMN data_id INTEGER"
        "  REFERENCES account_entity_data ON DELETE CASCADE"
    )

    computer_ids = tuple(
        row[0] for row in store.execute("SELECT id FROM computer_twin").get_all()
    )

    if computer_ids:
        result = get_main_store().execute(
            "SELECT id, account_id, ?, encode(secure_id, 'escape'),"
            " access_context_id FROM computer WHERE id IN ?",
            [ACCOUNT_COMPUTER_TWIN_ENTITY_TYPE, computer_ids],
        )

        for row in result.get_all():
            computer_id = row[0]
            computer_data = tuple(row[1:])
            # Insert an entity data for the computer.  The secure_id is used as
            # entity name.
            [entity_data_id] = store.execute(
                "INSERT INTO account_entity_data ("
                " account_id, entity_type, name, access_context_id) VALUES ?"
                " RETURNING id",
                [computer_data],
            ).get_one()
            # Link the computer_twin to the account_entity_data
            store.execute(
                "UPDATE computer_twin SET data_id = ? WHERE id = ?",
                [entity_data_id, computer_id],
            )

        # There might be leftover entries in the account database that are no
        # longer in the main one. These won't have a corresponding
        # account_entity_data (since they are created from computer IDs taken
        # from main) and can be dropped.
        store.execute("DELETE FROM computer_twin WHERE data_id IS NULL")

    store.execute(
        "ALTER TABLE computer_twin"
        " DROP COLUMN account_id,"
        " ALTER COLUMN data_id SET NOT NULL"
    )
