from __future__ import print_function

# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import str
import json
from canonical.landscape.schema.patch_381 import __doc__
from landscape.lib import bpickle


def apply(store):
    print(__doc__)

    # Add columns with a temporary name to hold the text keys and values.
    store.execute(
        "ALTER TABLE system_configuration "
        "  ADD COLUMN temp_key text, "
        "  ADD COLUMN temp_value json"
    )

    result = store.execute("SELECT key, value FROM system_configuration")
    for key, value in result:
        # Store the unpickled value in the new text value column as a JSON
        # dump.
        # Note: key and value inside this loop are "buffers" from storm
        # hence the initial cast to str().
        new_key = str(key).decode("utf-8")
        new_value = json.dumps(bpickle.loads(str(value))).decode("utf-8")
        store.execute(
            "UPDATE system_configuration SET (temp_key, temp_value) = (?, ?) "
            "WHERE key = (?)",
            (new_key, new_value, str(key)),
        )

    # delete the old columns.
    store.execute(
        "ALTER TABLE system_configuration " "  DROP COLUMN key, " "  DROP COLUMN value "
    )
    # rename the new text columns
    store.execute(
        "ALTER TABLE system_configuration " "  RENAME COLUMN temp_value TO value"
    )
    store.execute(
        "ALTER TABLE system_configuration " "  RENAME COLUMN temp_key TO key "
    )
    # Re-add a primary key constraint on the new key column
    store.execute("ALTER TABLE system_configuration " "  ADD PRIMARY KEY (key)")
    store.execute(
        "ALTER TABLE system_configuration " "  ALTER COLUMN value SET NOT NULL"
    )
