from __future__ import print_function

# Copyright 2005-2016 Canonical Ltd. All rights reserved.

from canonical.landscape.schema.patch_385 import __doc__
from canonical.landscape.model.main.store import get_main_store

ADD_DATA_ID_COLUMN = """
ALTER TABLE juju_environment
    ADD COLUMN data_id INTEGER REFERENCES account_entity_data ON DELETE CASCADE
"""

SELECT_ENVIRONMENTS = """
SELECT id, account_id, name, creation_time FROM juju_environment
"""

SELECT_ACCESS_CONTEXT_ID = """
SELECT access_context_id FROM account WHERE id = ?
"""

INSERT_ENTITY_DATA = """
INSERT INTO account_entity_data(
    account_id, name, creation_time, access_context_id, entity_type)
    VALUES(?, ?, ?, ?, 3) RETURNING id
"""

UPDATE_ENVIRONMENT = """
UPDATE juju_environment SET data_id = ? WHERE id = ?
"""

DROP_OLD_COLUMNS = [
    """
ALTER TABLE juju_environment DROP COLUMN account_id
""",
    """
ALTER TABLE juju_environment DROP COLUMN name
""",
    """
ALTER TABLE juju_environment DROP COLUMN creation_time
""",
]

ADD_NOT_NULL_DATA_ID = """
ALTER TABLE juju_environment
    ALTER COLUMN data_id SET NOT NULL
"""

ADD_UUID_UNIQUE_CONSTRAINT = """
ALTER TABLE juju_environment ADD CONSTRAINT
    juju_environment_uuid_key UNIQUE (uuid)
"""

UPDATE_ACTIVITIES = """
UPDATE activity SET entity_data_id = juju_environment.data_id
    FROM juju_request_data, juju_environment
    WHERE juju_request_data.activity_id = activity.id
    AND juju_request_data.juju_environment_id = juju_environment.id
"""


def apply(store):
    print(__doc__)
    # Migrate data from juju_environments columns to account_entity_data
    # columns, inserting a new account_entity_data row for each
    # juju_environment row and linking the two via the
    # juju_environment.data_id column.
    store.execute(ADD_DATA_ID_COLUMN)
    for row in store.execute(SELECT_ENVIRONMENTS).get_all():
        environment_id = row[0]
        account_id = row[1]
        # Get the access context ID associated with the account
        access_context_id = (
            get_main_store()
            .execute(SELECT_ACCESS_CONTEXT_ID, (account_id,))
            .get_one()[0]
        )
        entity_data = row[1:]
        entity_data += (access_context_id,)
        data_id = store.execute(INSERT_ENTITY_DATA, entity_data).get_one()[0]
        store.execute(UPDATE_ENVIRONMENT, (data_id, environment_id))
    for statement in DROP_OLD_COLUMNS:
        store.execute(statement)
    store.execute(ADD_NOT_NULL_DATA_ID)

    # We need to re-add the UUID constraint, because it got dropped as
    # side-effect of dropping the account_id columns (the former UNIQUE
    # constraint was a compound one). Since UUIDs are expected to be
    # unique also across accounts, this should be a safe constraint.
    store.execute(ADD_UUID_UNIQUE_CONSTRAINT)

    # Finally link existing juju activities to the new account_entity_data rows
    store.execute(UPDATE_ACTIVITIES)
