from __future__ import print_function

# Copyright 2005-2016 Canonical Ltd. All rights reserved.

from storm.expr import Insert

from canonical.landscape.schema.patch_387 import __doc__

from canonical.landscape.model.main.store import get_main_store


REGION_ENTITY_TYPE = 4


def apply(store):
    print(__doc__)

    store.execute(
        """
        ALTER TABLE region
        ADD COLUMN data_id INTEGER REFERENCES account_entity_data
          ON DELETE CASCADE
        """
    )

    # Store account to access context mapping in a table to make it possible to
    # add account_entity_data with a single query.  We can't use a temporary
    # table here since they don't work with 2PC (it's not possible to PREPARE a
    # transaction which uses temporary tables).
    store.execute(
        """
        CREATE TABLE temp_account_access_context (
          account_id INTEGER,
          access_context_id INTEGER)
        """
    )

    result = get_main_store().execute("SELECT id, access_context_id FROM account")
    accounts_to_access_contexts = result.get_all()
    if accounts_to_access_contexts:
        insert = Insert(
            ["account_id", "access_context_id"],
            values=accounts_to_access_contexts,
            table="temp_account_access_context",
        )
        store.execute(insert)

    result = store.execute(
        """
        INSERT INTO account_entity_data (
          account_id, entity_type, name, access_context_id, creation_time)
            (SELECT cloud.account_id, 4, region.name,
                    temp_account_access_context.access_context_id,
                    region.creation_time
             FROM region, cloud, temp_account_access_context
             WHERE region.cloud_id = cloud.id
               AND cloud.account_id = temp_account_access_context.account_id)
        RETURNING id, account_id, name
        """
    )

    for row in result:
        store.execute(
            """
            UPDATE region
            SET data_id = ?
            FROM cloud
            WHERE cloud.account_id = ? AND region.name = ?
              AND region.cloud_id = cloud.id
            """,
            row,
        )

    store.execute(
        """
        ALTER TABLE region
        DROP COLUMN name,
        DROP COLUMN creation_time,
        ALTER COLUMN data_id SET NOT NULL
        """
    )

    store.execute("DROP TABLE temp_account_access_context")

    # Link entities to Region-related activities.
    store.execute(
        """
        UPDATE activity
        SET entity_data_id = region.data_id
        FROM region_request_data, region
        WHERE region_request_data.activity_id = activity.id
          AND region.id = region_request_data.region_id
        """
    )
