from __future__ import print_function

# Copyright 2005-2016 Canonical Ltd. All rights reserved.

from storm.expr import Insert

from canonical.landscape.model.main.store import get_main_store

from canonical.landscape.schema.patch_390 import __doc__


def apply(store):
    print(__doc__)

    computers_access_contexts = (
        get_main_store().execute("SELECT id, access_context_id FROM computer").get_all()
    )
    if not computers_access_contexts:
        return

    # Store computer to access context mapping in a table to make it possible
    # to update twins with a single query.  We can't use a temporary table here
    # since it doesn't work with 2PC (it's not possible to PREPARE a
    # transaction which uses temporary tables).
    store.execute(
        """
        CREATE TABLE temp_computer_access_context (
          computer_id INTEGER,
          access_context_id INTEGER)
        """
    )
    insert = Insert(
        ["computer_id", "access_context_id"],
        values=computers_access_contexts,
        table="temp_computer_access_context",
    )
    store.execute(insert)

    store.execute(
        """
        UPDATE account_entity_data
        SET access_context_id = temp_computer_access_context.access_context_id
        FROM computer_twin, temp_computer_access_context
        WHERE account_entity_data.id = computer_twin.data_id
          AND computer_twin.id = temp_computer_access_context.computer_id
        """
    )

    store.execute("DROP TABLE temp_computer_access_context")
