from __future__ import print_function

# Copyright 2005-2016 Canonical Ltd. All rights reserved.

from . import __doc__

# Map each possible status to the name of its count column in the activity
# table.
STATUS_COLUMNS = {
    1: "succeeded_count",
    2: "scheduled_count",
    3: "waiting_count",
    4: "queued_count",
    5: "inprogress_count",
    6: "blocked_count",
    7: "canceled_count",
    8: "failed_count",
    1001: "unapproved_count",
}


def apply(store):
    print(__doc__)

    # Remove parents without children.
    store.execute(
        """
        DELETE FROM activity
        WHERE parent_id IS NULL
          AND id NOT IN (
            SELECT DISTINCT parent_id
            FROM activity
            WHERE parent_id IS NOT NULL)
        """
    )

    # Update parent progress
    store.execute(
        """
        UPDATE activity
        SET progress = child.avg_progress
        FROM (
          SELECT parent_id, AVG(progress) AS avg_progress
          FROM activity
          GROUP BY parent_id) AS child
        WHERE id = child.parent_id
        """
    )

    # Update counts for each status
    for status_id, column in STATUS_COLUMNS.items():
        store.execute(
            """
            UPDATE activity
            SET {} = child.count
            FROM (
              SELECT parent_id, count(*)
              FROM activity
              WHERE status = ?
              GROUP BY parent_id) AS child
            WHERE id = child.parent_id
            """.format(
                column
            ),
            [status_id],
        )
