from __future__ import print_function

# Copyright 2005-2016 Canonical Ltd. All rights reserved.

from . import __doc__

CREATE_NEW_TABLE = [
    """
CREATE TABLE region_hypervisor (
    region_id INTEGER NOT NULL REFERENCES region ON DELETE CASCADE,
    name TEXT NOT NULL,
    percentage INTEGER NOT NULL CHECK (percentage > 0 AND percentage <= 100),
    PRIMARY KEY (region_id, name))
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE region_hypervisor TO landscape
""",
]

# Inserting 100 is always correct since we never released any code that
# allows multiple hypervisors yet.
INSERT_HYPERVISOR = """
INSERT INTO region_hypervisor (region_id, name, percentage)
    VALUES (?, ?, 100)"""

DROP_REGION_HYPERVISORS = """
ALTER TABLE region DROP COLUMN hypervisors"""


def apply(store):
    print(__doc__)
    for statement in CREATE_NEW_TABLE:
        store.execute(statement)

    result = store.execute("""SELECT id, hypervisors FROM region""")
    for region in result:
        region_id, hypervisors = region
        for hypervisor in hypervisors:
            store.execute(INSERT_HYPERVISOR, (region_id, hypervisor))

    store.execute(DROP_REGION_HYPERVISORS)
