# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Add package profile tables."""
from __future__ import print_function

STATEMENTS = [
    """
CREATE TABLE package_profile (
    id SERIAL NOT NULL PRIMARY KEY,
    account_id INTEGER NOT NULL REFERENCES account_twin ON DELETE CASCADE,
    name TEXT NOT NULL,
    description TEXT NOT NULL,
    version INTEGER NOT NULL,
    computer_group_id INTEGER NOT NULL REFERENCES computer_group
        ON DELETE CASCADE,
    creation_time TIMESTAMP NOT NULL DEFAULT (now() AT TIME ZONE 'UTC'),
    modification_time TIMESTAMP NOT NULL DEFAULT (now() AT TIME ZONE 'UTC'),
    UNIQUE (account_id, name))
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE package_profile TO landscape, landscape_maintenance
""",
    """
GRANT SELECT, UPDATE
    ON TABLE package_profile_id_seq TO landscape, landscape_maintenance
""",
    """
CREATE TABLE package_profile_constraint (
    id SERIAL NOT NULL PRIMARY KEY,
    package_profile_id INTEGER NOT NULL REFERENCES package_profile
        ON DELETE CASCADE,
    package_name TEXT NOT NULL,
    operator INTEGER not NULL,
    relation INTEGER NOT NULL,
    version TEXT,
    UNIQUE (package_profile_id, package_name, operator, relation, version))
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE package_profile_constraint TO landscape, landscape_maintenance
""",
    """
GRANT SELECT, UPDATE
    ON TABLE package_profile_constraint_id_seq TO landscape,
        landscape_maintenance
""",
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)
