# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Mark computers in the main database as inconsistent if they have pending
resynchronisations.
"""
from __future__ import print_function
from canonical.landscape.model.main import get_main_store
from canonical.landscape.model.main import Computer


def apply(store):
    print(__doc__)

    # Now we need to find all computers that are currently inconsistent.
    inconsistent_ids = []

    # Get DELIVERED and UNDELIVERED RESYNCHRONIZE messages
    query = (
        "SELECT DISTINCT computer_id FROM operation "
        "WHERE type=3 AND status IN (2, 3)"
    )
    inconsistent_ids = [x[0] for x in store.execute(query)]

    # inconsistent_ids now contains all computers which need to be updated.
    print("Making %d computers inconsistent." % len(inconsistent_ids))
    main_store = get_main_store()
    try:
        result = main_store.find(Computer, Computer.id.is_in(inconsistent_ids))
        result.set(is_inconsistent=True)
    except:
        main_store.rollback()
        raise
    else:
        main_store.commit()
