# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Clean up groups with duplicate names and fix the constraints on the
computer_group table.
"""
from __future__ import print_function

from storm.expr import In
from canonical.landscape.model.resource import Group


indexes = [
    """
ALTER TABLE computer_group
  ADD CONSTRAINT computer_group_computer_id_key UNIQUE (computer_id, name)
""",
    """
CREATE INDEX computer_user_group_group_id_idx ON computer_user_group (group_id)
""",
]


def apply(store):
    print(__doc__)

    query = store.execute("SELECT id, computer_id, name, gid FROM computer_group")

    computers = {}

    for id, computer_id, name, gid in query:
        computer = computers.setdefault(computer_id, {})
        groupnames = computer.setdefault(name, [])
        groupnames.append((gid, id))

    delete_ids = []

    for computer_id, groups in computers.items():
        for groupname, group_keys in groups.items():
            if len(group_keys) > 1:
                group_keys.sort()
                for gid, id in group_keys[1:]:
                    delete_ids.append(id)

    if delete_ids:
        print("Removing %d groups with duplicate names" % len(delete_ids))
        result = store.find(Group, In(Group.id, delete_ids))
        result.remove()

    for index in indexes:
        store.execute(index)
