from __future__ import print_function

# Copyright 2005-2016 Canonical Ltd. All rights reserved.

# The reason we do an "IF EXISTS" is because some users (IS) may have renamed
# the sequence manually (see RT 92053).
RENAME_METADATA_ID_SEQ = """
ALTER SEQUENCE IF EXISTS metadata_id_seq RENAME TO annotation_id_seq
"""

# When the annotation table was renamed from "metadata" we forgot to rename
# the primary key constraint and foreign key key constraint.  Databases
# created after that point will have the correct names while databases created
# before that point will have the incorrect name so we need to rename them
# conditionally.
METADATA_PKEY_EXISTS = """
SELECT 1 FROM pg_constraint WHERE conname = 'metadata_pkey'
"""

RENAME_METADATA_PKEY = """
ALTER TABLE annotation
    RENAME CONSTRAINT metadata_pkey TO annotation_pkey;
"""

METADATA_FKEY_EXISTS = """
SELECT 1 FROM pg_constraint WHERE conname = 'metadata_computer_id_fkey'
"""

RENAME_METADATA_FKEY = """
ALTER TABLE annotation
    RENAME CONSTRAINT metadata_computer_id_fkey TO annotation_computer_id_fkey;
"""


def apply(store):
    print("Rename metadata_id_seq to annotation_id_seq if it exists.")
    store.execute(RENAME_METADATA_ID_SEQ)

    # If the incorrectly-named metadata_pkey constraint exists, rename it.
    if store.execute(METADATA_PKEY_EXISTS).rowcount:
        print("Rename metadata_pkey to annotation_pkey.")
        store.execute(RENAME_METADATA_PKEY)

    # If the incorrectly-named metadata_computer_id_fkey constraint exists,
    # rename it.
    if store.execute(METADATA_FKEY_EXISTS).rowcount:
        print("Rename metadata_computer_id_fkey to " "annotation_computer_id_fkey.")
        store.execute(RENAME_METADATA_FKEY)
