from __future__ import print_function

# Copyright 2005-2016 Canonical Ltd. All rights reserved.

from . import __doc__

STATEMENTS = [
    # Add a reference to the account (since the computer_id might be null)
    """
ALTER TABLE computer_utilisation
ADD COLUMN account_id INTEGER REFERENCES account (id) ON DELETE CASCADE,
ADD COLUMN computer_type INTEGER
""",
    """
UPDATE computer_utilisation
SET account_id = computer.account_id,
    computer_type = (
      CASE
        WHEN container_info IS NOT NULL THEN 3
        WHEN vm_info IS NOT NULL THEN 2
        ELSE 1
      END)
FROM computer
WHERE computer_utilisation.computer_id = computer.id
""",
    """
ALTER TABLE computer_utilisation ALTER COLUMN account_id SET NOT NULL
""",
    # The primary key is not needed since computer_id is a foreign key, but should
    # still be unique
    """
ALTER TABLE computer_utilisation
DROP CONSTRAINT computer_utilisation_pkey,
ADD UNIQUE (computer_id),
ALTER COLUMN computer_id DROP NOT NULL
""",
    # Add indexes for foreign keys that are used to select/update
    """
CREATE INDEX computer_utilisation_computer_id_idx
ON computer_utilisation (computer_id)
""",
    """
CREATE INDEX computer_utilisation_account_id_idx
ON computer_utilisation (account_id)
""",
    # Recreate the foreign key without the ON DELETE CASCADE behavior
    """
ALTER TABLE computer_utilisation
DROP CONSTRAINT computer_utilisation_computer_id_fkey,
ADD CONSTRAINT computer_utilisation_computer_id_fkey
  FOREIGN KEY (computer_id)
  REFERENCES computer (id)
  ON DELETE SET NULL
""",
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)
