from __future__ import print_function

# Copyright 2005-2017 Canonical Ltd. All rights reserved.
# landscape-lint: noqa

from . import __doc__


STATEMENTS = [
    """
ALTER TABLE computer_packages
ADD COLUMN autoremovable integer[] NOT NULL DEFAULT '{}'::integer[]
""",
    """
ALTER TABLE computer_packages_buffer
ADD COLUMN autoremovable integer[] NOT NULL DEFAULT '{}'::integer[]
""",
    """
ALTER TABLE computer_packages_buffer
ADD COLUMN not_autoremovable integer[] NOT NULL DEFAULT '{}'::integer[]
""",
    # Argument signature is different from the new one, so drop the old.
    """
DROP FUNCTION IF EXISTS update_computer_packages(
  computer_id INT, available INT[], available_upgrades INT[],
  installed INT[], held INT[], not_available INT[],
  not_available_upgrades INT[], not_installed INT[], not_held INT[],
  reset BOOL)
""",
    """
CREATE OR REPLACE FUNCTION update_computer_packages(
  computer_id INT, available INT[], available_upgrades INT[],
  installed INT[], held INT[], autoremovable INT[], not_available INT[],
  not_available_upgrades INT[], not_installed INT[], not_held INT[],
  not_autoremovable INT[], reset BOOL)
RETURNS BOOL AS
$$
  def update_set(s, add, remove):
    '''Adds/remove elements to a set and return a list'''
    s.difference_update(remove)
    s.update(add)
    return list(s)

  def validate_deltas(s, add, remove):
    '''
    Check that all elements in the add sequence are not in s, and all in the
    remove one are.
    '''
    return not (set(remove).difference(s) or s.intersection(add))

  fields_to_deltas = (
    ("available", available, not_available),
    ("available_upgrades", available_upgrades, not_available_upgrades),
    ("installed", installed, not_installed),
    ("held", held, not_held),
    ("autoremovable", autoremovable, not_autoremovable))

  if reset:
    packages = {
      "available": set(),
      "available_upgrades": set(),
      "installed": set(),
      "held": set(),
      "autoremovable": set()}
  else:
    # get current packages
    packages_plan = plpy.prepare('''
      SELECT available, available_upgrades, installed, held, autoremovable
      FROM computer_packages
      WHERE computer_id = $1''', ["int"])
    packages = plpy.execute(packages_plan, [computer_id])[0]
    packages = dict((key, set(value)) for key, value in packages.iteritems())

  # Validate packages to add/remove, checking for package state that all new
  # packages are not already present, and all removed packages are currently
  # present.
  for field, add, remove in fields_to_deltas:
     if not validate_deltas(packages[field], add, remove):
       plpy.warning("Invalid deltas for '%s'" % field)
       return False

  params = [
    update_set(packages[field], add, remove)
    for field, add, remove in fields_to_deltas]
  params.append(computer_id)

  # Cross-state validation, after package sets have been updated with deltas.
  # This ensures that the overall state for the computer is consistent.
  if packages["held"] - packages["installed"]:
    plpy.warning("Packages in held must be installed")
    return False
  if packages["available_upgrades"] - packages["available"]:
    plpy.warning("Packages in available_upgrades must be available")
    return False
  if packages["available_upgrades"] & packages["installed"]:
    plpy.warning("Packages in available_upgrades must not be installed")
    return False
  if packages["autoremovable"] - packages["installed"]:
    plpy.warning("Packages in autoremovable must be installed")
    return False

  update_packages_plan = plpy.prepare('''
      UPDATE computer_packages
      SET available = $1, available_upgrades = $2, installed = $3, held = $4,
          autoremovable = $5
      WHERE computer_id = $6''',
     ["int[]", "int[]", "int[]", "int[]", "int[]", "int"])
  plpy.execute(update_packages_plan, params)

  return True
$$
LANGUAGE plpythonu
    """,
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)
