# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Merge the various columns of the package_profile_constraint table."""
from __future__ import print_function

from canonical.landscape.model.package import DEB_REQUIRES, DEB_CONFLICTS

STATEMENTS = [
    """
ALTER TABLE package_profile_constraint RENAME COLUMN relation TO type
""",
    """
ALTER TABLE package_profile_constraint ADD COLUMN value TEXT
""",
    """
ALTER TABLE package_profile_constraint DROP COLUMN package_name
""",
    """
ALTER TABLE package_profile_constraint DROP COLUMN operator
""",
    """
ALTER TABLE package_profile_constraint DROP COLUMN version
""",
    """
ALTER TABLE package_profile_constraint
ADD CONSTRAINT package_profile_constraint_package_profile_id_key
UNIQUE (package_profile_id, value, type)
""",
]

OPERATOR_MAP = {0: None, 1: "<", 2: "<=", 3: "=", 4: ">=", 5: ">"}

RELATION_MAP = {0: DEB_REQUIRES, 1: DEB_CONFLICTS}


def apply(store):
    print(__doc__)

    select = (
        "SELECT id, relation, package_name, operator, version "
        "FROM package_profile_constraint"
    )
    rows = list(store.execute(select))

    for statement in STATEMENTS:
        store.execute(statement)

    for id, relation, package_name, operator, version in rows:
        update = (
            "UPDATE package_profile_constraint " "SET type=%s, value=%s WHERE id=%s"
        )
        symbol = OPERATOR_MAP[operator]
        type = RELATION_MAP[relation]
        if symbol is None:
            value = package_name
        else:
            value = "%s %s %s" % (package_name, symbol, version)
        params = (type, value, id)
        store.execute(update, params)

    alter = "ALTER TABLE package_profile_constraint " "ALTER COLUMN value SET NOT NULL"
    store.execute(alter)
