# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Add UNIQUE constraint to salesforce keys to prevent duplicates."""
from __future__ import print_function


def apply(store):
    print(__doc__)
    store.execute(
        "ALTER TABLE account_invitation "
        "ADD CONSTRAINT account_invitation_salesforce_key_key "
        "UNIQUE (salesforce_key)"
    )
    store.execute(
        "ALTER TABLE salesforce_user "
        "ADD CONSTRAINT salesforce_user_salesforce_key_key "
        "UNIQUE (salesforce_key)"
    )

    duplicated_keys = store.execute(
        "SELECT salesforce_key from account_invitation "
        "INTERSECT "
        "SELECT salesforce_key from salesforce_user"
    )
    duplicated_keys = list(duplicated_keys)
    if duplicated_keys:
        raise RuntimeError(
            "Oh no! The following salesforce keys have an outstanding "
            "invitation *and* are already used by salesforce_users: %s"
            % ([x[0] for x in duplicated_keys],)
        )
