# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Change package activities model."""
from __future__ import print_function


def apply(store):
    print(__doc__)
    store.execute(
        """
        ALTER TABLE change_package_request RENAME TO change_package_request_old
    """
    )
    store.execute(
        """
    CREATE TABLE change_package_request (
        activity_id INTEGER PRIMARY KEY REFERENCES activity ON DELETE CASCADE,
        changes INT[][] NOT NULL DEFAULT '{}')
    """
    )
    store.execute(
        """
    GRANT SELECT, INSERT, UPDATE, DELETE
        ON TABLE change_package_request TO landscape, landscape_maintenance
    """
    )
    store.execute(
        """
    CREATE TABLE change_package_profile_request (
        activity_id INTEGER PRIMARY KEY REFERENCES activity ON DELETE CASCADE,
        package_profile_id INTEGER NOT NULL REFERENCES package_profile
            ON DELETE CASCADE,
        changes INT[][] NOT NULL DEFAULT '{}')
    """
    )
    store.execute(
        """
    GRANT SELECT, INSERT, UPDATE, DELETE
        ON TABLE change_package_profile_request
        TO landscape, landscape_maintenance
    """
    )

    result = store.execute(
        """
    SELECT package_id, id FROM package_profile
    """
    )

    # Map packages to profiles
    profile_packages = dict(result)

    # Map activities to changes
    changes = {}
    # Map activities to profiles
    profile_changes = {}

    INSTALL_TYPE = 202
    REMOVE_TYPE = 203
    UPGRADE_ALL_TYPE = 204
    UPGRADE_TYPE = 205
    DOWNGRADE_TYPE = 206

    result = store.execute(
        """
    SELECT id, package_id, parent_id, info_type, approval_time FROM
    change_package_request_old, activity, computer_request_data WHERE
    change_package_request_old.activity_id = activity.id AND
    computer_request_data.activity_id = activity.id
    """
    )
    for activity_id, package_id, parent_id, info_type, approval_time in result:
        if info_type == INSTALL_TYPE:
            flag = 4
            if package_id in profile_packages:
                profile_changes[parent_id] = profile_packages[package_id]
        elif info_type == REMOVE_TYPE:
            flag = 2
        changes.setdefault(parent_id, []).append(
            [flag, package_id, None, approval_time]
        )
        store.execute("DELETE FROM activity WHERE id=?", (activity_id,))

    result = store.execute(
        """
    SELECT id, install_package_id, remove_package_id, parent_id,
    info_type, approval_time FROM upgrade_package_request, activity,
    computer_request_data WHERE upgrade_package_request.activity_id =
    activity.id AND computer_request_data.activity_id = activity.id
    """
    )
    for (
        activity_id,
        install_package_id,
        remove_package_id,
        parent_id,
        info_type,
        approval_time,
    ) in result:
        if info_type == UPGRADE_TYPE:
            flag = 16
            if install_package_id in profile_packages:
                profile_changes[parent_id] = profile_packages[install_package_id]
        elif info_type == DOWNGRADE_TYPE:
            flag = 8
        changes.setdefault(parent_id, []).append(
            [flag, install_package_id, remove_package_id, approval_time]
        )
        store.execute("DELETE FROM activity WHERE id=?", (activity_id,))

    for activity, change in changes.items():
        approval_times = set(sub_change[3] for sub_change in change)
        if None in approval_times:
            approval_times.remove(None)
        if approval_times:
            # We have at least one approval, let's compute the correct flag
            automatic_approve = min(approval_times)
            new_change = [
                [sub_change[0] | 32, sub_change[1], sub_change[2]]
                for sub_change in change
                if sub_change[3] != automatic_approve
            ]
            new_change.extend(
                [
                    sub_change[:3]
                    for sub_change in change
                    if sub_change[3] == automatic_approve
                ]
            )
        else:
            new_change = [sub_change[:3] for sub_change in change]
        if activity in profile_changes:
            profile = profile_changes[activity]
            store.execute(
                """
                INSERT INTO change_package_profile_request VALUES (?, ?, ?)
            """,
                (activity, profile, new_change),
            )
            store.execute(
                """
                UPDATE activity SET info_type = 211 WHERE id = ?
            """,
                (activity,),
            )
        else:
            store.execute(
                """
                INSERT INTO change_package_request VALUES (?, ?)
            """,
                (activity, new_change),
            )

    # Update upgrade-all activities with no changes
    result = store.execute(
        """
        SELECT id FROM activity LEFT JOIN change_package_request
        ON activity.id = change_package_request.activity_id WHERE
        change_package_request.activity_id IS NULL AND info_type = ?
        """,
        (UPGRADE_ALL_TYPE,),
    )
    for activity in result:
        store.execute(
            """
            INSERT INTO change_package_request VALUES (?, '{}')
        """,
            (activity[0],),
        )

    store.execute("DROP TABLE change_package_request_old")
    store.execute("DROP TABLE upgrade_package_request")
