# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Add client message type tables and columns.
"""
from __future__ import print_function


STATEMENTS = [
    """
CREATE TABLE message_type (
    id SERIAL PRIMARY KEY,
    name TEXT NOT NULL UNIQUE)
""",
    """
GRANT SELECT, INSERT
    ON TABLE message_type TO landscape, landscape_maintenance
""",
    """
GRANT SELECT, UPDATE
    ON TABLE message_type_id_seq TO landscape, landscape_maintenance
""",
    """
CREATE TABLE computer_message_type (
    computer_id INTEGER NOT NULL REFERENCES computer ON DELETE CASCADE,
    message_type_id INTEGER NOT NULL REFERENCES message_type ON DELETE CASCADE,
    PRIMARY KEY (computer_id, message_type_id))
""",
    """
GRANT SELECT, INSERT, DELETE
    ON TABLE computer_message_type TO landscape, landscape_maintenance
""",
    """
ALTER TABLE computer ADD COLUMN accepted_message_types_hash BYTEA
""",
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)

    for name in (
        "add-group",
        "add-group-member",
        "add-user",
        "change-packages",
        "custom-graph-add",
        "custom-graph-remove",
        "edit-group",
        "edit-user",
        "execute-script",
        "lock-user",
        "package-ids",
        "remove-group",
        "remove-group-member",
        "remove-user",
        "shutdown",
        "signal-process",
        "unlock-user",
        "accepted-types",
        "registration",
        "resynchronize",
        "set-id",
        "set-intervals",
        "unknown-id",
    ):

        store.execute("INSERT INTO message_type (name) VALUES (?)", (name,))
