# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Add cloud and cloud_controller tables
"""
from __future__ import print_function

STATEMENTS = [
    """
CREATE TABLE cloud (
    id SERIAL NOT NULL PRIMARY KEY,
    account_id INTEGER NOT NULL REFERENCES account_twin ON DELETE CASCADE,
    title TEXT NOT NULL,
    endpoint TEXT NOT NULL,
    access_key BYTEA NOT NULL,
    secret_key BYTEA NOT NULL,
    public BOOL NOT NULL DEFAULT false,
    creation_time TIMESTAMP NOT NULL DEFAULT (now() AT TIME ZONE 'UTC'),
    UNIQUE (account_id, title),
    UNIQUE (account_id, endpoint, access_key))
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE cloud TO landscape, landscape_maintenance
""",
    """
GRANT SELECT, UPDATE
    ON TABLE cloud_id_seq TO landscape, landscape_maintenance
""",
    """
CREATE TABLE cloud_controller (
    computer_id INTEGER PRIMARY KEY REFERENCES computer_twin ON DELETE CASCADE,
    account_id INTEGER NOT NULL REFERENCES account_twin ON DELETE CASCADE,
    cloud_id INTEGER REFERENCES cloud ON DELETE SET NULL,
    UNIQUE (cloud_id))
""",
    """
CREATE INDEX cloud_controller_account_id_idx ON cloud_controller (account_id)
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE cloud_controller TO landscape, landscape_maintenance
""",
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)
