# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Make the cloud model crazy
"""
from __future__ import print_function

STATEMENTS = [
    """
ALTER TABLE ec2_access_info RENAME TO cloud
""",
    """
ALTER TABLE ec2_access_info_id_seq RENAME TO cloud_id_seq
""",
    """
CREATE TABLE ec2_cloud (
    cloud_id INTEGER NOT NULL PRIMARY KEY REFERENCES cloud ON DELETE CASCADE,
    account_id INTEGER NOT NULL REFERENCES account ON DELETE CASCADE,
    endpoint TEXT NOT NULL,
    access_key_id BYTEA NOT NULL,
    access_secret_key BYTEA NOT NULL,
    UNIQUE (account_id, endpoint, access_key_id))
""",
    """
GRANT SELECT, INSERT, DELETE, UPDATE
    ON TABLE ec2_cloud TO landscape, landscape_maintenance
""",
    """
CREATE TABLE cloud_instance (
    id SERIAL NOT NULL PRIMARY KEY,
    instance_key TEXT NOT NULL,
    account_id INTEGER NOT NULL REFERENCES account ON DELETE CASCADE,
    cloud_id INTEGER NOT NULL
        REFERENCES cloud ON DELETE CASCADE,
    computer_id INTEGER REFERENCES computer ON DELETE CASCADE,
    creation_time TIMESTAMP NOT NULL DEFAULT (now() AT TIME ZONE 'UTC'),
    UNIQUE (instance_key, cloud_id))
""",
    """
CREATE INDEX cloud_instance_computer_id_idx ON cloud_instance (computer_id)
""",
    """
GRANT SELECT, INSERT, DELETE, UPDATE
    ON TABLE cloud_instance TO landscape, landscape_maintenance
""",
    """
GRANT SELECT, UPDATE
    ON TABLE cloud_instance_id_seq TO landscape, landscape_maintenance
""",
    """
CREATE TABLE cloud_registration_otp (
    otp BYTEA PRIMARY KEY,
    cloud_instance_id INTEGER REFERENCES cloud_instance ON DELETE CASCADE)
""",
    """
GRANT SELECT, INSERT, DELETE
    ON TABLE cloud_registration_otp TO landscape, landscape_maintenance
""",
    # Now that we've got the schemas mostly set up, do the data migration
    """
INSERT INTO ec2_cloud (cloud_id, endpoint, access_key_id, access_secret_key)
    (SELECT id, endpoint, access_key_id, access_secret_key
     FROM cloud)
""",
    # And delete the columns left over in 'cloud' from 'ec2_access_info'.
    """
ALTER TABLE cloud DROP COLUMN endpoint
""",
    """
ALTER TABLE cloud DROP COLUMN access_key_id
""",
    """
ALTER TABLE cloud DROP COLUMN access_secret_key
""",
    # And now fix all the column names and fiddly index names and stuff
    """
ALTER INDEX ec2_access_info_pkey RENAME TO cloud_pkey
""",
    """
ALTER TABLE cloud DROP CONSTRAINT ec2_access_info_account_id_fkey
""",
    """
ALTER TABLE cloud ADD CONSTRAINT cloud_account_id_fkey
    FOREIGN KEY (account_id) REFERENCES account(id) ON DELETE CASCADE
""",
    """
ALTER INDEX ec2_access_info_account_id_key1 RENAME TO cloud_account_id_key
""",
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)
