# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Add two helper functions to optimize package searches."""
from __future__ import print_function


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)


STATEMENTS = [
    """
CREATE FUNCTION is_valid_package_id(package_id INTEGER, package_data TEXT)
    RETURNS BOOL AS $$

# The internal caching of this function is initialized by calling it
# once with C{package_data} being non-NULL and a fake
# C{package_id}. If the function is not initialized, an error is
# raised. If you forget to re-initialize it, it might still contain
# invalid cached data from a previous query though, so be careful!

import sys
import array
import bz2
import base64

if package_data is not None:
    # Using C{array.tostring} and C{array.fromstring} is the
    # fastest available method to serialize a list of integers to
    # a string in our measurements, but we have to ensure that the
    # endianess of the data is consistent on both sides. Since the
    # default endianess for the Intel platform is 'little', we
    # default to that and swap the bytes on the array in the
    # exceptional case.
    ids = array.array("L")
    if sys.byteorder != "little":
        ids.byteswap()

    # In order to reduce the size of the data sent across the wire to
    # initialize this function, we pack the list of ids to a string
    # using the L{array} module, then bzip it and base64 encode such
    # that the data is safe for usage in a SQL query and smaller than
    # the original size.
    ids.fromstring(bz2.decompress(base64.b64decode(package_data)))
    SD["package-ids-map"] = ids_map = set(ids)
    return False

ids_map = SD.get("package-ids-map")
if ids_map is None:
    plpy.error("is_valid_package_id() SQL Function not initialized")
    return False

return package_id in ids_map

$$ LANGUAGE plpythonu
"""
]
