# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Add missing foreign keys and create computer table."""
from __future__ import print_function
from canonical.landscape.model.main import get_main_store, Computer


def apply(store):
    print("Creating table 'computer' in resource database.")
    store.execute(
        """
    CREATE TABLE computer (
        id INTEGER PRIMARY KEY)
    """
    )

    main_store = get_main_store()
    for computer in main_store.find(Computer):
        store.execute("INSERT INTO computer VALUES (?)", (computer.id,))

    print("Adding foreign key constraint to message_info.computer_id.")
    store.execute(
        """
    ALTER TABLE message_info
        ADD CONSTRAINT message_info_computer_id_fkey
        FOREIGN KEY (computer_id) REFERENCES computer
        ON DELETE CASCADE
    """
    )

    print("Adding foreign key constraint to memory_info.computer_id.")
    store.execute(
        """
    ALTER TABLE memory_info
        ADD CONSTRAINT memory_info_computer_id_fkey
        FOREIGN KEY (computer_id) REFERENCES computer
        ON DELETE CASCADE
    """
    )

    print("Adding foreign key constraint to active_process.computer_id.")
    store.execute(
        """
    ALTER TABLE active_process
        ADD CONSTRAINT active_process_computer_id_fkey
        FOREIGN KEY (computer_id) REFERENCES computer
        ON DELETE CASCADE
    """
    )

    print("Adding foreign key constraint to historic_process.computer_id.")
    store.execute(
        """
    ALTER TABLE historic_process
        ADD CONSTRAINT historic_process_computer_id_fkey
        FOREIGN KEY (computer_id) REFERENCES computer
        ON DELETE CASCADE
    """
    )

    print("Adding foreign key constraint to load_average.computer_id.")
    store.execute(
        """
    ALTER TABLE load_average
        ADD CONSTRAINT load_average_computer_id_fkey
        FOREIGN KEY (computer_id) REFERENCES computer
        ON DELETE CASCADE
    """
    )

    print("Adding foreign key constraint to processor.computer_id.")
    store.execute(
        """
    ALTER TABLE processor
        ADD CONSTRAINT processor_computer_id_fkey
        FOREIGN KEY (computer_id) REFERENCES computer
        ON DELETE CASCADE
    """
    )

    print("Adding foreign key constraint to thermal_zone.computer_id.")
    store.execute(
        """
    ALTER TABLE thermal_zone
        ADD CONSTRAINT thermal_zone_computer_id_fkey
        FOREIGN KEY (computer_id) REFERENCES computer
        ON DELETE CASCADE
    """
    )

    print("Adding ON DELETE CASCADE to temperature.thermal_zone_id.")
    store.execute(
        """
    ALTER TABLE temperature
        DROP CONSTRAINT temperature_thermal_zone_id_fkey
    """
    )
    store.execute(
        """
    ALTER TABLE temperature
        ADD CONSTRAINT temperature_thermal_zone_id_fkey
        FOREIGN KEY (thermal_zone_id) REFERENCES thermal_zone
        ON DELETE CASCADE
    """
    )

    print("Adding foreign key constraint to client_uptime.computer_id.")
    store.execute(
        """
    ALTER TABLE client_uptime
        ADD CONSTRAINT client_uptime_computer_id_fkey
        FOREIGN KEY (computer_id) REFERENCES computer
        ON DELETE CASCADE
    """
    )

    print("Adding ON DELETE CASCADE to " "client_uptime_component.client_uptime_id.")
    store.execute(
        """
    ALTER TABLE client_uptime_component
        DROP CONSTRAINT client_uptime_component_client_uptime_id_fkey
    """
    )
    store.execute(
        """
    ALTER TABLE client_uptime_component
        ADD CONSTRAINT client_uptime_component_client_uptime_id_fkey
        FOREIGN KEY (client_uptime_id) REFERENCES client_uptime
        ON DELETE CASCADE
    """
    )

    print("Adding foreign key constraint to mount_info.computer_id.")
    store.execute(
        """
    ALTER TABLE mount_info
        ADD CONSTRAINT mount_info_computer_id_fkey
        FOREIGN KEY (computer_id) REFERENCES computer
        ON DELETE CASCADE
    """
    )

    print("Adding ON DELETE CASCADE to mount_activity.mount_info_id.")
    store.execute(
        """
    ALTER TABLE mount_activity
        DROP CONSTRAINT mount_activity_mount_info_id_fkey
    """
    )
    store.execute(
        """
    ALTER TABLE mount_activity
        ADD CONSTRAINT mount_activity_mount_info_id_fkey
        FOREIGN KEY (mount_info_id) REFERENCES mount_info
        ON DELETE CASCADE
    """
    )

    print("Adding ON DELETE CASCADE to free_space.mount_info_id.")
    store.execute(
        """
    ALTER TABLE free_space
        DROP CONSTRAINT free_space_mount_info_id_fkey
    """
    )
    store.execute(
        """
    ALTER TABLE free_space
        ADD CONSTRAINT free_space_mount_info_id_fkey
        FOREIGN KEY (mount_info_id) REFERENCES mount_info
        ON DELETE CASCADE
    """
    )

    print("Adding foreign key constraint to computer_uptime.computer_id.")
    store.execute(
        """
    ALTER TABLE computer_uptime
        ADD CONSTRAINT computer_uptime_computer_id_fkey
        FOREIGN KEY (computer_id) REFERENCES computer
        ON DELETE CASCADE
    """
    )

    print("Adding foreign key constraint to computer_user.computer_id.")
    store.execute(
        """
    ALTER TABLE computer_user
        ADD CONSTRAINT computer_user_computer_id_fkey
        FOREIGN KEY (computer_id) REFERENCES computer
        ON DELETE CASCADE
    """
    )

    print("Adding foreign key constraint to device.computer_id.")
    store.execute(
        """
    ALTER TABLE device
        ADD CONSTRAINT device_computer_id_fkey
        FOREIGN KEY (computer_id) REFERENCES computer
        ON DELETE CASCADE
    """
    )

    print("Adding ON DELETE CASCADE to device_property.device_id.")
    store.execute(
        """
    ALTER TABLE device_property
        DROP CONSTRAINT device_property_device_id_fkey
    """
    )
    store.execute(
        """
    ALTER TABLE device_property
        ADD CONSTRAINT device_property_device_id_fkey
        FOREIGN KEY (device_id) REFERENCES device
        ON DELETE CASCADE
    """
    )
