# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Check and update the package alerts for computers with locked packages."""
from __future__ import print_function

import transaction

from canonical.landscape.model.main import Computer, get_main_store
from canonical.landscape.model.package.alerts import (
    PackageUpgradesAlert,
    SecurityUpgradesAlert,
)


def apply(store):
    print(__doc__)
    result = store.execute(
        "SELECT computer_id "
        "FROM computer_packages WHERE "
        "array_upper(locked, 1) > 0"
    )
    if result:
        computer_ids = [computer_id for (computer_id,) in result]
        for computer in get_main_store().find(
            Computer, Computer.id.is_in(computer_ids)
        ):
            computer.check_rules(PackageUpgradesAlert)
            computer.check_rules(SecurityUpgradesAlert)
        transaction.commit()
