# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Redo of live package ids stored procedure with python 2.5 compatibility."""
from __future__ import print_function

STATEMENTS = [
    """
DROP FUNCTION get_live_packages()
""",
    """
CREATE FUNCTION get_live_packages()
-- Fetch all live packages, ie. those referenced in the computer_packages table
-- and return them as a bzip / base 64 encoded str representation of the
-- package ids set.
RETURNS text AS
$$
import array
import bz2
import base64
import sys

select_package_batch_plan = plpy.prepare('''
   SELECT available, available_upgrades, installed
   FROM computer_packages LIMIT $1 OFFSET $2
   ''', ['int4', 'int4'])

batch_size = 200
live_packages = set()

computer_count = plpy.execute(
      'SELECT count(*) as count FROM computer_packages')[0]['count']

# batch iterate throughall the computer packages rows, assembling a set
# of all package ids referenced.
for index in range(0, computer_count, batch_size):
    for computer_row in plpy.execute(
        select_package_batch_plan, [batch_size, index]):
        available = computer_row['available'][1:-1].split(',')
        installed = computer_row['installed'][1:-1].split(',')
        upgrades  = computer_row['available_upgrades'][1:-1].split(',')
        live_packages.update(available)
        live_packages.update(installed)
        live_packages.update(upgrades)

# remove empty upgrades/installed/available
live_packages.discard('')

package_ids = array.array('I')
package_ids.fromlist(map(int, live_packages))

# we always transfer in little endian (intel)
if sys.byteorder != 'little':
    package_ids.byteswap()

# compress the result to minimize wire traffic, and b64 encode for sql safety
return base64.b64encode(bz2.compress(package_ids.tostring()))
$$ LANGUAGE plpythonu VOLATILE;
""",
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)
