# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Add a max_people_count column to the account table. The default value
for existing and new accounts is 2.
"""
from __future__ import print_function

alteration = (
    "ALTER TABLE account ADD COLUMN max_people_count " "INTEGER NOT NULL DEFAULT 2"
)

select = (
    "SELECT account_id, count(person_id) FROM person_account " "GROUP BY account_id"
)

update = "UPDATE account SET max_people_count=%d WHERE id=%d"


def apply(store):
    print("Adding account.max_people_count.")
    store.execute(alteration)
    result = store.execute(select)
    for (account_id, people_count) in result.get_all():
        if people_count > 2:
            store.execute(update % (people_count, account_id))
