# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Add and alter tables to support account-related alerts."""
from __future__ import print_function


ACCOUNT_RULE_STATE_STATEMENTS = [
    """
CREATE TABLE account_rule_state (
    rule_id INTEGER PRIMARY KEY REFERENCES rule ON DELETE CASCADE,
    active BOOL NOT NULL DEFAULT false,
    dismissed BOOL NOT NULL DEFAULT false)
""",
    """
CREATE INDEX account_rule_state_rule_id_idx ON account_rule_state (rule_id)
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE account_rule_state TO landscape, landscape_maintenance
""",
]


COMPUTER_RULE_STATE_STATEMENTS = [
    """
UPDATE computer_rule_state SET active=false WHERE active IS NULL
""",
    """
ALTER TABLE computer_rule_state ALTER COLUMN active SET NOT NULL
""",
    """
ALTER TABLE computer_rule_state ALTER COLUMN active SET DEFAULT false
""",
    """
UPDATE computer_rule_state SET dismissed=false WHERE dismissed IS NULL
""",
    """
ALTER TABLE computer_rule_state ALTER COLUMN dismissed SET NOT NULL
""",
    """
ALTER TABLE computer_rule_state ALTER COLUMN dismissed SET DEFAULT false
""",
    """
CREATE INDEX computer_rule_state_computer_id_idx
    ON computer_rule_state (computer_id)
""",
    """
CREATE INDEX computer_rule_state_rule_id_idx ON computer_rule_state (rule_id)
""",
]


SAMPLE_RULE_STATEMENTS = [
    """
ALTER TABLE sample_rule RENAME TO sample_computer_rule
""",
    """
ALTER INDEX sample_rule_pkey RENAME TO sample_computer_rule_pkey
""",
    """
ALTER TABLE sample_computer_rule DROP CONSTRAINT sample_rule_rule_id_fkey
""",
    """
ALTER TABLE sample_computer_rule
    ADD CONSTRAINT sample_computer_rule_rule_id_fkey
    FOREIGN KEY (rule_id) REFERENCES rule
    ON DELETE CASCADE
""",
    """
CREATE TABLE sample_account_rule (
    rule_id INTEGER PRIMARY KEY REFERENCES rule ON DELETE CASCADE,
    data TEXT)
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE sample_account_rule TO landscape, landscape_maintenance
""",
]


def apply(store):
    print(__doc__)
    for statement in ACCOUNT_RULE_STATE_STATEMENTS:
        store.execute(statement)
    for statement in COMPUTER_RULE_STATE_STATEMENTS:
        store.execute(statement)
    for statement in SAMPLE_RULE_STATEMENTS:
        store.execute(statement)
