# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Remove the timestamp from mount_info."""
from __future__ import print_function

from builtins import range
import operator
import time

import transaction


STATEMENTS = [
    """
ALTER TABLE mount_info DROP timestamp
""",
    """
ALTER TABLE mount_info ADD CONSTRAINT mount_info_computer_id_key UNIQUE
(computer_id, mount_point)
""",
    """
GRANT UPDATE on mount_info TO landscape, landscape_maintenance
""",
]


def apply(store):
    print(__doc__)
    computer_ids = list(store.execute("SELECT id FROM computer_twin"))
    for computer_id in sorted(c[0] for c in computer_ids):
        infos = list(
            store.execute(
                "SELECT id, mount_point, timestamp FROM mount_info "
                "WHERE computer_id = ?",
                (computer_id,),
            )
        )
        mount_infos = {}
        for info_id, mount_point, timestamp in infos:
            mount_infos.setdefault(mount_point, []).append((info_id, timestamp))
        for mount_point, data in mount_infos.items():
            if len(data) > 1:
                t = time.time()
                data.sort(key=operator.itemgetter(1))
                last_info_id = data.pop()[0]
                ids_to_remove = [d[0] for d in data]
                for j in range(0, len(ids_to_remove), 200):
                    batch = ids_to_remove[j : j + 200]
                    store.execute(
                        "UPDATE mount_activity SET mount_info_id = ? "
                        "WHERE mount_info_id = ANY(?)",
                        (last_info_id, batch),
                    )
                    store.execute(
                        "UPDATE free_space SET mount_info_id = ? "
                        "WHERE mount_info_id = ANY(?)",
                        (last_info_id, batch),
                    )
                    store.execute(
                        "DELETE FROM mount_info " "WHERE id = ANY(?)", (batch,)
                    )
                print(
                    "Handled '%s' for computer %d, took %.2f seconds"
                    % (mount_point, computer_id, time.time() - t)
                )
        transaction.commit()
    for statement in STATEMENTS:
        store.execute(statement)
