# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Support postgres 9.
"""
from __future__ import print_function

STATEMENTS = [
    """
CREATE OR REPLACE FUNCTION change_array(source_array INT[],
                             remove_array INT[],
                             append_array INT[]) RETURNS INT[] AS
$$
    def change_array_8(source_array, remove_array, append_array):
        if source_array != "{}":
            result = set(source_array[1:-1].split(','))
        else:
            result = set()
        if remove_array != "{}":
            result.difference_update(remove_array[1:-1].split(','))
        if append_array != "{}":
            result.update(append_array[1:-1].split(','))
        return '{%s}' % ','.join(result)

    if isinstance(source_array, str):
        return change_array_8(source_array, remove_array, append_array)
    result = set(source_array)
    result.difference_update(remove_array)
    result.update(append_array)
    return list(result)
$$
LANGUAGE plpythonu
""",
    """
CREATE OR REPLACE FUNCTION get_live_packages() RETURNS text AS
$$
# Fetch all live packages, ie. those referenced in the computer_packages table
# and return them as a bzip / base 64 encoded str representation of the
# package ids set.

import array
import bz2
import base64
import sys

select_package_batch_plan = plpy.prepare('''
   SELECT available, available_upgrades, installed
   FROM computer_packages LIMIT $1 OFFSET $2
   ''', ['int4', 'int4'])

batch_size = 200
live_packages = set()

computer_count = plpy.execute(
      'SELECT count(*) as count FROM computer_packages')[0]['count']

def get_package_data_8(computer_row):
    available = computer_row['available'][1:-1].split(',')
    installed = computer_row['installed'][1:-1].split(',')
    upgrades = computer_row['available_upgrades'][1:-1].split(',')
    return available, installed, upgrades

# batch iterate throughall the computer packages rows, assembling a set
# of all package ids referenced.
for index in range(0, computer_count, batch_size):
    for computer_row in plpy.execute(
        select_package_batch_plan, [batch_size, index]):
        if isinstance(computer_row['available'], str):
            available, installed, upgrades = get_package_data_8(computer_row)
        else:
            available = computer_row['available']
            installed = computer_row['installed']
            upgrades = computer_row['available_upgrades']
        live_packages.update(available)
        live_packages.update(installed)
        live_packages.update(upgrades)

# remove empty upgrades/installed/available
live_packages.discard('')

package_ids = array.array('I')
package_ids.fromlist(map(int, live_packages))

# we always transfer in little endian (intel)
if sys.byteorder != 'little':
    package_ids.byteswap()

# compress the result to minimize wire traffic, and b64 encode for sql safety
return base64.b64encode(bz2.compress(package_ids.tostring()))
$$ LANGUAGE plpythonu VOLATILE;
""",
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)
