# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Add full text search capabilities to hardware_info.
"""
from __future__ import print_function

STATEMENTS = [
    """ALTER TABLE hardware_info ADD COLUMN str_value_vector tsvector""",
    """
CREATE FUNCTION update_hardware_info_tsvector()
  RETURNS trigger AS $PROC$
BEGIN
    IF (NEW.str_value_vector IS NULL) THEN
        NEW.str_value_vector :=
            TO_TSVECTOR('simple', COALESCE(NEW.str_value, ''));
    END IF;
    RETURN NEW;
END
$PROC$ LANGUAGE plpgsql;
""",
    """
GRANT EXECUTE
    ON FUNCTION update_hardware_info_tsvector() TO landscape
""",
    """
CREATE TRIGGER hardware_info_insert
BEFORE INSERT ON hardware_info
    FOR EACH ROW EXECUTE PROCEDURE update_hardware_info_tsvector();
""",
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)
