# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Refactor cloud topology tables to match the new model."""
from __future__ import print_function


STATEMENTS = [
    """
DROP TABLE cloud_instance_node
""",
    """
DROP TABLE cloud_controller
""",
    """
CREATE TABLE topology (
    id SERIAL NOT NULL PRIMARY KEY,
    cloud_id INTEGER NOT NULL REFERENCES cloud ON DELETE CASCADE,
    endpoint TEXT NOT NULL
    )
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE topology TO landscape
""",
    """
GRANT SELECT, UPDATE ON topology_id_seq TO landscape
""",
    """
CREATE UNIQUE INDEX topology_cloud_id_endpoint_idx
    ON topology (cloud_id, endpoint)
""",
    """
CREATE TABLE walrus_controller (
    id SERIAL NOT NULL PRIMARY KEY,
    topology_id INTEGER NOT NULL UNIQUE REFERENCES topology ON DELETE CASCADE,
    ip_address TEXT NOT NULL,
    name TEXT NOT NULL
    )
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE walrus_controller TO landscape
""",
    """
GRANT SELECT, UPDATE ON walrus_controller_id_seq TO landscape
""",
    """
CREATE TABLE cluster_controller (
    id SERIAL NOT NULL PRIMARY KEY,
    topology_id INTEGER NOT NULL REFERENCES topology ON DELETE CASCADE,
    ip_address TEXT NOT NULL,
    name TEXT NOT NULL
    )
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE cluster_controller TO landscape
""",
    """
GRANT SELECT, UPDATE ON cluster_controller_id_seq TO landscape
""",
    """
CREATE UNIQUE INDEX cluster_controller_topology_id_ip_address_idx
    ON cluster_controller (topology_id, ip_address)
""",
    """
CREATE UNIQUE INDEX cluster_controller_topology_id_name_idx
    ON cluster_controller (topology_id, name)
""",
    """
CREATE TABLE storage_controller (
    id SERIAL NOT NULL PRIMARY KEY,
    cluster_controller_id INTEGER NOT NULL UNIQUE
        REFERENCES cluster_controller ON DELETE CASCADE,
    ip_address TEXT NOT NULL
    )
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE storage_controller TO landscape
""",
    """
GRANT SELECT, UPDATE ON storage_controller_id_seq TO landscape
""",
    """
CREATE TABLE node_controller (
    id SERIAL NOT NULL PRIMARY KEY,
    cluster_controller_id INTEGER NOT NULL
        REFERENCES cluster_controller ON DELETE CASCADE,
    ip_address TEXT NOT NULL,
    instance_ids TEXT[]
    )
""",
    """
GRANT SELECT, INSERT, UPDATE, DELETE
    ON TABLE node_controller TO landscape
""",
    """
GRANT SELECT, UPDATE ON node_controller_id_seq TO landscape
""",
    """
CREATE UNIQUE INDEX node_controller_topology_id_ip_address_idx
    ON node_controller (cluster_controller_id, ip_address)
""",
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)
