# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Reset smart locks information for non-APT clients on hosted."""
from __future__ import print_function

from builtins import str
from canonical.lib.dpkg import version_compare
from canonical.landscape.model.main.store import get_main_store


def apply(store):
    print(__doc__)
    main_store = get_main_store()
    result = main_store.execute("SELECT id, current_version FROM computer")
    computer_ids = []
    for computer_id, current_version in result:

        # If the client hasn't reported information yet, skip it
        if current_version is None:
            continue

        # If it's a new APT client, it's good, skip it
        if version_compare(current_version, "12.04") >= 0:
            continue

        computer_ids.append(computer_id)

    # Reset locks for old clients
    if computer_ids:
        store.execute(
            "UPDATE computer_packages SET locked = '{}' "
            "WHERE computer_id IN (%s)"
            % ",".join(str(computer_id) for computer_id in computer_ids)
        )
