# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Drop 'repository_' prefix from tables."""
from __future__ import print_function

STATEMENTS = [
    """
ALTER TABLE repository_distribution RENAME TO distribution
""",
    """
ALTER TABLE repository_series RENAME TO series
""",
    """
ALTER TABLE repository_pocket RENAME TO pocket
""",
    """
ALTER TABLE repository_upload RENAME TO upload
""",
    """
ALTER TABLE repository_pocket_upload_gpg_key RENAME TO pocket_upload_gpg_key
""",
    """
ALTER TABLE sync_repository_pocket_request RENAME TO sync_pocket_request
""",
    """
ALTER INDEX repository_distribution_pkey RENAME TO distribution_pkey
""",
    """
ALTER INDEX repository_distribution_account_id_key
    RENAME TO distribution_account_id_key
""",
    """
ALTER INDEX repository_series_pkey RENAME TO series_pkey
""",
    """
ALTER INDEX repository_series_distribution_id_key
    RENAME TO series_distribution_id_key
""",
    """
ALTER INDEX repository_pocket_pkey RENAME TO pocket_pkey
""",
    """
ALTER INDEX repository_pocket_series_id_key RENAME TO pocket_series_id_key
""",
    """
ALTER INDEX repository_pocket_upload_gpg_key_pkey
    RENAME TO pocket_upload_gpg_key_pkey
""",
    """
ALTER INDEX sync_repository_pocket_request_pkey
    RENAME TO sync_pocket_request_pkey
""",
    """
ALTER INDEX repository_upload_pkey
    RENAME TO upload_pkey
""",
    """
ALTER INDEX repository_upload_distribution_id_key
    RENAME TO upload_distribution_id_key
""",
    """
ALTER INDEX repository_upload_pocket_id_idx
    RENAME TO upload_pocket_id_idx
""",
    """
ALTER SEQUENCE repository_distribution_id_seq RENAME TO distribution_id_seq
""",
    """
ALTER SEQUENCE repository_series_id_seq RENAME TO series_id_seq
""",
    """
ALTER SEQUENCE repository_pocket_id_seq RENAME TO pocket_id_seq
""",
    """
ALTER SEQUENCE repository_upload_id_seq RENAME TO upload_id_seq
""",
    """
ALTER TABLE distribution
    DROP CONSTRAINT repository_distribution_account_id_fkey
""",
    """
ALTER TABLE distribution ADD CONSTRAINT distribution_account_id_fkey
    FOREIGN KEY (account_id) REFERENCES account_twin(id) ON DELETE CASCADE
""",
    """
ALTER TABLE series
    DROP CONSTRAINT repository_series_distribution_id_fkey
""",
    """
ALTER TABLE series ADD CONSTRAINT repository_series_distribution_id_fkey
    FOREIGN KEY (distribution_id) REFERENCES distribution(id) ON DELETE CASCADE
""",
    """
ALTER TABLE pocket
    DROP CONSTRAINT repository_pocket_fetch_gpg_key_id_fkey
""",
    """
ALTER TABLE pocket
    DROP CONSTRAINT repository_pocket_gpg_key_id_fkey
""",
    """
ALTER TABLE pocket
    DROP CONSTRAINT repository_pocket_pull_pocket_id_fkey
""",
    """
ALTER TABLE pocket
    DROP CONSTRAINT repository_pocket_series_id_fkey
""",
    """
ALTER TABLE pocket ADD CONSTRAINT pocket_fetch_gpg_key_id_fkey
   FOREIGN KEY (fetch_gpg_key_id) REFERENCES gpg_key(id) ON DELETE CASCADE
""",
    """
ALTER TABLE pocket ADD CONSTRAINT pocket_gpg_key_id_fkey
   FOREIGN KEY (gpg_key_id) REFERENCES gpg_key(id) ON DELETE CASCADE
""",
    """
ALTER TABLE pocket ADD CONSTRAINT pocket_pull_pocket_id_fkey
   FOREIGN KEY (pull_pocket_id) REFERENCES pocket(id) ON DELETE CASCADE
""",
    """
ALTER TABLE pocket ADD CONSTRAINT pocket_series_id_fkey
   FOREIGN KEY (series_id) REFERENCES series(id) ON DELETE CASCADE
""",
    """
ALTER TABLE upload
    DROP CONSTRAINT repository_upload_distribution_id_fkey
""",
    """
ALTER TABLE upload
    DROP CONSTRAINT repository_upload_pocket_id_fkey
""",
    """
ALTER TABLE upload ADD CONSTRAINT upload_distribution_id_fkey
    FOREIGN KEY (distribution_id) REFERENCES distribution(id) ON DELETE CASCADE
""",
    """
ALTER TABLE upload ADD CONSTRAINT upload_pocket_id_fkey
    FOREIGN KEY (pocket_id) REFERENCES pocket(id) ON DELETE CASCADE
""",
    """
ALTER TABLE pocket_upload_gpg_key
    DROP CONSTRAINT repository_pocket_upload_gpg_key_gpg_key_id_fkey
""",
    """
ALTER TABLE pocket_upload_gpg_key
    DROP CONSTRAINT repository_pocket_upload_gpg_key_pocket_id_fkey
""",
    """
ALTER TABLE pocket_upload_gpg_key ADD CONSTRAINT
    pocket_upload_gpg_key_gpg_key_id_fkey
    FOREIGN KEY (gpg_key_id) REFERENCES gpg_key(id) ON DELETE CASCADE
""",
    """
ALTER TABLE pocket_upload_gpg_key ADD CONSTRAINT
    pocket_upload_gpg_key_pocket_id_fkey
    FOREIGN KEY (pocket_id) REFERENCES pocket(id) ON DELETE CASCADE
""",
    """
ALTER TABLE sync_pocket_request
    DROP CONSTRAINT sync_repository_pocket_request_activity_id_fkey
""",
    """
ALTER TABLE sync_pocket_request
    DROP CONSTRAINT sync_repository_pocket_request_pocket_id_fkey
""",
    """
ALTER TABLE sync_pocket_request ADD CONSTRAINT
    sync_pocket_request_activity_id_fkey
    FOREIGN KEY (activity_id) REFERENCES activity(id) ON DELETE CASCADE
""",
    """
ALTER TABLE sync_pocket_request ADD CONSTRAINT
    sync_pocket_request_pocket_id_fkey
    FOREIGN KEY (pocket_id) REFERENCES pocket(id) ON DELETE CASCADE
""",
]


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)
