# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Add table for tracking current releases of EC2 images.

There can be one AMI for each (ubuntu release, architecture, region).
"""
from __future__ import print_function

AMAZON_US = "us-east-1"
AMAZON_US_WEST = "us-west-1"
AMAZON_EU = "eu-west-1"
AMAZON_APAC_SINGAPORE = "ap-southeast-1"
AMAZON_APAC_TOKYO = "ap-northeast-1"


STATEMENTS = [
    """
CREATE TABLE ec2_current_image (
    id SERIAL NOT NULL PRIMARY KEY,
    ami TEXT NOT NULL,
    ubuntu_release_name TEXT NOT NULL,
    bits INTEGER NOT NULL,
    region TEXT NOT NULL,
    UNIQUE (ubuntu_release_name, bits, region))
""",
    """
GRANT SELECT, INSERT, DELETE, UPDATE
    ON TABLE ec2_current_image TO landscape_maintenance
""",
    """
GRANT SELECT, INSERT
    ON TABLE ec2_current_image TO landscape
""",
    """
GRANT SELECT, UPDATE
    ON TABLE ec2_current_image_id_seq TO landscape, landscape_maintenance
""",
]


IMAGE_BY_PLATFORM_ENDPOINT_VERSION = {
    (32, AMAZON_US, "dapper"): "ami-c2cb29ab",
    (64, AMAZON_US, "dapper"): "ami-b6cb29df",
    (32, AMAZON_US, "hardy"): "ami-9cef07f5",
    (64, AMAZON_US, "hardy"): "ami-c2e008ab",
    (32, AMAZON_US, "jaunty"): "ami-fb32df92",
    (64, AMAZON_US, "jaunty"): "ami-530de03a",
    (32, AMAZON_US, "karmic"): "ami-449f772d",
    (64, AMAZON_US, "karmic"): "ami-7690781f",
    (32, AMAZON_US, "lucid"): "ami-65f21b0c",
    (64, AMAZON_US, "lucid"): "ami-bff51cd6",
    (32, AMAZON_US_WEST, "dapper"): "ami-072f7e42",
    (64, AMAZON_US_WEST, "dapper"): "ami-192f7e5c",
    (32, AMAZON_US_WEST, "hardy"): "ami-01b5e444",
    (64, AMAZON_US_WEST, "hardy"): "ami-0db5e448",
    (32, AMAZON_US_WEST, "jaunty"): "ami-f52a7bb0",
    (64, AMAZON_US_WEST, "jaunty"): "ami-eb2a7bae",
    (32, AMAZON_US_WEST, "karmic"): "ami-efb3e2aa",
    (64, AMAZON_US_WEST, "karmic"): "ami-85b3e2c0",
    (32, AMAZON_US_WEST, "lucid"): "ami-7d80d138",
    (64, AMAZON_US_WEST, "lucid"): "ami-0d80d148",
    (32, AMAZON_EU, "dapper"): "ami-f1022985",
    (64, AMAZON_EU, "dapper"): "ami-fd022989",
    (32, AMAZON_EU, "hardy"): "ami-2f03295b",
    (64, AMAZON_EU, "hardy"): "ami-0b03297f",
    (32, AMAZON_EU, "jaunty"): "ami-9ff4dfeb",
    (64, AMAZON_EU, "jaunty"): "ami-81f4dff5",
    (32, AMAZON_EU, "karmic"): "ami-c70f25b3",
    (64, AMAZON_EU, "karmic"): "ami-af0f25db",
    (32, AMAZON_EU, "lucid"): "ami-6f547e1b",
    (64, AMAZON_EU, "lucid"): "ami-69547e1d",
    (32, AMAZON_APAC_SINGAPORE, "hardy"): "ami-521a6000",
    (64, AMAZON_APAC_SINGAPORE, "hardy"): "ami-581a600a",
    (32, AMAZON_APAC_SINGAPORE, "karmic"): "ami-e6344ab4",
    (64, AMAZON_APAC_SINGAPORE, "karmic"): "ami-90344ac2",
    (32, AMAZON_APAC_SINGAPORE, "lucid"): "ami-d8205a8a",
    (64, AMAZON_APAC_SINGAPORE, "lucid"): "ami-e8205aba",
    (32, AMAZON_APAC_TOKYO, "hardy"): "ami-d6b105d7",
    (64, AMAZON_APAC_TOKYO, "hardy"): "ami-02b20603",
    (32, AMAZON_APAC_TOKYO, "karmic"): "ami-240fa425",
    (64, AMAZON_APAC_TOKYO, "karmic"): "ami-2a0fa42b",
    (32, AMAZON_APAC_TOKYO, "lucid"): "ami-40b40041",
    (64, AMAZON_APAC_TOKYO, "lucid"): "ami-58b40059",
}


def migrate_current_images(store):
    """Insert the current images that were hardcoded before."""
    query = """
        INSERT INTO ec2_current_image(
            ami, ubuntu_release_name, bits, region)
        VALUES(?, ?, ?, ?)
    """
    for key, ami in IMAGE_BY_PLATFORM_ENDPOINT_VERSION.items():
        bits, endpoint, release_name = key
        store.execute(
            query,
            (ami, release_name, bits, "https://ec2-%s-amazonaws.com" % endpoint),
            noresult=True,
        )


def apply(store):
    print(__doc__)
    for statement in STATEMENTS:
        store.execute(statement)
    migrate_current_images(store)
