# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Drop root_parent_id column from the activity table."""
from __future__ import print_function


def apply(store):
    print(__doc__)

    store.execute(
        """
CREATE OR REPLACE FUNCTION synchronize_activities_for_computers(
    computer_ids INTEGER[])
    RETURNS VOID AS
$$

STATUS_PRIORITY = [1, 7, 2, 3, 5, 6, 4]

def get_highest_priority_status(statuses):
    if len(statuses) == 1:
        return statuses.pop()
    else:
        for status in STATUS_PRIORITY:
            if status in statuses:
                return status
    return None

select_group_activities_plan = plpy.prepare('''
    SELECT activity.id, activity_group.children_data FROM activity,
    activity_group WHERE activity.id = activity_group.activity_id AND
    activity.info_type = 6 AND activity_group.children_data != '{}' AND
    EXISTS (SELECT 1 FROM activity AS child_activity
    WHERE child_activity.parent_id = activity.id AND
    child_activity.computer_id = ANY($1))
''', ["int4[]"])

select_status_plan = plpy.prepare('''
    SELECT computer_request_data.status FROM computer_request_data, activity
    WHERE computer_request_data.activity_id = activity.id AND
    activity.parent_id = $1
''', ["int4"])

delete_child_activities_plan = plpy.prepare('''
    DELETE FROM activity WHERE computer_id = ANY($1) AND parent_id = $2
''', ["int4[]", "int4"])

delete_activity_plan = plpy.prepare('''
    DELETE FROM activity WHERE id = $1
''', ["int4"])

update_activity_plan = plpy.prepare('''
    UPDATE activity_group SET children_data = $2, status = $3
    WHERE activity_id = $1
''', ["int4", "int4[]", "int4"])

select_remaining_activities = plpy.prepare('''
    SELECT id, parent_id FROM activity WHERE computer_id = ANY($1)
    AND parent_id is not NULL
''', ["int4[]"])

delete_empty_activities_notice = plpy.prepare('''
    DELETE FROM activity WHERE activity.info_type = 6 AND activity.id = ANY($1)
    AND NOT EXISTS (SELECT 1 FROM activity AS child_activity WHERE
    child_activity.parent_id = activity.id)
''', ["int4[]"])

# First, delete computer request activities
computer_ids_set = set(map(int, computer_ids[1:-1].split(",")))
for activity in plpy.execute(select_group_activities_plan, [computer_ids]):
    activity_id = activity["id"]
    children_data = activity["children_data"]
    real_children_data = map(int, children_data[1:-1].split(","))
    for computer_id in real_children_data[:]:
        if computer_id in computer_ids_set:
            real_children_data.remove(computer_id)

    plpy.execute(delete_child_activities_plan, [computer_ids, activity_id])

    if not real_children_data:
        plpy.execute(delete_activity_plan, [activity_id])
    else:
        new_children_data = ",".join(str(computer_id) for computer_id in
                                     real_children_data)
        new_children_data = "{%s}" % new_children_data
        statuses = list(plpy.execute(select_status_plan, [activity_id]))
        status = get_highest_priority_status([s["status"] for s in statuses])
        plpy.execute(
            update_activity_plan, [activity_id, new_children_data, status])

# Let's take care of notice activities
parent_ids = set()
for activity in plpy.execute(select_remaining_activities, [computer_ids]):
    activity_id = activity["id"]
    parent_id = activity["parent_id"]
    parent_ids.add(parent_id)
    plpy.execute(delete_activity_plan, [activity_id])

parent_ids = "{%s}" % (",".join(map(str, parent_ids)),)
plpy.execute(delete_empty_activities_notice, [parent_ids])

$$ LANGUAGE plpythonu
"""
    )

    store.execute("ALTER TABLE activity DROP COLUMN root_parent_id")
