--
-- PostgreSQL database dump
--

-- Dumped from database version 12.15 (Ubuntu 12.15-0ubuntu0.20.04.1)
-- Dumped by pg_dump version 12.15 (Ubuntu 12.15-0ubuntu0.20.04.1)

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET xmloption = content;
SET client_min_messages = warning;
SET row_security = off;

--
-- Name: plpython3u; Type: PROCEDURAL LANGUAGE; Schema: -; Owner: -
--

CREATE OR REPLACE PROCEDURAL LANGUAGE plpython3u;


--
-- Name: intarray; Type: EXTENSION; Schema: -; Owner: -
--

CREATE EXTENSION IF NOT EXISTS intarray WITH SCHEMA public;


--
-- Name: EXTENSION intarray; Type: COMMENT; Schema: -; Owner: -
--

COMMENT ON EXTENSION intarray IS 'functions, operators, and index support for 1-D arrays of integers';


--
-- Name: apply_set_delta(integer[], integer[], integer[], boolean); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION public.apply_set_delta(base integer[], add integer[], remove integer[], reset boolean) RETURNS integer[]
    LANGUAGE plpgsql
    AS $$
DECLARE
    _base integer[];
    result integer[];
BEGIN
    IF NOT reset THEN
        _base := base;
    ELSE
        _base = ARRAY[]::integer[];
    END IF;

    -- Check that the delta is consistent with the base.
    IF _base && add OR NOT _base @> remove THEN
        RETURN NULL;
    END IF;

    SELECT INTO STRICT result
        COALESCE(array_agg(e ORDER BY e), ARRAY[]::integer[])
    FROM (
        SELECT unnest(_base) e
        UNION SELECT unnest(add)
        EXCEPT SELECT unnest(remove)
    ) r;
    RETURN result;
END;
$$;


--
-- Name: get_load_average(); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION public.get_load_average() RETURNS double precision
    LANGUAGE plpython3u
    AS $$
    import os
    return os.getloadavg()[0]
$$;


--
-- Name: update_computer_packages(integer, integer[], integer[], integer[], integer[], integer[], integer[], integer[], integer[], integer[], integer[], integer[], integer[], boolean); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION public.update_computer_packages(computer_id integer, available integer[], available_upgrades integer[], installed integer[], held integer[], autoremovable integer[], security integer[], not_available integer[], not_available_upgrades integer[], not_installed integer[], not_held integer[], not_autoremovable integer[], not_security integer[], reset boolean) RETURNS boolean
    LANGUAGE plpgsql
    AS $$
DECLARE
  old computer_packages%ROWTYPE;
  new_available integer[];
  new_available_upgrades integer[];
  new_installed integer[];
  new_held integer[];
  new_autoremovable integer[];
  new_security integer[];
BEGIN
    SELECT * INTO STRICT old FROM computer_packages
    WHERE computer_packages.computer_id = update_computer_packages.computer_id;

    new_available := apply_set_delta(
        old.available, available, not_available, reset);
    new_available_upgrades := apply_set_delta(
        old.available_upgrades, available_upgrades, not_available_upgrades,
        reset);
    new_installed := apply_set_delta(
        old.installed, installed, not_installed, reset);
    new_held := apply_set_delta(old.held, held, not_held, reset);
    new_autoremovable := apply_set_delta(
        old.autoremovable, autoremovable, not_autoremovable, reset);
    new_security := apply_set_delta(
        old.security, security, not_security, reset);

    -- If any of the new values are NULL, a delta was invalid. Return an error.
    IF new_available IS NULL OR new_available_upgrades IS NULL
        OR new_installed IS NULL OR new_held IS NULL
        OR new_autoremovable IS NULL OR new_security IS NULL THEN
        RETURN false;
    END IF;

    -- Verify the invariant relations between the new sets.
    IF NOT new_held <@ new_installed
        OR NOT new_available_upgrades <@ new_available
        OR new_available_upgrades && new_installed
        OR NOT new_autoremovable <@ new_installed THEN
        RETURN false;
    END IF;

    UPDATE computer_packages
    SET
        available = new_available,
        available_upgrades = new_available_upgrades,
        installed = new_installed,
        held = new_held,
        autoremovable = new_autoremovable,
        security = new_security
    WHERE computer_packages.computer_id = update_computer_packages.computer_id;
    RETURN true;
END;
$$;


--
-- Name: update_hardware_info_tsvector(); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION public.update_hardware_info_tsvector() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
    IF (NEW.str_value_vector IS NULL) THEN
        NEW.str_value_vector :=
            TO_TSVECTOR('simple', COALESCE(NEW.str_value, ''));
    END IF;
    RETURN NEW;
END
$$;


SET default_tablespace = '';

SET default_table_access_method = heap;

--
-- Name: active_process; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.active_process (
    id bigint NOT NULL,
    computer_id integer NOT NULL,
    pid integer NOT NULL,
    uid bigint NOT NULL,
    gid bigint NOT NULL,
    name text NOT NULL,
    state bytea NOT NULL,
    start_time timestamp without time zone NOT NULL,
    vm_size bigint,
    cpu_utilisation real
);


--
-- Name: active_process_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.active_process_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: active_process_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.active_process_id_seq OWNED BY public.active_process.id;


--
-- Name: annotation; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.annotation (
    id integer NOT NULL,
    computer_id integer NOT NULL,
    key text NOT NULL,
    value text
);


--
-- Name: annotation_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.annotation_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: annotation_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.annotation_id_seq OWNED BY public.annotation.id;


--
-- Name: ceph_usage; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.ceph_usage (
    computer_id integer NOT NULL,
    "timestamp" timestamp without time zone NOT NULL,
    ring_uuid text NOT NULL,
    total bigint NOT NULL,
    used bigint NOT NULL,
    available bigint NOT NULL
);


--
-- Name: cloud_instance_metadata; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.cloud_instance_metadata (
    computer_id integer NOT NULL,
    ami_id text NOT NULL,
    instance_type text NOT NULL,
    instance_id text NOT NULL
);


--
-- Name: computer_apt_preferences_file; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.computer_apt_preferences_file (
    computer_id integer NOT NULL,
    filename text NOT NULL,
    contents text NOT NULL
);


--
-- Name: computer_group; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.computer_group (
    id integer NOT NULL,
    computer_id integer NOT NULL,
    gid bigint NOT NULL,
    name text NOT NULL
);


--
-- Name: computer_group_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.computer_group_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: computer_group_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.computer_group_id_seq OWNED BY public.computer_group.id;


--
-- Name: computer_packages; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.computer_packages (
    computer_id integer NOT NULL,
    available integer[] DEFAULT '{}'::integer[] NOT NULL,
    available_upgrades integer[] DEFAULT '{}'::integer[] NOT NULL,
    installed integer[] DEFAULT '{}'::integer[] NOT NULL,
    held integer[] DEFAULT '{}'::integer[] NOT NULL,
    autoremovable integer[] DEFAULT '{}'::integer[] NOT NULL,
    security integer[] DEFAULT '{}'::integer[] NOT NULL
);


--
-- Name: computer_packages_buffer; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.computer_packages_buffer (
    computer_id integer NOT NULL,
    last_changed timestamp without time zone DEFAULT now() NOT NULL,
    available integer[] DEFAULT '{}'::integer[] NOT NULL,
    not_available integer[] DEFAULT '{}'::integer[] NOT NULL,
    available_upgrades integer[] DEFAULT '{}'::integer[] NOT NULL,
    not_available_upgrades integer[] DEFAULT '{}'::integer[] NOT NULL,
    installed integer[] DEFAULT '{}'::integer[] NOT NULL,
    not_installed integer[] DEFAULT '{}'::integer[] NOT NULL,
    held integer[] DEFAULT '{}'::integer[] NOT NULL,
    not_held integer[] DEFAULT '{}'::integer[] NOT NULL,
    autoremovable integer[] DEFAULT '{}'::integer[] NOT NULL,
    not_autoremovable integer[] DEFAULT '{}'::integer[] NOT NULL,
    security integer[] DEFAULT '{}'::integer[] NOT NULL,
    not_security integer[] DEFAULT '{}'::integer[] NOT NULL
);


--
-- Name: computer_twin; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.computer_twin (
    id integer NOT NULL,
    account_id integer NOT NULL
);


--
-- Name: computer_user; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.computer_user (
    id integer NOT NULL,
    computer_id integer NOT NULL,
    uid bigint NOT NULL,
    primary_gid bigint,
    username text NOT NULL,
    enabled boolean NOT NULL,
    name text,
    location text,
    home_phone text,
    work_phone text,
    CONSTRAINT computer_user_username_check CHECK ((username <> ''::text))
);


--
-- Name: computer_user_group; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.computer_user_group (
    user_id integer NOT NULL,
    group_id integer NOT NULL
);


--
-- Name: computer_user_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.computer_user_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: computer_user_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.computer_user_id_seq OWNED BY public.computer_user.id;


--
-- Name: cpu_usage; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.cpu_usage (
    computer_id integer NOT NULL,
    "timestamp" timestamp without time zone NOT NULL,
    cpu_usage real NOT NULL
);


--
-- Name: custom_graph_data; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.custom_graph_data (
    id integer NOT NULL,
    computer_id integer NOT NULL,
    custom_graph_id integer NOT NULL,
    error text
);


--
-- Name: custom_graph_data_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.custom_graph_data_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: custom_graph_data_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.custom_graph_data_id_seq OWNED BY public.custom_graph_data.id;


--
-- Name: custom_graph_data_point; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.custom_graph_data_point (
    custom_graph_data_id integer NOT NULL,
    "timestamp" timestamp without time zone NOT NULL,
    value double precision NOT NULL
);


--
-- Name: free_space; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.free_space (
    mount_info_id integer NOT NULL,
    "timestamp" timestamp without time zone NOT NULL,
    free_space bigint NOT NULL
);


--
-- Name: hardware_info; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.hardware_info (
    id bigint NOT NULL,
    computer_id integer NOT NULL,
    key text NOT NULL,
    str_value text NOT NULL,
    int_value bigint,
    str_value_vector tsvector
);


--
-- Name: hardware_info_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.hardware_info_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: hardware_info_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.hardware_info_id_seq OWNED BY public.hardware_info.id;


--
-- Name: hardware_info_key; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.hardware_info_key (
    hardware_info_id bigint NOT NULL,
    key text NOT NULL
);


--
-- Name: historic_process; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.historic_process (
    id integer NOT NULL,
    computer_id integer NOT NULL,
    pid integer NOT NULL,
    uid bigint NOT NULL,
    gid bigint NOT NULL,
    name text NOT NULL,
    exit_code integer NOT NULL,
    start_time timestamp without time zone NOT NULL,
    stop_time timestamp without time zone NOT NULL
);


--
-- Name: historic_process_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.historic_process_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: historic_process_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.historic_process_id_seq OWNED BY public.historic_process.id;


--
-- Name: keystone_token; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.keystone_token (
    computer_id integer NOT NULL,
    token bytea NOT NULL
);


--
-- Name: load_average; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.load_average (
    computer_id integer NOT NULL,
    "timestamp" timestamp without time zone NOT NULL,
    load_average real NOT NULL
);


--
-- Name: memory_info; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.memory_info (
    computer_id integer NOT NULL,
    "timestamp" timestamp without time zone NOT NULL,
    free_memory integer NOT NULL,
    free_swap integer NOT NULL
);


--
-- Name: message; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.message (
    id integer NOT NULL,
    computer_id integer NOT NULL,
    data bytea NOT NULL,
    "timestamp" timestamp without time zone NOT NULL
);


--
-- Name: message_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.message_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: message_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.message_id_seq OWNED BY public.message.id;


--
-- Name: message_info; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.message_info (
    computer_id integer NOT NULL,
    client_expected_sequence integer DEFAULT 0 NOT NULL,
    client_pending_offset integer DEFAULT 0 NOT NULL
);


--
-- Name: mount_info; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.mount_info (
    id integer NOT NULL,
    computer_id integer NOT NULL,
    device text NOT NULL,
    mount_point text NOT NULL,
    filesystem text NOT NULL,
    total_space bigint NOT NULL
);


--
-- Name: mount_info_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.mount_info_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: mount_info_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.mount_info_id_seq OWNED BY public.mount_info.id;


--
-- Name: network_device; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.network_device (
    id integer NOT NULL,
    computer_id integer NOT NULL,
    interface bytea NOT NULL,
    ip_address bytea NOT NULL,
    mac_address bytea NOT NULL,
    broadcast_address bytea NOT NULL,
    netmask bytea NOT NULL,
    flags integer NOT NULL,
    speed integer,
    duplex boolean DEFAULT false NOT NULL,
    creation_time timestamp without time zone DEFAULT timezone('UTC'::text, now()) NOT NULL
);


--
-- Name: network_device_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.network_device_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: network_device_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.network_device_id_seq OWNED BY public.network_device.id;


--
-- Name: network_traffic; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.network_traffic (
    computer_id integer NOT NULL,
    interface bytea NOT NULL,
    "timestamp" timestamp without time zone NOT NULL,
    bytes_in bigint NOT NULL,
    bytes_out bigint NOT NULL
);


--
-- Name: package_reporter_result; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.package_reporter_result (
    computer_id integer NOT NULL,
    code integer NOT NULL,
    err text NOT NULL,
    "timestamp" timestamp without time zone
);


--
-- Name: processor; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.processor (
    id integer NOT NULL,
    computer_id integer NOT NULL,
    processor_id integer NOT NULL,
    cache_size integer NOT NULL,
    model text NOT NULL,
    vendor text NOT NULL
);


--
-- Name: processor_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.processor_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: processor_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.processor_id_seq OWNED BY public.processor.id;


--
-- Name: reboot_required_info; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.reboot_required_info (
    computer_id integer NOT NULL,
    packages text[]
);


--
-- Name: swift_usage; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.swift_usage (
    computer_id integer NOT NULL,
    "timestamp" timestamp without time zone NOT NULL,
    device text NOT NULL,
    total bigint NOT NULL,
    used bigint NOT NULL,
    available bigint NOT NULL
);


--
-- Name: temperature; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.temperature (
    thermal_zone_id integer NOT NULL,
    "timestamp" timestamp without time zone NOT NULL,
    temperature integer NOT NULL
);


--
-- Name: thermal_zone; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.thermal_zone (
    id integer NOT NULL,
    computer_id integer NOT NULL,
    name text NOT NULL
);


--
-- Name: thermal_zone_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE public.thermal_zone_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: thermal_zone_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE public.thermal_zone_id_seq OWNED BY public.thermal_zone.id;


--
-- Name: usn_issue; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.usn_issue (
    usn_id integer NOT NULL,
    computer_id integer,
    resolve_time timestamp without time zone
);


--
-- Name: active_process id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.active_process ALTER COLUMN id SET DEFAULT nextval('public.active_process_id_seq'::regclass);


--
-- Name: annotation id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.annotation ALTER COLUMN id SET DEFAULT nextval('public.annotation_id_seq'::regclass);


--
-- Name: computer_group id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_group ALTER COLUMN id SET DEFAULT nextval('public.computer_group_id_seq'::regclass);


--
-- Name: computer_user id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_user ALTER COLUMN id SET DEFAULT nextval('public.computer_user_id_seq'::regclass);


--
-- Name: custom_graph_data id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.custom_graph_data ALTER COLUMN id SET DEFAULT nextval('public.custom_graph_data_id_seq'::regclass);


--
-- Name: hardware_info id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.hardware_info ALTER COLUMN id SET DEFAULT nextval('public.hardware_info_id_seq'::regclass);


--
-- Name: historic_process id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.historic_process ALTER COLUMN id SET DEFAULT nextval('public.historic_process_id_seq'::regclass);


--
-- Name: message id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.message ALTER COLUMN id SET DEFAULT nextval('public.message_id_seq'::regclass);


--
-- Name: mount_info id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.mount_info ALTER COLUMN id SET DEFAULT nextval('public.mount_info_id_seq'::regclass);


--
-- Name: network_device id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.network_device ALTER COLUMN id SET DEFAULT nextval('public.network_device_id_seq'::regclass);


--
-- Name: processor id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.processor ALTER COLUMN id SET DEFAULT nextval('public.processor_id_seq'::regclass);


--
-- Name: thermal_zone id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.thermal_zone ALTER COLUMN id SET DEFAULT nextval('public.thermal_zone_id_seq'::regclass);


--
-- Name: active_process active_process_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.active_process
    ADD CONSTRAINT active_process_pkey PRIMARY KEY (id);


--
-- Name: annotation annotation_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.annotation
    ADD CONSTRAINT annotation_pkey PRIMARY KEY (id);


--
-- Name: ceph_usage ceph_usage_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.ceph_usage
    ADD CONSTRAINT ceph_usage_pkey PRIMARY KEY (computer_id, "timestamp", ring_uuid);


--
-- Name: cloud_instance_metadata cloud_instance_metadata_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.cloud_instance_metadata
    ADD CONSTRAINT cloud_instance_metadata_pkey PRIMARY KEY (computer_id);


--
-- Name: computer_apt_preferences_file computer_apt_preferences_file_computer_id_filename_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_apt_preferences_file
    ADD CONSTRAINT computer_apt_preferences_file_computer_id_filename_key UNIQUE (computer_id, filename);


--
-- Name: computer_group computer_group_computer_id_name_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_group
    ADD CONSTRAINT computer_group_computer_id_name_key UNIQUE (computer_id, name);


--
-- Name: computer_group computer_group_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_group
    ADD CONSTRAINT computer_group_pkey PRIMARY KEY (id);


--
-- Name: computer_packages_buffer computer_packages_buffer_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_packages_buffer
    ADD CONSTRAINT computer_packages_buffer_pkey PRIMARY KEY (computer_id);


--
-- Name: computer_packages computer_packages_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_packages
    ADD CONSTRAINT computer_packages_pkey PRIMARY KEY (computer_id);


--
-- Name: computer_twin computer_twin_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_twin
    ADD CONSTRAINT computer_twin_pkey PRIMARY KEY (id);


--
-- Name: computer_user computer_user_computer_id_username_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_user
    ADD CONSTRAINT computer_user_computer_id_username_key UNIQUE (computer_id, username);


--
-- Name: computer_user_group computer_user_group_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_user_group
    ADD CONSTRAINT computer_user_group_pkey PRIMARY KEY (user_id, group_id);


--
-- Name: computer_user computer_user_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_user
    ADD CONSTRAINT computer_user_pkey PRIMARY KEY (id);


--
-- Name: cpu_usage cpu_usage_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.cpu_usage
    ADD CONSTRAINT cpu_usage_pkey PRIMARY KEY (computer_id, "timestamp");


--
-- Name: custom_graph_data custom_graph_data_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.custom_graph_data
    ADD CONSTRAINT custom_graph_data_pkey PRIMARY KEY (id);


--
-- Name: custom_graph_data_point custom_graph_data_point_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.custom_graph_data_point
    ADD CONSTRAINT custom_graph_data_point_pkey PRIMARY KEY (custom_graph_data_id, "timestamp");


--
-- Name: free_space free_space_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.free_space
    ADD CONSTRAINT free_space_pkey PRIMARY KEY (mount_info_id, "timestamp");


--
-- Name: hardware_info hardware_info_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.hardware_info
    ADD CONSTRAINT hardware_info_pkey PRIMARY KEY (id);


--
-- Name: historic_process historic_process_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.historic_process
    ADD CONSTRAINT historic_process_pkey PRIMARY KEY (id);


--
-- Name: keystone_token keystone_token_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.keystone_token
    ADD CONSTRAINT keystone_token_pkey PRIMARY KEY (computer_id);


--
-- Name: load_average load_average_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.load_average
    ADD CONSTRAINT load_average_pkey PRIMARY KEY (computer_id, "timestamp");


--
-- Name: memory_info memory_info_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.memory_info
    ADD CONSTRAINT memory_info_pkey PRIMARY KEY (computer_id, "timestamp");


--
-- Name: message_info message_info_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.message_info
    ADD CONSTRAINT message_info_pkey PRIMARY KEY (computer_id);


--
-- Name: message message_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.message
    ADD CONSTRAINT message_pkey PRIMARY KEY (id);


--
-- Name: mount_info mount_info_computer_id_mount_point_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.mount_info
    ADD CONSTRAINT mount_info_computer_id_mount_point_key UNIQUE (computer_id, mount_point);


--
-- Name: mount_info mount_info_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.mount_info
    ADD CONSTRAINT mount_info_pkey PRIMARY KEY (id);


--
-- Name: network_device network_device_computer_id_interface_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.network_device
    ADD CONSTRAINT network_device_computer_id_interface_key UNIQUE (computer_id, interface);


--
-- Name: network_device network_device_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.network_device
    ADD CONSTRAINT network_device_pkey PRIMARY KEY (id);


--
-- Name: network_traffic network_traffic_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.network_traffic
    ADD CONSTRAINT network_traffic_pkey PRIMARY KEY (computer_id, interface, "timestamp");


--
-- Name: package_reporter_result package_reporter_result_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.package_reporter_result
    ADD CONSTRAINT package_reporter_result_pkey PRIMARY KEY (computer_id);


--
-- Name: processor processor_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.processor
    ADD CONSTRAINT processor_pkey PRIMARY KEY (id);


--
-- Name: reboot_required_info reboot_required_info_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.reboot_required_info
    ADD CONSTRAINT reboot_required_info_pkey PRIMARY KEY (computer_id);


--
-- Name: swift_usage swift_usage_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.swift_usage
    ADD CONSTRAINT swift_usage_pkey PRIMARY KEY (computer_id, "timestamp", device);


--
-- Name: temperature temperature_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.temperature
    ADD CONSTRAINT temperature_pkey PRIMARY KEY (thermal_zone_id, "timestamp");


--
-- Name: thermal_zone thermal_zone_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.thermal_zone
    ADD CONSTRAINT thermal_zone_pkey PRIMARY KEY (id);


--
-- Name: usn_issue usn_issue_usn_id_computer_id_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.usn_issue
    ADD CONSTRAINT usn_issue_usn_id_computer_id_key UNIQUE (usn_id, computer_id);


--
-- Name: active_process_computer_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX active_process_computer_id_idx ON public.active_process USING btree (computer_id);


--
-- Name: ceph_usage_ring_uuid_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX ceph_usage_ring_uuid_idx ON public.ceph_usage USING btree (ring_uuid);


--
-- Name: computer_group_computer_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX computer_group_computer_id_idx ON public.computer_group USING btree (computer_id);


--
-- Name: computer_twin_account_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX computer_twin_account_id_idx ON public.computer_twin USING btree (account_id);


--
-- Name: computer_user_computer_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX computer_user_computer_id_idx ON public.computer_user USING btree (computer_id);


--
-- Name: computer_user_group_group_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX computer_user_group_group_id_idx ON public.computer_user_group USING btree (group_id);


--
-- Name: custom_graph_data_computer_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX custom_graph_data_computer_id_idx ON public.custom_graph_data USING btree (computer_id);


--
-- Name: hardware_info_computer_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX hardware_info_computer_id_idx ON public.hardware_info USING btree (computer_id);


--
-- Name: hardware_info_int_value_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX hardware_info_int_value_idx ON public.hardware_info USING btree (int_value) WHERE (int_value IS NOT NULL);


--
-- Name: hardware_info_key_hardware_info_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX hardware_info_key_hardware_info_id_idx ON public.hardware_info_key USING btree (hardware_info_id);


--
-- Name: hardware_info_key_key_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX hardware_info_key_key_idx ON public.hardware_info_key USING btree (key);


--
-- Name: historic_process_computer_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX historic_process_computer_id_idx ON public.historic_process USING btree (computer_id);


--
-- Name: message_computer_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX message_computer_id_idx ON public.message USING btree (computer_id);


--
-- Name: message_info_computer_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX message_info_computer_id_idx ON public.message_info USING btree (computer_id);


--
-- Name: mount_info_computer_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX mount_info_computer_id_idx ON public.mount_info USING btree (computer_id);


--
-- Name: network_device_computer_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX network_device_computer_id_idx ON public.network_device USING btree (computer_id);


--
-- Name: processor_computer_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX processor_computer_id_idx ON public.processor USING btree (computer_id);


--
-- Name: thermal_zone_computer_id_idx; Type: INDEX; Schema: public; Owner: -
--

CREATE INDEX thermal_zone_computer_id_idx ON public.thermal_zone USING btree (computer_id);


--
-- Name: hardware_info hardware_info_insert; Type: TRIGGER; Schema: public; Owner: -
--

CREATE TRIGGER hardware_info_insert BEFORE INSERT ON public.hardware_info FOR EACH ROW EXECUTE FUNCTION public.update_hardware_info_tsvector();


--
-- Name: active_process active_process_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.active_process
    ADD CONSTRAINT active_process_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: annotation annotation_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.annotation
    ADD CONSTRAINT annotation_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: cloud_instance_metadata cloud_instance_metadata_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.cloud_instance_metadata
    ADD CONSTRAINT cloud_instance_metadata_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: computer_apt_preferences_file computer_apt_preferences_file_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_apt_preferences_file
    ADD CONSTRAINT computer_apt_preferences_file_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: computer_group computer_group_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_group
    ADD CONSTRAINT computer_group_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: computer_packages_buffer computer_packages_buffer_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_packages_buffer
    ADD CONSTRAINT computer_packages_buffer_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: computer_packages computer_packages_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_packages
    ADD CONSTRAINT computer_packages_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: computer_user computer_user_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_user
    ADD CONSTRAINT computer_user_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: computer_user_group computer_user_group_group_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_user_group
    ADD CONSTRAINT computer_user_group_group_id_fkey FOREIGN KEY (group_id) REFERENCES public.computer_group(id) ON DELETE CASCADE;


--
-- Name: computer_user_group computer_user_group_user_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.computer_user_group
    ADD CONSTRAINT computer_user_group_user_id_fkey FOREIGN KEY (user_id) REFERENCES public.computer_user(id) ON DELETE CASCADE;


--
-- Name: custom_graph_data custom_graph_data_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.custom_graph_data
    ADD CONSTRAINT custom_graph_data_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: custom_graph_data_point custom_graph_data_point_custom_graph_data_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.custom_graph_data_point
    ADD CONSTRAINT custom_graph_data_point_custom_graph_data_id_fkey FOREIGN KEY (custom_graph_data_id) REFERENCES public.custom_graph_data(id) ON DELETE CASCADE;


--
-- Name: hardware_info hardware_info_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.hardware_info
    ADD CONSTRAINT hardware_info_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: hardware_info_key hardware_info_key_hardware_info_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.hardware_info_key
    ADD CONSTRAINT hardware_info_key_hardware_info_id_fkey FOREIGN KEY (hardware_info_id) REFERENCES public.hardware_info(id) ON DELETE CASCADE;


--
-- Name: historic_process historic_process_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.historic_process
    ADD CONSTRAINT historic_process_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: keystone_token keystone_token_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.keystone_token
    ADD CONSTRAINT keystone_token_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: message message_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.message
    ADD CONSTRAINT message_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: message_info message_info_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.message_info
    ADD CONSTRAINT message_info_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: mount_info mount_info_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.mount_info
    ADD CONSTRAINT mount_info_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: network_device network_device_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.network_device
    ADD CONSTRAINT network_device_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: package_reporter_result package_reporter_result_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.package_reporter_result
    ADD CONSTRAINT package_reporter_result_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: processor processor_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.processor
    ADD CONSTRAINT processor_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: reboot_required_info reboot_required_info_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.reboot_required_info
    ADD CONSTRAINT reboot_required_info_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: thermal_zone thermal_zone_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.thermal_zone
    ADD CONSTRAINT thermal_zone_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: usn_issue usn_issue_computer_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.usn_issue
    ADD CONSTRAINT usn_issue_computer_id_fkey FOREIGN KEY (computer_id) REFERENCES public.computer_twin(id) ON DELETE CASCADE;


--
-- Name: TABLE active_process; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.active_process TO landscape;


--
-- Name: SEQUENCE active_process_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.active_process_id_seq TO landscape;


--
-- Name: TABLE annotation; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.annotation TO landscape;


--
-- Name: SEQUENCE annotation_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.annotation_id_seq TO landscape;


--
-- Name: TABLE ceph_usage; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.ceph_usage TO landscape;


--
-- Name: TABLE cloud_instance_metadata; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.cloud_instance_metadata TO landscape;


--
-- Name: TABLE computer_apt_preferences_file; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.computer_apt_preferences_file TO landscape;


--
-- Name: TABLE computer_group; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.computer_group TO landscape;


--
-- Name: SEQUENCE computer_group_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.computer_group_id_seq TO landscape;


--
-- Name: TABLE computer_packages; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,UPDATE ON TABLE public.computer_packages TO landscape;


--
-- Name: TABLE computer_packages_buffer; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.computer_packages_buffer TO landscape;


--
-- Name: TABLE computer_twin; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.computer_twin TO landscape;


--
-- Name: TABLE computer_user; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.computer_user TO landscape;


--
-- Name: TABLE computer_user_group; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.computer_user_group TO landscape;


--
-- Name: SEQUENCE computer_user_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.computer_user_id_seq TO landscape;


--
-- Name: TABLE cpu_usage; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.cpu_usage TO landscape;


--
-- Name: TABLE custom_graph_data; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.custom_graph_data TO landscape;


--
-- Name: SEQUENCE custom_graph_data_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.custom_graph_data_id_seq TO landscape;


--
-- Name: TABLE custom_graph_data_point; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.custom_graph_data_point TO landscape;


--
-- Name: TABLE free_space; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.free_space TO landscape;


--
-- Name: TABLE hardware_info; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.hardware_info TO landscape;


--
-- Name: SEQUENCE hardware_info_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.hardware_info_id_seq TO landscape;


--
-- Name: TABLE hardware_info_key; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.hardware_info_key TO landscape;


--
-- Name: TABLE historic_process; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.historic_process TO landscape;


--
-- Name: SEQUENCE historic_process_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.historic_process_id_seq TO landscape;


--
-- Name: TABLE keystone_token; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.keystone_token TO landscape;


--
-- Name: TABLE load_average; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.load_average TO landscape;


--
-- Name: TABLE memory_info; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.memory_info TO landscape;


--
-- Name: TABLE message; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.message TO landscape;


--
-- Name: SEQUENCE message_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.message_id_seq TO landscape;


--
-- Name: TABLE message_info; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,UPDATE ON TABLE public.message_info TO landscape;


--
-- Name: TABLE mount_info; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.mount_info TO landscape;


--
-- Name: SEQUENCE mount_info_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.mount_info_id_seq TO landscape;


--
-- Name: TABLE network_device; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.network_device TO landscape;


--
-- Name: SEQUENCE network_device_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.network_device_id_seq TO landscape;


--
-- Name: TABLE network_traffic; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.network_traffic TO landscape;


--
-- Name: TABLE package_reporter_result; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.package_reporter_result TO landscape;


--
-- Name: TABLE processor; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.processor TO landscape;


--
-- Name: SEQUENCE processor_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.processor_id_seq TO landscape;


--
-- Name: TABLE reboot_required_info; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.reboot_required_info TO landscape;


--
-- Name: TABLE swift_usage; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.swift_usage TO landscape;


--
-- Name: TABLE temperature; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.temperature TO landscape;


--
-- Name: TABLE thermal_zone; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE ON TABLE public.thermal_zone TO landscape;


--
-- Name: SEQUENCE thermal_zone_id_seq; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,UPDATE ON SEQUENCE public.thermal_zone_id_seq TO landscape;


--
-- Name: TABLE usn_issue; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.usn_issue TO landscape;


--
-- PostgreSQL database dump complete
--

