--
-- PostgreSQL database dump
--

-- Dumped from database version 12.15 (Ubuntu 12.15-0ubuntu0.20.04.1)
-- Dumped by pg_dump version 12.15 (Ubuntu 12.15-0ubuntu0.20.04.1)

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET xmloption = content;
SET client_min_messages = warning;
SET row_security = off;

--
-- Name: get_generation(bytea, interval, interval); Type: FUNCTION; Schema: public; Owner: -
--

CREATE FUNCTION public.get_generation(provided_client_id bytea, update_access_time interval, update_generation interval) RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
    session_record RECORD;
BEGIN
    -- Do we have a fresh generation which has a recent access time%s
    SELECT INTO session_record generation FROM session_data
        WHERE session_data.client_id = provided_client_id AND
              session_data.access_time >
              now() AT TIME ZONE 'UTC' - update_access_time;

    IF FOUND THEN
        -- Fantastic!  That's the cheapest as no updating is necessary.
        RETURN session_record.generation;
    END IF;

    -- No luck.  Either we'll have to update an older one, or create it.
    -- For doing that we lock the row to prevent race conditions.
    SELECT INTO session_record generation, access_time FROM session_data
        WHERE session_data.client_id = provided_client_id FOR UPDATE;

    IF FOUND THEN

        -- Ok, there is an existing row.  Now we have to figure if the
        -- row has expired, or if it just needs to get a new access time.
        -- Note that for this test to work correctly, and thus the whole
        -- system, it's important that the isolation level be set to
        -- READ COMMITTED (or AUTOCOMMIT).  Otherwise, even though we've
        -- locked the row above, we're looking at old data, and given
        -- the right conditions, this could allow for two different
        -- generations to be used in parallel in a short interval of time.
        IF session_record.access_time <
           now() AT TIME ZONE 'UTC' - update_generation THEN

            -- Yeah, it's pretty old.  Let's bump the generation.
            UPDATE session_data SET generation=generation+1,
                                    access_time=now() AT TIME ZONE 'UTC'
                WHERE session_data.client_id = provided_client_id;

            RETURN session_record.generation+1;

        ELSE

            -- It's recent enough.  Just update the access time.
            UPDATE session_data SET access_time=now() AT TIME ZONE 'UTC'
                WHERE session_data.client_id = provided_client_id;

            RETURN session_record.generation;

        END IF;
    END IF;

    -- There's no row whatsoever.  We'll have to create it.
    BEGIN
        INSERT INTO session_data (client_id) VALUES (provided_client_id);
    EXCEPTION
        WHEN unique_violation THEN
            NULL; -- Someone else won the race.  We don't care.
    END;
    -- Whatever happened, it's the first generation.
    RETURN 0;
END;
$$;


SET default_tablespace = '';

SET default_table_access_method = heap;

--
-- Name: openid_association; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.openid_association (
    server_url bytea NOT NULL,
    handle bytea NOT NULL,
    secret bytea NOT NULL,
    issued integer NOT NULL,
    lifetime integer NOT NULL,
    association_type bytea NOT NULL
);


--
-- Name: openid_nonce; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.openid_nonce (
    server_url bytea NOT NULL,
    "timestamp" integer NOT NULL,
    salt bytea NOT NULL
);


--
-- Name: session_data; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.session_data (
    client_id bytea NOT NULL,
    generation integer DEFAULT 0 NOT NULL,
    access_time timestamp without time zone DEFAULT timezone('UTC'::text, now()) NOT NULL
);


--
-- Name: session_pkg_data; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.session_pkg_data (
    client_id bytea NOT NULL,
    generation integer NOT NULL,
    product_id bytea NOT NULL,
    key bytea NOT NULL,
    data bytea NOT NULL
);


--
-- Name: openid_association openid_association_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.openid_association
    ADD CONSTRAINT openid_association_pkey PRIMARY KEY (server_url, handle);


--
-- Name: openid_nonce openid_nonce_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.openid_nonce
    ADD CONSTRAINT openid_nonce_pkey PRIMARY KEY (server_url, "timestamp", salt);


--
-- Name: session_data session_data_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.session_data
    ADD CONSTRAINT session_data_pkey PRIMARY KEY (client_id);


--
-- Name: session_pkg_data session_pkg_data_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.session_pkg_data
    ADD CONSTRAINT session_pkg_data_pkey PRIMARY KEY (client_id, generation, product_id, key);


--
-- Name: TABLE openid_association; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.openid_association TO landscape;


--
-- Name: TABLE openid_nonce; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.openid_nonce TO landscape;


--
-- Name: TABLE session_data; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.session_data TO landscape;


--
-- Name: TABLE session_pkg_data; Type: ACL; Schema: public; Owner: -
--

GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE public.session_pkg_data TO landscape;


--
-- PostgreSQL database dump complete
--

