# Copyright 2005-2020 Canonical Limited.  All rights reserved.

import transaction

from canonical.landscape.model.main.standalone import LDSScriptExecutionManagement
from canonical.landscape.model.alert.mail import (
    send_pending_alert_emails,
    AlertEmailError,
)
from canonical.landscape.model.account.alerts import check_pending_expired_accounts
from canonical.landscape.model.computer.alerts import check_offline_computers
from canonical.landscape.scripts.batch import BatchScript


UPDATE_SCRIPT_NAME = "update_alerts.sh"


class ProcessAlerts(BatchScript):
    """
    Process all rules across all accounts, sending emails for the pending ones.
    """

    _name = "process-alerts"
    _config = "scripts"

    def run(self):
        try:
            send_pending_alert_emails()
        except AlertEmailError:
            return 1


class UpdateAlerts(BatchScript):
    """
    Update the state of rules that need a periodic check.
    """

    _name = "update-alerts"
    _config = "scripts"
    _setup_amqp = True

    def run(self):
        management = LDSScriptExecutionManagement()
        success = False
        with transaction.manager:
            management.mark_start(UPDATE_SCRIPT_NAME)

        try:
            check_offline_computers()
            check_pending_expired_accounts()
            success = True
        finally:
            with transaction.manager:
                management.mark_end(UPDATE_SCRIPT_NAME, success)


run_process = ProcessAlerts()
run_update = UpdateAlerts()
