# Copyright 2005-2016 Canonical Limited.  All rights reserved.

from builtins import str
import logging

import transaction

from canonical.landscape.model.main.store import get_main_store
from canonical.landscape.model.main.account import Account, get_account_by_id
from canonical.landscape.model.account.collection import AccountCollection
from canonical.landscape.model.billing.usage import charge_account
from canonical.landscape.scripts.batch import BatchScript
from canonical.landscape.stripe import STRIPE_MINIMUM_CHARGE


class BillAccounts(BatchScript):
    """Create Payments for current costs for all self-service accounts."""

    _name = "bill-accounts"

    def run(self):
        for account_id in self._get_account_ids():
            try:
                self._bill_account(account_id)
            except Exception as error:
                logging.error(
                    "Billing failed for account ID {}: {}".format(
                        account_id, str(error)
                    )
                )

    def _get_account_ids(self):
        """Return ids for self-service accounts."""
        collection = AccountCollection(get_main_store(), self_service=True)
        return collection.find().values(Account.id)

    def _bill_account(self, account_id):
        """Create a Payment for an account in a transaction."""
        with transaction.manager:
            account = get_account_by_id(account_id)
            charge_account(account, min_charge=STRIPE_MINIMUM_CHARGE)


run = BillAccounts()
