# Copyright 2019 Canonical Limited. All rights reserved.

import sys
import logging
import argparse

from canonical.landscape.model.activity.removals import cleanup_activities

from canonical.landscape.application import setup_logging
from canonical.landscape.setup import load_config


def get_option_parser():
    """
    Create and populate the options for the OptionParser.
    """
    parser = argparse.ArgumentParser(description="Removes old, finished activities.")
    parser.add_argument(
        "--dry-run",
        action="store_true",
        help="Don't actually do anything, just count the affected activities.",
    )
    parser.add_argument(
        "older_than_days",
        type=int,
        help="Remove finished activities older than these many days.",
    )
    return parser


def run_cleanup_activities(args):
    """
    When run, this performs the cleanup of L{ActivityParent} (and children
    activities), removing finished objects older than the specified number of
    days.
    """
    parser = get_option_parser()
    args = parser.parse_args(args)
    cleanup_activities(older_than_days=args.older_than_days, dry_run=args.dry_run)


def run():
    setup_logging("cleanup-activities", level=logging.INFO)
    load_config("maintenance")
    run_cleanup_activities(sys.argv[1:])


if __name__ == "__main__":
    run()
