# Copyright 2019 Canonical Limited. All rights reserved.

import sys
import logging
import argparse

from canonical.landscape.model.eventlog.removals import cleanup_events

from canonical.landscape.application import setup_logging
from canonical.landscape.setup import load_config


def get_option_parser():
    """
    Create and populate the options for the OptionParser.
    """
    parser = argparse.ArgumentParser(description="Removes old event log entries.")
    parser.add_argument(
        "--dry-run",
        action="store_true",
        help="Don't actually do anything, just count the affected event logs.",
    )
    parser.add_argument(
        "older_than_days",
        type=int,
        help="Remove event logs older than these many days.",
    )
    return parser


def run_cleanup_events(args):
    """
    When run, this performs the cleanup of L{EventLogEntry}, removing
    objects older than the specified number of days.
    """
    parser = get_option_parser()
    args = parser.parse_args(args)
    cleanup_events(older_than_days=args.older_than_days, dry_run=args.dry_run)


def run():
    setup_logging("cleanup-events", level=logging.INFO)
    load_config("maintenance")
    run_cleanup_events(sys.argv[1:])


if __name__ == "__main__":
    run()
