# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from argparse import ArgumentParser

from canonical.landscape.model.main.distributedlock import (
    acquire_distributed_lock,
    release_distributed_lock,
)
from canonical.landscape.scripts.batch import BatchScript


class GetDistributedLock(BatchScript):
    """
    Try to grab a lock in the Landscape database to allow running a process
    that needs mutual exclusion to the database.
    """

    _name = "distributed-lock"
    _config = "scripts"

    def run(self):
        parser = ArgumentParser(
            description="Grab an exclusive, named runlock from the database"
        )
        parser.add_argument(
            "script", type=str, help="The script to run with the acquired lock."
        )
        parser.add_argument(
            "--release",
            action="store_true",
            default=False,
            help="Specify if the lock is to be released",
        )

        args = parser.parse_args(self._args[1:])
        lock_name = args.script.split("/")[-1].split(".")[0]
        if args.release:
            release_distributed_lock(lock_name)
        else:
            if not acquire_distributed_lock(lock_name):
                return 1


run = GetDistributedLock(ignore_maintenance_flag=True)
