# Copyright 2005-2013 Canonical Limited.  All rights reserved.
from __future__ import print_function

import sys
import logging
import optparse

from canonical.landscape.model.account.removals import remove_expired_accounts

from canonical.landscape.application import setup_logging
from canonical.landscape.setup import load_config


def get_option_parser():
    """
    Create and populate the options for the OptionParser.
    """
    parser = optparse.OptionParser(description="Performs trial Account removals.")

    parser.add_option(
        "--dry-run",
        action="store_true",
        help="Don't actually do anything, just list " "affected accounts.",
    )
    return parser


def run_expire_accounts(args):
    """
    When run, this performs L{Account} expiry, removing old L{Account}
    objects, and leaving any associated TrialAccounts.
    """
    parser = get_option_parser()
    options, args = parser.parse_args(args)
    remove_expired_accounts(dry_run=options.dry_run)


def run():
    print("Loading site configuration...")
    setup_logging("expire-accounts", level=logging.INFO)
    load_config("maintenance")
    run_expire_accounts(sys.argv[1:])
