"""Dump pickle files from lshw XML output.

Pickle hardware files are used to generate sample data.
They're located in canonical/landscape/sample/hardware-X.bpickle

Usage:
 - Use XML output from lshw on the current machine.
     dump-hardware-info <output-file>
 - Convert a lshw XML dump to pickle.
     dump-hardware-info <output-file> <xml-dump>
"""

import subprocess
import sys
from os import path

from landscape.lib import bpickle

from canonical.lib.hardware import parse_lshw

LSHW = "/usr/bin/lshw"


def error_exit(message):
    sys.exit(message + "\n")


def run():
    if len(sys.argv) == 1:
        error_exit(__doc__)
    elif len(sys.argv) > 2:
        # If a second filename is passed, read lshw data from file rather than
        # calling lshw.
        with open(sys.argv[2]) as datafile:
            data = datafile.read()
    else:
        if not path.exists(LSHW):
            error_exit("%s not found" % LSHW)

        data = subprocess.check_output(["sudo", LSHW, "-quiet", "-xml"])

    dump = bpickle.dumps(list(parse_lshw(data)))
    with file(sys.argv[1], "w") as output:
        output.write(dump)
