# Copyright 2005-2013 Canonical Limited.  All rights reserved.

import logging
import sys
import transaction

from twisted.internet import reactor

from zope.component import getUtility

from canonical.amqp.message.interfaces import IDispatcher
from canonical.amqp.job.registry import JobRegistry
from canonical.landscape.application import setup_logging
from canonical.landscape.setup import load_config, run_amqp_client_in_thread
from canonical.landscape.environment import get_modules


def keywordify(args):
    """
    Scans the command line arguments looking for keyword arguments and build a
    dictionary.

    Arguments that end with _id will be converted to integers.
    """
    kwargs = {}
    for arg in args:
        if arg.count("=") == 0:
            raise ValueError(
                "Positional arguments are not supported. Found '%s' while "
                "parsing command line arguments." % arg
            )
        key, value = arg.split("=")
        if key.endswith("_id"):
            value = int(value)
        kwargs[key] = value
    return kwargs


def run(args=sys.argv, _registry=None, reactor=reactor):
    """Invoke a registered Job passing arguments to it."""
    if len(args) <= 2:
        raise ValueError(
            "The script must be invoked by passing the name of the job runner"
            " and its keyword arguments."
        )

    job_name, kwargs = args[1], keywordify(args[2:])
    config = load_config("scripts")
    setup_logging("job-invoker", level=logging.INFO, always_log_to_stdout=True)
    run_amqp_client_in_thread(config)
    try:
        # XXX Maybe it would be better to get a global registry instead of
        # re-scanning the job modules.
        if _registry is None:  # For testing purposes.
            modules = get_modules(["model/*/jobs", "model/*/jobs.py"])
            registry = JobRegistry()
            registry.scan(modules)
        else:
            registry = _registry
        if registry.get(job_name) is None:
            raise ValueError(
                "Job '%s' not found. Options:\n %s"
                % (job_name, "\n ".join(sorted(registry._runners.keys())))
            )

        dispatcher = getUtility(IDispatcher)
        dispatcher.create_job(None, "job-handler", job_name, **kwargs)
        transaction.commit()
    finally:
        reactor.callFromThread(reactor.stop)
