# Copyright 2005-2013 Canonical Limited.  All rights reserved.
from builtins import object
import sys

from zope.component import getUtility

from canonical.security.interfaces import IRoleRegistry

from canonical.lib.timestamp import utctoday
from canonical.landscape.setup import load_config
from canonical.landscape.model.main.store import get_main_store
from canonical.landscape.model.main.standalone import LDSLicense, LicenseLDSLicense
from canonical.landscape.model.main.license import License
from canonical.landscape.model.main.account import Account
from canonical.landscape.model.main.person import Person
from canonical.landscape.model.main.personaccess import PersonAccess


class LDSAdminAddresses(object):
    """
    A scripts class to gather all email addresses fo administrators from
    accounts with active LDS licenses.
    """

    def __init__(self):
        self.store = get_main_store()

    def _get_access_context_ids_with_active_LDS(self):
        """
        Get a list of L{Account} objects that have an active (expiring after
        "now") LDS license.
        """
        where = [
            Account.id == LDSLicense.account_id,
            LicenseLDSLicense.lds_license_id == LDSLicense.id,
            LicenseLDSLicense.license_id == License.id,
            License.expiration_date >= utctoday(),
        ]
        result = self.store.find(Account.access_context_id, *where)
        return list(result)

    def _get_admin_emails_from_access_context_ids(self, context_ids):
        """
        Given a list of accounts, fetch the L{GlobalAdmin}'s L{Person} email
        address.
        """
        owner = getUtility(IRoleRegistry).get("Owner")
        where = [
            Person.id == PersonAccess.person_id,
            PersonAccess.role_key == owner.key,
            PersonAccess.access_context_id.is_in(context_ids),
        ]
        result = self.store.find(Person.email, *where).group_by(Person.email)

        return list(result)

    def run(self, stdout=sys.stdout):
        context_ids = self._get_access_context_ids_with_active_LDS()
        emails = self._get_admin_emails_from_access_context_ids(context_ids)

        stdout.write("\n".join(emails))
        stdout.write("\n")


def run():
    load_config("maintenance")

    admins = LDSAdminAddresses()
    admins.run()
