# Copyright 2005-2020 Canonical Limited.  All rights reserved.

import transaction

from zope.event import notify

from canonical.landscape.model.events import GlobalMaintenanceEvent
from canonical.landscape.model.main.standalone import LDSScriptExecutionManagement
from canonical.landscape.scripts.batch import BatchScript


SCRIPT_NAME = "maintenance.sh"


class Maintenance(BatchScript):
    """Emit a L{GlobalMaintenanceEvent} that various subcribers can catch."""

    _name = "maintenance-script"
    _config = "maintenance"
    _setup_amqp = True

    def run(self):
        management = LDSScriptExecutionManagement()
        with transaction.manager:
            management.mark_start(SCRIPT_NAME)
        success = False
        try:
            notify(GlobalMaintenanceEvent())
            success = True
        finally:
            with transaction.manager:
                management.mark_end(SCRIPT_NAME, success)


run = Maintenance()
