# Copyright 2005-2013 Canonical Limited.  All rights reserved.
"""Publish anonymous metrics about Landscape On Premises to Canonical."""

from argparse import ArgumentParser
import json
import logging
import sys

from canonical.landscape.prometheus.metrics import get_standalone_account_metrics
from canonical.landscape.scripts.batch import BatchScript

from landscape.lib.fetch import fetch, FetchError


class ReportAnonymousMetrics(BatchScript):
    """Report anonymous metrics about Landscape On Premises to Canonical."""

    _name = "report-anonymous-metrics"
    _config = "scripts"

    def _report_anonymous_metrics(self, url):
        """Send anonymous metrics to the provided url.

        No metrics are reported when "Do Not Track" standalone setting is
        checked.

        @raises: FetchError if unable to POST to the URL.
        """
        metrics_data = get_standalone_account_metrics()
        if not metrics_data:
            logging.info(
                "No metrics reported due to 'Do Not Track' configuration" " setting."
            )
            return
        logging.info("Reporting anonymous metrics.")
        fetch(
            url,
            post=True,
            data=json.dumps(metrics_data),
            headers={"content-type": "application/json"},
            connect_timeout=30,
            total_timeout=120,
        )

    def run(self):
        parser = ArgumentParser(description=self.__doc__)
        parser.add_argument(
            "--metrics-url",
            default="https://landscape.canonical.com/anonymous-metrics",
            help=(
                "The url of the Landscape SAAS server where metrics get" " reported."
            ),
            type=str,
        )
        args = parser.parse_args(self._args[1:])
        try:
            self._report_anonymous_metrics(args.metrics_url)
        except FetchError as error:
            logging.error(
                "Failed to publish anoymous metrics to {}: '{}'\n".format(
                    args.metrics_url, error
                )
            )
            sys.exit(1)


run = ReportAnonymousMetrics()
