#!/usr/bin/python3

# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
This script is intended to be used on machines that host Landscape KVM/Qemu
virtual machines. It will be distributed to customers for use during the
stand-alone Landscape install process.

Despite this module itself having no Landscape dependencies, other landscape
modules need to import it. As such, this module needs to remain in a Landscape
Python namespace, thus it's presence in this package.
"""

from builtins import object
import os

CONFIG_BASE = "/etc/landscape"
CONFIG_FILENAME = "server.conf"
GUEST_BASE = "/opt/canonical"

STARTUP_MESSAGE = "Landscape configuration started."


class SetupScriptError(Exception):
    "The stand-alone setup script has encountered an error."


class StandaloneScript:
    """
    A base class that holds the common methods for all stand-alone scripts.
    """

    def __init__(self, logger, plugins=[]):
        if not os.path.exists(CONFIG_BASE):
            os.mkdir(CONFIG_BASE)
        self._config = None
        self.logger = logger
        self.plugins = plugins
        # The following attributes are used by other parts of this script as
        # part of the API; changing them shouldn't be done without care.
        self.config_filename = "%s/%s" % (CONFIG_BASE, CONFIG_FILENAME)

    def run(self):
        for plugin in self.plugins:
            plugin(self.logger).run()
