# Copyright 2005-2013 Canonical Limited.  All rights reserved.

import optparse

from canonical.landscape.model.account.notifications import (
    send_notifications_to_expiring_trials,
)
from canonical.landscape.scripts.batch import BatchScript


class TrialAccountNotifications(BatchScript):
    """Send notifications to accounts that have expiring Trial licenses."""

    _name = "trial_account_notifications"
    _config = "scripts"

    def run(self):
        parser = self._get_option_parser()
        opts, args = parser.parse_args(self._args)
        license_count = send_notifications_to_expiring_trials(dry_run=opts.dry_run)
        self._stdout.write("Sent notifications to %d accounts.\n" % license_count)

    def _get_option_parser(self):
        """Create and populate the options for the OptionParser."""
        parser = optparse.OptionParser(
            description="Performs trial account notification."
        )
        parser.add_option(
            "--dry-run",
            action="store_true",
            help="Don't actually do anything, just list affected accounts.",
        )
        return parser


run = TrialAccountNotifications()
