# Copyright 2005-2013 Canonical Limited.  All rights reserved.

import logging
import os
import signal

from twisted.python.log import PythonLoggingObserver
from twisted.scripts.twistd import runApp

from canonical.twisted.script import ServerOptions
from canonical.diagnostics.memory import gc_dump

from canonical.landscape.application import setup_logging
from canonical.landscape.environment import get_raw_config
from canonical.landscape.model.configuration import log_revision
from canonical.landscape.scripts import get_top_level_directory
from canonical.landscape.setup import get_instance_id


MEMORY_DUMP_SIGNAL = 44


def dump_memory_handler(signum, frame):
    config = get_raw_config()
    dump_dir = config["global"]["log-path"]
    log = logging.getLogger()
    log.info(gc_dump(dump_dir))


def run_tac(tac_file, log_name=None):
    """Run a TAC file.

    A TAC file contains information to run a Twisted service, see:

      http://twistedmatrix.com/documents/current/core/howto/application.html

    for more information.

    @param tac_file: Path to the TAC file to run.
    """
    signal.signal(MEMORY_DUMP_SIGNAL, dump_memory_handler)
    if log_name is None:
        # Ocassionally the tac_fils are suffixed ".tac", we don't want
        # this in the logs
        log_name, _ = os.path.splitext(os.path.basename(tac_file))
    instance_id = get_instance_id()
    log_name = log_name + "-%s" % instance_id

    tac_file = os.path.join(get_top_level_directory(), tac_file)
    options = ServerOptions()
    options["python"] = tac_file
    options.parseOptions()  # Parse command line options from sys.argv

    setup_logging(log_name, level=logging.INFO)
    logging.info(log_revision())

    # Configure the Twisted logging machinery so it forwards messages to
    # the standard Python logging system, which is the one Landscape's code
    # uses since it's thread-safe. See also twisted.application.app.AppLogger.
    observer = PythonLoggingObserver(loggerName=log_name)
    options["logger"] = lambda: observer.emit
    options["debug"] = bool(os.getenv("LANDSCAPE_DEBUG", False))

    runApp(options)
