# Copyright 2005-2022 Canonical Limited. All rights reserved.

import simplejson as json

import transaction

from canonical.landscape.model.main.standalone import LDSScriptExecutionManagement
from canonical.landscape.model.package.usn import update_from_usn_tool_db
from canonical.landscape.model.package.alerts import check_security_upgrades_alerts
from canonical.landscape.model.resource.package import purge_stale_packages_buffers
from canonical.landscape.model.usn.issue import update_usn_issues
from canonical.landscape.scripts.batch import BatchScript


SCRIPT_NAME = "update_security_db.sh"


def transact(method, *args, **kwargs):
    """Run the method in a new transaction."""
    transaction.begin()
    method(*args, **kwargs)
    transaction.commit()


class ProcessUSNs(BatchScript):

    _name = "usn-script"
    _setup_amqp = True  # We need a broker connection to send AJAX updates

    def run(self):
        management = LDSScriptExecutionManagement()
        transact(management.mark_start, SCRIPT_NAME)
        success = False
        try:
            with open(self._args[1]) as file_handle:
                db = json.load(file_handle)
            changeset = update_from_usn_tool_db(db)
            transaction.commit()
            package_ids = set(pkg_id for pkg_id, _ in changeset.added_package_usns)
            check_security_upgrades_alerts(package_ids)
            update_usn_issues()
            transaction.commit()
            purge_stale_packages_buffers()
            success = True
        finally:
            transact(management.mark_end, SCRIPT_NAME, success)


run = ProcessUSNs()
