# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import object
from zope.interface import Interface, implementer
from zope.schema import Object, Bool
from zope.security.interfaces import IPrincipal
from zope.publisher.interfaces import IRequest
from zope.authentication.interfaces import IUnauthenticatedPrincipal


class ILandscapePrincipal(IPrincipal):
    """A principal of Landscape."""


class IPrincipalLoginEvent(Interface):
    """An Event when a Person Principal performs a Login"""

    principal = Object(ILandscapePrincipal)
    request = Object(IRequest)
    update = Bool()


@implementer(IPrincipalLoginEvent)
class PrincipalLoginEvent(object):
    def __init__(self, principal, request, update=True):
        self.principal = principal
        self.request = request
        self.update = update


class IPersonPrincipal(ILandscapePrincipal):
    """Principal representing a person accessing the system."""

    def get_roles(access_context_id):
        """Return roles in access_context_id, or global roles if it's None."""


class IComputerPrincipal(ILandscapePrincipal):
    """Principal representing a computer accessing the system."""


class IPendingComputerPrincipal(ILandscapePrincipal):
    """Principal representing a pending computer accessing the system."""


class IAnonymousPrincipal(ILandscapePrincipal, IUnauthenticatedPrincipal):
    """Principal for unauthenticated access."""


class IClientRequest(IRequest):
    """Marker defining that a request is being made by a client."""


class IComputerRequest(IClientRequest):
    """Marker defining that a request is being made by a computer."""


class IPendingComputerRequest(IClientRequest):
    """Marker defining that a request is being made by a pending computer."""


class IUnknownComputerRequest(IClientRequest):
    """Marker defining that a request is being made by an unknown computer."""
