# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""Service layer implementing use-case oriented interactions with the model.

The service layer sits on top of the model and provides a common entry point
for the UI and API that use its high-level business-logic operations.

L{canonical.landscape.model} implements, mainly, domain logic. It is
responsible for core data organisation, access and manipulation. By
contrast, the service layer supports specific use cases. It fulfills
its consumers requests, by driving the core domain logic in the model,
and enforces security rules.

Interaction with the service layer is designed around the concepts of
principal, resource lookup, and operation. In a nutshell a typical usage
pattern would be for example::

  # Identify the user interacting with the service layer
  principal = PersonPrincipal(person_id)

  # Get a particular context resource by building the relevant L{ServiceLookup}
  # sub-class and passing it the identifier of the context resource. Typically
  # the L{ServiceLookup} sub-class will perform security checks to ensure that
  # the principal is allowed to access the desired context resource.
  lookup = SomeLookup(principal)
  context = lookup("some-id")

  # Finally we perform an operation on the context resource by building the
  # relevant L{ServiceOperation} sub-class and invoking it passing whatever
  # parameters it expects. The L{ServiceOperation} sub-class will make sure
  # that the principal is allowed to perform such action.
  operation = SomeOperation(context, principal)
  operation("some-paramater")

Start looking at L{canonical.landscape.service.lookup} and
L{canonical.landscape.service.operation} for more details.

See also http://martinfowler.com/eaaCatalog/serviceLayer.html for reference.
"""
