# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.landscape.service.entity.create import CreateEntity
from canonical.landscape.service.accesscontext.lookup import AccessContextLookup
from canonical.landscape.service.accesscontext.errors import DuplicateAccessGroupError
from canonical.landscape.model.main.accesscontext import (
    get_access_context,
    get_unique_access_context_name,
)


class CreateAccessContext(CreateEntity):
    """Create an L{AccessContext}.

    @ivar context: The L{Account} to create the access context in.
    """

    _requires = "CreateAccessContext"

    _duplicate_error = DuplicateAccessGroupError

    @classmethod
    def errors(cls):
        errors = super(CreateAccessContext, cls).errors()
        return errors | AccessContextLookup.errors()

    def _create(self, name, description=None, parent=None):
        """Create an access context.

        @param name: The name for the L{AccessContext}.
        @param description: Optional description of the L{AccessContext}.
        @param parent: Optionally the key of an L{AccessContext} to set as
            parent.
        @return: The newly created L{AccessContext}.
        """
        account = self.context
        root_access_context = account.access_context
        if parent is None:
            parent_access_context = root_access_context
        else:
            lookup = AccessContextLookup(self.principal)
            parent_access_context = lookup(account, parent)

        # XXX support for the legacy API CreateAccessGroup method, which
        # doesn't let the user choose the title. This bit of code can
        # be dropped when we stop supporting the legacy API.
        if name is None:
            name = get_unique_access_context_name(root_access_context, description)
            if name is None:
                raise DuplicateAccessGroupError(description)

        return parent_access_context.create_child(name, description=description)

    def _get_entity(self, name):
        return get_access_context(self.context.access_context, name)
