# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.landscape.service.entity.edit import EditEntity
from canonical.landscape.service.accesscontext.errors import DuplicateAccessGroupError
from canonical.landscape.model.main.accesscontext import get_access_context
from canonical.landscape.service.accesscontext.errors import InvalidAccessGroupError


class EditAccessContext(EditEntity):
    """Edit an L{AccessContext}.

    @ivar context: The L{AccessContext} to edit.
    """

    _requires = "EditAccessContext"

    _duplicate_error = DuplicateAccessGroupError

    @classmethod
    def errors(cls):
        errors = super(EditAccessContext, cls).errors()
        return errors | set([InvalidAccessGroupError])

    def _edit(self, name=None, description=None):
        """
        @param name: The modified name for the L{AccessContext}.
        @param description: Optional description of the L{AccessContext}.
        """
        access_context = self.context

        # We don't want users to change the name or description
        # of the global access group
        if access_context.is_root:
            message = "Can't edit the default access group"
            raise InvalidAccessGroupError(message)

        access_context.description = description
        return access_context

    def _get_entity(self, name):
        return get_access_context(self.context.root, name)
