# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.landscape.model.main.accesscontext import (
    get_access_context,
    AccessContextCollection,
)
from canonical.landscape.service.entity.lookup import EntityLookup
from canonical.landscape.service.collection.lookup import CollectionLookup
from canonical.landscape.service.accesscontext.errors import UnknownAccessGroupError


class AccessContextLookup(EntityLookup):
    """Lookup an L{AccessContext}.

    @ivar context: An L{Account} instance.
    """

    _requires = "ViewAccount"
    _unknown_error = UnknownAccessGroupError

    def _lookup(self, account, key):
        return get_access_context(account.access_context, key)


class AccessContextCollectionLookup(CollectionLookup):
    """Lookup a collection of AccessContexts.

    @ivar context: The Account to search access contexts in.
    """

    _requires = "ViewAccount"
    _collection_class = AccessContextCollection

    def _perform(self, context, **filters):
        # Set the lookup context to the root access context of the account.
        account = context
        context = account.access_context
        return super(AccessContextCollectionLookup, self)._perform(context, **filters)
