# Copyright 2005-2016 Canonical Limited.  All rights reserved.

from canonical.landscape.service.entity.create import CreateEntity
from canonical.landscape.service.account.errors import DuplicateAccountError
from canonical.landscape.model.main.account import (
    get_account_by_name,
    bootstrap_account,
    generate_random_account_name,
)
from canonical.landscape.model.billing.management import BillingManagement


# 100USD credit
# This is stored in UtilityCredit.initial_amount.
INITIAL_CREDIT = 1000000


class CreateAccount(CreateEntity):
    """Create an account."""

    _requires = None  # any person can create an account

    _duplicate_error = DuplicateAccountError

    def _create(
        self,
        name,
        stripe_customer_id=None,
        is_business=None,
        vat_number=None,
        vat_country=None,
        marketing_emails=False,
    ):
        # We generate random names for self-service accounts, to
        # avoid tying to creator name and having rename requests.
        slug_name = generate_random_account_name()
        account = bootstrap_account(
            slug_name,
            name,
            person=self.principal.person,
            stripe_customer_id=stripe_customer_id,
            is_business=is_business,
            vat_number=vat_number,
            vat_country=vat_country,
            marketing_emails=marketing_emails,
        )
        self._add_utility_credit(account)
        return account

    def _get_entity(self, name):
        return get_account_by_name(name)

    def _add_utility_credit(self, account):
        """Add initial utility credit to the account if it's self-service."""
        if not account.is_self_service:
            return

        management = BillingManagement(account)
        management.add_credit(INITIAL_CREDIT)
