# Copyright 2005-2015 Canonical Limited. All rights reserved.

from canonical.landscape.model.account.alerts import LicenseExpiryAlert
from canonical.landscape.service.operation import ServiceOperation


class GetAlertsOperation(ServiceOperation):
    """Return a summary of all alert rules.

    @ivar context: the Account to use.

    @ivar principal: the person requesting the alerts, an instance of
    PersonPrincipal
    """

    _requires = "QueryAlertRule"

    def _perform(self):
        """Generate a list of summaries of rule state."""
        person = self.principal.person
        subscribed_rules = self.context.get_subscribed_rules(person)
        # We must restrict the rule.info.is_active call to the
        # machines we're allowed to see.
        computer_ids = person.get_computer_ids(self.context)
        rules = []
        for rule in self.context.get_rules(person=person):
            if (
                isinstance(rule.info, LicenseExpiryAlert)
                and self.context.is_self_service
            ):
                continue
            state = rule.get_state_for_computers(computer_ids=computer_ids)
            subscribed = "No"
            if rule in subscribed_rules:
                subscribed = "Yes"
            state["subscribed"] = subscribed
            state["rule"] = rule
            rules.append(state)

        return sorted(rules, key=lambda x: x["alert_type"])
