# Copyright 2005-2015 Canonical Limited. All rights reserved.

from canonical.landscape.service.operation import ServiceOperation
from canonical.landscape.model.alert.rule import (
    get_rule_info_class_by_name,
    UnknownAlertTypeError,
)
from canonical.landscape.service.errors import UnauthorisedError


class SubscribeToAlertOperation(ServiceOperation):
    """Subscribe a person to an alert.

    @ivar context: the Account to use.

    @ivar principal: the person subscribing to the alert.
    """

    _requires = "SubscribeAlert"

    @classmethod
    def errors(cls):
        errors = super(SubscribeToAlertOperation, cls).errors()
        return errors | {UnknownAlertTypeError}

    def _perform(self, alert_type):
        """
        Lookup an alert rule with the given alert_type and subscribe the person
        to it.
        """
        info_type = get_rule_info_class_by_name(alert_type)
        person = self.principal.person
        rule = self.context.get_rules(person=person, info_classes=[info_type]).one()
        if rule is None:
            # None means "permission denied".
            raise UnauthorisedError()
        if rule is not None:
            rule.subscribe(person)
