# Copyright 2005-2016 Canonical Limited.  All rights reserved.

from canonical.landscape.service.operation import ServiceOperation
from canonical.landscape.model.configuration import (
    set_stripe_api_keys,
    get_billing_credentials,
    set_billing_credentials,
    get_marketo_credentials,
    set_marketo_credentials,
)


class SetStripeAPIKeys(ServiceOperation):
    """Updates or sets the public and secret key for the Stripe API."""

    _requires = "ManageBillingConfig"

    @classmethod
    def errors(cls):
        errors = super(SetStripeAPIKeys, cls).errors()
        return errors

    def _perform(self, public_key, secret_key):
        set_stripe_api_keys(public_key, secret_key)


class SetInvoiceStorageCredentials(ServiceOperation):
    """Set up the billing credentials for storing invoices in OpenStack."""

    _requires = "ManageBillingConfig"

    def _perform(self, keystone_url, username, password, tenant):
        set_billing_credentials(keystone_url, username, password, tenant)
        return get_billing_credentials()


class SetMarketoCredentials(ServiceOperation):
    """Set the marketo credentials for pushing new self-service users."""

    _requires = "ManageBillingConfig"

    @classmethod
    def errors(cls):
        errors = super(SetMarketoCredentials, cls).errors()
        return errors

    def _perform(self, account, client_id, client_secret):
        set_marketo_credentials(account, client_id, client_secret)
        return get_marketo_credentials()
