# Copyright 2005-2016 Canonical Limited.  All rights reserved.
from datetime import timedelta

from canonical.lib.timestamp import utctoday

from canonical.landscape.service.operation import ServiceOperation
from canonical.landscape.service.billing.errors import UnknownComputerTypeError
from canonical.landscape.model.billing.cost import (
    set_utility_cost,
    get_utility_costs_over_period,
)
from canonical.landscape.model.main.computer import COMPUTER_TYPES


class GetCurrentUtilityCost(ServiceOperation):
    """Get the current utility cost for a type of computer."""

    _requires = "AccessUtilityCost"

    @classmethod
    def errors(cls):
        errors = super(GetCurrentUtilityCost, cls).errors()
        return errors | {UnknownComputerTypeError}

    def _perform(self, computer_type):
        if computer_type not in COMPUTER_TYPES:
            raise UnknownComputerTypeError(
                "Unknown computer type. Must be one of {}".format(COMPUTER_TYPES)
            )
        costs = get_utility_costs_over_period(utctoday() - timedelta(1), utctoday())
        return costs[computer_type]


class UpdateUtilityCost(ServiceOperation):
    """Update the utility cost for a type of computer."""

    _requires = "AccessUtilityCost"

    @classmethod
    def errors(cls):
        errors = super(UpdateUtilityCost, cls).errors()
        return errors | {UnknownComputerTypeError}

    def _perform(self, computer_type, valid_since, hourly_cost):
        if computer_type not in COMPUTER_TYPES:
            raise UnknownComputerTypeError(
                "Unknown computer type. Must be one of {}".format(COMPUTER_TYPES)
            )
        set_utility_cost(computer_type, valid_since, hourly_cost)
