# Copyright 2005-2016 Canonical Limited.  All rights reserved.

import math

from canonical.landscape.service.operation import ServiceOperation
from canonical.landscape.service.billing.errors import (
    UnknownCountryError,
    InvalidVATRate,
)
from canonical.landscape.model.billing.vat import update_country_vat_rate


class ChangeCountryVATRate(ServiceOperation):
    """Update the VAT rate for a country."""

    _requires = "EditVatRate"

    @classmethod
    def errors(cls):
        errors = super(ChangeCountryVATRate, cls).errors()
        return errors | {UnknownCountryError, InvalidVATRate}

    def _perform(self, country_code, rate):
        self._validate_rate(rate)
        updated = update_country_vat_rate(country_code, rate)
        if not updated:
            raise UnknownCountryError("Unknown country code")

    def _validate_rate(self, rate):
        """Validate the VAT range is in the 0-100% range."""
        if rate < 0.0 or rate > 1.0 or math.isnan(rate):
            raise InvalidVATRate("The VAT rate must be between 0.0 and 1.0")
