# Copyright 2005-2013 Canonical Limited.  All rights reserved.
from zope.interface.verify import verifyObject
from zope.security.proxy import removeSecurityProxy

from canonical.lib.undef import Undef

from canonical.landscape.model.main.interfaces import ICollectionContext
from canonical.landscape.service.lookup import ServiceLookup


class CollectionLookup(ServiceLookup):
    """Base class for looking up model collections.

    @cvar _collection_class: The CollectionBase sub-class to use to lookup
        the desired models.
    """

    _collection_class = Undef()  # Must be defined by sub-classes

    def _perform(self, context, **filters):
        """
        @param context: The resource the entities will be looked up in. It
            must implement the ICollectionContext interface (this parameter
            will usually be an Account).
        @param filters: Filter parameters to apply to the collection.
        @return: Return a collection configured with the given filters.
        """
        # It's safe to remove the security proxy because from this point
        # we're inside the service layer, which will take care of security
        # concerns
        context = removeSecurityProxy(context)

        verifyObject(ICollectionContext, context)

        store = self._get_store(context)
        search_filters = self._get_default_filters(context)
        search_filters.update(filters)
        collection = self._collection_class(store, **search_filters)
        return collection

    def _get_store(self, context):
        """Get the store to use for the collection.

        By default context.store is used (so typically Account.store), but
        sub-classes can override this (for example to use the main store).
        """
        return context.store

    def _get_default_filters(self, context):
        """Get default context-specific filters that always get applied."""
        return {context.collection_filter: context}
