# Copyright 2005-2016 Canonical Limited.  All rights reserved.

from canonical.landscape.service.collection.accesscontextchange import (
    CollectionAccessContextChange,
)
from canonical.landscape.model.main.computer import get_computers_by_ids
from canonical.landscape.model.eventlog.management import EventLog
from canonical.landscape.model.computer.access import (
    update_computer_groups_access_context,
)


class ComputerAccessContextChange(CollectionAccessContextChange):
    """Change access context for computers."""

    _requires = "RemoveComputerFromAccessContext"
    _target_requires = "AddComputerToAccessContext"

    def _after(self, account, access_context, computer_ids):
        self._update_computers_access_context(access_context, computer_ids)
        update_computer_groups_access_context(account, computer_ids, access_context.id)
        self._log_changes(account, access_context, computer_ids)
        return computer_ids

    def _update_computers_access_context(self, access_context, computer_ids):
        """Update the access context for computers in the main store."""
        get_computers_by_ids(computer_ids).set(access_context_id=access_context.id)

    def _log_changes(self, account, access_context, computer_ids):
        """Add event log entries for computers that have been updated."""
        event_log = EventLog(account, self.principal.person)
        for computer in account.get_computers(computer_ids=computer_ids):
            event_log.create_log_entry(
                computer, "Moved to access group '%s'." % access_context.name
            )
