# Copyright 2005-2015 Canonical Limited.  All rights reserved.

from canonical.landscape.service.collection.operation import CollectionOperation
from canonical.landscape.model.main.computer import cleanup_after_removed_computers
from canonical.landscape.model.computer.jobs import create_job_for_computers_removal
from canonical.landscape.model.selection.selection import ComputerSelection
from canonical.landscape.model.computer.management import ComputerManagement


class RemoveComputers(CollectionOperation):
    """Submit a job to remove Computers.

    @ivar context: The Account to use.
    """

    _requires = "RemoveComputer"

    def _perform(self, collection, uuid=None):
        """Remove Computers in the collection.

        @param collection: the Collection yielding computers to remove.
        @param uuid: An optional unique ID to pass to the job to get
            notification about job result. If this is provided, the removal is
            performed asynchronously through a job.
        """
        computer_ids = list(self._get_entity_ids(collection))

        account = self.context.filters["account"]
        if uuid:
            self._remove_computers_async(account, computer_ids, uuid)
        else:
            self._remove_computers_sync(account, computer_ids)

    def _remove_computers_async(self, account, computer_ids, uuid):
        """Create a job to remove computers."""
        create_job_for_computers_removal(
            account, computer_ids, person=self.principal.person, page_key=uuid
        )

    def _remove_computers_sync(self, account, computer_ids):
        """
        Remove computers from main and account stores and create a job to
        remove resource data.
        """
        selection = ComputerSelection(account)
        selection.select_computers(computer_ids)
        management = ComputerManagement(selection, self.principal.person)
        management.remove_computers()
        cleanup_after_removed_computers(account, computer_ids)
