# Copyright 2005-2015 Canonical Limited.  All rights reserved.

from canonical.landscape.service.operation import ServiceOperation
from canonical.landscape.service.errors import UnauthorisedError
from canonical.landscape.model.activity.resynchronize import resynchronize_computers


class ResynchronizeComputers(ServiceOperation):
    """Request resynchronisation of a set of computers."""

    _requires = None  # Security is enforced internally by the role check

    @classmethod
    def errors(cls):
        errors = super(ResynchronizeComputers, cls).errors()
        return errors | UnauthorisedError.errors()

    def _perform(self, computer_ids):
        """Create an ActivityGroup and the its ResynchronizeRequest children.

        @param computer_ids: A list of computer IDs to be resynchronised.
        """
        account = self.context

        if not self.principal.person.has_global_role("Operator"):
            raise UnauthorisedError()

        return resynchronize_computers(account, computer_ids)
