# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.landscape.service.operation import ServiceOperation


class CreateEntity(ServiceOperation):
    """Base class for operations create model entities.

    @cvar _duplicate_error: The L{ServiceError} subclass to use to raise an
        error when an entity with the same name of the given one is already
        there. See also L{canonical.landscape.service.entity.errors}.

    @ivar context: The L{Account} to create the access context in.
    """

    _duplicate_error = None  # Must be defined by sub-classes

    @classmethod
    def errors(cls):
        return super(CreateEntity, cls).errors() | set([cls._duplicate_error])

    def _perform(self, name, *args, **kwargs):
        """
        @param name: The name of the entity to be created. If another entity
            the same name exists, an error will be raised.
        """
        entity = self._get_entity(name)
        if entity is not None:
            raise self._duplicate_error(name)
        return self._create(name, *args, **kwargs)

    def _create(self, name, *args, **kwargs):
        """
        Subclasses should override this to implement the actual creation
        logic.
        """
        raise NotImplementedError()

    def _get_entity(self, name):
        """Return any existing entity matching the given C{name}."""
        raise NotImplementedError("Must be defined by sub-classes")
