# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.landscape.service.errors import ServiceError


class UnknownEntityError(ServiceError):
    """Base class for model entities lookup errors.

    This class shouldn't be used directly, but rather sub-classed.

    @cvar _term: A term to be used when referring to the entity type in
        generated error messages.
    """

    _term = "entity"

    def __init__(self, key, suffix=None):
        """
        @param key: The key identifying the unknown entity.
        @param suffix: Optionally, a suffix string providing more context
            and information about the unknown entity.
        """
        message = "Unknown %s '%s'" % (self._term, key)
        if suffix:
            message += " %s" % suffix
        super(UnknownEntityError, self).__init__(message)


class DuplicateEntityError(ServiceError):

    _term = "entity"

    def __init__(self, name):
        message = "Duplicate %s '%s'" % (self._term, name)
        super(DuplicateEntityError, self).__init__(message)
