# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.landscape.service.lookup import ServiceLookup


class EntityLookup(ServiceLookup):
    """Lookup a single model entity.

    This is a helper class for implementing classes that lookup a single model
    entity.

    @cvar _unknown_error: The L{ServiceError} subclass to use to raise an error
        when the lookup fails. Subclasses must set this to an entity-specific
        error.
    """

    @classmethod
    def errors(cls):
        return super(EntityLookup, cls).errors() | set([cls._unknown_error])

    def _perform(self, context, key):
        """
        @param context: The resource the entity will be looked up in. Since
            most resources live in an account, in most cases this should be
            an Account object.
        @param key: The key of the entity to lookup (e.g. database ID or name).
        """
        entity = self._lookup(context, key)
        if entity is None:
            raise self._unknown_error(key)
        return entity
