# Copyright 2005-2014 Canonical Limited.  All rights reserved.

from datetime import timedelta

from canonical.lib.timestamp import utcnow

from canonical.landscape.model.eventlog.management import EventLog
from canonical.landscape.service.operation import ServiceOperation


class GetEventLogEntries(ServiceOperation):

    _requires = "ViewEventLog"

    def _perform(self, days=None, limit=None, offset=None):
        """Lookup L{EventLogEntry}s.

        @param days: The number of days to be used when retrieving
            L{EventLog}s.
        @param limit: The maximum number of results returned by this operation.
        @param offset:  The offset inside the list of results.
        """
        if days is None:
            # Default to 30 days
            days = 30
        start_time = utcnow() - timedelta(days=days)
        management = EventLog(self.context, self.principal.person)
        result = management.get_entries(
            start_time=start_time, limit=limit, offset=offset
        )

        return list(result)


class GetEventLogEntriesCount(ServiceOperation):
    """
    Get a count of L{EventLogEntries}s.
    """

    _requires = "ViewEventLog"

    def _perform(self, days=30):
        """
        @param days: The number of days to be used when retrieving
            L{EventLogEntry}s.
        """
        management = EventLog(self.context, self.principal.person)
        if days is None:
            # Default to 30 days
            days = 30
        start_time = utcnow() - timedelta(days=days)
        return management.get_entries_count(start_time=start_time)
