# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from datetime import datetime

from canonical.landscape.service.operation import ServiceOperation

from canonical.landscape.model.account.alerts import LicenseExpiryAlert


_not_set = object()


class EditLicense(ServiceOperation):
    """Edit a L{License}.

    @ivar context: The L{License} to edit.
    """

    _requires = "EditLicense"

    def _perform(self, expiration_date=_not_set, seats=None):
        """Edit the license.

        @param expiration_date: The new expiration date. If set to C{None} the
            license does not expire.
        @param seats: The number of seats in the license.

        @return: A boolean indicating whether license details has been
           changed. It will be C{False} if provided values don't differ from
           the current ones.
        """
        if isinstance(expiration_date, datetime):
            # Use only the date part, so comparison works.
            expiration_date = expiration_date.date()

        changed = False
        if (
            expiration_date is not _not_set
            and expiration_date != self.context.expiration_date
        ):

            self.context.expiration_date = expiration_date
            changed = True
        if seats is not None and seats != self.context.seats:
            self.context.seats = seats
            changed = True

        if changed:
            self.context.account.check_rules([LicenseExpiryAlert])
        return changed
