# Copyright 2005-2016 Canonical Limited.  All rights reserved.

from canonical.landscape.model.main.account import DEFAULT_ACCESS_CONTEXT_NAME
from canonical.landscape.service.accesscontext.lookup import AccessContextLookup
from canonical.landscape.service.entity.create import CreateEntity
from canonical.landscape.service.errors import UnauthorisedError
from canonical.landscape.service.repository.errors import DuplicateDistributionError


class CreateDistribution(CreateEntity):
    """Create a Distribution.

    @ivar context: The RepositoryManagement object to use.
    """

    # TODO: Re-enable _requires once authorization is fixed to respect
    # a provided access group.
    _requires = None
    # _requires = "CreateDistribution"
    _duplicate_error = DuplicateDistributionError

    @classmethod
    def errors(cls):
        errors = super(CreateDistribution, cls).errors()
        return errors | AccessContextLookup.errors()

    def _create(self, name, access_group=None):
        if access_group is None:
            access_group = DEFAULT_ACCESS_CONTEXT_NAME
        lookup = AccessContextLookup(self.principal)
        access_context = lookup(self.context.account, access_group)

        # TODO: Drop this once _requires is re-enabled.
        if not self.principal.has("CreateDistribution", on=access_context):
            raise UnauthorisedError()

        return self.context.create_distribution(name, access_context=access_context)

    def _get_entity(self, name):
        return self.context.get_distribution(name)
