from builtins import range
from canonical.landscape.service.operation import ServiceOperation
from canonical.landscape.model.sandbox.activities import SingleInfo, MultiInfo


class CreateSmallActivity(ServiceOperation):
    """Create a small parent activity with a few children.

    @return: The created L{Activity}.
    """

    _requires = None

    def _perform(self):
        account = self.context.account()

        parent = account.create_activity(MultiInfo)
        child1 = parent.add(SingleInfo)
        child2 = parent.add(SingleInfo)
        child3 = parent.add(SingleInfo)
        child4 = parent.add(SingleInfo)
        child3.after(child1, minimum_progress=50)
        child4.after(child3)
        child4.after(child2)

        parent.settle()

        return parent


class CreateBigActivity(ServiceOperation):
    """Create a big parent activity with lots of children.

    @return: The created L{Activity}.
    """

    _requires = None

    def _perform(self):
        account = self.context.account()

        parent = account.create_activity(MultiInfo)

        child1 = parent.add(SingleInfo)
        child2 = parent.add(SingleInfo)

        # Create a bunch of activities waiting for child1
        child3_list = []
        for i in range(25):
            child = parent.add(SingleInfo)
            child.after(child1, minimum_progress=50)
            child3_list.append(child)

        # Create a bunch of activities waiting for child2 and all children
        # in child3_list
        child4_list = []
        for i in range(25):
            child = parent.add(SingleInfo)
            child.after(child2)
            for child3 in child3_list:
                child.after(child3)
            child4_list.append(child)

        parent.settle()

        return parent
