// Copyright 2005-2013 Canonical Limited.  All rights reserved.

LS.use("event", "landscape.notifications.transport",
       "landscape.activity.detail", "io-base", "substitute",
       "landscape.ui.dialog", function(Y) {


// Since the height of the activity result overlay varies from resolution to
// resolution, we use a factor that is used to calculate the height based on the
// view port size.
var MAX_HEIGHT_FACTOR = 0.35;


Y.on("domready", function() {

    var overlay = null,
        resultNode = null,
        table = Y.one("#activities-table");

    var handleEvent = function(evt) {
        var approvedDetail = resultNode.one(".approved-detail");
        var href = evt.currentTarget.get("href").split("/");
        var activityId = href[href.length - 2];
        var detailData = detailsData[activityId];

        if (detailData.approval_time) {
            approvedDetail.removeClass("hidden");
            approvedDetail.one(".time-detail").set(
                "text", detailData.approval_time);
        } else {
            approvedDetail.addClass("hidden");
        }
        var deliveredDetail = resultNode.one(".delivered-detail");
        if (detailData.delivery_time) {
            deliveredDetail.removeClass("hidden");
            deliveredDetail.one(".time-detail").set(
                "text", detailData.delivery_time);
        } else {
            deliveredDetail.addClass("hidden");
        }
        var completedDetail = resultNode.one(".completed-detail");
        if (detailData.completion_time) {
            completedDetail.removeClass("hidden");
            completedDetail.one(".time-detail").set(
                "text", detailData.completion_time);
        } else {
            completedDetail.addClass("hidden");
        }

        var fullResult = resultNode.one(".activity-full-result");
        var output = resultNode.one(".output");
        fullResult.addClass("hidden");
        output.addClass("hidden");

        if (detailData.has_text) {
            href = evt.currentTarget.get("href");
            Y.io(href, {on: {success: function(id, response) {
                fullResult.removeClass("hidden");
                output.removeClass("hidden");
                output.set("text", response.responseText);
                fullResult.set("href", href);
            }}});
        }
        if (!overlay.get("rendered")) {
            overlay.render("#content");
        }
        overlay.show();
    };

    if (!Y.Lang.isNull(table)) {
        table.delegate("click", function(evt) {
            evt.preventDefault();
            // XXX Bug 1316261 means that under certain circumstances there can
            // be more than one overlay.  This is a crude way of ameliorating
            // the issue until we can fix it properly.
            if (!Y.Lang.isNull(overlay)) {
                overlay.destroy();
            }
            // Create an overlay to hold the
            // result text. Centralize it within the table row
            // and hide it initially.
            var tableRow = evt.currentTarget.ancestor("tr"),
                height = Y.one("body").get("winHeight") * MAX_HEIGHT_FACTOR;
            
            overlay = new Y.landscape.ui.Dialog({
                visible: false,
                width: tableRow.get("region").width * 0.90,
                constrain: true,
                align: {
                    node: ".activity-detail-table",
                    points: ["tc", "tc"]
                }
            });

            // Now replace the overlay body with a placeholder node for the
            // activity result and show the overlay.
            resultNode = Y.Node.create(
                Y.substitute([
                    "<div><h3>Details</h3>",
                    "<table>",
                    "<tr class='delivered-detail'>",
                    "<td class='tight-fit'>Delivered at:</td>",
                    "<td class='time-detail'></td></tr>",
                    "<tr class='approved-detail'>",
                    "<td class='tight-fit'>Approved at:</td>",
                    "<td class='time-detail'></td></tr>",
                    "<tr class='completed-detail'>",
                    "<td class='tight-fit'>Completed at:</td>",
                    "<td class='time-detail'></td></tr>",
                    "</table>",
                    "<pre class='output' ",
                    "style='max-height: {height}px; ",
                    "overflow-y: auto;'></pre>",
                    "<a class='activity-full-result' target='_blank'>",
                    "View plain text result...</a></div>"].join(""),
                    {height: height}));
            overlay.setStdModContent(
                Y.WidgetStdMod.BODY,
                resultNode,
                Y.WidgetStdMod.REPLACE);
            handleEvent(evt);
        }, ".activity-status-result");
    }

    var activityStatusGraph = Y.one(".activity-detail-progress .graph");
    if (!Y.Lang.isNull(activityStatusGraph)) {
        var transport = Y.landscape.notifications.transport,
            detail = new Y.landscape.activity.ActivityDetail(
                {contentBox: "#activity-detail",
                 updateOnRender: false,
                 detailsData: detailsData,
                 availableActivityIds: availableActivityIds,
                 totalActivities: totalActivities,
                 activitySearchCriteria: activity_search_criteria});
        detail.render();
        Y.on("notification:activity-changed", function(e) {
            detail.syncUI();
        });
    }

    Y.config.eventbinder.flush(Y, "click");


    var searchHelpNode =  Y.one("#help-overlay-activity-search");
    if (searchHelpNode) {
        var helpOverlay = new Y.landscape.ui.Dialog({
            visible: false,
            boundingBox: "#help-overlay",
            contentBox: "#help-overlay > .yui3-dialog-content",
            width: "90%",
            align: {node: "#tight-content", points: ["tc", "tc"]}});
        helpOverlay.render();
        searchHelpNode.on("click", function(e) {
            e.preventDefault();
            helpOverlay.show();
        });
    }

});

});
