// Copyright 2005-2013 Canonical Limited.  All rights reserved.

LS.use("node", "node-screen", "event", "datatype-date-format",
       "io-base", "json-parse", "landscape.util.text", "landscape.util.url",
       function(Y) {

Y.on("domready", function() {
    // Pick 5 colors, as we have at most 5 computers at a time
    var colors = ["#77216F", "#DD4814", "#00CC99", "#1166CC", "#AA0011"];
    var allImages = {};
    var imagesFetched = {};

    var font = 'UbuntuBeta, Ubuntu, "Bitstream Vera Sans", "DejaVu Sans", Tahoma, sans-serif',
        fontAttrs = {"font-size": 13, "font": font, "text-anchor": "start"};

    var content = Y.one("#content");
    var contentWidth = content.get("region").width;

    legendHoverIn = function(o, x, y, point, line, legend) {
        point.attr({r: 5});
        legend.attr({"font-weight": 800});
        if (line[0].attr("stroke-width") !== 0) {
            line.attr({"stroke-width": 2});
        }
    };
    legendHoverOut = function(o, x, y, point, line, legend) {
        point.attr({r: 4});
        legend.attr({"font-weight": 400});
        if (line[0].attr("stroke-width") !== 0) {
            line.attr({"stroke-width": 1});
        }
    };

    legendClick = function(evt, x, y, point, line, legend) {
        evt.preventDefault();
        if (line[0].attr("stroke-width") === 0) {
            line.attr({"stroke-width": 2});
            point.attr({"opacity": 1});
        } else {
            line.attr({"stroke-width": 0});
            point.attr({"opacity": 0.3});
        }
    };

    handleResponse = function(id, xhr, args) {
        var json = JSON.parse(xhr.responseText);
        var link = Y.one("#" + args.domId);
        var region = link.ancestor("div").get("region");
        var chartWidth;
        var chartHeight = region.height - 60;   /* room for legend values */
        var shouldAddValue = false;
        link.setStyle("background", "none");
        var axisxstep = 5;
        if (region.height > 400) {  /* we are a large graph */
            chartWidth = contentWidth - 50;
            chartHeight -= 20;
            axisxstep = 8;
        } else {
            chartWidth = (contentWidth - 50) / 2;
        }
        var paper = new Raphael(args.domId, chartWidth, chartHeight);
        var keys = [];
        var values = [];
        var computerIndex = [];
        Y.Object.each(json.data, function(data, computerID) {
            var subKeys = [];
            var subValues = [];
            var value, v;
            if (data.length > 1) {
                // Only consider if we have at least 2 points. Raphael is
                // confused otherwise.
                Y.each(data, function(elt) {
                    v = elt[0];
                    while (value < v - json.step) {
                        value += json.step;
                        subKeys.push(value);
                        subValues.push(null);
                    }
                    subKeys.push(v);
                    value = v;
                    subValues.push(elt[1]);
                    if (elt[1] >= 0 && elt[1] < 1) {
                        // If the value is less than 1, we must flag it so the
                        // graph is not plotted with negative values;
                        shouldAddValue = true;
                    }
                });
            }
            computerIndex.push(computerID);
            keys.push(subKeys);
            values.push(subValues);
        });

        keys.push([json.start, json.stop]);

        var hoverElements = paper.set();
        var legends = [];
        var yAxisPosition;

        formatDate = function(value) {
            var intValue = parseInt(value); // make sure it's a number
            var now = new Date();
            var lblDate = new Date(
                intValue*1000 + now.getTimezoneOffset()*60000);
            return Y.DataType.Date.format(lblDate, {format: "%d/%m %H:%M"});
        };

        chartHoverIn = function(evt, x, y) {
            // XXX this function is a bit slow, we should optimize it for a
            // smoother effect.
            for (var index=0; index < this.y.length; index++) {
                if (index === 0) {
                    hoverElements.push(paper.popup(this.x, yAxisPosition, formatDate(this.axis), "down"));
                }
                if (this.lines[index][0].attr("stroke-width") !== 0) {
                    hoverElements.push(paper.circle(this.x, this.y[index], 3));
                    var legend = legends[index];
                    var valueText = paper.text(
                        legend[0], legend[1],
                        "value: " + Y.landscape.util.formatValue(this.values[index]));
                    valueText.attr(fontAttrs);
                    hoverElements.push(valueText);
                }
            }
        };

        chartHoverOut = function(o, x, y) {
            hoverElements.remove();
        };

        // If none of the values are bigger than 1, we force add a "1" value to
        // the values array so the chart does not display negative numbers.
        if (shouldAddValue) {
            values.push([1]);
        }

        var chart = paper.linechart(
            45, 20, chartWidth - 90, chartHeight - 70, keys, values,
            {colors: colors, axis: "0 0 1 1", axisxstep: axisxstep, width: 1});
        yAxisPosition = chart.axis[0].getBBox().y;

        // Add vertical lines for the grid
        Y.each(chart.axis[0].text.items, function(label, index) {
            label.attr({"text": formatDate(label.attr("text"))});

            var vline = paper.path("M" + label.attr("x") + " 30V" + (chartHeight - 55));
            vline.attr({"opacity": 0.1});
        });

        // Make the best effort to avoid duplicated numbers in the Y axis by
        // increasing the precision.
        var precision;
        var maxPrecision = 2;
        for (precision = 1; precision <= maxPrecision; precision++) {
            var yAxisValues = [];
            // Collect all the Y axis values from the graph.
            Y.each(chart.axis[1].text.items, function(label, index) {
                var value = Number(label.attr("text"));
                var toDisplay = Y.landscape.util.formatValue(value, precision);
                yAxisValues.push(toDisplay);
            });
            // Check if there are duplicates by comparing the total number of
            // items with the result of Y.Array.unique().
            var totalItems = yAxisValues.length;
            if (Y.Array.unique(yAxisValues).length == totalItems) {
                break;
            }
        }
        
        // Convert the numbers using the computed precision.
        var convertedNumbers = [];
        Y.each(chart.axis[1].text.items, function(label, index) {
            var value = Number(label.attr("text"));
            convertedNumbers.push(Y.landscape.util.formatValue(value, precision));
        });

        // Reformat Y axis values using the precision computer above.
        var formatted = Y.landscape.util.removeCommonTrailingZeros(convertedNumbers);
        Y.each(chart.axis[1].text.items, function(label, index) {
            var value = formatted[index];
            label.attr({"text": value});
        });

        var chartTitle = paper.text((chartWidth - 30) / 2, 10, json.title);
        chartTitle.attr({"font-size": 16, "font": font});

        var yLabel = paper.text(5, (chartHeight - 40) / 2, json.label);
        yLabel.attr({"font-size": 13, "font": font});
        yLabel.transform("r270");

        // Add horizontal lines for the grid
        Y.each(chart.axis[1].text.items, function(label, index) {
            if (index && ((index % 3) === 0)) {
                var hline = paper.path(
                    "M50 " + label.attr("y") + "H" + (chartWidth - 55));
                hline.attr({"opacity": 0.1});
            }
        });

        if (!values.length) {
            return;
        }

        chart.hoverColumn(chartHoverIn, chartHoverOut);

        // Display the legend under the graph itself
        var xIndex = 40;
        var yIndex = chartHeight - 25;
        var currentPadding;
        // XXX we don't align legends on a grid
        Y.each(chart.lines, function(line, i) {
            if (!Y.Lang.isUndefined(json.legend[computerIndex[i]])) {
                var point = paper.circle(xIndex, yIndex, 4);
                xIndex += 8;
                point.attr({fill: colors[i], stroke: "none"});
                var legend = paper.text(
                    xIndex, yIndex, json.legend[computerIndex[i]]);
                legend.attr(fontAttrs);
                currentPadding = legend.getBBox().width + 30;
                xIndex += currentPadding;
                if (xIndex > chartWidth) {
                    paper.setSize(null, paper.height + 50);
                    if (region.height <= 400) {  /*  we are a small graph */
                        // Make room for a 2nd row of computers in the legend
                        var graphHeight = parseInt(link.getStyle("height"));
                        link.setStyle("height", graphHeight + 50 + "px");
                    }
                    yIndex += 40;
                    xIndex = 40;
                    point.attr({"cx": xIndex, "cy": yIndex});
                    xIndex += 8;
                    legend.attr({"x": xIndex, "y": yIndex});
                    xIndex += currentPadding;
                }
                hoverIn = Y.rbind(legendHoverIn, this, point, line, legend);
                hoverOut = Y.rbind(legendHoverOut, this, point, line, legend);
                point.hover(hoverIn, hoverOut);
                legend.hover(hoverIn, hoverOut);
                point.click(Y.rbind(legendClick, this, point, line, legend));
                legend.click(Y.rbind(legendClick, this, point, line, legend));
                legends.push([legend.attr("x"),
                              legend.attr("y") + 20]);
            }
        });
    };

    Y.all("a.graph").each(function(link) {
        var domId = Y.Event.generateId(link);
        link.setAttribute("id", domId);
        var url = link.get("title");
        allImages[domId] = url;

        link.setAttribute("title", link.getAttribute("alt"));
    });

    // Our 'fold' region is tracked by the containing div, which has
    // absolute positioning and scrolling.
    var contentNode = Y.one("#filtered-content-area");
    var subscribers = [];

    var foldCheck = function() {
         var imageFetched, contentHeight,
             heightLimit = Y.DOM.viewportRegion().bottom + 40,
             allFetched = true;

         if (!Y.Lang.isNull(contentNode)) {
             // Compute the fold as relative to the top coordinates of the
             // containing node + the visible height + the scrolling
             // distance + a threshold.
             contentHeight = (contentNode.getY() +
                              contentNode.get("region").bottom +
                              contentNode.get("scrollTop") + 40);
             if (contentHeight < heightLimit || contentNode.get("scrollTop")) {
                 heightLimit = contentHeight;
             }
         }

        var io = new Y.IO();

        Y.each(allImages, function(url, domId) {
            var graphY = Y.one("#" + domId).getY();
            if (graphY < heightLimit && !imagesFetched.hasOwnProperty(domId)) {
                io.send(url, {on: {complete: handleResponse},
                              arguments: {domId: domId}});
                imagesFetched[domId] = true;
            } else {
                allFetched = false;
            }
        });

         // Once all images have been fetched, detach the subscribers,
         // since we don't need to load anything else.
         if (allFetched) {
             Y.Array.each(subscribers, function(subscriber) {
                 subscriber.detach();
             });
         }
    };

    var initialize = function() {
        // Detach previous subscribers, if any.
        Y.Array.each(subscribers, function(subscriber) {
            subscriber.detach();
        });

        // Do an initial fold check.
        foldCheck();
        if (!Y.Lang.isNull(contentNode)) {
            // Bind subscribers to changes in the visible area
            // of the containing element.
            subscribers.push(Y.on("mousewheel", foldCheck, contentNode));
            subscribers.push(Y.on("scroll", foldCheck, contentNode));
        }

        // Bind subscribers to changes in the visible area of 'window'.
        subscribers.push(Y.on("scroll", foldCheck, window));
        subscribers.push(Y.on("resize", foldCheck, window));
    };

    initialize();

    Y.one("#graph-period-filter-form").on("change", function(event) {
        var days = event.target.get("value");
        var url = Y.landscape.util.updateURL(
            window.location.href, {"days": days});
        window.location.replace(url);
    });
});

});
