// Copyright 2005-2023 Canonical Limited.  All rights reserved.

LS.use("node", "dom", "event", "landscape.notifications.transport",
       "landscape.selection.computer", function(Y) {

var onOperatorChange = function(evt) {
    var operatorSelect = evt.target;
    var versionInput = operatorSelect.next();
    versionInput.set("disabled", operatorSelect.get("value") === "");
};

Y.on("domready", function() {
    var field = Y.one("#package-constraints-field"),
        computerIdField = Y.one("#computer-id"),
        computerNameField = Y.one("#computer-name"),
        inputFileName = Y.one("#file-name"),
        inputFileData = Y.one("#file-data"),
        formAttachment = Y.one("input[id='form.attachment']"),
        attachmentContainer = Y.one("span[class='file-upload']"),
        firstManualConstraint = Y.one("input[name$='.package:records']"),
        addButton = Y.one("#add-field"),
        cancelLinks = Y.all("#cancel-from-file"),
        fileInfo = Y.one("#attached-file-info");

    var cancelFileInput =  function(evt) {
        if (evt) {
            evt.halt();
        }
        inputFileName.set("value", "");
        formAttachment.set("value","");
        inputFileData.set("value", "");
        if (!Y.Lang.isUndefined(attachmentContainer)) {
            fileMessage = attachmentContainer.one(".file-message");
            fileMessage.set("text", "No file chosen");
        }
        fileInfo.setContent("");
        cancelLinks.hide();
        attachmentContainer.show();
    };

    var selectConstraintType = function(type, cleanData) {
        // Make cleanData default == true
        cleanData = typeof cleanData !== 'undefined' ? cleanData : true;

        // Hide all unselected constraint types
        var allConstraintContent = Y.all("div[id^='constraints-from']"),
            radios = Y.all("input[type=radio]"),
            removeButtons = Y.all(".remove-button"),
            showContent = Y.all("#constraints-" + type);

        allConstraintContent.hide();
        if (cleanData) {
            // Clean hidden form data
            if (removeButtons.size() > 0) {
                // Remove each additional constraint line > 1
                var index;
                for (index = removeButtons.size() - 1; index > 0; index--) {
                    removePackage({target: removeButtons.item(index)});
                }
            }

            var constraintInputs = Y.all(
                    "input[name^=computer],input[name^=constraint]," +
                    "input[type=file]"),
                selectOperator = Y.one("select[name$=.operator:records]"),
                constraintVersionInputs = Y.all(
                    "input[name$=.version:records]");

            if (!Y.Lang.isNull(selectOperator)) {
                //  Setting manual constraint operator dropdown to "any"
                selectOperator.set("value", "");
            }

            constraintInputs.set("value", "");
            constraintVersionInputs.set("disabled", true);
            radios.set("checked", false);
            cancelFileInput();
            cancelLinks.hide();
            attachmentContainer.show();
        } else {
            // We are not cleaning data, but set dropdown appropriately
            var constraintOperator = Y.one("select[name^=create-constraints]");
            if (!Y.Lang.isNull(constraintOperator)) {
                constraintOperator.set("value", type);
            }
        }
        if (showContent) {
            showContent.show();
        }
    };

    var constraintSelect = Y.one("#create-constraints");
    // If already mid-dialog with form errors, we need to ensure we display
    // the proper constraint type
    var selectedComputerId = computerIdField.get("value");
    if (selectedComputerId !== "") {
        selectConstraintType("from-computer", false);
    } else if (inputFileName.get("value") !== "") {
        selectConstraintType("from-file", false);
    } else {
        if (firstManualConstraint &&
            firstManualConstraint.get("value") !== "") {
            
            selectConstraintType("from-manual", false);
        }
    }

    var removePackage = function(evt) {
        var button = evt.target;
        var parentNode = button.ancestor(".form-field");
        var grandParent = parentNode.get("parentNode");
        if (!parentNode.next(".form-field")) {
            var previous = parentNode.previous(".form-field");
            previous.one(".form-widget").appendChild(addButton);
        }
        parentNode.remove();
        var widgets = grandParent.all(".form-field");
        if (widgets.size() == 1) {
            var input = widgets.item(0).one("input.remove-button");
            input.remove();
        }
    };

    var formatProfileName = function(name) {
        // Format Computer name to fit with requirements
        var formattedName = name.toLowerCase().replace("'","");
        formattedName = formattedName.replace(/ /g, "-");
        formattedName = formattedName.replace(/[^a-z0-9-]/g, ".");
        return formattedName + "-profile";
    };

    if (inputFileName.get("value") !== "") {
        fileInfo.setContent(
            ["Attached file: <b>", inputFileName.get("value"),
             "</b>"].join(""));
        fileInfo.setStyle("display", "inline-block");
    }

    var computersListing = new Y.landscape.selection.ComputerSelection(
        {recordSource: new Y.DataSource.IO({
             source: account_url + "computers/available"}),
         pageDataSource: Y.landscape.notifications.transport,
         pageSize: 10,
         chooseOne: true,
         selectionInfo: "Select a computer to generate a list of package " +
                        "constraints",
         selectable: false,
         visible: false});

    // use POST to avoid URL limits when sending computer ids
    computersListing.get("pager").set("requestConfig", {method: "post"});

    // Setup computersListing and render
    computersListing.set("availableComputerIds", availableComputerIds);
    computersListing.set("unselectedComputerIds", availableComputerIds);
    computersListing.set("noComputersMessage",
        ["No computers reporting installed packages. You can register ",
         "new computers by <a href='", account_url,
         "how-to-register'>following these ",
         "instructions</a>."].join(""));

    var pager = computersListing.get("pager");
    pager.set("recordSourceArguments",
              {all_computer_ids: availableComputerIds.join(",")});

    if (selectedComputerId !== "") {
        computersListing.selectOneComputer(selectedComputerId);
    }
    computersListing.render("#constraints-from-computer");

    if (constraintSelect) {
        constraintSelect.on("change", function (e) {
            // Depending on UI select choice, we want to show and hide dialogs
            selectConstraintType(e._currentTarget.value);
        });
    }

    var computerContent = Y.one("#constraints-from-computer"),
        form = Y.one("#form-form"),
        titleField = form.one("input[id='form.title']"),
        updateTitleField = (! titleField.get("value")),
        descriptionField = form.one("input[id='form.description']"),
        updateDescriptionField = (! descriptionField.get("value"));

    Y.each(cancelLinks, function(link) {
        link.on("click", cancelFileInput);
    }, this);

    // Stop updating the name and title automatically if the user has edited
    // the values, unless the field has been left empty.
    titleField.on("valueChange", function(e) {
        updateTitleField = (! titleField.get("value"));
    });
    descriptionField.on("valueChange", function(e) {
        updateDescriptionField = (! descriptionField.get("value"));
    });


    computersListing.on("computerChosen", function(e) {
        computerIdField.set("value", e.computer_id);
        computerNameField.set("value", e.computer_name);

        if (updateTitleField) {
            titleField.set("value", formatProfileName(e.computer_name));
        }
        if (updateDescriptionField) {
            descriptionField.set("value", "Profile created from packages " +
                "installed on computer " + e.computer_name +  ".");
        }

        computerContent.show();
    });

    if (formAttachment) {
        formAttachment.on("change", function(evt) {
            var filePath = evt.currentTarget.get("value");
            if (filePath) {
               var fileName = filePath.split("\\").pop();
               // Clear any computers that could have been chosen
               computerIdField.set("value", "");
               computerNameField.set("value", "");

               inputFileName.set("value", fileName);
               fileInfo.setContent(
                   ["Attached file: <b>", inputFileName.get("value"),
                    "</b>"].join(""));
               cancelLinks.show();
               fileInfo.setStyle("display", "inline-block");
               attachmentContainer.hide();
               if (descriptionField.get("value") === "") {
                   descriptionField.set(
                       "value",
                       "Profile created from imported file named " +
                           fileName +  ".");
               }
            }
        });
    }

    let buttonCounter = 0;
    if (addButton) {
        // If we see the manual constraints addButton, ensure clicking it on
        // this existing row will do the following:
        // - add a removeButton for this line
        // - remove the existing addButton from this line
        // - setup and add a new constraint row below
        addButton.on("click", function(evt) {
            var currentField = evt.target.ancestor(".form-field");
            if (!currentField.previous(".form-field")) {
                var input = ("<input type='button' name='remove' " +
                             "value='&minus;' class='remove-button'>"),
                    removeButton = Y.Node.create(input);
                currentField.one(".form-widget").appendChild(removeButton);
                removeButton.on("click", removePackage);
            }

            addButton.remove();
            var template = field.one(".form-field").cloneNode(true);
            template.one("[name$='.package:records']").set("value", "");
            var operatorSelect = template.one("[name$='.operator:records']");
            operatorSelect.one("option").set("selected", true);
            operatorSelect.on("change", onOperatorChange);
            operatorSelect.on("keyup", onOperatorChange);
            var versionInput = template.one("[name$='.version:records']");
            versionInput.set("value", "");
            versionInput.set("disabled", true);
            template.one("[name$='.relation:records']").one("option").set("selected", true);
            template.one(".remove-button").on("click", removePackage);
            template.one(".form-widget").appendChild(addButton);
            buttonCounter++;
            let zopeThings = template.all('[name]');
            zopeThings.each(function(thing) {
                let name = thing.getAttribute("name");
                if (name.includes(":records")) {
                    let splitted = name.split(".");
                    // Add underscore to avoid conflict with rows already present starting at zero
                    let newName = "constraint" + "_" + buttonCounter + "." + splitted[1];
                    thing.setAttribute("name", newName);
                };
            });
            field.appendChild(template);
        });
    }

    field.all(".remove-button").on("click", removePackage);

    field.all("select.operator-select").each(function(operatorSelect) {
        var versionInput = operatorSelect.next();
        versionInput.set("disabled", operatorSelect.get("value") === "");
        operatorSelect.on("change", onOperatorChange);
        operatorSelect.on("keyup", onOperatorChange);
    });
});

});
