// Copyright 2005-2013 Canonical Limited.  All rights reserved.

/**
 * Computer Selection UI
 *
 * Uses the Pagination Widget with a custom row renderer and event
 * subscribers to allow for pagination and selection of computers.
 *
 * The page expects several variables to be defined before the YUI on
 * ready event is fired (see the constructor of ComputerSelection for
 * all the variables).
 */

LS.use("node", "io-base", "anim", "overlay",
       "landscape.notifications.transport", "landscape.ui.overlay",
       "landscape.selection.computer", function(Y) {

Y.on("domready", function() {
    var toggle = Y.one("#computer-selection-toggle");
    if (!toggle) {
        return;
    }
    if (Y.one("#computer-selection-form")) {
        return;
    }

    var recordSource = new Y.DataSource.IO({source: recordSourceUrl});
    var bb = overlayBoundingBox;

    // Create an overlay to hold the ComputerSelectionWidget. Centralize it
    // within the '#toolbar-content-area' div, and hide it initially.
    var selectionFactory = function() {
        // Initialize the ComputerSelection widget.
        var selection = new Y.landscape.selection.ComputerSelection({
            renderFirstPage: true,
            recordSource: recordSource,
            availableComputerIds: selectedComputerIds,
            pageDataSource: Y.landscape.notifications.transport,
            accountUrl: accountUrl,
            pageSize: 15,
            visible: false,
            selectable: false
        });

        selection.get("pager").after("after-page-change", function() {
            selection.get("boundingBox").setStyle("padding", "8px 16px");
            selection.fire("contentUpdate");
        });

        return selection;
    };

    var overlay = new Y.landscape.ui.SlidingOverlay({
            boundingBox: bb,
            align: {node: "#toolbar",
                    points: ["tl", "bl"]},
            factory: selectionFactory
    });
    overlay.render(Y.one("#content"));

    // When the toggle is clicked, toggle the sliding overlay.
    toggle.on("mouseenter", function() {
        toggle.addClass("toggle-active");
    });

    toggle.on("mouseleave", function() {
        toggle.removeClass("toggle-active");
    });

    toggle.on("click", function() {
        overlay.toggle();
    });

    overlay.overlay.on("visibleChange", function(evt) {
        if (evt.newVal) {
            toggle.addClass("toggle-selected");
        } else {
            toggle.removeClass("toggle-selected");
        }
    });
});

});
