// Copyright 2005-2013 Canonical Limited.  All rights reserved.

/**
 * Computer Selection UI
 *
 * Uses the Pagination Widget with a custom row renderer and event
 * subscribers to allow for pagination and selection of computers.
 *
 * The page expects several variables to be defined before the YUI on
 * ready event is fired (see the constructor of ComputerSelection for
 * all the variables).
 */

LS.use("node", "node-base", "io-base", "io-form", "landscape.notes",
       "landscape.notifications.transport",
       "landscape.selection.computer", "landscape.util.text",
       "landscape.selection.deletesavedsearch",
       "landscape.selection.savedsearch", "landscape.selection.reboot",
       "landscape.activity.schedule", function(Y) {

Y.on("domready", function() {
    // Notification area for form messages.
    var notes = new Y.landscape.notes.Notes({contentBox: "#notes",
                                             animDuration: 0.01});

    // Save Search modal form
    if (Y.one("#save-search-form")) {
        var savedSearch = new Y.landscape.selection.SavedSearch(
            {contentBox: "#toolbar-content-area"});
        savedSearch.render();
    }

    // Delete search modal form
    if (!Y.Lang.isNull(Y.one("#delete-saved-search-form"))) {
        var deleteSavedSearchWidget = new Y.landscape.selection.DeleteSavedSearch(
            {contentBox: "#delete-saved-search-form",
             source: Y.landscape.notifications.transport,
             notes: notes});
        deleteSavedSearchWidget.render("#content");
    }

    // Reboot modal form
    if (Y.one("#reboot-form")) {
        var rebootWidget = new Y.landscape.selection.Reboot(
            {contentBox: "#toolbar-content-area"});
        rebootWidget.render();

        var schedule = new Y.landscape.activity.ActivitySchedule({
            contentBox: Y.one("#reboot-activity-form"),
            activityButtons: [Y.one("#request-restart-button"),
                            Y.one("#request-shutdown-button")],
            deliverNowButton: Y.one("#deliver-now-button"),
            deliverAfterButton: Y.one("#deliver-after-button"),
            deliverAfterTimeInput: Y.one("#deliver-after-time-input"),
            statusMessage: Y.one("#activity-schedule-message"),
            timeZoneOffset: timeZoneOffset
        });
        schedule.render();
    }

    // If no computer is listed, do nothing.
    if (! Y.one("#selection_json")) {
        return;
    }

    var tools = Y.one("#tools");
    var download_csv = Y.one("#download_csv");
    var reboot_button = Y.one("#reboot-button");

    var toggleTools = function(enable) {
        if (enable) {
            tools.replaceClass("toolbar-item-disabled",
                               "toolbar-item-enabled");
        } else {
            tools.replaceClass("toolbar-item-enabled",
                               "toolbar-item-disabled");
        }
        download_csv.set("disabled", !enable);

        if (Y.Lang.isValue(reboot_button)) {
            reboot_button.set("disabled", !enable);
        }
    };

    var updateToolbarStatus = function(selectedCount, rowCount) {
        var countNode = Y.one("#computer-selected-count"),
            textNode = Y.one("#computer-selected-text");
        countNode.set("text", selectedCount);
        if (selectedCount == 1) {
            textNode.set("innerHTML", "computer<br/>selected");
        } else {
            textNode.set("innerHTML", "computers<br/>selected");
        }
        var widget = Y.one(".computer-selected-widget");
        if (!selectedCount) {
            widget.addClass("computer-selected-widget-disabled");
        }
        else {
            widget.removeClass("computer-selected-widget-disabled");
        }
    };

    var selection = new Y.landscape.selection.ComputerSelection({
        contentBox: Y.one("#computers"),
        renderFirstPage: false,
        availableComputerIds: availableComputerIds,
        selectedComputerIds: selectedComputerIds,
        pageSize: pageSize,
        pageDataSource: Y.landscape.notifications.transport,
        availableComputerIdsSource: new Y.DataSource.IO({source: "available_ids"}),
        searchCriteria: searchCriteria,
        accountUrl: accountUrl
    });

    selection.after("selectedComputerIdsChange", function(evt) {
        var selected = evt.newVal.length;
        if (!selected) {
            Y.io("noop_ajax", {"method":"POST", "data":"select_none=1"});
        }
        updateToolbarStatus(
            selected, this.get("pager").get("totalRecords"));
        toggleTools(selected);
    }, selection);
    selection.after("render", Y.bind(function(){
        var selected = this.get("selectedComputerIds").length;
        updateToolbarStatus(selected,
                            this.get("pager").get("totalRecords"));
        toggleTools(selected);
    }, selection));
    selection.render();

    var updateSelectedComputers = function(evt, next_url) {
        var selectedComputerIds = selection.get("selectedComputerIds");
        evt.preventDefault();
        if (!selectedComputerIds.length) {
            return;
        }
        var input = Y.one("#selection_json");
        input.set("value", "" + selectedComputerIds);
        input = Y.one("#next_url");
        input.set("value", next_url);
        Y.one("#computer-selection-form").submit();
    };

    // Intercept toolbar clicks to populate form before submit.
    tools.delegate("click", function(evt) {
        updateSelectedComputers(evt, evt.currentTarget.get("href"));
    }, "a");

    download_csv.on("click", function(evt) {
        var selectedComputerIds = selection.get("selectedComputerIds");
        if (selectedComputerIds.length) {
            var input = Y.one("#selection_json");
            input.set("value", "" + selectedComputerIds);
        }
    });

    if (Y.Lang.isValue(reboot_button)) {
        reboot_button.on("click", function(evt) {
            evt.preventDefault();
            var selectedComputerIds = selection.get("selectedComputerIds");
            if (selectedComputerIds.length) {
                var input = Y.one("#selection_json");
                input.set("value", "" + selectedComputerIds);
            }
            rebootWidget.updateSelection(
                Y.bind(rebootWidget.showOverlay, rebootWidget));
        });
    }

    Y.config.eventbinder.flush(Y, "click");
});

});
