# Copyright 2005-2022 Canonical Limited. All rights reserved.

from storm.locals import Unicode

from canonical.security.protect import requires, requires_advisor, PRIVATE

from canonical.landscape.model.alert.account import (
    AccountRuleInfo,
    StoredAccountRuleInfo,
)
from canonical.landscape.model.alert.computer import (
    ComputerRuleInfo,
    StoredComputerRuleInfo,
)
from canonical.landscape.model.alert.rule import RuleState


__requires_prefix__ = "landscape."


@requires_advisor
class SampleStoredAccountAlert(StoredAccountRuleInfo):
    """A database-backed sample L{StoredAccountRuleInfo} implementation."""

    __storm_table__ = "sample_account_rule"

    data = Unicode()

    title = "A sample database account rule"

    def __init__(self, rule, data):
        super(SampleStoredAccountAlert, self).__init__(rule)
        self.data = data

    def check(self):
        pass

    def get_description(self):
        return "description: %s" % (self.data,)

    @requires("ViewAlertRule")
    def get_summary(self):
        return "A test summary!"


@requires_advisor
class SampleAccountAlert(AccountRuleInfo):
    """An in-memory sample L{AccountRuleInfo} implementation."""

    title = "A sample in-memory account rule"

    def check(self):
        pass

    @requires("ViewAlertRule")
    def get_summary(self):
        return "A test account summary!"

    def get_resolution_url(self):
        return "/sample/account/url"


@requires_advisor
class SampleStoredComputerAlert(StoredComputerRuleInfo):
    """A database-backed sample L{StoredComputerRuleInfo} implementation."""

    __storm_table__ = "sample_computer_rule"

    data = Unicode()

    title = "A sample database computer rule"

    def __init__(self, rule, data):
        super(SampleStoredComputerAlert, self).__init__(rule)
        self.data = data

    def check(self, computer_ids):
        pass

    def get_description(self):
        return "description: %s" % (self.data,)

    @requires("ViewAlertRule")
    def get_summary(self):
        return "A test summary!"


@requires_advisor
class SampleComputerAlert(ComputerRuleInfo):
    """An in-memory sample L{ComputerRuleInfo} implementation."""

    requires("ViewAlertRule", PRIVATE, ["title"])

    title = "A sample in-memory computer rule"

    def check(self, computer_ids):
        pass

    def get_message(self, state):
        return ("Subject", "Sample message.")

    @requires("ViewAlertRule")
    def get_summary(self, computer_ids=None):
        """Get a sample summary for the rule.

        @param computer_ids: a list of computers ids to limit the generated
            summary to.
        """
        result = self.get_states(active=True, computer_ids=computer_ids)
        return "A test computer summary with %d states!" % result.count()

    def get_resolution_url(self, computer_ids=None):
        """
        Return a URL pointing to the computers currently offline.

        @param computer_ids: a list of computers ids to limit the generated
            URL to.
        """
        result = self.get_states(active=True, computer_ids=computer_ids)
        result = result.values(RuleState.computer_id)
        computer_ids = "+".join(str(computer_id) for computer_id in result)
        if not computer_ids:
            return None
        return "/sample/computer/url/%s" % computer_ids
