# Copyright 2005-2015 Canonical Limited.  All rights reserved.

from future import standard_library

standard_library.install_aliases()
from builtins import str
from builtins import object
import sys
from io import StringIO


output_streams = {
    sys.stdout: "stdout",
    sys.stderr: "stderr",
}


class redirected(object):
    """A context manager to redirect stdout or stderr for testing."""

    def __init__(self, stream):
        try:
            self.stream_name = output_streams[stream]
        except KeyError:
            raise ValueError("Unrecognized stream: %r" % stream)
        self.stream = stream
        self.temp_stream = StringIO()

    def __enter__(self):
        """The context has been entered, substitute a temporary stream."""
        setattr(sys, self.stream_name, self.temp_stream)
        return self

    def __exit__(self, *ignored):
        """The context has been exited, put the original stream back."""
        setattr(sys, self.stream_name, self.stream)

    def __str__(self):
        """The string representation of this object is the stream content."""
        return self.temp_stream.getvalue()

    def __repr__(self):
        return repr(str(self))

    def __eq__(self, other):
        """When comparing for equality, the temporary stream's value is used."""
        return str(self) == other

    def __ne__(self, other):
        """When comparing for equality, the temporary stream's value is used."""
        return str(self) != other

    def __contains__(self, needle):
        """When asked if this object contains something we look in the stream."""
        return needle in str(self)
