# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import object
from zope.component import getUtility

from storm.twisted.testing import FakeTransactor

from canonical.testing.fake import FakeTransaction
from canonical.amqp.message.interfaces import IDispatcher

from canonical.landscape.testing.model import TwistedModelTest
from future.utils import with_metaclass


class JobRunnerTestMixin(object):
    """
    Helper class with common tests for job runner classes.

    Tests in this class will be executed for subclasses of L{JobRunnerTest}
    with the proper job runner.
    """

    def test_registration(self):
        """
        The runner is registered in the global job handlers.
        """
        self.assertTrue(self.job_runner.__venusian_callbacks__)


class JobRunnerTestMeta(type):
    """
    Metaclass to setup L{JobRunnerTest} class.
    """

    def __new__(cls, name, bases, clsdict):
        if clsdict.get("job_runner_class") is not None:
            bases += (JobRunnerTestMixin,)

        return type.__new__(cls, name, bases, clsdict)


class JobRunnerTest(with_metaclass(JobRunnerTestMeta, TwistedModelTest)):
    """
    A test class for L{JobRunner}s testing.

    @cvar job_runner_class: the L{JobRunner} class under test.
    """

    job_runner_class = None

    with_fake_transaction = False

    def setUp(self):
        super(JobRunnerTest, self).setUp()

        if self.job_runner_class is not None:
            if self.with_fake_transaction:
                transaction = FakeTransaction()
            else:
                transaction = None
            self.transactor = FakeTransactor(transaction)
            self.job_runner = self.job_runner_class(transactor=self.transactor)
            self.dispatcher = getUtility(IDispatcher)
            self.dispatcher.jobs = [self.job_runner]
