# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import str
from canonical.landscape.model.juju.model import JujuModel
from canonical.landscape.model.juju.target import MaasTargetMachine


def create_model(account, units):
    """
    Create a JujuModel and units given a simple configuration.

    @param units: A dict mapping charm-names to lists of computers. For
        every unique charm-name, a Juju L{Service} will be created. For
        every computer in the list, a Juju L{Unit} will be created
        associated with the respective application.
    """
    store = account.store
    juju_model = store.add(
        JujuModel(
            account=account,
            name="test-environment",
            endpoints=None,
            username=None,
            password=None,
            uuid="test-env-uuid",
            cloud_endpoint="https://10.1.2.3/MAAS/",
            provider_type="maas",
            juju_name="test-model",
            externally_managed=False,
        )
    )
    machine_id = 1
    apps = {}
    for charm_name in units:
        apps[charm_name] = juju_model.create_application(
            str(charm_name), "cs:precise/%s-1" % (charm_name,)
        )
    for charm_name, computers in units.items():
        app = apps[charm_name]
        for i, computer in enumerate(computers):
            machine = juju_model.create_machine(
                str(machine_id),
                instance_id="/api/1.0/nodes/short-id-%d/" % machine_id,
                computer=computer,
            )
            machine.address = "juju-%s-%s" % (app.name, i)
            target_machine = MaasTargetMachine(
                juju_model,
                "machine%d.maas" % machine_id,
                juju_machine_id=str(machine_id),
            )
            store.add(target_machine)
            unit_name = "%s/%s" % (app.name, i)
            app.create_unit(unit_name, machine=machine)
            machine_id += 1
    return juju_model
