# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import object
from openid.consumer.consumer import SUCCESS
from openid.message import Message
from openid.extensions.ax import FetchResponse


def setup_new_user_success(identity, invitation=None):
    consumer_factory = FakeConsumerFactory()
    auth_request = consumer_factory.add_begin_response("https://login.ubuntu.com/")
    auth_request.add_redirectURL_response(
        "http://localhost/", result="https://provider.example.com/"
    )
    return_to = "http://localhost/login/handle-openid"
    if invitation:
        return_to += "?invitation=%s" % invitation
    consumer_factory.add_complete_result(return_to, FakeStatus(SUCCESS, identity))
    return consumer_factory


class FakeConsumerFactory(object):
    def __init__(self):
        self.responses = {}
        self.completions = {}
        self.consumers = []
        self.completed = []

    def add_begin_response(self, identity):
        """
        Specify that the given C{identity} should be expected.
        @return: A L{FakeAuthRequest} object which you should do stuff with.
        """
        response = FakeAuthRequest()
        self.responses[identity] = response
        return response

    def add_complete_result(self, return_to, result):
        self.completions[return_to] = result

    def __call__(self, *args, **kwargs):
        consumer = FakeConsumer(self, *args, **kwargs)
        self.consumers.append(consumer)
        return consumer


class FakeConsumer(object):
    def __init__(self, factory, session, store):
        self.factory = factory
        self.session = session
        self.store = store

    def begin(self, identity):
        return self.factory.responses[identity]

    def complete(self, form_data, return_to_url):
        self.factory.completed.append((form_data, return_to_url))
        return self.factory.completions[return_to_url]


class FakeAuthRequest(object):
    def __init__(self):
        self.responses = {}
        self.redirections = []
        self.extensions = []

    def add_redirectURL_response(self, realm, return_to=None, result=None):
        if return_to is not None:
            self.responses[realm, return_to] = result
        else:
            self.responses[realm] = result

    def redirectURL(self, realm, return_to):
        self.redirections.append((realm, return_to))
        if (realm, return_to) in self.responses:
            return self.responses[realm, return_to]
        else:
            return self.responses[realm]

    def addExtension(self, extension):
        self.extensions.append(extension)


class FakeStatus(object):
    def __init__(self, status, identity_url):
        self.status = status
        self.identity_url = identity_url
        self.message = Message()
        self.ax_message = FetchResponse()

    def getSignedNS(self, ns_uri):
        return self.message.getArgs(ns_uri)

    def extensionResponse(self, ns_uri, signed):
        """
        This function is only called when using ax protocol. It returns the
        key value pairs in the ax format.
        """
        ax_args = self.ax_message.getExtensionArgs()
        return ax_args
