# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.testing.gpg import (
    SAMPLE_SECRET_KEY_FINGERPRINT,
    SAMPLE_SECRET_KEY_MATERIAL,
    SAMPLE_SECRET_KEY_PUBLIC_MATERIAL,
)
from canonical.testing.reprepro import RepreproTestCase
from canonical.landscape.testing.fixture import RepositoryFixture
from canonical.landscape.testing.api import APITest
from canonical.landscape.testing.model import TwistedModelTest
from canonical.landscape.model.repository.management import RepositoryManagement
from canonical.landscape.model.gpg.management import GPGKeyManagement


class RepositoryTestCase(TwistedModelTest, RepreproTestCase):
    """Base class for non-API repository management tests."""

    with_repository_management = True
    with_gpg_key_management = True

    def setUp(self):
        super(RepositoryTestCase, self).setUp()
        if self.with_repository_management:
            self.repository_management = RepositoryManagement(self.account, self.person)
        if self.with_gpg_key_management:
            self.gpg_key_management = GPGKeyManagement(self.account, self.person)
        repository_fixture = self.useFixture(RepositoryFixture())
        self.repository_path = repository_fixture.path
        self.config = repository_fixture.config
        self.sign_key = self.gpg_key_management.create_key(
            "sign-key",
            SAMPLE_SECRET_KEY_FINGERPRINT,
            SAMPLE_SECRET_KEY_PUBLIC_MATERIAL,
            SAMPLE_SECRET_KEY_MATERIAL,
        )


class RepositoryAPITestCase(APITest, RepositoryTestCase):
    """Base class for Repository API Test Cases."""

    with_repository_management = True
    with_gpg_key_management = True
