# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from collections import defaultdict

from zope.cachedescriptors.property import Lazy

from canonical.url import get_url

from canonical.landscape.model.computer.search import AccessGroupCriteria
from canonical.landscape.ui.account.page import AccountPage


def get_access_context_computers_link(account, access_context, request):
    """Return a computer search URL for computer in the access context."""
    criteria = AccessGroupCriteria(access_context.name, account)
    return "%s/computers/criteria/%s" % (
        get_url(account, request),
        criteria.to_string(),
    )


class AccessContextPage(AccountPage):
    """Page shows details about an L{AccessContext}."""

    @Lazy
    def administrators(self):
        """
        Return a list of C{dict}s, each containing a L{Person} in the account
        and the list of roles that person holds and that grant some permission
        on the L{AccessContext}.
        """
        persons_roles = defaultdict(list)

        for role in self.context.get_roles():
            for person in role.get_persons():
                persons_roles[person].append(role.name)

        person_names = sorted(persons_roles, key=lambda person: person.name)
        return [
            {"person": person, "roles": sorted(persons_roles[person])}
            for person in person_names
        ]

    @Lazy
    def administrators_count(self):
        """Number of persons with permissions on the L{AccessContext}."""
        return len(self.administrators)

    @Lazy
    def computers_count(self):
        """The number of L{Computer}s in the current L{AccessContext}."""
        return self.context.account.get_computers(
            access_context_ids=[self.context.id]
        ).count()

    @Lazy
    def computer_search_link(self):
        return get_access_context_computers_link(
            self.context.account, self.context, self.request
        )
