# Copyright 2005-2022 Canonical Limited. All rights reserved.


from canonical.content.form import Fields, action
from canonical.url import get_url

from canonical.landscape.service.accesscontext.create import CreateAccessContext
from canonical.landscape.service.accesscontext.errors import DuplicateAccessGroupError
from canonical.landscape.ui.form import LandscapeFormProvider, LongTextWidget
from canonical.landscape.model.main.interfaces import IAccessContext


class CreateAccessContextForm(LandscapeFormProvider):

    prefix = "access-group"

    fields = Fields(IAccessContext)
    fields = fields.omit("name")

    fields["title"].custom_widget = LongTextWidget

    dropdown_css_class = "dropdown-spacer-left"

    @action("Save", primary=True)
    def save(self, action, data):
        operation = CreateAccessContext(self.context.account, self.request.principal)
        try:
            access_context = operation(
                None, data["title"], parent=data.get("access_context")
            )
        except DuplicateAccessGroupError as error:
            self.add_error(str(error), "title")
        else:
            url = get_url(access_context, self.request)
            self.request.response.redirect(url)
