# Copyright 2005-2022 Canonical Limited. All rights reserved.

from zope.cachedescriptors.property import Lazy

from canonical.content.form import Fields, action
from canonical.url import get_url

from canonical.landscape.ui.account.page import AccountPage
from canonical.landscape.ui.form import LandscapeFormProvider, LongTextWidget
from canonical.landscape.model.main.interfaces import IAccessContext
from canonical.landscape.service.accesscontext.edit import EditAccessContext
from canonical.landscape.service.accesscontext.errors import (
    DuplicateAccessGroupError,
    InvalidAccessGroupError,
)


class EditAccessContextPage(AccountPage):
    """Access group edit view."""

    requires = "landscape.EditAccessContext"

    @Lazy
    def permission_context(self):
        # The Person must be a full administrator.
        return self.context.account


class EditAccessContextForm(LandscapeFormProvider):
    """Access group edit form."""

    summary = "Edit access group"

    description = "Change or delete this access group"

    @Lazy
    def fields(self):
        fields = Fields(IAccessContext).omit("access_context")
        fields["title"].custom_widget = LongTextWidget
        return fields

    def get_initial_data(self):
        return {"name": self.context.name, "title": self.context.description}

    @action("Save", primary=True)
    def save(self, action, data):
        operation = EditAccessContext(self.context, self.request.principal)
        try:
            operation(data["name"], data["title"])
        except DuplicateAccessGroupError as error:
            self.add_error(str(error), "name")
            return
        except InvalidAccessGroupError as error:
            self.add_error(str(error))
            return

        message = "Access group '%s' successfuly modified." % data["title"]
        self.view.notes.info(message)
        url = get_url(self.context, self.request)
        self.request.response.redirect(url)

    @action("Delete", condition=lambda form, _: not form.context.is_root)
    def remove(self, action, data):
        """
        Redirect to a confirmation form.
        """
        url = get_url(self.context, self.request) + "/confirm-remove"
        self.request.response.redirect(url)
