# Copyright 2005-2022 Canonical Limited. All rights reserved.

from zope.cachedescriptors.property import Lazy

from canonical.url import get_url
from canonical.content.form import action
from canonical.landscape.ui.account.page import AccountPage
from canonical.landscape.ui.form import LandscapeFormProvider
from canonical.landscape.service.accesscontext.remove import RemoveAccessContext
from canonical.landscape.service.accesscontext.errors import InvalidAccessGroupError


class RemoveAccessContextPage(AccountPage):
    """Confirmation page for removing access groups."""

    title = "Remove access group?"

    requires = "landscape.EditAccessContext"

    @Lazy
    def permission_context(self):
        # The Person must be a full administrator.
        return self.context.account


class RemoveAccessContextForm(LandscapeFormProvider):

    summary = "Remove access group?"

    @Lazy
    def description(self):
        return (
            "Are you sure you want to remove the '%s' access group?"
            % self.context.description
        )

    @action("Confirm")
    def remove(self, action, data):
        """Remove access group."""
        operation = RemoveAccessContext(self.context, self.request.principal)
        try:
            operation()
        except InvalidAccessGroupError as error:
            url = get_url(self.context, self.request)
            self.add_error(str(error))
        else:
            url = "%s/access-groups" % get_url(self.context.account, self.request)
        self.request.response.redirect(url)

    @action("Cancel", primary=True)
    def cancel(self, action, data):
        """Redirect to the access group page."""
        url = get_url(self.context, self.request)
        self.request.response.redirect(url)
