# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.browserpage import ViewPageTemplateFile

from canonical.landscape.ui.account.page import AccountPage
from canonical.landscape.ui.accesscontext.accesscontext import (
    get_access_context_computers_link,
)


def build_structure(context, request=None):
    """
    Return a simplified version of the access group hierarchy that can be
    consumed easily by a template.

    A simple hierarchy looks like this:

       [{"name": "global",
         "title": "Global access",
         "id": 1,
         "children": [{"name": "desktops",
                       "title": "Desktop machines",
                       "id": 2,
                       "children": []},
                      {"name": "servers",
                       "title": "Server machines",
                       "id": 3,
                       "children": []}
                       ]
        }]
    """
    # Use a list as a queue of nodes to visit in order build the result by
    # traversing the tree iteratively rather than recursively (Python like
    # Ouroboros has a tendency to eat it's own tail).
    structured = []
    nodes_to_visit = [(context.account.access_context, structured)]
    while len(nodes_to_visit) > 0:
        current_node, parent_list = nodes_to_visit.pop(0)
        computer_count = context.account.get_computers(
            access_context_ids=[current_node.id]
        ).count()
        current_dict = {
            "name": current_node.name,
            "title": current_node.description,
            "id": current_node.id,
            "computer_count": computer_count,
            "children": [],
        }
        if request is not None:
            computer_search_link = get_access_context_computers_link(
                context.account, current_node, request
            )
            current_dict.update({"computer_search_link": computer_search_link})
        parent_list.append(current_dict)
        for child in current_node.children:
            nodes_to_visit.append((child, current_dict["children"]))
    return structured


class AccessContextSummaryPage(AccountPage):
    """Summary listing page shows L{AccessContext}s in an L{Account}."""

    render_groups = ViewPageTemplateFile("render-groups.pt")

    def __init__(self, context, request):
        super(AccessContextSummaryPage, self).__init__(context, request)
        self.parent_access_context = self.context.account.access_context

    def access_context_structure(self):
        return build_structure(self.context, self.request)
