# Copyright 2005-2013 Canonical Limited.  All rights reserved.


from zope.security.management import checkPermission

from canonical.content.form import Fields, action
from canonical.url import get_url

from canonical.landscape.ui.account.page import AccountPage
from canonical.landscape.ui.form import LandscapeFormProvider
from canonical.landscape.model.main.interfaces import IAccount
from canonical.landscape.ui.salesforce.key import validate_salesforce_account_key


class EditAccountPage(AccountPage):

    title = "Account"


class EditAccountForm(LandscapeFormProvider):

    fields = Fields(IAccount, render_context=True)

    summary = "Account"
    description = "Please provide the following information."

    def validate(self, action, data):
        """Validate form data submitted by the user."""
        salesforce_account_key = data.get("salesforce_account_key")
        if (
            salesforce_account_key
            and not salesforce_account_key == self.context.salesforce_account_key
        ):
            validate_salesforce_account_key(
                self, "salesforce_account_key", salesforce_account_key
            )

    def update(self):
        """Select form fields on-the-fly, basing on the user's privileges."""
        field_names = []
        if checkPermission("landscape.EditAccount", self.context):
            field_names.append("title")
            field_names.append("registration_password")
        if checkPermission("landscape.EditMaxPeopleCount", self.context):
            field_names.append("max_people_count")
        if checkPermission("landscape.EditSalesforceKey", self.context):
            field_names.append("salesforce_account_key")
        if checkPermission("landscape.EditMaxAttachmentSize", self.context):
            field_names.append("max_attachment_size")
        self.fields = self.fields.select(*field_names)
        super(EditAccountForm, self).update()

    @action("Save", primary=True)
    def handle_save_action(self, action, data):
        account_changed = False
        requires_audit_log = False

        if self.fields.get("max_attachment_size"):
            if "max_attachment_size" in data:
                max_attachment_size = data.get("max_attachment_size")
                if (
                    max_attachment_size
                    and max_attachment_size != self.context.max_attachment_size
                ):
                    self.context.max_attachment_size = max_attachment_size
                    account_changed = True
                del data["max_attachment_size"]

        old_max_count = self.context.max_people_count

        changes_applied = self.apply_changes(self.context, data)
        requires_audit_log |= old_max_count != self.context.max_people_count

        if changes_applied or account_changed:
            self.view.notes.info("Account changed.")
        else:
            self.view.notes.info("No changes.")
        self.request.response.redirect(get_url(self.context, self.request))
