# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.url import get_url_object

from canonical.landscape.ui.sidebar.page import SidebarPage
from canonical.landscape.model.feature.flag import is_feature_enabled
from canonical.landscape.model.main.interfaces import IAccount
from canonical.landscape.model.license.management import LicenseManagement
from canonical.landscape.model.main.standalone import AccountLDSLicenseAPI


class AccountPage(SidebarPage):
    """A sidebar page for the account-level pages."""

    status = ""

    license_management = None

    def __init__(self, context, request):
        super(AccountPage, self).__init__(context, request)
        if self.account is not None:
            self.license_management = LicenseManagement(self.account)

    def has_lds_access(self):
        """Does this account have access to Landscape On Prem?"""
        account = get_url_object(self.context, self.request, IAccount)
        api = AccountLDSLicenseAPI(account)
        return api.has_valid_license()

    def is_self_service_account(self):
        """Is this account a self-service one?"""
        account = get_url_object(self.context, self.request, IAccount)
        return account.is_self_service and is_feature_enabled("self-service")
