# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from datetime import datetime
from pytz import timezone, UTC


def get_deliver_after_time(request):
    """Get the deliver-after-time from the request, if it's present.

    The date submitted to the form must be in C{YYYY-MM-DD HH:MM} format.  It
    is passed to the form as the C{deliver-after-time} value.  If present, the
    value is parsed and transformed into a C{datetime} before being returned.

    @return: A C{datetime} instance or C{None} if a time isn't present.
    """
    deliver_after_time = request.get("deliver-after-time")
    if isinstance(deliver_after_time, list):
        deliver_after_time = deliver_after_time[0]
    if deliver_after_time:
        creator = request.principal.person
        deliver_after_time = datetime.strptime(
            deliver_after_time.strip(), "%Y-%m-%d %H:%M"
        )
        local_delivery_time = timezone(creator.timezone).localize(deliver_after_time)
        return local_delivery_time.astimezone(UTC)
    return None


def get_deliver_delay_window(request):
    """Get the deliver-delay-window from the request, if it is present.

    The C{int} submitted to the form is a length in minutes over which
    activities will be randomly delayed before delivery.  It is passed to the
    form as the C{deliver-delay-window} value.  If present, the value is
    returned.

    @return: A C{int} instance or C{int(0)} if a number of minutes isn't
    present.
    """
    deliver_delay_window = request.get("deliver-delay-window")
    if deliver_delay_window:
        return int(deliver_delay_window)
    return 0
