# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.interface import Interface

from zope.schema import Password, TextLine

from canonical.landscape.model.main.schema import EmailAddress


class INewOpenIDPerson(Interface):

    name = TextLine(
        title="Name",
        description="The first and last name.",
        min_length=1,
        max_length=50,
        required=True,
        readonly=False,
    )

    email = EmailAddress(
        title="E-mail address",
        description="Personal e-mail address.",
        min_length=5,
        max_length=200,
        required=True,
        readonly=False,
    )

    invitation = TextLine(
        title="Invitation", description="Invitation ID.", required=False
    )


class INewLocalPerson(INewOpenIDPerson):
    """
    The INewLocalPerson subclasses INewOpenIDPerson because the OpenID
    interface is more general and the local person interface needs a
    few more attributes and an additional method.
    """

    password = Password(
        title="Passphrase",
        description="A secret passphrase.",
        min_length=3,
        max_length=50,
        required=True,
        readonly=False,
    )

    verified_password = Password(
        title="Verify passphrase",
        description="Verify the secret passphrase.",
        min_length=3,
        max_length=50,
        required=True,
        readonly=False,
    )


class INewPAMPerson(INewOpenIDPerson):
    """
    The INewPAMPerson subclasses INewOpenIDPerson because the OpenID
    interface is more general and the local PAM interface needs to get the
    identity, but doesn't require a password verification as we don't store it,
    we use it to authenticate against the local PAM environment.
    """

    identity = TextLine(
        title="Identity",
        description="Will be used to authenticate against the underlying "
        "PAM system.",
        min_length=1,
        max_length=50,
        required=True,
        readonly=False,
    )

    password = Password(
        title="Passphrase",
        description="Password for user identity in external system.",
        min_length=3,
        max_length=50,
        required=True,
        readonly=False,
    )
