# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.url import get_url, quote_url

from zope.security.management import checkPermission

from canonical.landscape.model.computer.search import UpgradeProfileCriteria

from canonical.landscape.ui.account.page import AccountPage
from canonical.landscape.ui.form import TagAssociationHelper
from canonical.landscape.ui.dateformat import get_tzoffset_string
from canonical.landscape.ui.autoupgrade.schedule import ViewSchedule


class UpgradeProfileDashboardPage(AccountPage, TagAssociationHelper):

    update_requires = "landscape.EditUpgradeProfile"

    def __init__(self, context, request):
        AccountPage.__init__(self, context, request)
        TagAssociationHelper.__init__(self, context, request)
        self.title = "Upgrade profile '%s'" % context.title

        url = get_url(self.context.account, self.request)
        criteria = UpgradeProfileCriteria(self.context.name, self.context.account)
        criteria_url = quote_url(criteria.to_string())
        self.search_url = "%s/computers/criteria/%s" % (url, criteria_url)

        self.can_edit = checkPermission("landscape.EditUpgradeProfile", context)
        self.computer_count = self.context.get_computer_count()
        self._initialize_summary()
        self.profile_timezone = self.context.timezone
        self.schedule = ViewSchedule(context, self.profile_timezone)
        self.access_group_text = context.access_context.title

        if self.computer_count:
            formatter = self.request.principal.person.formatter
            time_and_tz = get_tzoffset_string(self.profile_timezone)
            self.next_run_time = (
                formatter.format_date(self.context.next_run_time, localize=False)
                + " "
                + time_and_tz
            )
        else:
            self.next_run_time = "Never"
        if self.request.method == "POST":
            self.update("profile")

        self.deliver_delay_window = self.context.deliver_after_window

    def _initialize_summary(self):
        if self.computer_count == 1:
            summary = "1 computer is associated with this profile."
        elif self.computer_count > 1:
            summary = "%d computers are associated with this profile." % (
                self.computer_count
            )
        else:
            summary = "The profile is not associated to any computer."
        self.associated_summary = summary
