# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.cachedescriptors.property import Lazy

from canonical.url import get_url
from canonical.content.decorator import json

from canonical.landscape.ui.account.page import AccountPage


class UpgradeProfileListingPage(AccountPage):

    title = "Upgrade profiles"

    def __init__(self, context, request):
        super(UpgradeProfileListingPage, self).__init__(context, request)
        self.upgrade_profiles = list(self.context.get_upgrade_profiles())
        self.can_edit = self.context.person_can("EditUpgradeProfile")

    @Lazy
    @json
    def buttons(self):
        """Return a list of actionable form buttons."""
        buttons = []
        if self.can_edit:
            buttons.append("#remove_button")
        return buttons

    def remove(self):
        """
        Method is called by Zope's traversal machinery when a profile removal
        is requested.  This method should only be called when form data has
        been POST'd to update the selection.  It always performs a redirect.
        """
        selected_profiles = [
            profile
            for profile in self.upgrade_profiles
            if profile.id in self.request.form.get("profile_id", ())
        ]

        if selected_profiles:
            not_removed = self.context.remove_upgrade_profiles(selected_profiles)
            if not_removed:
                names = [profile.name for profile in not_removed]
                self.notes.warning(
                    "Unable to remove upgrade profiles: %s. Unauthorized"
                    % ",".join(names)
                )
        self.request.response.redirect(get_url(self.context, self.request))

    def get_enabled_for_text(self, profile):
        """
        Generate a message reporting the tags this profile is associated with,
        and hence the computers it is enabled for.
        """
        access_group_message = " in the <a href='%s'>%s</a> access group" % (
            get_url(profile.access_context, self.request),
            profile.access_context.title,
        )

        if profile.all_computers:
            message = "All computers"
        else:
            tags = sorted([tag.name for tag in profile.get_tags()])
            if not tags:
                message = "No computers"
            else:
                message = "Computers with %s %s" % (
                    ", ".join(tags),
                    "tag" if len(tags) == 1 else "tags",
                )
        return message + access_group_message

    def _get_computer_count_text(self, count):
        """Generate a message according to the given computer C{count}."""
        if count == 0:
            return None
        elif count == 1:
            return "1 Computer"
        else:
            return "%d Computers" % count
