# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import str
from zope.security.proxy import removeSecurityProxy

from canonical.content.decorator import json

from canonical.landscape.model.computer.collection import AccountComputerTwinCollection
from canonical.landscape.service.computer.remove import RemoveComputers
from canonical.landscape.service.collection.errors import UnknownEntityIDsError

from canonical.landscape.ui.page.page import ActionPage


class RemoveComputersActionPage(ActionPage):
    """Remove all computers in the context selection."""

    @json
    def __call__(self):
        page_key = self.request.form.pop("page_key", self.page_key)

        # Remove the proxy to access the store
        account = removeSecurityProxy(self.context.account)
        collection = AccountComputerTwinCollection(account.store, account=account)
        collection = collection.with_ids(self.context.get_computer_ids())
        operation = RemoveComputers(collection, self.request.principal)

        global_errors = []
        result = {"widget_errors": {}, "global_errors": global_errors}
        status = 200
        try:
            operation(uuid=page_key)
        except UnknownEntityIDsError as error:
            status = 400
            global_errors.append(str(error))
        self.request.response.setStatus(status)
        return result
