# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.routes import NonePage, route, Redirect
from canonical.url import get_url, get_context_url

from canonical.landscape.ui.routes import LandscapeRoutes
from canonical.landscape.ui.page.page import check_request_csrf_token
from canonical.landscape.service.computer.resynchronize import ResynchronizeComputers


class ComputerRoutes(LandscapeRoutes):
    def default_traverse(self, stack):
        """Transform the computer in a computer selection."""
        return get_context_url(self.context, self.request).parent

    def browserDefault(self, request):
        info_url = get_url(self.context, self.request) + "/info"
        self.request.response.redirect(info_url)
        return NonePage, ()

    @route("resynchronize")
    def resynchronize(self):
        """Start resynchronizing one or more C{Computer}s."""
        check_request_csrf_token(self.request, require_post=True)

        person = self.request.principal.person
        if person.has_global_role("Operator"):
            account = self.context.account
            operation = ResynchronizeComputers(account, self.request.principal)
            operation([self.context.id])
            self.notes.info("Data for this computer will be resynchronized.")
        info_url = get_url(self.context, self.request) + "/info"
        raise Redirect(info_url)
