# Copyright 2005-2022 Canonical Limited. All rights reserved.

from zope.security.interfaces import Unauthorized

from canonical.routes import Redirect
from canonical.url import get_url

from canonical.landscape.ui.page.page import LandscapePage


class DashboardPage(LandscapePage):

    title = "Dashboard"

    def __init__(self, context, request):
        super(DashboardPage, self).__init__(context, request)
        self.accounts = sorted(
            self.context.person.accounts, key=lambda x: x.name.lower()
        )

        # On LDS there is no need for the dashboard page if the person is a
        # member of the standalone account, as there is only one. Redirect to
        # the account page instead.
        if self.is_standalone() and len(self.accounts) == 1:
            raise Redirect(get_url(self.accounts[0], self.request))

    def get_active_rules(self, account):
        try:
            return list(
                account.get_rules(active=True, person=self.request.principal.person)
            )
        except Unauthorized:
            return ()
