# Copyright 2005-2014 Canonical Limited.  All rights reserved.

from future import standard_library

standard_library.install_aliases()
import csv
from io import StringIO

from canonical.content.download import set_csv_download
from canonical.landscape.ui.account.page import AccountPage
from canonical.landscape.service.eventlog.get import GetEventLogEntries
from canonical.landscape.ui.eventlog.listing import DOWNLOAD_DAYS


ENTRY_ATTRIBUTES = (
    "creation_time",
    "person_id",
    "person_name",
    "entity_type",
    "entity_id",
    "entity_name",
    "message",
)

HEADER = (
    "Creation Time",
    "Person ID",
    "Person Name",
    "Entity Type",
    "Entity ID",
    "Entity Name",
    "Message",
)


class AccountEventLogCSVPage(AccountPage):
    """Export L{EventLogEntry}s as CSV."""

    def __call__(self):
        """
        Given a number of C{days}, export the L{EventLogEntry}s as CSV.
        """
        operation = GetEventLogEntries(self.context.account, self.request.principal)
        result = operation(days=DOWNLOAD_DAYS)
        if not result:
            return

        rows = generate_csv_data(result)
        filename = "Event Log - %s" % self.context.account.name
        set_csv_download(self.request.response, filename)
        output = StringIO()
        writer = csv.writer(output)
        writer.writerows(rows)
        return output.getvalue()


def generate_csv_data(log):
    """Take a list of C{EventLogEntry}s and generate CSV data.

    @param log: A list of L{EventLogEntry}s to export to CSV.
    """
    yield HEADER
    for log_entry in log:
        row = []
        state = log_entry.get_state()
        for attribute in ENTRY_ATTRIBUTES:
            row.append(state[attribute])
        yield row
