# Copyright 2005-2014 Canonical Limited. All rights reserved.

from zope.cachedescriptors.property import Lazy

from canonical.batching.info import BatchingInfo

from canonical.landscape.ui.account.page import AccountPage
from canonical.landscape.service.eventlog.get import (
    GetEventLogEntries,
    GetEventLogEntriesCount,
)
from canonical.landscape.ui.pagination.provider import PaginationProvider


DOWNLOAD_DAYS = 90

ITEMS_PER_PAGE = 25


class EventLogEntriesListingPage(AccountPage):
    """
    A page that allows viewing and downloading the event log entries.
    """

    title = "Event Log"
    _batch_size = ITEMS_PER_PAGE

    @Lazy
    def batching_info(self):
        """
        Create the L{BatchingInfo} object to be used by the pagination
        machinery.
        """
        return BatchingInfo(
            self._total_items,
            position=self.request.get("page", 1),
            batch_size=self._batch_size,
        )

    @Lazy
    def log_entries(self):
        """Return a list containing states of the log entries."""
        operation = GetEventLogEntries(self.context.account, self.request.principal)
        offset = self.batching_info.first_item - 1
        return operation(days=DOWNLOAD_DAYS, limit=self._batch_size, offset=offset)

    @Lazy
    def has_items(self):
        """Check if there are items to render."""
        return self._total_items > 0

    @Lazy
    def _total_items(self):
        """
        Return the total number of available entries.
        """
        operation = GetEventLogEntriesCount(
            self.context.account, self.request.principal
        )
        return operation(days=DOWNLOAD_DAYS)


class EventLogListingPaginationProvider(PaginationProvider):
    def _get_url(self, page):
        return "?page=%d" % page
