# Copyright 2005-2013 Canonical Limited.  All rights reserved.


from builtins import object


class IconView(object):
    """View provides icon paths for context objects.

    Sub-classes must provide a C{get_path_and_title} method that
    returns a C{(image-path, image-title)} 2-tuple for the context.
    The C{image-path} must contain two C{%s} placeholders for X and Y
    dimensions, as in C{image-%sx%s.png}.

    Icon paths are accessible with C{context/@@icon/small} and
    C{context/@@icon/large} in templates.  The sub-class needs to be
    registered as the C{icon} view for the context object it provides
    icons for::

      <zope:view
          name='icon'
          for='sample.interfaces.ISample'
          factory='.icon.SampleIcon'
          type='*' />
    """

    def __init__(self, context, request):
        self.context = context
        self.request = request

    def small(self):
        """Returns a 16x16 pixel icon that represents the context."""
        path_and_title = self.get_path_and_title()
        if path_and_title:
            path = path_and_title[0] % (16, 16)
            return "/static/%s" % path
        return "/static/default-16x16.png"

    def large(self):
        """Returns a 32x32 pixel icon that represents the context."""
        path_and_title = self.get_path_and_title()
        if path_and_title:
            path = path_and_title[0] % (32, 32)
            return "/static/%s" % path
        return "/static/default-32x32.png"

    def get_path_and_title(self):
        """Return path and title to icon.

        By default return None, which means that the default icon will
        be used.
        """
        return None
