# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.browserpage import ViewPageTemplateFile
from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm

from canonical.content.form import Fields, action
from canonical.url import get_url

from canonical.landscape.ui.knowledge.page import KnowledgeBaseSidebarPage
from canonical.landscape.ui.form import (
    LandscapeFormProvider,
    LongTextWidget,
    MultiCheckBoxWidget,
)
from canonical.landscape.model.knowledge.interfaces import IArticle

from safe.canonical.landscape.model.knowledge.article import create_article
from safe.canonical.landscape.model.knowledge.category import get_categories


class CreateArticlePage(KnowledgeBaseSidebarPage):

    title = "Create article"


class CreateArticleForm(LandscapeFormProvider):

    summary = "Create article"

    fields = Fields(IArticle)

    fields["title"].custom_widget = LongTextWidget
    fields["categories"].custom_widget = MultiCheckBoxWidget

    additional_content = ViewPageTemplateFile("create-upload-fields.pt")

    attachments_error = ""

    def categories(self):
        return get_categories()

    def get_initial_data(self):
        return {"body": DEFAULT_BODY}

    @action("Save", primary=True)
    def save(self, action, data):
        article = create_article(
            data["title"], data["body"], data["published"], data["categories"]
        )

        attachment = self.request.form.get("form.new_attachment")
        if attachment:
            attachment_data = attachment.read()
            article.add_attachment(attachment.filename, attachment_data)

        self.view.notes.info("Article created.")
        self.request.response.redirect(get_url(article, self.request))


def get_kb_categories(context):
    vocabulary_terms = [
        SimpleTerm(category.id, title=category.title) for category in get_categories()
    ]
    return SimpleVocabulary(vocabulary_terms)


DEFAULT_BODY = """
## Title - Use clear, precise keywords, should not be part of the body of the
solution ##

= Section title =

## Choose categories, use unsupported if needed ##

## Start with context/issue this solves ##

## CLI/GUI - Provide alternative ##

== Sub section title ==

## Tilde - "~" needs to be repeated in WikiCreole ##
Example: Go to ~~/home/user/.gconf2

## Adding a package use Software Name, Package Name- Link to install method ##

Example:
This can be done by adding the Thunderbid OpenPGP plugin
(package: **thunderbird-enigmail**) to your system
([[https://landscape.canonical.com/kb/article/2353|See KB Article #2353]]).

## When making screenshots use a fresh VM for each step (with the default Human
theme) ##

## Recommendation - Use Shutter for screenshots ##

Example:
# this is instruction1\\{{attachment/screenshot.png|Image}}
# this is instruction2\\{{attachment/screenshot.png|Image}}
# this is instruction3\\{{attachment/screenshot.png|Image}}
# this is instruction4\\{{attachment/screenshot.png|Image}}

## Editing files as the super-user ##

Example:
Edit {{{/etc/fstab}}} as the super user
([[https://landscape.canonical.com/kb/article/2375|See KB Article #2375]]),
and add the following line:
{{{
line
}}}

## Include references: man, lp, docs ##
= Related Solutions =
* [[../0000|#0000 - Solution Name Here]] - Additional information goes here
(optional)

= External Links =
* [[http://bugs.launchpad.net/bugs/000000|Bug #000000 - Bug Title Here]] -
Additional information goes here (optional)

## Spell check your entry using US_EN ##

## Test the solution ##

## Unsupported Disclaimer - use when necessary ##
= Notes =

The information shared in this solution is unsupported by Canonical. We provide
this information as a courtesy to our support customers but cannot guarantee
any specific outcome.

Please note that adding any non-supported packages through third party
repositories or websites can result in a system on which Canonical can not
guarantee any level of support. This includes any packages downloaded through
any means than a package manager using the default archive.ubuntu.com
repositories for your release
([[https://landscape.canonical.com/kb/article/2544|See KB Article #2544]]).
"""
