# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.url import get_url

from canonical.landscape.model.knowledge.parser import create_wiki_parser
from canonical.landscape.ui.format import split
from canonical.landscape.ui.knowledge.page import KnowledgeBaseFilteredSidebarPage
from safe.canonical.landscape.model.knowledge.category import get_categories
from safe.canonical.landscape.model.knowledge.article import get_articles_by_category_id
from safe.canonical.landscape.model.knowledge.search import search_articles


class SearchPage(KnowledgeBaseFilteredSidebarPage):
    """
    Knowledge base dashboard provides search facility and category browser.
    """

    title = "Knowledge base"
    category_columns = 3

    def __init__(self, context, request):
        super(SearchPage, self).__init__(context, request)
        self.categories = list(get_categories())
        self.category_columns = split(self.categories, self.category_columns)


class SearchResultsPage(KnowledgeBaseFilteredSidebarPage):
    """Results page shows articles matching search terms."""

    title = "Search results"

    def __init__(self, context, request):
        super(SearchResultsPage, self).__init__(context, request)
        self.search_terms = self.request.get("search-terms")
        if not self.search_terms:
            self.notes.error("Please provide search terms.")
            self.request.response.redirect(get_url(self.context, self.request))

    def get_search_results(self):
        """Find ranked articles matching search terms."""
        parser = create_wiki_parser(format="text")
        result = []
        for article, rank, excerpt in search_articles(self.search_terms):
            result.append(
                {"article": article, "excerpt": parser(excerpt).decode("utf-8")}
            )
        return result


class CategoryPage(KnowledgeBaseFilteredSidebarPage):
    """Results page shows articles matching a category."""

    search_terms = ""
    title = "Knowledge base category"

    def get_search_results(self):
        result = []
        for article in get_articles_by_category_id(self.context.id):
            result.append({"article": article, "excerpt": ""})
        return result
