# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.url import TALESContextURL
from canonical.routes.publisher import get_route_object

from canonical.landscape.model.knowledge.search import KnowledgeBase
from canonical.landscape.ui.knowledge.routes import AccountKnowledgeBase


class KnowledgeBaseContextURL(TALESContextURL):
    @property
    def parent(self):
        """
        If current url is inside an account, return the current
        account wrapped in a L{AccountKnowledgeBase} as
        parent. Otherwise return a raw L{KnowledgeBase}.

        This allows the knowledge base to be accessed directly from
        the root as well as account-relative.
        """
        account_routes = get_route_object(AccountKnowledgeBase, self.request)
        if account_routes:
            return account_routes
        return get_route_object(KnowledgeBase, self.request)


class CategoryContextURL(KnowledgeBaseContextURL):

    path_expr = "string:category/${context/id}"


class ArticleContextURL(KnowledgeBaseContextURL):

    path_expr = "string:article/${context/id}"


class WikiRulesContextURL(KnowledgeBaseContextURL):

    path_expr = "string:wiki-rules"
