# Copyright 2005-2022 Canonical Limited. All rights reserved.

from zope.security.interfaces import Unauthorized
from zope.cachedescriptors.property import Lazy

from canonical.navigation import Navigation
from canonical.url import get_url

from canonical.landscape.model.alert.rule import Rule
from canonical.landscape.ui.account.routes import get_current_account
from canonical.landscape.ui.menu.account import AccountNavigationItem


class NotificationsNavigation(Navigation):

    name = "notifications"
    split = True
    button = False
    account = None

    def __init__(self, context, request):
        super(NotificationsNavigation, self).__init__(context, request)
        self.account = get_current_account(self.request)

    def get_items(self):
        """
        Like L{Navigation.get_items}, but only return items if there's a
        current account.
        """
        if self.account is not None:
            return super(NotificationsNavigation, self).get_items()
        return []


class AlertsItem(AccountNavigationItem):

    PERMISSIONS = "landscape.QueryAlertRule"

    name = "account-global-alerts"
    order = 10
    account = None

    def __init__(self, context, request, parent=None):
        super(AlertsItem, self).__init__(context, request, parent)
        if parent is not None:
            self.account = parent.account

    @Lazy
    def title(self):
        person = self.request.principal.person
        try:
            result = self.parent.account.get_rules(active=True, person=person)
            count = result.count(Rule.id, True)
        except Unauthorized:
            # is_available will hide this item, but we need to have a valid
            # title anyway
            count = 0
        return str(count)

    @property
    def action(self):
        return "#account-global-alerts-menu"

    def is_selected(self):
        """
        L{AlertsItem} is never selected since we want the L{AccountItem} to be
        selected instead.
        """
        return False


class AlertsConfigurationItem(AccountNavigationItem):

    PERMISSIONS = "landscape.SubscribeAlert"

    name = "account-global-alerts-configuration"
    title = "Configure alerts"

    def __init__(self, context, request, parent=None):
        super(AlertsConfigurationItem, self).__init__(context, request, parent)
        if parent is not None:
            self.account = parent.account

    @property
    def action(self):
        return "%s/alerts" % get_url(self.account, self.request)

    def is_selected(self):
        """L{AlertsConfigurationItem} is never selected."""
        return False
