# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.security.proxy import removeSecurityProxy

from canonical.url import get_url

from canonical.landscape.ui.toolbar.page import ToolbarPage


class ReleaseUpgradePage(ToolbarPage):

    title = "Release upgrade"

    def __init__(self, context, request):
        super(ReleaseUpgradePage, self).__init__(context, request)
        self.release_upgrades = []
        self.release_upgrades_index = {}
        index = removeSecurityProxy(self.context.get_release_upgrade_computers_index())
        for (upgrade_from, upgrade_to), computer_ids in index.items():
            key = "%d-%d" % (upgrade_from.id, upgrade_to.id)
            count = len(computer_ids)
            if count == 1:
                count = "%d computer" % count
            else:
                count = "%d computers" % count
            upgrade_info = {
                "key": key,
                "from": upgrade_from,
                "to": upgrade_to,
                "count": count,
                "computer_ids": computer_ids,
            }
            self.release_upgrades_index[key] = upgrade_info
            self.release_upgrades.append(upgrade_info)
        self.release_upgrades.sort(
            key=lambda info: (info["from"].date, info["to"].date)
        )

    def apply_changes(self):
        """
        Create the activities for the requested release upgrades.
        """
        self._check_request_csrf_token(require_post=True)

        upgrade_meta_releases = self.request.get("upgrade_meta_release", [])
        computer_ids = set()
        if upgrade_meta_releases:
            for meta_release_key in upgrade_meta_releases:
                upgrade_info = self.release_upgrades_index[meta_release_key]
                computer_ids.update(upgrade_info["computer_ids"])
        if computer_ids:
            parent = self.context.request_release_upgrade(
                self.request.principal.person, computer_ids
            )
            self.request.response.redirect(get_url(parent, self.request))
        else:
            self.notes.warning("No release upgrade requested")
            self.request.response.redirect(get_url(self.context, self.request))
