# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.cachedescriptors.property import Lazy

from canonical.url import get_url

from canonical.landscape.ui.toolbar.page import ToolbarPage
from canonical.landscape.ui.dateformat import format

from canonical.landscape.model.resource.package import PackageReporterResultAPI


class DisplayReporterErrorsPage(ToolbarPage):
    title = "Package reporting issues"

    @Lazy
    def reporter_count(self):
        """
        Return the number of computers that reported data at all.
        """
        api = PackageReporterResultAPI(self.context.selection.account)
        computer_ids = self.context.selection.get_selected_computer_ids()
        return api.get_package_reporter_result_count(computer_ids)

    @Lazy
    def reporter_errors(self):
        """
        Return a list of (computer, code, error) for the current selection.
        """
        account = self.context.selection.account
        api = PackageReporterResultAPI(account)
        data = api.get_package_reporter_errors(
            self.context.selection.get_selected_computer_ids()
        )
        computer_ids = [d[0] for d in data]
        computer_by_ids = dict(
            (computer.id, computer)
            for computer in account.get_computers(computer_ids=computer_ids)
        )
        result = []
        for computer_id, code, err, timestamp in data:
            computer = computer_by_ids[computer_id]

            formatted_timestamp = ""
            if timestamp is not None:
                formatted_timestamp = format(timestamp, self.request)
            result.append(
                {
                    "computer": computer,
                    "code": code,
                    "err": err,
                    "timestamp": formatted_timestamp,
                    "computer_url": get_url(computer, self.request),
                }
            )
        result.sort(key=lambda obj: obj["computer"].title)
        return result
