# Copyright 2005-2013 Canonical Limited.  All rights reserved.

import os
from base64 import b64encode

from zope.viewlet.viewlet import ViewletBase
from zope.cachedescriptors.property import Lazy

from z3c.pt.pagetemplate import ViewPageTemplateFile

from canonical.landscape.ui.constants import STATIC_DIR


class ExternalLinksCSSViewlet(ViewletBase):
    """Provide CSS rules for external links.

    We need to generate these CSS rules dynamically because they
    require accessing the application's root URL, which is stored in
    the database in case of LDS.
    """

    template = ViewPageTemplateFile("external-links-css.pt")

    def render(self):
        return self.template()

    @Lazy
    def icons(self):
        colors = ("white", "orange", "aubergine")
        return {color: _encode_external_link_icon(color) for color in colors}


def _encode_external_link_icon(color):
    filename = "external-link-%s.png" % color
    with open(os.path.join(STATIC_DIR, filename), "rb") as fd:
        return b64encode(fd.read())
