# Copyright 2005-2013 Canonical Limited.  All rights reserved.

import json

from zope.cachedescriptors.property import Lazy

from zope.viewlet.viewlet import ViewletBase
from z3c.pt.pagetemplate import ViewPageTemplateFile

from canonical.landscape.ui.urlformat import get_debug
from canonical.landscape.model.feature.flag import get_feature_flags


class ScriptsViewlet(ViewletBase):

    template = ViewPageTemplateFile("scripts.pt")

    def render(self):
        return self.template()

    @Lazy
    def debug_yui(self):
        """Whether to enable YUI debugging."""
        return get_debug("yui")

    @Lazy
    def js_debug_log(self):
        """JavaScript-friendly value for enabling debug logs."""
        return "true" if get_debug("log") else "false"

    @Lazy
    def js_debug_js(self):
        """JavaScript-friendly value for debug."""
        return "true" if get_debug("js") else "false"

    @Lazy
    def js_debug_yui(self):
        """JavaScript-friendly value for YUI debug."""
        return "true" if self.debug_yui else "false"

    @Lazy
    def js_feature_flags(self):
        """Render a JSON object containing all feature flags."""
        flags = {flag["name"]: flag["enabled"] for flag in get_feature_flags()}
        return json.dumps(flags)
