# Copyright 2005-2014 Canonical Limited. All rights reserved.
from zope.cachedescriptors.property import Lazy

from canonical.content.provider import TemplateContentProvider


class PaginationProvider(TemplateContentProvider):
    """Render pagination controls for a certain pagination batch.

    It expects C{view.batching_info} to be an instance of L{BatchingInfo}
    holding pagination infromation.
    """

    template_filename = "provider.pt"

    @Lazy
    def has_next_page(self):
        """Whether there is another page beyond the current one."""
        return not self.view.batching_info.at_last_batch()

    @Lazy
    def has_previous_page(self):
        """Whether there's another page before the current one."""
        return not self.view.batching_info.at_first_batch()

    @Lazy
    def first_url(self):
        """Returns the URL to navigate to the first page."""
        return self._get_url(1)

    @Lazy
    def last_url(self):
        """Returns the URL to navigate to the last page."""
        return self._get_url(self.view.batching_info.total_batches)

    @Lazy
    def previous_url(self):
        """Returns the URL to navigate to the previous page."""
        return self._get_url(self.view.batching_info.position - 1)

    @Lazy
    def next_url(self):
        """Returns the URL to navigate to the next page."""
        return self._get_url(self.view.batching_info.position + 1)

    @Lazy
    def current_page(self):
        """Return the index of the current page."""
        return self.view.batching_info.position

    @Lazy
    def first_item(self):
        """Return the index of the first item."""
        return self.view.batching_info.first_item

    @Lazy
    def last_item(self):
        """Return the index of the last item."""
        return self.view.batching_info.last_item

    @Lazy
    def total_items(self):
        """Return the total number of items being paginated."""
        return self.view.batching_info.total_items

    def _get_url(self, page):
        """Return the URL for the given page.

        @param page: The index of the page to return the URL for.
        """
        raise NotImplementedError("Must be implemented by sub-classes")
