# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.schema import Choice
from zope.security.interfaces import Unauthorized

from canonical.url import get_url

from canonical.landscape.ui.account.page import AccountPage
from canonical.landscape.ui.form import LandscapeFormProvider

from canonical.landscape.model.computer.interfaces import IRemovalProfile
from canonical.content.form import Fields, action
from canonical.landscape.model.main.person import PersonAccessContextsVocabularyFactory


class CreateRemovalProfilePage(AccountPage):

    title = "Create an removal profile"

    def __init__(self, context, request):
        AccountPage.__init__(self, context, request)
        if not self.context.person_can("EditRemovalProfile"):
            raise Unauthorized()


class CreateRemovalProfileForm(LandscapeFormProvider):

    summary = "Create a removal profile"

    fields = Fields(IRemovalProfile)

    dropdown_css_class = "dropdown-spacer-removal"

    def __init__(self, context, request, view):
        super(CreateRemovalProfileForm, self).__init__(context, request, view)
        access_context = Choice(
            __name__="access_context",
            title="Access group",
            source=PersonAccessContextsVocabularyFactory("EditRemovalProfile"),
            default="Global",
            description="The access group the profile should belong to.",
            required=True,
        )
        self.fields += Fields(access_context)

    def get_initial_data(self):
        return {"access_context": self.context.account.access_context.name}

    def validate(self, action, data):
        days_without_exchange = int(data.get("days_without_exchange", 0))
        if days_without_exchange <= 0:
            self.add_error(
                "Days without exchange must be a number greater than or equal "
                "to 1. ",
                "days_without_exchange",
            )

    @action("Save", primary=True)
    def save(self, action, data):
        title = data["title"]
        days_without_exchange = data["days_without_exchange"]

        profile = self.context.create_removal_profile(
            title, days_without_exchange, access_context_name=data["access_context"]
        )

        self.request.response.redirect(get_url(profile, self.request))
