# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from canonical.url import get_url, quote_url

from zope.cachedescriptors.property import Lazy
from zope.security.management import checkPermission

from canonical.landscape.ui.account.page import AccountPage
from canonical.landscape.ui.form import TagAssociationHelper

from canonical.landscape.model.computer.search import RemovalProfileCriteria


class RemovalProfileDashboardPage(AccountPage, TagAssociationHelper):

    update_requires = "landscape.EditRemovalProfile"

    def __init__(self, context, request):
        AccountPage.__init__(self, context, request)
        TagAssociationHelper.__init__(self, context, request)
        if self.request.method == "POST":
            self.update("profile")

    @Lazy
    def title(self):
        """Return the title for this L{RemovalProfileDashboardPage}"""
        return "Removal profile '%s'" % self.context.title

    @Lazy
    def can_edit(self):
        """Return whether the person has permission to edit this profile"""
        return checkPermission("landscape.EditRemovalProfile", self.context)

    @Lazy
    def access_group_text(self):
        """Return the title for this L{RemovalProfileDashboardPage}"""
        return self.context.access_context.title

    @Lazy
    def days_text(self):
        """Return human-readable days_text for display"""
        days_text = "%d day" % self.context.days_without_exchange
        if self.context.days_without_exchange > 1:
            days_text += "s"
        return days_text

    @Lazy
    def search_url(self):
        """
        Return url pointing at the search criteria for this L{RemovalProfile}
        """
        url = get_url(self.context.account, self.request)
        criteria = RemovalProfileCriteria(self.context.name, self.context.account)
        criteria_url = quote_url(criteria.to_string())
        return "%s/computers/criteria/%s" % (url, criteria_url)

    @Lazy
    def summary(self):
        """Return a summary of the number of associated computers"""
        computer_count = self.context.get_computer_count()
        if computer_count == 1:
            summary = "1 computer is associated with this profile."
        elif computer_count > 1:
            summary = "%d computers are associated with this profile." % (
                computer_count
            )
        else:
            summary = "The profile is not associated to any computer."
        return summary
