# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.schema import TextLine
from zope.cachedescriptors.property import Lazy

from canonical.content.form import Fields, action
from canonical.url import get_url

from canonical.landscape.model.computer.removal import RemovalProfileManagement
from canonical.landscape.model.computer.interfaces import IRemovalProfile

from canonical.landscape.ui.account.page import AccountPage
from canonical.landscape.ui.form import LandscapeFormProvider


class EditRemovalProfilePage(AccountPage):

    title = "Edit removal profile"

    requires = "landscape.EditRemovalProfile"


class EditRemovalProfileForm(LandscapeFormProvider):

    prefix = "removal-profile"

    def __init__(self, context, request, view):
        super(EditRemovalProfileForm, self).__init__(context, request, view)
        self.person = self.request.principal.person

    @Lazy
    def fields(self):
        fields = Fields(IRemovalProfile, render_context=True)
        fields += Fields(
            TextLine(
                __name__="access_context",
                title="Access group",
                readonly=True,
                default=self.context.access_context.title,
            )
        )
        fields += Fields(
            TextLine(
                __name__="name",
                title="Name (generated at creation)",
                readonly=True,
                default=self.context.name,
            )
        )
        return fields

    @Lazy
    def summary(self):
        """Return a summary of the number of associated computers"""
        return "Edit removal profile '%s'" % self.context.name

    @action("Save", primary=True)
    def save(self, action, data):
        management = RemovalProfileManagement(self.context.account, person=self.person)
        days_without_exchange = int(data.get("days_without_exchange", 0))
        management.edit_removal_profile(
            self.context.name, data.get("title"), days_without_exchange
        )
        self.request.response.redirect(get_url(self.context, self.request))
