# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.cachedescriptors.property import Lazy
from zope.browserpage import ViewPageTemplateFile

from canonical.content.form import Fields, action
from canonical.url import get_url

from canonical.landscape.ui.role.create import RolePage
from canonical.landscape.ui.form import LandscapeFormProvider, MultiCheckBoxWidget
from canonical.landscape.ui.role.interfaces import IRoleForm
from canonical.landscape.model.access.errors import DuplicateRoleError
from canonical.landscape.ui.accesscontext.summary import build_structure
from canonical.landscape.model.access.management import AccessControlManagement
from canonical.landscape.model.access.permissions import ACCOUNT_MACRO_PERMISSIONS


class CopyRolePage(RolePage):

    title = "Copy role"

    @Lazy
    def is_stored(self):
        permissions = {permission: False for permission in ACCOUNT_MACRO_PERMISSIONS}
        for permission in self.context.get_account_permissions():
            permissions[permission] = True
        return permissions


class CopyRoleForm(LandscapeFormProvider):

    prefix = "role"
    summary = "Copy role"

    render_groups = ViewPageTemplateFile("render-groups.pt")

    def __init__(self, context, request, view):
        super(CopyRoleForm, self).__init__(context, request, view)
        self.person = request.principal.person

    @Lazy
    def access_groups(self):
        return build_structure(self.context)

    @Lazy
    def role_access_groups(self):
        return [
            access_context.name for access_context in self.context.get_access_contexts()
        ]

    @Lazy
    def fields(self):
        fields = Fields(IRoleForm)
        fields["permissions"].custom_widget = MultiCheckBoxWidget
        return fields

    def get_initial_data(self):
        return {
            "name": self.context.name,
            "permissions": self.context.get_permissions(),
            "account_permissions": self.context.get_account_permissions(),
        }

    @action("Save", primary=True)
    def save(self, action, data):
        management = AccessControlManagement(self.context.account, self.person)

        access_contexts = data.get("access_contexts", [])
        context_permissions = data.get("permissions", set())
        account_permissions = data.get("account_permissions", set())
        permissions = context_permissions.union(account_permissions)

        try:
            role = management.create_role(
                data["name"], permissions=permissions, access_contexts=access_contexts
            )
        except DuplicateRoleError:
            self.add_error("Role name already taken.", "name")
            return

        message = "Role '%s' successfully created." % role.name
        url = get_url(self.context, self.request)

        url = "/".join(url.split("/")[:-2] + ["roles"])

        self.view.notes.info(message)
        self.request.response.redirect(url)
