# Copyright 2005-2013 Canonical Limited.  All rights reserved.
from zope.cachedescriptors.property import Lazy
from zope.browserpage import ViewPageTemplateFile


from canonical.url import get_url
from canonical.content.form import Fields, action

from canonical.landscape.ui.account.page import AccountPage
from canonical.landscape.ui.form import LandscapeFormProvider, MultiCheckBoxWidget
from canonical.landscape.ui.role.interfaces import IRoleForm
from canonical.landscape.ui.accesscontext.summary import build_structure
from canonical.landscape.model.access.permissions import ACCOUNT_MACRO_PERMISSIONS


class RolePage(AccountPage):

    can_copy = False

    @Lazy
    def account_permissions(self):
        return ACCOUNT_MACRO_PERMISSIONS

    @Lazy
    def is_stored(self):
        return {permission: False for permission in ACCOUNT_MACRO_PERMISSIONS}


class CreateRolePage(RolePage):

    title = "Create new role"


class CreateRoleForm(LandscapeFormProvider):

    prefix = "role"
    summary = "Create new role"

    render_groups = ViewPageTemplateFile("render-groups.pt")

    @Lazy
    def access_groups(self):
        return build_structure(self.context)

    @Lazy
    def fields(self):
        fields = Fields(IRoleForm)
        fields["permissions"].custom_widget = MultiCheckBoxWidget
        fields["account_permissions"].custom_widget = MultiCheckBoxWidget
        return fields

    @action("Save", primary=True)
    def save(self, actions, data):
        name = data["name"]
        if self.context.get_roles(names=[name]):
            self.add_error("Role name already taken.", "name")
            return

        # Since the access context is not a real widget, it does not get
        # handled by formlib, thus the check.
        access_contexts = data.get("access_contexts")
        context_permissions = data.get("permissions", set())
        account_permissions = data.get("account_permissions", set())
        permissions = context_permissions.union(account_permissions)

        role = self.context.create_role(
            name, permissions=permissions, access_contexts=access_contexts
        )

        message = "Role '%s' successfully created." % role.name
        url = get_url(self.context, self.request)

        self.view.notes.info(message)
        self.request.response.redirect(url)
