# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.interface import Interface
from zope.schema import TextLine, Set, Choice

from canonical.lib.validators import validator

from canonical.landscape.model.access.role import is_valid_role_name


class IRoleForm(Interface):

    name = TextLine(
        title="Role name",
        description=(
            "Role names must start with a letter and can "
            "contain alphanumeric characters, '-' and '+'."
        ),
        constraint=validator(is_valid_role_name, "Invalid name format."),
        required=True,
    )

    permissions = Set(
        title="Permissions",
        description=("These permissions only apply to selected access groups"),
        value_type=Choice(vocabulary="macro_permissions"),
        required=False,
    )

    account_permissions = Set(
        title="Global Permissions",
        description=(
            "These permissions are for managing the account as a"
            " whole. They are not limited to the specified access"
            " groups, but instead apply globally."
        ),
        value_type=Choice(vocabulary="account_macro_permissions"),
        required=False,
    )

    access_contexts = Set(
        title="Access groups",
        value_type=Choice(vocabulary="access_contexts"),
        required=False,
    )
