from __future__ import division

# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from past.utils import old_div
from collections import defaultdict

from zope.cachedescriptors.property import Lazy

from canonical.url import get_url

from canonical.landscape.ui.account.page import AccountPage


class RoleSummaryPage(AccountPage):
    """Summary page for account roles"""

    def __init__(self, context, request):
        super(RoleSummaryPage, self).__init__(context, request)
        self.can_edit = self.context.person_can("EditRole")

    @Lazy
    def roles(self):
        """Return available roles in the account."""
        return self.context.get_roles()

    @Lazy
    def memberships(self):
        """Return membership information."""
        return self.context.get_memberships(self.roles)

    @Lazy
    def width(self):
        """Width of the matrix cells."""
        # XXX use a fixed width once we support pagination in the matrix
        return old_div(80, len(self.roles))

    def save(self):
        """Update the stored role associations according to the posted form."""
        self._check_request_csrf_token()
        url = get_url(self.context, self.request)
        changes = defaultdict(lambda: defaultdict(list))

        for value in self.request.form.get("membership", ""):
            [email, role_name, flag] = value.split(":")
            changes[role_name][flag].append(email)

        if len(changes["GlobalAdmin"]["on"]) == 0:
            self.notes.error(
                "The account must have at least one person with" " the GlobalAdmin role"
            )
            self.request.response.redirect(url)
            return

        for role_name in list(changes.keys()):
            self.context.edit_membership(
                role_name, changes[role_name]["on"], changes[role_name]["off"]
            )

        self.notes.info("Role membership successfully updated")
        self.request.response.redirect(url)
