# Copyright 2005-2022 Canonical Limited. All rights reserved.

import os
import tarfile
from io import BytesIO

from zope.publisher.browser import BrowserView

from canonical.content.download import set_gzipped_tar_download

from canonical.landscape.constants import LANDSCAPE_DIR

API_CLIENT_DIR = os.path.join(LANDSCAPE_DIR, "api", "client")


class APIClientView(BrowserView):
    """Return a tarball with the code of the Landscape API Python client."""

    def __call__(self):
        def is_pyc(tarinfo):
            if tarinfo.name.endswith(".pyc"):
                return None

            return tarinfo

        set_gzipped_tar_download(
            self.request.response, "landscape-api.tar.gz", timestamped=False
        )
        data = BytesIO()
        archive = tarfile.open(mode="w:gz", fileobj=data)
        archive.add(API_CLIENT_DIR, arcname="landscape_api", filter=is_pyc)
        archive.close()
        return data.getvalue()
