# Copyright 2005-2022 Canonical Limited. All rights reserved.

import os
import tarfile

from io import BytesIO

from zope.publisher.browser import BrowserView

from canonical.content.download import set_gzipped_tar_download

from canonical.landscape.constants import ROOT_DIR

PAGE_OBJECTS_DIR = os.path.join(ROOT_DIR, "tests", "helpers", "pages")


class PageObjectsView(BrowserView):
    """Return a tarball of available page objects."""

    def __call__(self):
        def is_pyc(tarinfo):
            if tarinfo.name.endswith(".pyc"):
                return None

            return tarinfo

        set_gzipped_tar_download(
            self.request.response, "page-objects.tar.gz", timestamped=False
        )
        data = BytesIO()
        archive = tarfile.open(mode="w:gz", fileobj=data)
        archive.add(PAGE_OBJECTS_DIR, arcname="pages", filter=is_pyc)
        archive.close()
        return data.getvalue()
