# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.cachedescriptors.property import Lazy

from canonical.landscape.ui.page.page import LandscapePage


class ScriptIssuesPage(LandscapePage):
    """View details about Landscape scripts with issues."""

    title = "Landscape scripts issues"

    @Lazy
    def executions(self):
        data = []
        for execution in self.context.get_executions(only_errored=True):
            if execution.exceeded_interval and not execution.ran:
                # The script has never run
                start_time, end_time = None, None
            else:
                start_time = execution.start_time
                end_time = execution.end_time

            data.append(
                {
                    "name": execution.name,
                    "start_time": self._get_time(start_time),
                    "end_time": self._get_time(end_time),
                    "status": self._get_status(execution),
                }
            )
        return data

    def _get_time(self, time):
        if not time:
            return "-"
        return self.request.principal.person.formatter.format_date(time)

    def _get_status(self, execution):
        if execution.exceeded_timeout:
            message = "Running for more than "
            if execution.run_timeout == 1:
                message += "1 minute"
            else:
                message += "%d minutes" % execution.run_timeout
            return message

        elif execution.exceeded_interval:
            if not execution.ran:
                return "Not run"

            message = "Not run in last "
            if execution.run_interval == 1:
                message += "minute"
            else:
                message += "%d minutes" % execution.run_interval
            return message

        elif not execution.success:
            return "Failed"
