# Copyright 2005-2013 Canonical Limited.  All rights reserved.

import posixpath

from zope.cachedescriptors.property import Lazy
from zope.publisher.interfaces import NotFound as ZopeNotFound
from zope.security.interfaces import Unauthorized

from canonical.landscape.security.interfaces import IAnonymousPrincipal
from canonical.landscape.security.roles import is_support
from canonical.notes.session import SessionNotes
from canonical.routes import RoutesPublisher, Redirect
from canonical.security.status import is_context_disabled
from canonical.url import get_url

from canonical.landscape.ui.service import service_lookup


def check_disabled(routes):
    """Redirect to <context>/disabled if the context is disabled."""
    if routes.request.get("PATH_INFO", "").endswith("/disabled"):
        return
    if is_context_disabled(routes):
        contexturl = get_url(routes.context, routes.request)
        raise Redirect(posixpath.join(contexturl, "disabled"))


class LandscapeRoutes(RoutesPublisher):
    """A routes publisher for Landscape."""

    CHECK_ANONYMOUS = False

    def __init__(self, context, request):
        super(LandscapeRoutes, self).__init__(context, request)
        if self.CHECK_ANONYMOUS:
            if IAnonymousPrincipal.providedBy(self.request.principal):
                raise Unauthorized()
        if not is_support(self.request):
            check_disabled(self)

    @Lazy
    def notes(self):
        """
        An L{INoteContainer} instance that can be used to generate
        user messages.
        """
        return SessionNotes(self.request)

    def _service_lookup(self, lookup_class, *args, **kwargs):
        """Convenience for performing service layer lookups.

        @see canonical.landscape.ui.service.lookup_entity
        """
        try:
            return service_lookup(self.request, lookup_class, *args, **kwargs)
        except ZopeNotFound:
            # We return None here, the routes machinery will eventually
            # take care of raising an appropriate NotFound.
            return
