from builtins import str
from zope.cachedescriptors.property import Lazy
from zope.publisher.browser import BrowserPage
from zope.security.proxy import removeSecurityProxy

from canonical.content.decorator import json

from canonical.landscape.model.activity.parent import get_parent_activity
from canonical.landscape.ui.sandbox.page import SandboxPage
from canonical.landscape.service.sandbox.activities import (
    CreateSmallActivity,
    CreateBigActivity,
)


class ActivitiesPage(SandboxPage):
    """Sandbox page exemplifying several activity system features.

    The following sections are available::

      - Small parent activity: shows how to create a parent activity with a
        small number of children and update its status/progress.

      - Big parent activity: shows how to create a parent activity with a
        large number of children and update its status/progress.

    See also L{canonical.landscape.service.sandbox}.
    """

    title = "Activities sandbox"

    @Lazy
    def small_activity(self):
        operation = CreateSmallActivity(self.context, self.request.principal)
        activity = operation()
        self.namespaces.append(activity.namespace)
        return activity

    @Lazy
    def small_activity_children(self):
        return self.small_activity.children()

    @Lazy
    def big_activity(self):
        operation = CreateBigActivity(self.context, self.request.principal)
        activity = operation()
        self.namespaces.append(activity.namespace)
        return activity

    @Lazy
    def big_activity_children(self):
        return self.big_activity.children(limit=10)


class ActivitiesAjax(BrowserPage):
    @json
    def __call__(self):
        activity_id = int(self.request["id"])
        activity = get_parent_activity(
            removeSecurityProxy(self.context.account()), activity_id
        )
        children = activity.children(limit=10)
        return [
            {
                "progress": activity.progress,
                "children": [
                    {"id": child.id, "status": str(child.status)} for child in children
                ],
            }
        ]
