# Copyright 2005-2014 Canonical Limited. All rights reserved.

from builtins import range
from zope.cachedescriptors.property import Lazy

from canonical.batching.info import BatchingInfo

from canonical.landscape.ui.sandbox.page import SandboxPage
from canonical.landscape.ui.pagination.provider import PaginationProvider


class PaginationPage(SandboxPage):
    """This page demonstrates how to setup pagination for arbitrary pages."""

    _batch_size = 5

    @Lazy
    def batching_info(self):
        return BatchingInfo(
            self._total_items,
            position=int(self.request.get("page", 1)),
            batch_size=self._batch_size,
        )

    @Lazy
    def items(self):
        """Generate simple data to be used in the template."""
        offset = self.batching_info.first_item
        size = self.batching_info.last_item - self.batching_info.first_item + 1
        result = []
        for i in range(size):
            identifier = i + offset
            result.append({"id": identifier, "name": "Some name %s" % identifier})
        return result

    @Lazy
    def _total_items(self):
        """Return the total number of available entries."""
        return 18


class SandBoxPaginationProvider(PaginationProvider):
    def _get_url(self, page):
        return "?page=%d" % page
