# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.browserpage import ViewPageTemplateFile

from canonical.content.form import action
from canonical.url.url import get_url

from canonical.landscape.ui.account.page import AccountPage
from canonical.landscape.ui.form import LandscapeFormProvider
from canonical.landscape.ui.selection.savedsearch import SavedSearchForm


class SavedSearchListingPage(AccountPage):
    """List and manage saved searches."""

    def __init__(self, context, request):
        super(SavedSearchListingPage, self).__init__(context, request)
        self.saved_searches = list(context.get_saved_searches())


class SavedSearchListingForm(LandscapeFormProvider):

    summary = "Saved searches"
    description = "Manage your saved searches"
    separator = "plain"
    prefix = "saved-searches"

    additional_content = ViewPageTemplateFile("listing-fields.pt")

    def __init__(self, context, request, view):
        super(SavedSearchListingForm, self).__init__(context, request, view)
        self.saved_searches = view.saved_searches

    @action("Remove", primary=True, disabled=True)
    def remove(self, action, data):
        ids = [int(id) for id in self.request.get("saved-searches.ids", [])]
        self.context.remove_saved_searches_by_ids(ids)
        self.view.notes.info("The selected searches have been removed")
        self.request.response.redirect(get_url(self.context, self.request))


class SavedSearchEditForm(SavedSearchForm):

    summary = "Edit search"

    def get_edit_saved_search_name(self):
        return self.request.form.get("form.name")
