# Copyright 2005-2022 Canonical Limited. All rights reserved.

import mimetypes

from zope.publisher.browser import BrowserPage


def is_image_type(mimetype):
    """Simply determine if mimetype is an image.

    Unknown extensions will yield a None mimetype from guess_type.
    """
    # FIXME: We might want this to be "is_download" or something
    # Which would allow text/plain and other things to be viewed directly in
    # the browser.
    return mimetype and mimetype.startswith("image/")


class ScriptAttachmentPage(BrowserPage):
    def __call__(self):
        mimetype, encoding = mimetypes.guess_type(self.context.filename)
        if mimetype is not None:
            self.request.response.setHeader("Content-Type", mimetype)
        if encoding is not None:
            self.request.response.setHeader("Content-Encoding", encoding)
        if not is_image_type(mimetype):
            filename = self.context.filename.replace('"', '\\"')
            self.request.response.setHeader(
                "Content-Disposition", 'attachment; filename="%s"' % filename
            )
        return self.context.get_data()
