# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.schema import Choice
from zope.cachedescriptors.property import Lazy

from canonical.content.form import Fields, action
from canonical.url import get_url

from canonical.landscape.ui.account.page import AccountPage
from canonical.landscape.ui.form import LandscapeFormProvider
from canonical.landscape.model.script.interfaces import IScript
from canonical.landscape.model.script.management import ScriptManagement
from canonical.landscape.model.script.script import DuplicateScriptError
from canonical.landscape.model.main.person import PersonAccessContextsVocabularyFactory
from canonical.landscape.model.main.account import DEFAULT_ACCESS_CONTEXT_NAME
from canonical.landscape.ui.script.create import ScriptAttachmentsFormMixin


class CopyScriptPage(AccountPage):

    title = "Copy script"


class CopyScriptForm(ScriptAttachmentsFormMixin, LandscapeFormProvider):

    fields = Fields(IScript, render_context=True)
    summary = "Copy script"

    def __init__(self, context, request, view):
        super(CopyScriptForm, self).__init__(context, request, view)
        self.management = ScriptManagement(
            self.context.account, self.request.principal.person
        )

    @Lazy
    def fields(self):
        access_context = Choice(
            __name__="access_context",
            title="Access group",
            source=PersonAccessContextsVocabularyFactory(
                "EditScript", self.request.principal.person
            ),
            default=DEFAULT_ACCESS_CONTEXT_NAME,
            description="The access group the script should belong to.",
            required=True,
        )
        fields = Fields(IScript, render_context=True) + Fields(access_context)
        return fields.select("title", "access_context")

    @action("Save", primary=True)
    def save(self, action, data):
        script_id = self.context.id
        script_title = data["title"]
        access_context_name = data["access_context"]

        try:
            self.management.copy_script(script_id, script_title, access_context_name)
        except DuplicateScriptError:
            self.add_error(
                "This title already exists. Please use a different one.", "title"
            )
            return

        self.view.notes.info("Script copied.")

        self.request.response.redirect(get_url(self.management, self.request))
