# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.cachedescriptors.property import Lazy

from canonical.url import get_url
from canonical.content.decorator import json

from canonical.landscape.ui.account.page import AccountPage


class AccountScriptsPage(AccountPage):

    title = "Scripts"

    def __init__(self, context, request):
        super(AccountScriptsPage, self).__init__(context, request)
        self.scripts = list(self.context.get_scripts())
        self.can_create = self.context.person_can("CreateScript")

    def update(self):
        """
        Method is called by Zope's traversal machinery when an action is called
        on the script selection page.  This method should only be called when
        form data has been POST'd to update the selection; it always performs a
        redirect.
        """
        self._check_request_csrf_token(require_post=True)

        if "delete" in self.request:
            selected_scripts_ids = self.request.form.get("script_id", ())
            if selected_scripts_ids:
                selected_scripts_ids = [int(id) for id in selected_scripts_ids]
                selected_scripts = [
                    script
                    for script in self.scripts
                    if script.id in selected_scripts_ids
                ]

                not_removed = self.context.remove_scripts(selected_scripts)
                if not_removed:
                    titles = ", ".join(script.title for script in not_removed)
                    self.notes.warning(
                        "Unable to remove scripts: %s. Unauthorised" % titles
                    )
            self.request.response.redirect(get_url(self.context, self.request))
        elif "select_all" in self.request:
            # Only used when javascript is disabled
            self.request.response.redirect(
                get_url(self.context, self.request) + "?select_all=1"
            )
        else:
            self.request.response.redirect(get_url(self.context, self.request))

    @Lazy
    @json
    def enabled_buttons(self):
        """Return a JS list of buttons that should be enabled."""
        buttons = []
        if not self.context.get_scripts(permission="EditScript").is_empty():
            buttons.append("#remove-script")
        return buttons
