# Copyright 2005-2013 Canonical Limited.  All rights reserved.

import logging

from zope.security import proxy

from canonical.url import get_url

from canonical.landscape.model.main.account import Account
from canonical.landscape.model.main.person import Person
from canonical.landscape.model.account.invitation import AccountInvitation
from safe.canonical.landscape.model.main.search import search
from canonical.landscape.ui.sidebar.page import SidebarPage


class SearchPage(SidebarPage):

    title = "Search results"

    def results(self):
        query = self.request.form.get("query", "")
        query = query.strip()
        if len(query) < 3:
            self.notes.error("Search query must have 3 characters or more.")
            search_results = []
        else:
            search_results = self.get_search_results(query)
            if len(search_results) == 1:
                self.notes.info(
                    "Only one result for %s." % (search_results[0]["description"])
                )
                self.request.response.redirect(search_results[0]["url"])
                return None
        return search_results

    def get_search_results(self, query):
        results = []
        for item in search(query):
            if proxy.isinstance(item, Account):
                results.append(
                    {
                        "name": item.name,
                        "description": item.title,
                        "url": get_url(item, self.request),
                        "icon_path": "/static/account/account-16x16.png",
                    }
                )
            elif proxy.isinstance(item, Person):
                path = "/static/administrator/administrator-16x16.png"
                results.append(
                    {
                        "name": item.email,
                        "description": item.name,
                        "url": get_url(item, self.request),
                        "icon_path": path,
                    }
                )
            elif proxy.isinstance(item, AccountInvitation):
                url = get_url(item.account, self.request) + "/administrators"
                path = "/static/administrator/invited-administrator-16x16.png"
                results.append(
                    {
                        "name": item.email,
                        "description": item.name,
                        "url": url,
                        "icon_path": path,
                    }
                )
            else:
                logging.warn(
                    "Got a search result I don't know how to " "render: %s" % repr(item)
                )
        return results
