# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from storm.locals import And, Select

from zope.interface import Interface
from zope.security.proxy import removeSecurityProxy

from canonical.routes import get_route_object

from canonical.landscape.model.activity.collection import ActivityChildCollection
from canonical.landscape.model.activity.activity import Activity
from canonical.landscape.model.computer.twin import AccountComputerTwin
from canonical.landscape.model.computer.activities import (
    get_next_parent_with_blocked_computer_activity,
)
from canonical.landscape.model.selection.selection import ComputerSelectionBase
from canonical.landscape.ui.activity.activity import ActivityPageMixin
from canonical.landscape.ui.activity.summary import ActivitiesPageMixin
from canonical.landscape.ui.toolbar.page import ToolbarPage


class IComputerSelectionActivity(Interface):
    """Decorator for activities being viewed inside a computer selection.

    This marker allows registering custom views (pages, providers, etc)
    depending on where the object is being viewed.
    """


class ComputerSelectionActivityPage(ActivityPageMixin, ToolbarPage):
    """Activity page rendered with a toolbar."""

    def get_next_unapproved_activity(self):
        """Get next unapproved activity for the selected computers."""
        selection = get_route_object(ComputerSelectionBase, self.request)
        selected_computer_ids = selection.get_selected_computer_ids()
        return get_next_parent_with_blocked_computer_activity(
            removeSecurityProxy(self.context), computer_ids=selected_computer_ids
        )


class ComputerSelectionActivitiesPage(ActivitiesPageMixin, ToolbarPage):
    """Mixin for the activities selection page."""

    def _get_collection_filters(self):
        """Filter by selected computer IDs."""
        account = removeSecurityProxy(self.context.selection.account)
        computer_ids = self.context.selection.get_selected_computer_ids()
        computer_twin_subquery = Select(
            AccountComputerTwin.data_id,
            where=AccountComputerTwin.id.is_in(computer_ids),
        )

        return {
            "ids": Select(
                Activity.parent_id,
                where=And(
                    Activity.entity_data_id.is_in(computer_twin_subquery),
                    Activity.account_id == account.id,
                ),
                distinct=True,
            )
        }
