# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import str
from canonical.url import ContextURL, quote_url


class ComputerSelectionContextURL(ContextURL):

    alias = "selection"

    @property
    def path(self):
        ids = sorted(self.context.get_included_computer_ids())
        if ids:
            context_url = "computer/" + "+".join(str(id) for id in ids)
        else:
            context_url = "computers"
        tags = [quote_url(tag.name) for tag in self.context.get_included_tags()]
        if tags:
            context_url += "/tags/%s" % ("+".join(sorted(tags)),)
        search = self.context.get_search_name()
        criteria = self.context.get_search_criteria()
        request_criteria = self.request.get("criteria")
        if search:
            context_url += "/search/%s" % search
        elif criteria and not request_criteria:
            # XXX this works if criteria don't contain slashes, otherwise the
            # url will be split.  At the moment we don't have such cases for
            # internally-generated URLs.
            context_url += "/criteria/%s" % criteria

        return context_url

    @property
    def parent(self):
        return self.context.account
