# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.interface import Interface
from zope.schema import Bool, TextLine

from canonical.landscape.model.main.schema import EmailAddress


class IStandaloneSettings(Interface):

    root_url = TextLine(
        title="Root URL",
        description="This should be the current site URL.",
        required=False,
    )

    ping_url = TextLine(
        title="Ping URL",
        description="This should be the URL for the ping service.  "
        "Configuring this value is not required, and should "
        "only be entered if the Ping Server is not running on "
        "port 80.",
        required=False,
    )

    system_email = EmailAddress(
        title="System email address",
        description="The address emails from Landscape will " "appear to come from.",
        required=True,
    )

    http_proxy = TextLine(
        title="Proxy for HTTP and HTTPS traffic",
        description="The proxy to use when interecting with "
        "external systems via HTTP. Requires an "
        "application restart if changed.",
        required=False,
    )

    no_proxy = TextLine(
        title="No proxy for",
        description="Comma separated list of hosts for which no "
        "HTTP proxy should be used. Requires an "
        "application restart if changed.",
        required=False,
    )

    do_not_track_ga = Bool(
        title="Do not track anonymous usage statistics",
        description="Whether to opt-out of tracking anonymous usage "
        "statistics including number of managed computers, use "
        "of MAAS and Autopilot. Tracking helps us improve "
        "Landscape and Autopilot.",
        required=False,
    )
