# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.component import getUtility
from zope.security.proxy import removeSecurityProxy

from canonical.content.form import Fields, action
from canonical.url import get_url

from canonical.landscape.ui.settings.interfaces import IStandaloneSettings
from canonical.landscape.model.account.alerts import StandaloneSystemEmailAlert
from canonical.landscape.ui.account.page import AccountPage
from canonical.landscape.ui.form import LandscapeFormProvider
from canonical.landscape.model.configuration import (
    LANDSCAPE_SYSTEM_EMAIL,
    LANDSCAPE_PING_URL,
    ISystemConfiguration,
    get_root_url,
    set_root_url,
    LANDSCAPE_HTTP_PROXY,
    LANDSCAPE_HTTPS_PROXY,
    LANDSCAPE_NO_PROXY,
    LANDSCAPE_DO_NOT_TRACK_GA,
)


class StandaloneSettingsPage(AccountPage):

    title = "Settings"


class StandaloneSettingsForm(LandscapeFormProvider):

    summary = "Settings"

    fields = Fields(IStandaloneSettings)

    dropdown_css_class = "dropdown-spacer-standalone-settings"

    def get_initial_data(self):
        """
        Prepare the form fields prior to display.
        """
        configuration = getUtility(ISystemConfiguration)
        data = {
            "system_email": configuration.get(LANDSCAPE_SYSTEM_EMAIL),
            "root_url": get_root_url() or "%s/" % self.request.URL[0],
            "ping_url": configuration.get(LANDSCAPE_PING_URL),
            "http_proxy": configuration.get(LANDSCAPE_HTTP_PROXY),
            "no_proxy": configuration.get(LANDSCAPE_NO_PROXY),
            "do_not_track_ga": configuration.get(LANDSCAPE_DO_NOT_TRACK_GA, False),
        }
        return data

    @action("Save", primary=True)
    def save(self, action, data):
        configuration = getUtility(ISystemConfiguration)
        updated = False

        new_system_email = data.get("system_email")
        cur_system_email = configuration.get(LANDSCAPE_SYSTEM_EMAIL)
        if new_system_email and new_system_email != cur_system_email:
            configuration.set(LANDSCAPE_SYSTEM_EMAIL, new_system_email)
            updated = True
            # Unproxy the account since persons don't have CheckRule
            # permission
            unproxied_account = removeSecurityProxy(self.context)
            unproxied_account.check_rules([StandaloneSystemEmailAlert])

        new_root_url = data.get("root_url")
        if new_root_url and new_root_url != get_root_url():
            if not new_root_url.endswith("/"):
                new_root_url = "%s/" % new_root_url
            set_root_url(new_root_url)
            updated = True

        new_ping_url = data.get("ping_url")
        if new_ping_url != configuration.get(LANDSCAPE_PING_URL):
            configuration.set(LANDSCAPE_PING_URL, new_ping_url)
            updated = True

        new_http_proxy = data.get("http_proxy")
        if new_http_proxy != configuration.get(LANDSCAPE_HTTP_PROXY):
            configuration.set(LANDSCAPE_HTTP_PROXY, new_http_proxy)
            updated = True
        if new_http_proxy != configuration.get(LANDSCAPE_HTTPS_PROXY):
            configuration.set(LANDSCAPE_HTTPS_PROXY, new_http_proxy)
            updated = True

        new_no_proxy = data.get("no_proxy")
        if new_no_proxy != configuration.get(LANDSCAPE_NO_PROXY):
            configuration.set(LANDSCAPE_NO_PROXY, new_no_proxy)
            updated = True

        new_do_not_track = data.get("do_not_track_ga", False)
        old_do_not_track = configuration.get(LANDSCAPE_DO_NOT_TRACK_GA, False)
        if new_do_not_track != old_do_not_track:
            configuration.set(LANDSCAPE_DO_NOT_TRACK_GA, new_do_not_track)
            updated = True

        if not updated:
            self.view.notes.info("Configuration not updated.")
        else:
            self.view.notes.info("Configuration changes saved.")
        self.request.response.redirect(get_url(self.context, self.request))
