from zope.cachedescriptors.property import Lazy

from canonical.content.provider import TemplateContentProvider

from canonical.landscape.model.license.management import LicenseManagement
from canonical.landscape.model.main.standalone import AccountLDSLicenseAPI
from canonical.landscape.service.computer.count import CountComputersByType
from canonical.landscape.ui.account.routes import get_current_account


class AccountSidebarProvider(TemplateContentProvider):
    """Content provider for rendering the account sidebar."""

    template_filename = "account.pt"

    @Lazy
    def seats(self):
        license_management = LicenseManagement(self.account)
        return license_management.get_seats()

    @Lazy
    def account(self):
        return get_current_account(self.request)

    @Lazy
    def has_lds_access(self):
        """Does this account have access to Landscape On Prem?"""
        api = AccountLDSLicenseAPI(self.account)
        return api.has_valid_license()

    @Lazy
    def computer_counts(self):
        """Return number of computers in the account by type."""
        operation = CountComputersByType(self.account, self.request.principal)
        return operation()

    @Lazy
    def total_computer_count(self):
        """Return the total count of computers in the account."""
        return sum(self.computer_counts.values())
