# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import object
from datetime import datetime
from operator import attrgetter
from pytz import common_timezones, timezone, UTC

from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm


class Timezone(object):
    """
    Hold the name and offset for a single timezone.

    @param name: The name of the timezone, like 'US/Eastern'.
    """

    def __init__(self, name):
        self.name = name
        tz = timezone(name)
        self.offset = self.find_offset(tz)
        self.integer_offset = int(self.offset)
        self.short_tz_name = datetime.now(tz=tz).strftime("%Z")

    def find_offset(self, timezone_):
        """
        Given the timezone information, return the offset from
        UTC in string form, like +0730.

        @param timezone_:  The tzinfo from pytz.timezone().
        """
        now_utc = datetime.now(UTC)
        now_timezone = now_utc.astimezone(timezone_)
        offset = now_timezone.strftime("%z")
        return offset


def get_timezones(context, timezone_list=common_timezones):
    """Return a vocabulary of all timezones currently in use worldwide."""
    timezones = [Timezone(timezone_name) for timezone_name in timezone_list]
    timezones = sorted(timezones, key=attrgetter("integer_offset", "name"))

    terms = []
    for tz in timezones:
        value = tz.name
        offset = tz.offset[:-2] + ":" + tz.offset[-2:]
        title = "(GMT %s %s) %s" % (offset, tz.short_tz_name, tz.name)
        terms.append(SimpleTerm(value, value, title))
    return SimpleVocabulary(terms)
