# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from future import standard_library

standard_library.install_aliases()
from urllib.parse import urlencode

from zope.component import getUtility
from zope.cachedescriptors.property import Lazy
from zope.formlib.textwidgets import TextAreaWidget

from canonical.content.form import Fields, action

from canonical.landscape.constants import UBUNTU_ADVANTAGE_PURCHASE_URL
from canonical.landscape.mail.interfaces import ILandscapeMailer
from canonical.landscape.mail.mail import format_address
from canonical.landscape.model.main.account import can_have_trial
from canonical.landscape.ui.trial.interfaces import ITrialRegistration
from canonical.landscape.ui.page.page import LandscapePage
from canonical.landscape.ui.form import LandscapeFormProvider
from canonical.landscape.model.main.account import create_trial_account
from canonical.landscape.model.feature.flag import is_feature_enabled


LANDSCAPE_TERMS_AND_CONDITIONS = """
UBUNTU ADVANTAGE: LANDSCAPE TRIAL AGREEMENT

This Ubuntu Advantage Landscape trial agreement ("Agreement") is a legal
agreement between you, on behalf of your employer (as identified on the
Landscape trial sign-up form, or on your own behalf if you did not identify a
company on the sign-up form) ("You"), and Canonical Group Limited, registered
in England (company number 6870835) whose registered office is at 5th Floor,
Blue Fin Building, 110 Southwark Street, London SE1 0SU ("Canonical") for
Canonical's Ubuntu Advantage Landscape service ("Landscape").

BY CLICKING ON THE "REGISTER" BUTTON BELOW, YOU AGREE TO THE TERMS OF THIS
AGREEMENT WHICH WILL BIND YOU. IF YOU DO NOT AGREE TO THE TERMS OF THIS
AGREEMENT, YOU MUST NOT USE LANDSCAPE.  IF YOU ARE AGREEING ON BEHALF OF YOUR
EMPLOYER, YOU REPRESENT AND WARRANT THAT YOU HAVE FULL LEGAL AUTHORITY TO BIND
YOUR EMPLOYER TO THIS AGREEMENT.

1.Service

1.1 In consideration of You agreeing to abide by the terms of this Agreement,
Canonical will permit you to access and use Landscape to manage up to fifty
(50) computer systems solely for the purpose of internal testing and internal
evaluation.

1.2 You will not allow any unauthorised access to Landscape or tamper with or
insert any data or information into Landscape which may cause any damage to
Canonical or third parties, or be unlawful.

2.Term and Termination

2.1 This Agreement begins on the date You click the "Accept" button and
terminates thirty (30) days thereafter.  Either party may terminate this
Agreement at any time for convenience by providing notice to the other party.

2.2 Upon termination of this Agreement, you shall immediately cease using
Landscape and Canonical may disable your access to Landscape.

3.Disclaimer of Warranty

LANDSCAPE IS PROVIDED "AS IS", AND CANONICAL MAKES NO REPRESENTATIONS OR
WARRANTIES OF ANY KIND, WHETHER ORAL OR WRITTEN, WHETHER EXPRESS, IMPLIED, OR
ARISING BY STATUTE, CUSTOM, COURSE OF DEALING OR TRADE USAGE, WITH RESPECT TO
LANDSCAPE OR ANY SOFTWARE OR RELATED MATERIALS IN CONNECTION WITH THIS
AGREEMENT.  CANONICAL SPECIFICALLY DISCLAIMS ANY AND ALL IMPLIED WARRANTIES OR
CONDITIONS OF TITLE, SATISFACTORY QUALITY, MERCHANTABILITY, FITNESS FOR A
PARTICULAR PURPOSE AND NON-INFRINGEMENT.

4.Limitation of Liability

4.1 IN NO EVENT SHALL CANONICAL BE LIABLE TO YOU OR ANY THIRD PARTY FOR ANY
INDIRECT, SPECIAL, INCIDENTAL, PUNITIVE, OR CONSEQUENTIAL LOSS OR DAMAGE OR FOR
ANY LOSS OF OR DAMAGE TO DATA, LOSS OF PROFIT, LOSS OF CONTRACT OR LOSS OF
OTHER ECONOMIC ADVANTAGE (IN EACH CASE WHETHER DIRECT OR INDIRECT) HOWSOEVER
ARISING OUT OF OR IN CONNECTION WITH THIS AGREEMENT OR ANY COLLATERAL CONTRACT,
OR THE PRODUCTION, SALE, SUPPLY OR USE (BY CANONICAL, YOU OR ANY THIRD PARTY)
OF ANY SOFTWARE OR SERVICES PROVIDED UNDER THIS AGREEMENT, EVEN IF ADVISED OF
THE POSSIBILITY OF THE SAME AND WHETHER FORESEEABLE OR NOT. THESE LIMITATIONS
SHALL APPLY NOTWITHSTANDING ANY FAILURE OF ESSENTIAL PURPOSE OR ANY LIMITED
REMEDY.

4.2 CANONICAL'S AGGREGATE LIABILITY TO YOU OR ANY THIRD PARTY FOR ALL CLAIMS
ARISING OUT OF OR IN CONNECTION WITH THIS AGREEMENT OR ANY COLLATERAL CONTRACT
OR OUT OF THE PRODUCTION, SALE, SUPPLY OR USE OF LANDSCAPE, WHETHER BASED UPON
CONTRACT, TORT (INCLUDING WITHOUT LIMITATION NEGLIGENCE) OR OTHERWISE, SHALL
NOT EXCEED 1,000 USD. THIS LIMITATION OF LIABILITY IS CUMULATIVE AND IS NOT PER
INCIDENT.

4.3 Nothing in this Agreement shall exclude or limit the liability of either
party for: death or personal injury; or for any misrepresentation fraudulent or
otherwise; or for any other liability which it is not permitted to exclude or
limit as a matter of applicable law.

4.4 The parties understand and agree that the limitations of liability set out
in clauses 4.1 and 4.2 are a reasonable allocation of risk between the parties
and, absent such allocation, the parties would not have entered into this
Agreement.

5.General

5.1 Neither party may assign, transfer, charge, create a trust over or
otherwise deal in its rights and/or obligations under this Agreement (or
purport to do so) without the other party's prior written consent.

5.2 Unless the right of enforcement is expressly granted, it is not intended
that any provision of this Agreement  shall be enforceable by virtue of the
Contracts (Rights of Third Parties) Act 1999, as amended from time to time, by
any person who is not a party to this Agreement.  Any of Canonical's group
companies may enforce this Agreement against You.

5.3 A failure or delay by a party to exercise any right or remedy under this
Agreement shall not be construed or operate as a waiver of that right or remedy
nor shall any single or partial exercise of any right or remedy preclude the
further exercise of that right or remedy by that party.

5.4 The terms and conditions of this Agreement, represents the entire terms
agreed between the parties in relation to its subject matter and supersedes all
previous contracts or arrangements (including any usage or custom and any terms
arising through any course of dealing) of any kind between the parties
relating to its subject matter.

5.5 Each of the provisions of this Agreement shall be construed as independent
of every other such provision, so that if any provision of this Agreement
shall be determined by any court of competent authority to be illegal, invalid
and/or unenforceable this shall not affect any other provision of this
Agreement, which shall remain in full force and effect.

5.6 Nothing in this Agreement and no action taken by the parties pursuant to
this Agreement shall be construed as creating a partnership or joint venture
of any kind between the parties or as constituting either party as the agent
of the other party.  No party shall have the authority to bind the other party
or to contract in the name of or create a liability against the other party.

5.7 Any notice required to be given or sent under this Agreement shall be in
writing and either delivered personally or sent by first class registered post
(or equivalent) to the registered office for the time being of the recipient.

5.8 Customer acknowledges that export laws and regulations of the United
States and European territories may apply to the Software. Customer agrees
that such export control laws and regulations govern its use of the Software
and any such materials and shall comply with all such laws and regulations.
Customer will not export, directly or indirectly, the Software in violation of
these laws or regulations, nor will it use them for any purpose prohibited
by these laws.

6. Governing Law

This Agreement shall be governed by and construed in accordance with the laws
of England and the parties hereby submit to the exclusive jurisdiction of the
courts of England.  The provisions of the United Nations Convention on
Contracts for the International Sale of Goods shall not apply to this
Agreement."""

LANDSCAPE_TRIAL_WELCOME_EMAIL = """
Dear %(first_name)s,

Welcome to your 30-day Ubuntu Advantage trial!  The trial gives you
access to Landscape, our systems management tool.  It includes our
knowledge base with articles to help you learn about and implement
best practices throughout your systems.

To access Landscape during your trial period, please visit
https://landscape.canonical.com.

You can have up to five administrators in your trial account and
register up to fifty computers to learn about Landscape.

If you like what you see you can signup for an Ubuntu Advantage
subscription which gives you access to dedicated support and legal
assurance, in addition to Landscape. Please visit our shop at
{ua_purchase_url} for details or to discuss specific
requirements you might have with our sales team.

Thanks for trying Ubuntu Advantage!

Regards,
The Canonical Team
""".format(
    ua_purchase_url=UBUNTU_ADVANTAGE_PURCHASE_URL
)


class LargeTextAreaWidget(TextAreaWidget):

    width = 80
    height = 15
    extra = "readonly"


class SmallTextAreaWidget(TextAreaWidget):

    height = 7


class TrialRegistrationPage(LandscapePage):

    title = "Ubuntu Advantage trial registration"
    layout = "fixed"

    def __call__(self):
        """Render the page.

        Registration is denied if the system is running in standalone
        environment, or if the L{Person} accessing the registration form is
        already a member of an L{Account}.  On staging, multiple registrations
        are allowed to make testing easy.
        """
        if is_feature_enabled("self-service"):
            self.request.response.redirect("/signup")
            return

        if not self.is_authenticated():
            # Let's send the user to SSO first
            params = {"next_url": "/trial-registration", "create": "yes"}
            url = "/login/authenticate?" + urlencode(params)
            self.request.response.redirect(url)
            return

        person = self.request.principal.person
        if not can_have_trial(person):
            self.notes.error(
                "A trial account can't be created when "
                "you're already a member of an account."
            )
            self.request.response.redirect("/")
            return

        return super(TrialRegistrationPage, self).__call__()


class TrialRegistrationForm(LandscapeFormProvider):

    summary = "Register for an Ubuntu Advantage trial"

    @Lazy
    def fields(self):
        fields = Fields(ITrialRegistration)
        fields["terms_and_conditions"].custom_widget = LargeTextAreaWidget
        fields["registration_comments"].custom_widget = SmallTextAreaWidget
        # Only display the timezone field if the person's timezone is still
        # the default one
        if self.request.principal.person.timezone != "UTC":
            fields = fields.omit("timezone")
        return fields

    def get_initial_data(self):
        return {"terms_and_conditions": LANDSCAPE_TERMS_AND_CONDITIONS}

    def validate(self, action, data):
        if not data.get("accepted_terms"):
            self.add_error(
                "You must accept the terms and conditions.", "accepted_terms"
            )

    def _send_welcome_email(self, person):
        """Send Welcome email to logged in C{person}."""
        first_name = person.name.split(" ")[0]
        recipient = format_address(person.name, person.email)
        body = LANDSCAPE_TRIAL_WELCOME_EMAIL % {"first_name": first_name}
        mailer = getUtility(ILandscapeMailer)
        mailer.send([recipient], "Welcome to Ubuntu Advantage", body)

    @action("Register", primary=True)
    def register(self, action, data):
        """Process the trial registration form to create a new L{Account}."""
        person = self.request.principal.person
        trial = create_trial_account(
            data["company_name"],
            daytime_phone=data["daytime_phone"],
            country=data["country"],
            region=data.get("region"),
            mailing_list_optin=data.get("mailing_list_optin"),
            registration_comments=data.get("registration_comments"),
        )
        trial.activate(person)
        self._send_welcome_email(person)
        self.view.notes.info("Trial account successfully activated.")
        self.request.response.redirect("/")
