# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm


def get_countries(context):
    """Return a list of possible registration countries.

    The list of countries is drawn from ISO-3166-1.  The code used to identify
    each country is from the alpha-2 list.  Information about the
    specification is available:

    U{http://en.wikipedia.org/wiki/ISO_3166-1}

    @return: A C{SimpleVocabulary} containing terms for each country.
    """
    countries = [
        ("Afghanistan", "AF"),
        ("\N{LATIN CAPITAL LETTER A WITH RING ABOVE}land Islands", "AX"),
        ("Albania", "AL"),
        ("Algeria", "DZ"),
        ("American Samoa", "AS"),
        ("Andorra", "AD"),
        ("Angola", "AO"),
        ("Anguilla", "AI"),
        ("Antarctica", "AQ"),
        ("Antigua and Barbuda", "AG"),
        ("Argentina", "AR"),
        ("Armenia", "AM"),
        ("Aruba", "AW"),
        ("Australia", "AU"),
        ("Austria", "AT"),
        ("Azerbaijan", "AZ"),
        ("Bahamas", "BS"),
        ("Bahrain", "BH"),
        ("Bangladesh", "BD"),
        ("Barbados", "BB"),
        ("Belarus", "BY"),
        ("Belgium", "BE"),
        ("Belize", "BZ"),
        ("Benin", "BJ"),
        ("Bermuda", "BM"),
        ("Bhutan", "BT"),
        ("Bolivia, Plurinational State of", "BO"),
        ("Bosnia and Herzegovina", "BA"),
        ("Botswana", "BW"),
        ("Bouvet Island", "BV"),
        ("Brazil", "BR"),
        ("British Indian Ocean Territory", "IO"),
        ("Brunei Darussalam", "BN"),
        ("Bulgaria", "BG"),
        ("Burkina Faso", "BF"),
        ("Burundi", "BI"),
        ("Cambodia", "KH"),
        ("Cameroon", "CM"),
        ("Canada", "CA"),
        ("Cape Verde", "CV"),
        ("Cayman Islands", "KY"),
        ("Central African Republic", "CF"),
        ("Chad", "TD"),
        ("Chile", "CL"),
        ("China", "CN"),
        ("Christmas Island", "CX"),
        ("Cocos (Keeling), Islands", "CC"),
        ("Colombia", "CO"),
        ("Comoros", "KM"),
        ("Congo", "CG"),
        ("Congo, the Democratic Republic of the", "CD"),
        ("Cook Islands", "CK"),
        ("Costa Rica", "CR"),
        ("C\N{LATIN CAPITAL LETTER O WITH CIRCUMFLEX}te D'ivoire", "CI"),
        ("Croatia", "HR"),
        ("Cuba", "CU"),
        ("Cyprus", "CY"),
        ("Czech Republic", "CZ"),
        ("Denmark", "DK"),
        ("Djibouti", "DJ"),
        ("Dominica", "DM"),
        ("Dominican Republic", "DO"),
        ("Ecuador", "EC"),
        ("Egypt", "EG"),
        ("El Salvador", "SV"),
        ("Equatorial Guinea", "GQ"),
        ("Eritrea", "ER"),
        ("Estonia", "EE"),
        ("Ethiopia", "ET"),
        ("Falkland Islands (Malvinas),", "FK"),
        ("Faroe Islands", "FO"),
        ("Fiji", "FJ"),
        ("Finland", "FI"),
        ("France", "FR"),
        ("French Guiana", "GF"),
        ("French Polynesia", "PF"),
        ("French Southern Territories", "TF"),
        ("Gabon", "GA"),
        ("Gambia", "GM"),
        ("Georgia", "GE"),
        ("Germany", "DE"),
        ("Ghana", "GH"),
        ("Gibraltar", "GI"),
        ("Greece", "GR"),
        ("Greenland", "GL"),
        ("Grenada", "GD"),
        ("Guadeloupe", "GP"),
        ("Guam", "GU"),
        ("Guatemala", "GT"),
        ("Guernsey", "GG"),
        ("Guinea", "GN"),
        ("Guinea-bissau", "GW"),
        ("Guyana", "GY"),
        ("Haiti", "HT"),
        ("Heard Island and Mcdonald Islands", "HM"),
        ("Holy See (Vatican City State),", "VA"),
        ("Honduras", "HN"),
        ("Hong Kong", "HK"),
        ("Hungary", "HU"),
        ("Iceland", "IS"),
        ("India", "IN"),
        ("Indonesia", "ID"),
        ("Iran, Islamic Republic of", "IR"),
        ("Iraq", "IQ"),
        ("Ireland", "IE"),
        ("Isle of Man", "IM"),
        ("Israel", "IL"),
        ("Italy", "IT"),
        ("Jamaica", "JM"),
        ("Japan", "JP"),
        ("Jersey", "JE"),
        ("Jordan", "JO"),
        ("Kazakhstan", "KZ"),
        ("Kenya", "KE"),
        ("Kiribati", "KI"),
        ("Korea, Democratic People's Republic of", "KP"),
        ("Korea, Republic of", "KR"),
        ("Kuwait", "KW"),
        ("Kyrgyzstan", "KG"),
        ("Lao People's Democratic Republic", "LA"),
        ("Latvia", "LV"),
        ("Lebanon", "LB"),
        ("Lesotho", "LS"),
        ("Liberia", "LR"),
        ("Libyan Arab Jamahiriya", "LY"),
        ("Liechtenstein", "LI"),
        ("Lithuania", "LT"),
        ("Luxembourg", "LU"),
        ("Macao", "MO"),
        ("Macedonia, the Former Yugoslav Republic of", "MK"),
        ("Madagascar", "MG"),
        ("Malawi", "MW"),
        ("Malaysia", "MY"),
        ("Maldives", "MV"),
        ("Mali", "ML"),
        ("Malta", "MT"),
        ("Marshall Islands", "MH"),
        ("Martinique", "MQ"),
        ("Mauritania", "MR"),
        ("Mauritius", "MU"),
        ("Mayotte", "YT"),
        ("Mexico", "MX"),
        ("Micronesia, Federated States of", "FM"),
        ("Moldova, Republic of", "MD"),
        ("Monaco", "MC"),
        ("Mongolia", "MN"),
        ("Montenegro", "ME"),
        ("Montserrat", "MS"),
        ("Morocco", "MA"),
        ("Mozambique", "MZ"),
        ("Myanmar", "MM"),
        ("Namibia", "NA"),
        ("Nauru", "NR"),
        ("Nepal", "NP"),
        ("Netherlands", "NL"),
        ("Netherlands Antilles", "AN"),
        ("New Caledonia", "NC"),
        ("New Zealand", "NZ"),
        ("Nicaragua", "NI"),
        ("Niger", "NE"),
        ("Nigeria", "NG"),
        ("Niue", "NU"),
        ("Norfolk Island", "NF"),
        ("Northern Mariana Islands", "MP"),
        ("Norway", "NO"),
        ("Oman", "OM"),
        ("Pakistan", "PK"),
        ("Palau", "PW"),
        ("Palestinian Territory, Occupied", "PS"),
        ("Panama", "PA"),
        ("Papua New Guinea", "PG"),
        ("Paraguay", "PY"),
        ("Peru", "PE"),
        ("Philippines", "PH"),
        ("Pitcairn", "PN"),
        ("Poland", "PL"),
        ("Portugal", "PT"),
        ("Puerto Rico", "PR"),
        ("Qatar", "QA"),
        ("R\N{LATIN CAPITAL LETTER E WITH ACUTE}union", "RE"),
        ("Romania", "RO"),
        ("Russian Federation", "RU"),
        ("Rwanda", "RW"),
        ("Saint Barth\N{LATIN CAPITAL LETTER E WITH ACUTE}lemy", "BL"),
        ("Saint Helena, Ascension and Tristan Da Cunha", "SH"),
        ("Saint Kitts and Nevis", "KN"),
        ("Saint Lucia", "LC"),
        ("Saint Martin", "MF"),
        ("Saint Pierre and Miquelon", "PM"),
        ("Saint Vincent and the Grenadines", "VC"),
        ("Samoa", "WS"),
        ("San Marino", "SM"),
        ("Sao Tome and Principe", "ST"),
        ("Saudi Arabia", "SA"),
        ("Senegal", "SN"),
        ("Serbia", "RS"),
        ("Seychelles", "SC"),
        ("Sierra Leone", "SL"),
        ("Singapore", "SG"),
        ("Slovakia", "SK"),
        ("Slovenia", "SI"),
        ("Solomon Islands", "SB"),
        ("Somalia", "SO"),
        ("South Africa", "ZA"),
        ("South Georgia and the South Sandwich Islands", "GS"),
        ("Spain", "ES"),
        ("Sri Lanka", "LK"),
        ("Sudan", "SD"),
        ("Suriname", "SR"),
        ("Svalbard and Jan Mayen", "SJ"),
        ("Swaziland", "SZ"),
        ("Sweden", "SE"),
        ("Switzerland", "CH"),
        ("Syrian Arab Republic", "SY"),
        ("Taiwan, Province of China", "TW"),
        ("Tajikistan", "TJ"),
        ("Tanzania, United Republic of", "TZ"),
        ("Thailand", "TH"),
        ("Timor-leste", "TL"),
        ("Togo", "TG"),
        ("Tokelau", "TK"),
        ("Tonga", "TO"),
        ("Trinidad and Tobago", "TT"),
        ("Tunisia", "TN"),
        ("Turkey", "TR"),
        ("Turkmenistan", "TM"),
        ("Turks and Caicos Islands", "TC"),
        ("Tuvalu", "TV"),
        ("Uganda", "UG"),
        ("Ukraine", "UA"),
        ("United Arab Emirates", "AE"),
        ("United Kingdom", "GB"),
        ("United States", "US"),
        ("United States Minor Outlying Islands", "UM"),
        ("Uruguay", "UY"),
        ("Uzbekistan", "UZ"),
        ("Vanuatu", "VU"),
        ("Venezuela, Bolivarian Republic of", "VE"),
        ("Viet Nam", "VN"),
        ("Virgin Islands, British", "VG"),
        ("Virgin Islands, U.S.", "VI"),
        ("Wallis and Futuna", "WF"),
        ("Western Sahara", "EH"),
        ("Yemen", "YE"),
        ("Zambia", "ZM"),
        ("Zimbabwe", "ZW"),
    ]
    return SimpleVocabulary(
        [SimpleTerm(code, title=country) for country, code in countries]
    )


def get_states(context):
    """Return a list of possible registration US states and Canadian provinces.

    @return: A C{SimpleVocabulary} containing terms for each state.
    """
    states = [
        ("Alabama", "AL"),
        ("Alaska", "AK"),
        ("Arizona", "AZ"),
        ("Arkansas", "AR"),
        ("California", "CA"),
        ("Colorado", "CO"),
        ("Connecticut", "CT"),
        ("Delaware", "DE"),
        ("Florida", "FL"),
        ("Georgia", "GA"),
        ("Hawaii", "HI"),
        ("Idaho", "ID"),
        ("Illinois", "IL"),
        ("Indiana", "IN"),
        ("Iowa", "IA"),
        ("Kansas", "KS"),
        ("Kentucky", "KY"),
        ("Louisiana", "LA"),
        ("Maine", "ME"),
        ("Maryland", "MD"),
        ("Massachusetts", "MA"),
        ("Michigan", "MI"),
        ("Minnesota", "MN"),
        ("Mississippi", "MS"),
        ("Missouri", "MO"),
        ("Montana", "MT"),
        ("Nebraska", "NE"),
        ("Nevada", "NV"),
        ("New Hampshire", "NH"),
        ("New Jersey", "NJ"),
        ("New Mexico", "NM"),
        ("New York", "NY"),
        ("North Carolina", "NC"),
        ("North Dakota", "ND"),
        ("Ohio", "OH"),
        ("Oklahoma", "OK"),
        ("Oregon", "OR"),
        ("Pennsylvania", "PA"),
        ("Rhode Island", "RI"),
        ("South Carolina", "SC"),
        ("South Dakota", "SD"),
        ("Tennessee", "TN"),
        ("Texas", "TX"),
        ("Utah", "UT"),
        ("Vermont", "VT"),
        ("Virginia", "VA"),
        ("Washington", "WA"),
        ("West Virginia", "WV"),
        ("Wisconsin", "WI"),
        ("Wyoming", "WY"),
        ("Alberta", "AB"),
        ("British Columbia", "BC"),
        ("Manitoba", "MB"),
        ("New Brunswick", "NB"),
        ("Newfoundland and Labrador", "NL"),
        ("Northwest Territories", "NT"),
        ("Nova Scotia", "NS"),
        ("Nunavut", "NU"),
        ("Ontario", "ON"),
        ("Prince Edward Island", "PE"),
        ("Quebec", "QC"),
        ("Saskatchewan", "SK"),
        ("Yukon", "YT"),
    ]
    return SimpleVocabulary([SimpleTerm(code, title=name) for name, code in states])


def get_company_sizes(context):
    """Return a list of company size options for registration.

    @return: A C{SimpleVocabulary} containing terms for each option
    """
    options = [
        "1-49",
        "50-99",
        "100-249",
        "250-499",
        "500-999",
        "1,000-4,999",
        "5,000-9,999",
        "10,000-24,999",
        "25,000-49,999",
        "50,000-99,999",
        "100,000+",
    ]

    return SimpleVocabulary([SimpleTerm(option) for option in options])


def get_desktop_ranges(context):
    """
    Return a list of ranges for numbers of Ubuntu desktops in an organisation.

    @return: A C{SimpleVocabulary} containing terms for each option
    """
    options = ["None", "50 or less", "51 - 100", "100 - 500", "501 or more"]

    return SimpleVocabulary([SimpleTerm(option) for option in options])


def get_server_ranges(context):
    """
    Return a list of ranges for numbers of Ubuntu servers in an organisation.

    @return: A C{SimpleVocabulary} containing terms for each option
    """
    options = ["25 or less", "26 - 100", "101 - 250", "251 - 500", "501 or more"]

    return SimpleVocabulary([SimpleTerm(option) for option in options])


def get_ubuntu_usage_options(context):
    """
    Return a list of options for Ubuntu usage in an organisation.

    @return: A C{SimpleVocabulary} containing options.
    """
    options = [
        "Privately only",
        "Commercially only",
        "Privately and commercially",
        "Not at all",
    ]

    return SimpleVocabulary([SimpleTerm(option) for option in options])
