# Copyright 2005-2022 Canonical Ltd. All rights reserved.
from datetime import datetime

from zope.cachedescriptors.property import Lazy

from canonical.landscape.ui.toolbar.page import ComputerPaginatorPage

EXPIRATION_DATE_FORMAT = "%a %b %d %H:%M:%S %Y %Z"


class ComputerUbuntuProInfoPage(ComputerPaginatorPage):

    title = "Ubuntu Pro Info"

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        self._ubuntu_pro_info = self.computer.parsed_ubuntu_pro_info()

        if not self._ubuntu_pro_info:
            self._ubuntu_pro_info = {}

        account = self._ubuntu_pro_info.get("account")
        contract = self._ubuntu_pro_info.get("contract")
        errors = self._ubuntu_pro_info.get("errors")

        if account:
            self.account_name = account.get("name")
        else:
            self.account_name = ""

        if contract:
            self.contract_name = contract.get("name")
            self.tech_support_level = contract.get("tech_support_level")
        else:
            self.contract_name = ""
            self.tech_support_level = ""

        if errors:
            self.errors = errors
        else:
            self.errors = []

        self.attached = self.account_name and not errors

    @property
    def ubuntu_pro_info(self):
        return self._ubuntu_pro_info

    @Lazy
    def expiration(self):
        expires = self._ubuntu_pro_info.get("expires")

        if not expires:
            return ""

        dt = datetime.fromisoformat(expires)
        return dt.strftime(EXPIRATION_DATE_FORMAT)
