# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.schema import Int

from zope.formlib.form import FormField

from canonical.content.form import Fields, action
from canonical.url import get_url

from canonical.landscape.ui.form import LandscapeFormProvider
from canonical.landscape.ui.users.interfaces import INewUser
from canonical.landscape.ui.toolbar.page import ToolbarPage


class AddUserPage(ToolbarPage):

    title = "Add user"

    requires = "landscape.RequestCreateUser"


class AddUserForm(LandscapeFormProvider):

    summary = "User details"
    fields = Fields(FormField(Int(__name__="index", title="index")), INewUser).hide(
        "index"
    )

    def get_initial_data(self):
        if "index" in self.request:
            # This is the form display phase, let's figure out what paginated
            # computer we are dealing with
            return {"index": self.request["index"]}
        else:
            # This is the form processing phase, the index is already set as
            # hidden input.
            return {"index": self.request.get("form.index")}

    @action("Add", primary=True)
    def handle_create(self, action, data):
        index = data.get("index")
        offset = int(index) - 1
        limit = 1
        self.context.create_user(
            data["username"],
            data["name"],
            data["passphrase"],
            require_passphrase_reset=data["require_passphrase_reset"],
            location=data["location"],
            home_phone=data["home_phone"],
            work_phone=data["work_phone"],
            offset=offset,
            limit=limit,
        )
        self.view.notes.info("User %s will be added." % data["username"])
        url = "%s?index=%s" % (get_url(self.context, self.request), index)
        self.request.response.redirect(url)
