# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import object
from zope.interface import Interface
from zope.component import adapts
from zope.publisher.interfaces.browser import IDefaultBrowserLayer

from canonical.landscape.model.users.users import UserSelection


class AffectedUsersProvider(object):

    adapts(UserSelection, IDefaultBrowserLayer, Interface)

    def __init__(self, context, request, view):
        self.context = context
        self.request = request
        self.view = view
        self._affected_users = None
        self._legend = None
        self._indices = None

    def legend(self):
        """
        Generates a dict that maps unique legend keys to computer
        instances.
        """
        if self._legend is None:
            computers = self.context.get_computers()
            indices = self._get_indices(computers)
            legend = {}
            for computer, index in indices.items():
                label = self._get_label(index)
                legend[label] = computer
            self._legend = legend
        return self._legend

    MAP = "0123456789ABCDEFGHIJKLMNOPQRSTUV"

    def _get_label(self, value):
        """
        @param value: An integer >= 0.
        @return: A short human-readable label that can be used in
            place of long computer names.
        """
        if not value:
            return "0"
        result = []
        while value:
            result.insert(0, self.MAP[value & 0x1F])
            value >>= 5
        return "".join(result)

    def affected_users(self):
        """
        Generates a dict that maps usernames to lists that contain
        information about computer relationships.  Each list index
        refers to a computer and contains either C{True} or C{False}
        to indicate whether the user/computer selection exists in the
        current user selection.
        """
        if self._affected_users is None:
            computers = self.context.get_computers()
            indices = self._get_indices(computers)
            template = [False for c in computers]
            index = {}
            for user in self.context.users:
                data = index.get(user.username)
                if data is None:
                    data = index[user.username] = list(template)
                computer_index = indices[user.computer]
                data[computer_index] = True
            self._affected_users = index
        return self._affected_users

    def _get_indices(self, computers):
        """
        Get a dict that maps computers to the index for the element
        that represents membership status in the matrix generated when
        affected users information is rendered.  To be clear, there is
        a direct correspondence between the indices generated here and
        list data produced by L{affected_users}.
        """
        if self._indices is None:
            computers = list(computers)
            computers.sort(key=lambda c: c.title)
            self._indices = {}
            for i, computer in enumerate(computers):
                self._indices[computer] = i
        return self._indices
