# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.interface import Interface, invariant
from zope import schema

from canonical.landscape.model.resource.schema import Username


class INewUser(Interface):

    name = schema.TextLine(title="Name", description="Full name for the new user")

    username = Username(
        title="Username", description="Ubuntu username for the new user"
    )

    passphrase = schema.Password(title="Passphrase")

    verified_passphrase = schema.Password(title="Confirm passphrase")

    require_passphrase_reset = schema.Bool(
        title="Require passphrase reset",
        description="User must change password at first login",
    )

    location = schema.TextLine(title="Location", required=False)

    home_phone = schema.TextLine(title="Home phone", required=False)

    work_phone = schema.TextLine(title="Work phone", required=False)

    @invariant
    def are_passphrases_equal(obj):
        if obj.passphrase != obj.verified_passphrase:
            raise schema.ValidationError("Passphrases are not equal")


class IEditUser(Interface):

    name = schema.TextLine(title="Person's Name", required=False)

    primary_group = schema.Choice(
        title="Primary Group", required=False, vocabulary="groupnames"
    )

    passphrase = schema.Password(title="Passphrase", required=False)

    verified_passphrase = schema.Password(title="Repeat Passphrase", required=False)

    location = schema.TextLine(title="Location", required=False, missing_value="")

    work_phone = schema.TextLine(title="Work phone", required=False, missing_value="")

    home_phone = schema.TextLine(title="Home phone", required=False, missing_value="")

    @invariant
    def are_passphrases_equal(obj):
        if obj.passphrase != obj.verified_passphrase:
            raise schema.ValidationError("Passphrases are not equal")
