# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import object
from zope.component import getMultiAdapter
from zope.formlib.widget import renderElement, SimpleInputWidget
from zope.formlib.widgets import DropdownWidget
from zope.formlib.interfaces import IInputWidget


class OptionalMixin(object):
    """
    A widget that will put a checkbox next to the default widget (as
    defined by adaptation). If the checkbox is not checked, then the
    data will be set to None.
    """

    def __call__(self):
        checkbox = renderElement(
            "input",
            type="checkbox",
            name=self.name + "-enabled",
            id=self.name + "-enabled",
            cssClass=self.cssClass,
            extra=self.extra,
        )
        span = renderElement("span", cssClass="checkbox")
        styled_checkbox = renderElement("label", contents=checkbox + span)
        return self.inner_widget() + "\n" + styled_checkbox

    def setPrefix(self, prefix):
        super(OptionalMixin, self).setPrefix(prefix)
        self.inner_widget.setPrefix(prefix)

    def getInputValue(self):
        if self.name + "-enabled" not in self.request:
            return None
        else:
            return super(OptionalMixin, self).getInputValue()

    def setRenderedValue(self, data):
        self.inner_widget.setRenderedValue(data)


class OptionalWidget(OptionalMixin, SimpleInputWidget):
    """
    This is only suitable for simple text field widgets, and provides the
    optional checkbox widget.
    """

    def __init__(self, form, request):
        super(OptionalMixin, self).__init__(form, request)
        self.inner_widget = getMultiAdapter((self.context, self.request), IInputWidget)


class OptionalDropdownWidget(OptionalMixin, DropdownWidget):
    """
    This provides a dropdown field widget, with the optional checkbox.
    """

    def __init__(self, field, request):
        vocabulary = field.vocabulary
        super(OptionalMixin, self).__init__(field, vocabulary, request)
        self.explicit_empty_selection = False
        self.inner_widget = getMultiAdapter((self.context, self.request), IInputWidget)
