# Copyright 2005-2022 Canonical Limited. All rights reserved.

from zope.formlib.widget import renderElement, SimpleInputWidget
from zope.session.interfaces import ISession


class HiddenPassThroughList(SimpleInputWidget):
    """
    A widget that will look for a list value in the session, and
    inserts a series of hidden inputs with the values from that list
    into the form. Rendering this widget regularly or hidden is the
    same.

    XXX: This should be changed to use vocabularies and not know
    anything about the session.
    """

    def __init__(self, field, request, session_category, session_key):
        super(HiddenPassThroughList, self).__init__(field, request)
        self.session_category = session_category
        self.session_key = session_key

    def hidden(self):
        items = []
        category = ISession(self.request).get(self.session_category, {})
        thingies = category.get(self.session_key)
        if not thingies:
            return ""
        for thingy in thingies:
            items.append(
                renderElement(
                    "input",
                    type="hidden",
                    name=self.name + ":list",
                    id=self.name,
                    value=thingy,
                    cssClass=self.cssClass,
                    extra=self.extra,
                )
            )
        return "\n".join(items)

    __call__ = hidden
