# Copyright 2005-2022 Canonical Limited. All rights reserved.

from zope.session.interfaces import ISession

from canonical.landscape.ui.toolbar.page import ComputerPaginatorPage
from safe.canonical.landscape.model.main.computer import get_computer_by_id


class UsersPage(ComputerPaginatorPage):

    title = "Users"

    def __init__(self, context, request):
        super(UsersPage, self).__init__(context, request)
        self.users = sorted(
            self.computer.get_users(),
            key=lambda user: (self.is_system_user(user), user.username),
        )
        self.user_count = len(self.users)

        self._row_css_class = ""
        self._clear_session_data()

    def _clear_session_data(self):
        """
        Delete all user selection data from the session so nothing
        strange happens when a user does a user-management operation,
        goes back to the user selection screen, doesn't select
        anybody, and clicks another action button.
        """
        users_category = ISession(self.request)["users"]
        if "users" in users_category:
            del users_category["users"]

    def is_system_user(self, user):
        return user.uid < 1000 or user.username == "nobody"


def get_user_from_descriptor(descriptor):
    computer_id, username = descriptor.split(",", 1)
    computer = get_computer_by_id(int(computer_id))
    return computer.get_user_by_username(username)


class UserDescriptor(object):
    """
    Helper class converts a User into a descriptor suitable for use as
    the value for an INPUT element.
    """

    def __init__(self, context, request):
        self.context = context
        self.request = request

    def __str__(self):
        return "%s,%s" % (self.context.computer.id, self.context.username)
