# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from builtins import str
import os

from zope.dottedname.resolve import resolve
from zope.app.wsgi import WSGIPublisherApplication

from convoy.combo import combo_app

from canonical.publication.wsgi import WSGIServerPortSecure
from canonical.landscape.model.root.landscape import create_root
from canonical.landscape.model.configuration import get_static_root_path
from canonical.landscape.ui.constants import STATIC_DIR


def create_zope_app(config=None):
    """Create the WSGI application for running the Landscape UI.

    This function wraps the plain WSGI zope application with a middleware
    based on the contents of the LANDSCAPE_MIDDLEWARE environment
    variable.

    The format of the value is a python dotted name to the middleware
    function or class. Multiple middleware can be specified with comma
    separated values.
    """
    if config is None:
        config = {}
    root = config.get("root")
    if root is None:
        root = create_root()
    application = WSGIPublisherApplication(db=root)
    # Wrap the Zope WSGI application with a middleware that honours the
    # X-Forwarded-Proto header.
    application = WSGIServerPortSecure(application)

    middleware_config = os.environ.get("LANDSCAPE_MIDDLEWARE", None)
    if middleware_config is not None:
        middleware_names = middleware_config.split(",")
    else:
        middleware_names = []
    for name in middleware_names:
        try:
            middleware = resolve(name)
        except ImportError:
            raise ValueError("Invalid Middleware %s" % (name))
        application = middleware(application)

    if config.get("devmode"):
        from canonical.openid.wsgi import OpenIdProviderMiddleware

        root_url = str(config.get("root-url"))

        # openid-connect fake provider, except for older releases
        try:
            from canonical.oidc.wsgi import OpenIdConnectProviderMiddleware

            application = OpenIdConnectProviderMiddleware(application, root_url)
        except ImportError:
            pass

        # openid v2 fake provider
        application = OpenIdProviderMiddleware(application, root_url)

    return application


def create_combo_app():
    """Create the WSGI application for the combo loader."""
    resource_prefix = str(get_static_root_path()) + "/static/"
    return combo_app(STATIC_DIR, resource_prefix=resource_prefix, rewrite_urls=True)
