# Copyright 2005-2012 Canonical Limited.  All rights reserved.

from canonical.lib.mathutils import least_squares


def forecast(series, threshold, max_forecast=None):
    """
    Provide a forecast for when the given series will reach the specified
    threshold value.

    If the forecast will not be reached in the future, max_forecast is
    returned.

    If the threshold has alreadby been crossed, zero is returned.

    @param series: the series of values to use in forecasting, in the form
        [(timestamp, value), ...]
    @param threshold: the target value to look for when forecasting
    @param max_forecast: when the forecast value is going to be large, return
        this value instead.
    @return: A float value for the difference between the last timestamp and
        when the threshold will be reached, or the value provided as
        C{max_forecast}.
    """
    try:
        a, b = least_squares(series)
        value = (threshold - b) / a
    except ZeroDivisionError:
        return max_forecast

    last_value = series[-1][0]
    # return the number of time units since the last point
    forecast = value - last_value

    if max_forecast is not None and forecast > max_forecast:
        forecast = max_forecast
    if forecast < 0:
        if a < 0:
            # usage is decreasing
            forecast = max_forecast
        else:
            # already crossed the threshold
            forecast = 0.0

    return forecast
