# Copyright 2005-2012 Canonical Limited.  All rights reserved.


def average(values):
    """Return the average for values."""
    if not values:
        return 0.0
    return float(sum(values)) / len(values)


def weighted_average(values):
    """
    Return the weighted average of a list of weighted values, expressed as
    (value, weight) tuples.
    """
    weights = 0
    total = 0.0
    for value, weight in values:
        total += value * weight
        weights += weight

    return total / weights if weights else 0.0


def least_squares(series):
    """
    Return a tuple with (a, b) coefficients for the straight line expressed by

      y = a * x + b

    approximating values for the specified series (expressed as (x, y) tuples),
    using the "Least squares" method.

    The series must contain at least two data points.
    """
    x, x_square, y, xy = [], [], [], []
    for sample_x, sample_y in series:
        x.append(sample_x)
        y.append(sample_y)
        x_square.append(sample_x ** 2)
        xy.append(sample_x * sample_y)

    n = float(1) / len(series)
    num = sum(xy) - n * float(sum(x) * sum(y))
    det = sum(x_square) - n * sum(x) ** 2
    a = num / det
    b = average(y) - a * average(x)
    return a, b
