# Copyright 2005-2016 Canonical Limited.  All rights reserved.

from random import uniform
from time import sleep

from storm.twisted.transact import RETRIABLE_ERRORS

import transaction


def uniform_exponential(max_retries):
    """Return a list of random sleep periods for an exponential backoff."""
    return [uniform(1, pow(2, i)) for i in range(max_retries)]


def retry(function, sleep_iterable, transaction=transaction):
    """Retry function() sleeping between attempts.

    The amount to sleep between each attempt is given in sleep_iterable
    (the length of which defines how many retries are attempted).

    Retries all attempts that raise a Storm "retriable error".
    """
    for sleep_time in sleep_iterable:
        try:
            result = function()
            transaction.commit()
        except RETRIABLE_ERRORS:
            transaction.abort()
            sleep(sleep_time)
            continue
        else:
            return result
    result = function()
    transaction.commit()
