# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.interface import implementer

from canonical.message.interfaces import IMessageHandler


@implementer(IMessageHandler)
class BaseHandler(object):
    def __init__(self, message_api):
        self.message_api = message_api

    def __call__(self, type, body):
        raise NotImplementedError("Handler.__call__ must be implemented")


def FunctionHandler(function):
    """A simple handler that delegates to a function.

    @param function: The function to call. It should accept three
        arguments: The first will be a message API, the second a type, and
        the third a message body.
    """

    class BaseFunctionHandler(BaseHandler):
        def __call__(self, type, body):
            return function(self.message_api, type, body)

    return BaseFunctionHandler


@implementer(IMessageHandler)
def NoHandler(message_api):
    return None
