# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.interface import Interface


class MessageAPINotFound(Exception):
    """Raised when a message API isn't found."""


class MessageHandlerNotFound(Exception):
    """Raised when a message isn't handled."""


class IMessageSystem(Interface):
    def dispatch(request):
        """Handle messages in the given request."""

    def handle(message_api, type, message):
        """Dispatch the given message to the message handler."""

    def get_handlers(message_api):
        """Return a list of two-tuples of (name, IMessageHandler provider)."""


class IMessageAPI(Interface):
    def send(message):
        """Send a message to the communicating entity."""

    def run():
        """Handle received messages."""


class IMessageHandler(Interface):
    def __call__(api, message):
        """Handle the given message."""
