# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.interface import Interface
from zope.schema import TextLine, Text, URI, Int


class INavigation(Interface):
    def get_items():
        """Return items associated with this navigation."""

    def is_available():
        """Return boolean indicating if this navigation should be rendered."""


class INavigationItem(INavigation):
    def is_selected():
        """Return boolean indicating if this item is selected."""

    name = TextLine(title="Name", description="Navigation item name.", required=True)

    title = TextLine(
        title="Title", description="Basic label for the navigation item.", required=True
    )

    description = Text(
        title="Description",
        description="Description of the navigation item. This might be shown "
        "on menu pages or in pop-up help for menu items.",
        required=False,
    )

    action = TextLine(
        title="The URL to display if the item is selected",
        description="When a user selects a navigation item, the URL"
        "given in the action is displayed.",
        required=True,
    )

    order = Int(
        title="Ordering hint",
        description="This attribute provides a hint for navigation item "
        "ordering. Menu items will generally be sorted by "
        "their `fitness` to the parent navigation, and then "
        "by the order.",
        required=False,
    )

    icon = URI(
        title="Icon URI",
        description="URI of the icon representing this menu item",
        required=False,
    )
