# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.configuration.exceptions import ConfigurationError
from zope.security.checker import CheckerPublic
from zope.component.zcml import adapter

from canonical.navigation.interfaces import INavigation, INavigationItem
from canonical.navigation.navigation import TALESNavigationItem


def navigation(_context, name, class_, for_=None, layer=None, parent=None):
    if parent is not None:
        adapter(
            _context,
            factory=(class_,),
            provides=INavigation,
            for_=(for_, layer, parent),
            permission=CheckerPublic,
            name=name,
        )
    else:
        adapter(
            _context,
            factory=(class_,),
            provides=INavigation,
            for_=(for_, layer),
            permission=CheckerPublic,
            name=name,
        )


def navigation_item(
    _context,
    name,
    parent,
    for_=None,
    layer=None,
    class_=None,
    permission=None,
    title=None,
    title_expr=None,
    description=None,
    description_expr=None,
    action=None,
    action_expr=None,
    icon=None,
    icon_expr=None,
    available_expr=None,
    selected_expr=None,
    order=None,
    extra_class=None,
):
    l = locals()

    for (a, b) in [
        ("title", "title_expr"),
        ("description", "description_expr"),
        ("action", "action_expr"),
        ("icon", "icon_expr"),
    ]:
        if l[a] is not None and l[b] is not None:
            raise ConfigurationError("Can't define %r and %r" % (a, b))

    if class_ is None:
        for (a, b) in [("title", "title_expr")]:
            if l[a] is None and l[b] is None:
                raise ConfigurationError("Must define %r or %r" % (a, b))

    if class_ is None:
        bases = (TALESNavigationItem,)
    elif issubclass(class_, TALESNavigationItem):
        bases = (class_,)
    else:
        bases = (class_, TALESNavigationItem)

    class_dict = {}
    for attr in [
        "name",
        "title",
        "title_expr",
        "order",
        "permission",
        "description",
        "description_expr",
        "action",
        "action_expr",
        "icon",
        "icon_expr",
        "available_expr",
        "selected_expr",
        "extra_class",
    ]:
        if l[attr] is not None:
            class_dict[attr] = l[attr]

    factory = type("ZCMLNavigationItem", bases, class_dict)

    adapter(
        _context,
        factory=(factory,),
        provides=INavigationItem,
        for_=(for_, layer, parent),
        permission=CheckerPublic,
        name=name,
    )
