# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.configuration.fields import GlobalObject, GlobalInterface
from zope.security.zcml import Permission
from zope.interface import Interface
from zope.schema import TextLine, Int


class INavigationDirective(Interface):

    name = TextLine(
        title="Name",
        description="Name this navigation will be registered as.",
        required=True,
    )

    for_ = GlobalObject(
        title="Target",
        description="The interface or class this navigation is for.",
        required=False,
    )

    layer = GlobalInterface(title="Request type", required=False)

    class_ = GlobalObject(
        title="Class", description="Class implementing INavigation.", required=True
    )

    parent = GlobalObject(
        title="Parent",
        description="When a parent is provided, navigation items registered "
        "for this navigation will automatically be used in the "
        "parent.",
        required=False,
    )


class INavigationItemDirective(Interface):

    name = TextLine(
        title="Name",
        description="Name this navigation item will be registered as.",
        required=True,
    )

    for_ = GlobalObject(
        title="Target",
        description="The interface or class this navigation item is for.",
        required=False,
    )

    layer = GlobalInterface(title="Request type", required=False)

    class_ = GlobalObject(
        title="Class", description="Class implementing INavigationItem.", required=False
    )

    parent = GlobalObject(
        title="Parent",
        description="Navigation (item) this item is attached to.",
        required=True,
    )

    title = TextLine(
        title="Title", description="Title of the navigation item.", required=False
    )

    title_expr = TextLine(
        title="Title expression",
        description="TALES expression evaluating to the title.",
        required=False,
    )

    description = TextLine(
        title="Description",
        description="Description of the navigation item.",
        required=False,
    )

    description_expr = TextLine(
        title="Description expression",
        description="TALES expression evaluating to the description.",
        required=False,
    )

    action = TextLine(
        title="Action",
        description="URL to be used when this item is activated.",
        required=False,
    )

    action_expr = TextLine(
        title="Action expression",
        description="TALES expression evaluating to the action.",
        required=False,
    )

    icon = TextLine(
        title="Icon",
        description="URL of an image to be shown with the item title.",
        required=False,
    )

    icon_expr = TextLine(
        title="Icon expression",
        description="TALES expression evaluating to the icon.",
        required=False,
    )

    available_expr = TextLine(
        title="Available expression",
        description="TALES expression evaluating to a boolean value that "
        "will tell if the item is available or not.",
        required=False,
    )

    selected_expr = TextLine(
        title="Selected expression",
        description="TALES expression evaluating to a boolean value that "
        "will tell if the item is selected or not.",
        required=False,
    )

    order = Int(
        title="Order",
        description="Order of rendering for this item, as an integer.",
        default=0,
        required=False,
    )

    permission = Permission(
        title="Permission",
        description="Permission needed to see the item (affects " "availability).",
        required=False,
    )

    extra_class = TextLine(
        title="Extra HTML element Class",
        description="An additional class to be applied to the item.",
        required=False,
    )
