# Copyright 2005-2014 Canonical Limited.  All rights reserved.

from canonical.openstack.api import OpenStackClient


class SwiftClient(OpenStackClient):
    """A client for the Swift API."""

    def create_container(self, name, public=False):
        """Create a container.

        @param name: The name of the container.
        @param public: Whether the container should be public, i.e. get
            ".r:*" read permissions.
        """
        headers = {}
        if public:
            headers["X-Container-Read"] = ".r:*"
        return self.request("PUT", name, headers=headers)

    def create_object(self, container, path, data):
        """Create an object inside a container.

        @param container: The name of the container to create the object in.
        @param path: The path to the object inside the container.
        @param data: The contents of the object.
        """
        return self.request("PUT", "%s/%s" % (container, path), body=data)

    def get_object(self, container, path):
        """Get an object from Swift.

        @param container: The name of the container with the object.
        @param path: The path to the object inside the container.
        @return data: The contents of the object.
        """
        return self.request("GET", "{}/{}".format(container, path))
