class WSGIServerPortSecure(object):
    """Set 'SERVER_PORT_SECURE' to match the X-Forwarded-Proto header.

    The Zope publication machinery looks for a custom 'SERVER_PORT_SECURE' key
    in the WSGI environment in order to decide if the original protocol of a
    proxied request is http or https. This class acts as an adapter converting
    the standard X-Forwarded-Proto header to Zope's SERVER_PORT_SECURE.
    """

    def __init__(self, zope_app):
        """
        @param app: The zope.app.wsgi,WSGIPublisherApplication to wrap.
        """
        self._zope_app = zope_app

    def __call__(self, environ, start_response):
        if environ.get("HTTP_X_FORWARDED_PROTO", "") == "https":
            environ["SERVER_PORT_SECURE"] = "1"
        return self._zope_app(environ, start_response)
