# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.interface import Interface
from zope.schema import Int, TextLine, Text


class IRoleRegistry(Interface):
    def add(role):
        """Add a role to the registry."""

    def remove(role):
        """Remove a role from the registry."""

    def get(key):
        """Get a role by key or name."""

    def grant(role, perm):
        """Grant permission to role."""

    def revoke(role, perm):
        """Revoke permission from role."""

    def may(roles, perm):
        """Check if the given set of roles has the permission."""


class IRole(Interface):

    name = TextLine(
        title="Name", description="Name for the role", required=True, readonly=True
    )

    title = TextLine(title="Title", description="Title for the role.", required=False)

    description = Text(
        title="Description", description="Description for the role.", required=False
    )

    key = Int(
        title="Key",
        description="Numeric key for the role",
        required=False,
        readonly=True,
    )

    def __init__(name, title, description, key, provides):
        """Constructor"""


class IPermissionChecker(Interface):
    def __call__(permission):
        """Check if permission is allowed in the context object."""
