from storm.exceptions import CompileError


def compile_columns(columns):
    """Convert Column objects into a comma-separated list of column names.

    An error will be raised if no columns are given or the columns don't
    belong to the same model.
    """
    if not columns:
        raise CompileError("No columns provided")

    model_class = columns[0].cls

    column_names = []
    for column in columns:
        if column.cls is not model_class:
            raise CompileError("Inconsistent column models")
        column_names.append(column.name)

    return ",".join(column_names)


def compile_rows(rows):
    """Convert Row tuples into a comma-separated list of parameter strings."""
    if not rows:
        raise CompileError("No values provided")

    return ",".join(("%s",) * len(rows))
