##############################################################################
#
# Copyright (c) 2003 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Functional testing framework for Zope 3.

Most of this code can go away once LP #574759 is fixed.
"""
import os.path
from http.cookies import SimpleCookie

import transaction

import z3c.etestbrowser.testing
import z3c.etestbrowser.wsgi

from openid import oidutil
from openid.fetchers import setDefaultFetcher, getDefaultFetcher

from canonical.testing.wsgiopenid import OpenIdWSGIFetcher


MAX_DEPTH = 3
BASE_PATH = os.path.abspath(os.path.sep.join(__file__.split(os.path.sep)[:-MAX_DEPTH]))


class CookieHandler(object):
    def __init__(self, *args, **kw):
        # Somewhere to store cookies between consecutive requests
        self.cookies = SimpleCookie()
        super(CookieHandler, self).__init__(*args, **kw)

    def httpCookie(self, path):
        """Return self.cookies as an HTTP_COOKIE environment value."""
        l = [
            m.OutputString().split(";")[0]
            for m in list(self.cookies.values())
            if path.startswith(m["path"])
        ]
        return "; ".join(l)

    def loadCookies(self, envstring):
        self.cookies.load(envstring)

    def saveCookies(self, response):
        """Save cookies from the response."""
        # Urgh - need to play with the response's privates to extract
        # cookies that have been set
        # TODO: extend the IHTTPRequest interface to allow access to all
        # cookies
        # TODO: handle cookie expirations
        for k, v in list(response._cookies.items()):
            k = k.encode("utf8")
            self.cookies[k] = v["value"].encode("utf8")
            if "path" in v:
                self.cookies[k]["path"] = v["path"]


class Browser(z3c.etestbrowser.wsgi.Browser):
    """A Zope `testbrowser` Browser that uses the Zope Publisher."""

    def __init__(self, url=None, wsgi_app=None):

        if wsgi_app is None:
            from canonical.landscape.ui.wsgi import create_ui_wsgi_app

            wsgi_app = create_ui_wsgi_app(
                {"devmode": True, "root-url": "http://localhost/"}
            )

        def wsgi_app_wrapper(*args, **kwargs):
            # Persist changes performed by test code before the WSGI request
            # is executed.
            orig_openid_log = oidutil.log
            orig_openid_fetcher = getDefaultFetcher()
            # Quiet OpenID logging
            oidutil.log = lambda message, level=0: None
            # Set a WSGI-based fetcher for open ID, to be able to use a test
            # OpenID provider without performing real HTTP requests
            setDefaultFetcher(OpenIdWSGIFetcher(wsgi_app))
            transaction.commit()
            result = wsgi_app(*args, **kwargs)
            oidutil.log = orig_openid_log
            setDefaultFetcher(orig_openid_fetcher)
            return result

        super(Browser, self).__init__(url=url, wsgi_app=wsgi_app_wrapper)
