# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.configuration import xmlconfig
from zope.component.hooks import setHooks, resetHooks, setSite

from canonical.root import Root
from canonical.testing.unit import UnitTest
from canonical.testing.doc import DocTest
from canonical.testing.resources import (
    ConfigurationContextResourceManager,
    CoreZcmlResourceManager,
    PublicationZcmlResourceManager,
    zcml_extension,
)
from canonical.testing.session import SessionFixture


class PublicationTest(UnitTest):
    """Base test of UI publication packages with ZCML directives."""

    resources = [
        ("context", ConfigurationContextResourceManager()),
        ("core", CoreZcmlResourceManager()),
        ("publication", PublicationZcmlResourceManager()),
    ]


class PublicationDocTest(PublicationTest, DocTest):
    """Convenience for running publication-related doc tests."""

    def setUp(self):
        super(PublicationDocTest, self).setUp()

        # Set up a site overlay, so the zcml snippets processed in the doctests
        # will populate a transient components registry
        setHooks()
        setSite(Root())
        context = zcml_extension()

        def zcml(s):
            xmlconfig.string(s, context)

        self.extraglobs.update(dict(zcml=zcml))
        self.useFixture(SessionFixture())

    def tearDown(self):
        super(PublicationDocTest, self).tearDown()
        setSite(None)
        resetHooks()
