# Copyright 2005-2022 Canonical Limited. All rights reserved.

import os
import tempfile

from gnupg import GPG

from canonical.lib.archive import DebFile, ChangesFile

from canonical.testing.gpg import SAMPLE_SECRET_KEY_MATERIAL, SAMPLE_SECRET_KEY_ID
from canonical.testing.twist import TwistedTestCase
from storm.tests.mocker import MockerTestCase


class RepreproTestCase(MockerTestCase, TwistedTestCase):
    def setUp(self):
        super(RepreproTestCase, self).setUp()
        self.tempdir = tempfile.TemporaryDirectory()
        self.addCleanup(self.tempdir.cleanup)
        self.basedir = self.tempdir.name

    def makeChanges(
        self,
        name,
        version,
        arch,
        distro,
        maintainer,
        sign=False,
        section="utils",
        md5=None,
        size=None,
        changed_by=None,
        basedir=None,
        udeb=False,
    ):

        if basedir is None:
            basedir = self.basedir

        incomingdir = os.path.join(basedir, "incoming")
        if not os.path.exists(incomingdir):
            os.makedirs(incomingdir)
        changes = ChangesFile(
            name,
            version,
            arch,
            distro,
            maintainer,
            section,
            "optional",
            date="Thu, 25 Aug 2011 16:35:28",
            changed_by=changed_by,
        )

        debfile = DebFile()
        debfile.field("Package", name)
        debfile.field("Version", version)
        debfile.field("Architecture", arch)
        debfile.field("Maintainer", maintainer)
        debfile.field("Section", section)
        debfile.field("Priority", "optional")
        debfile.field("Description", "some package")
        ext = "udeb" if udeb else "deb"
        debpath = os.path.join(incomingdir, "%s_%s_%s.%s" % (name, version, arch, ext))
        if size is None:
            path = self.makeFile(path=debpath)
            with open(path, "wb") as fp:
                fp.write(debfile.pack())

        changes.add_file(debpath, md5=md5, size=size)

        if sign:
            gnupghome_dir = tempfile.TemporaryDirectory()
            self.addCleanup(gnupghome_dir.cleanup)
            gnupghome = gnupghome_dir.name
            gpg = GPG(gnupghome=gnupghome)
            gpg.import_keys(SAMPLE_SECRET_KEY_MATERIAL)
            content = changes.content(
                signed_with=SAMPLE_SECRET_KEY_ID, gpg_options={"gnupghome": gnupghome}
            )
        else:
            content = changes.content()

        self.makeFile(content, path=os.path.join(incomingdir, changes.default_name))
        # Return a unicode so it can be used in model attributes.
        return str(changes.default_name)
