# Copyright 2005-2013 Canonical Limited.  All rights reserved.

"""
Test runner for Landscape tests.
"""

import os
import sys

_worker = None


def run():
    from twisted.scripts.trial import run

    os.environ["LANDSCAPE_TESTRUN"] = "1"

    argv_no_options = [arg for arg in sys.argv[1:] if not arg.startswith("-")]
    if "selenium-test" in sys.argv[0]:
        os.environ["LANDSCAPE_TEST_SELENIUM"] = "1"
        default_tests = "canonical.landscape.ui.tests.test_selenium"
    else:
        # This is "canonical" but isn't hardcoded as such to prevent
        # breakages if you run tests from outside of the root of the
        # repository.
        default_tests = os.path.dirname(os.path.dirname(__file__))
    if not argv_no_options:
        sys.argv.append(default_tests)

    # If we're being invoked by testr, we got an additional --load-list
    # command line argument, which trial does not natively support. It
    # points to a temporary file with a list of tests to run.
    is_testr_run = "--load-list" in sys.argv
    if is_testr_run:
        # Since twisted.scripts.trail.run looks directly at sys.argv, we need
        # to mangle it directly, by removing the extra --load-list parameter
        # and its file argument and inserting the list of tests to run.
        index = sys.argv.index("--load-list")
        sys.argv.pop(index)
        with open(sys.argv.pop(index)) as fd:
            test_ids = fd.read().split("\n")
        if test_ids[-1] == "":
            test_ids = test_ids[:-1]
        sys.argv.extend(test_ids)

    # Wrap run() in a try/except, since if we're being invoked by testr, we
    # don't want to terminate with a non-zero exit code, otherwise testr will
    # add a synthetic test failure to the report. See:
    #
    #   https://code.launchpad.net/~lifeless/testrepository/\
    #     exit-code/+merge/130746
    try:
        run()
    except SystemExit:
        if not is_testr_run:
            raise


def coverage_run():
    from coverage import coverage

    coverage_instance = coverage(data_suffix=True, config_file=True)
    coverage_instance.start()
    try:
        return run()
    finally:
        coverage_instance.stop()
        coverage_instance.save()


def get_worker():
    """Get the identifier of the worker process being run.

    @return: When -jN is used, an integer identifying the specific worker
        being run, otherwise C{None}.
    """
    global _worker
    cwd = os.getcwd()
    parent_directory = os.path.basename(os.path.dirname(cwd))
    if parent_directory == "_trial_temp":
        # This means we're a worker process.
        _worker = int(os.path.basename(cwd))
    return _worker
