# Copyright 2005-2022 Canonical Limited. All rights reserved.

from openid.fetchers import HTTPResponse

from webtest import TestApp, lint


webtest_check_content_type = lint.check_content_type


def check_content_type(status, headers):
    """Workaround webtest's lint requiring a Content-Type header for redirects.

    Webtest doesn't like responses generated by the Zope publisher when raising
    a Redirect exception, because they don't contain a Content-Type header.

    Maybe we should consider adding an exception-handling view, see also
    zope.app.publication.zopepublication.ZopePublication.handleException.
    """
    code = int(status.split(None, 1)[0])
    if code == 302:
        return
    return webtest_check_content_type(status, headers)


lint.check_content_type = check_content_type


class OpenIdWSGIFetcher(object):
    """A WSGI-based OpenID fetcher to be used in tests."""

    def __init__(self, wsgi_app):
        self.test_app = TestApp(wsgi_app)

    def fetch(self, url, body=None, headers=None):
        if body is None:
            response = self.test_app.get(url)
        else:
            response = self.test_app.post(url, body)
        return HTTPResponse(
            final_url=url,
            status=int(response.status.split(" ")[0]),
            headers=dict(list(response.headers.items())),
            body=response.body,
        )
