# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.component import getUtility

from storm.databases.postgres import PostgresTimeoutTracer
from storm.tracer import get_tracers, install_tracer

from canonical.timer.interfaces import ITimer


class RequestTimeoutTracer(PostgresTimeoutTracer):
    def __init__(self, allowed_request_time):
        super(RequestTimeoutTracer, self).__init__()
        self._allowed_request_time = allowed_request_time
        self._timer = getUtility(ITimer)

    def get_remaining_time(self):
        return self._allowed_request_time - self._timer.get("request")

    def set_allowed_request_time(self, request_time):
        """Update the allowed request time post instantiation."""
        self._allowed_request_time = request_time


def set_allowed_request_time(timeout):
    """
    Set the allowed request time on the installed
    L{RequestTimeoutTracer}, or create a new one with that timeout.
    """
    tracers = get_tracers()
    for tracer in tracers:
        if isinstance(tracer, RequestTimeoutTracer):
            tracer.set_allowed_request_time(timeout)
            return
    install_tracer(RequestTimeoutTracer(timeout))
