# Copyright 2005-2013 Canonical Limited.  All rights reserved.

import threading
import time

from zope.interface import implementer

from canonical.timer.interfaces import ITimer


@implementer(ITimer)
class Timer(object):
    def __init__(self):
        self._initialize_storage()

    def _initialize_storage(self):
        self._running = {}
        self._stopped = {}

    def start(self, what):
        """Start timing the given event."""
        self._running[what] = time.time()

    def stop(self, what):
        """Stop timing the given event."""
        self._stopped[what] = time.time() - self._running.pop(what)

    def reset(self, what=None):
        """Forget elapsed time for the given event."""
        if what:
            self._running.pop(what, None)
            self._stopped.pop(what, None)
        else:
            self._running.clear()
            self._stopped.clear()

    def get(self, what):
        """Get elapsed time for the given event.

        @return: Elapsed time for the given event, or 0 if tracking of
                 the given event hasn't started yet.
        """
        if what in self._running:
            return time.time() - self._running[what]
        elif what in self._stopped:
            return self._stopped[what]
        return 0


class ThreadTimer(Timer):
    def _initialize_storage(self):
        self._local = threading.local()

    @property
    def _running(self):
        try:
            return self._local._running
        except AttributeError:
            self._local._running = {}
            return self._local._running

    @property
    def _stopped(self):
        try:
            return self._local._stopped
        except AttributeError:
            self._local._stopped = {}
            return self._local._stopped


thread_timer_utility = ThreadTimer()
