from urllib.parse import quote


def encode(string):
    """Encodes a string per the canonicalization rules."""
    if isinstance(string, str):
        string = string.encode()

    return quote(string, safe="~")


def get_canonical_query_params(params):
    """Returns the canonical query params used in signing."""
    result = ["{}={}".format(encode(k), encode(v)) for k, v in params.items()]
    return "&".join(result)


def signing_text(endpoint, params):
    """Creates the text to be signed when signing a request.

    @param endpoint: The L{ServiceEndpoint} to consider.
    @param params: A C{dict} of parameters to consider.
    """
    return "\n".join(
        (
            endpoint.method,
            endpoint.get_canonical_host(),
            endpoint.path,
            get_canonical_query_params(params),
        )
    ).encode()
