import hmac
import time
from base64 import b64encode
from hashlib import sha1, sha256

from urllib.parse import urlparse, urlunparse


def hmac_sha1(secret, data):
    digest = hmac.new(secret, data, sha1).digest()

    return b64encode(digest)


def hmac_sha256(secret, data):
    digest = hmac.new(secret, data, sha256).digest()

    return b64encode(digest)


def iso8601time(time_tuple):
    """Formats `time_tuple` as a ISO8601 time string.

    :param time_tuple: Either None (for current time) or a tuple representing a
        datetime.
    """
    if time_tuple:
        return time.strftime("%Y-%m-%dT%H:%M:%SZ", time_tuple)

    return time.strftime("%Y-%m-%dT%H:%M:%SZ", time.gmtime())


def parse(url, defaultPort=True):
    """
    Splits `url` into its cheme, host, port, and path.

    @type url: C{str}
    @param url: A URL to parse.

    @type defaultPort: C{bool}
    @param defaultPort: If True, returns the default port associated with the
        scheme of `url`, if it does not specific one.

    @return: a four-tuple of scheme, host, port, and path for `url`. All are
    C{str} instances except for port, which is C{int}.
    """
    url = url.strip()
    parsed = urlparse(url)
    scheme = parsed[0]
    path = urlunparse(("", "") + parsed[2:])
    host = parsed[1]

    if ":" in host:
        host, port = host.split(":")

        try:
            port = int(port)
        except ValueError:
            # A non-int port, it will be replaced with an appropriate default
            # if defaultPort is True.
            port = None
    else:
        port = None

    if port is None and defaultPort:
        if scheme == "https":
            port = 443
        else:
            port = 80

    if path == "":
        path = "/"

    return (str(scheme), str(host), port, str(path))
