# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.configuration.exceptions import ConfigurationError
from zope.security.checker import CheckerPublic
from zope.component.zcml import adapter
from zope.component import getUtility

from canonical.url.interfaces import IContextURL
from canonical.url.url import TALESContextURL


def url(
    _context,
    for_,
    layer=None,
    class_=None,
    path_expr=None,
    parent_expr=None,
    parent_utility=None,
    parent_utility_name="",
    alias=None,
):

    if class_:
        if path_expr or parent_expr:
            raise ConfigurationError(
                "Can't use 'class' with " "'path_expr' or 'parent_expr'"
            )

        class ZCMLContextURL(class_):
            if parent_utility:

                def parent(self):
                    return getUtility(parent_utility, parent_utility_name)

                parent = property(parent, lambda self: None)

        if alias is not None:
            ZCMLContextURL.alias = alias

    elif path_expr:
        if parent_expr and parent_utility:
            raise ConfigurationError("Can't use 'parent_utility' with " "'parent_expr'")

        path_expr_ = path_expr
        parent_expr_ = parent_expr

        class ZCMLContextURL(TALESContextURL):
            path_expr = path_expr_
            parent_expr = parent_expr_

            if parent_utility:

                def parent(self):
                    return getUtility(parent_utility, parent_utility_name)

                parent = property(parent, lambda self: None)

        if alias is not None:
            ZCMLContextURL.alias = alias

    else:
        raise ConfigurationError("Must provide 'class' or 'path_expr'")

    adapter(
        _context,
        factory=(ZCMLContextURL,),
        provides=IContextURL,
        for_=(for_, layer),
        permission=CheckerPublic,
    )
