from future import standard_library

standard_library.install_aliases()
from builtins import object

# Copyright 2005-2013 Canonical Limited.  All rights reserved.

import posixpath
import urllib.request, urllib.parse, urllib.error
import re

import six

from zope.tales import expressions
from zope.tales.tales import NAME_RE
from zope.component import getMultiAdapter
from zope.interface.interfaces import IInterface
from zope.interface import implementer
from zope.pagetemplate.engine import Engine

from canonical.url.interfaces import IContextURL

# XXX monkey patch to workaround a backward incompatible
# change in zope.tales.expression see #1131729
expressions._interp = re.compile(r"\$(%(n)s)|\${(%(n)s(?:/[^}]*)*)}" % {"n": NAME_RE})


__all__ = [
    "get_context_url",
    "get_url",
    "get_url_object",
    "quote_url",
    "ContextURL",
    "TALESContextURL",
]


def get_context_url(context, request):
    return getMultiAdapter((context, request), IContextURL)


def get_url(context, request):
    parts = []
    while context:
        context_url = getMultiAdapter((context, request), IContextURL)
        path = context_url.path
        if path:
            parts.append(path)
        context = context_url.parent
    parts.reverse()
    return posixpath.join("/", *parts)


def get_url_object(context, request, spec):
    if isinstance(spec, six.string_types):
        while context:
            context_url = getMultiAdapter((context, request), IContextURL)
            if context_url.alias == spec:
                return context
            context = context_url.parent
    elif isinstance(spec, type):
        while context:
            if isinstance(context, spec):
                return context
            context_url = getMultiAdapter((context, request), IContextURL)
            context = context_url.parent
    elif IInterface.providedBy(spec):
        while context:
            if spec.providedBy(context):
                return context
            context_url = getMultiAdapter((context, request), IContextURL)
            context = context_url.parent
    return None


def quote_url(url):
    return urllib.parse.quote(url.encode("utf-8"))


@implementer(IContextURL)
class ContextURL(object):

    alias = None
    path = ""
    parent = None

    def __init__(self, context, request):
        self.context = context
        self.request = request


class TALESContextURLMeta(type):
    """Dynamically compile expressions at class creation."""

    def __new__(cls, name, bases, namespace):
        cls = type.__new__(cls, name, bases, namespace)
        if cls.path_expr:
            cls._compiled_path_expr = Engine.compile(cls.path_expr)
        else:
            cls._compiled_path_expr = None
        if cls.parent_expr:
            cls._compiled_parent_expr = Engine.compile(cls.parent_expr)
        else:
            cls._compiled_parent_expr = None
        return cls


class TALESContextURL(ContextURL, metaclass=TALESContextURLMeta):
    path_expr = None
    parent_expr = None

    def __init__(self, context, request):
        super(TALESContextURL, self).__init__(context, request)
        tales_context = TALESContext(self)
        # First compile the parent, so that it may be used in path.
        parent_expr = getattr(self, "_compiled_parent_expr")
        path_expr = getattr(self, "_compiled_path_expr")

        if parent_expr:
            self.parent = parent_expr(tales_context)
        if path_expr:
            self.path = path_expr(tales_context)


class TALESContext(object):
    def __init__(self, context_url):
        self._context_url = context_url

    def __getitem__(self, name):
        value = self.get(name, self)
        if value is self:
            raise KeyError(name)
        return value

    def get(self, name, default=None):
        if name == "context":
            return self._context_url.context
        elif name == "request":
            return self._context_url.request
        elif name == "parent":
            return self._context_url.parent
        return default

    @property
    def vars(self):
        return self
