<?xml version="1.0" encoding="UTF-8"?>
<!--

This file is Copyright 2012 Canonical Limited.  All rights
reserved.  Note that this is a derived work. The relevant upstream
licensing information can be found at:

/usr/share/doc/docbook-xsl/copyright

-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xi="http://www.w3.org/2001/XInclude" xmlns:exsl="http://exslt.org/common" xmlns="http://www.w3.org/1999/xhtml" version="1.0" exclude-result-prefixes="exsl">

  <!-- This file is a controller for the standard DocBook processing
       stylesheets.  We override specific templates here to modify their
       output in ways they do not support by parameterisation.  Sadly
       this approach leaves us open to issues should the XSLT in the
       mainstream package change, so we try to use it sparingly. -->

  <!-- The following file is found in the Ubuntu docbook-xsl package and
       is an explicit dependency of this code. It is very important that
       this line comes first in the code as which version of a template
       is used hangs on when it is defined.-->
  <xsl:import href="file:///usr/share/xml/docbook/stylesheet/docbook-xsl/xhtml-1_1/chunkfast.xsl"/>

  <xsl:strip-space elements="*"/>
  <xsl:output method="xml" omit-xml-declaration="no" encoding="UTF-8" indent="yes"/>

  <!-- By default the title attribute is set on divs which results in an
       annoying tooltip following your mouse.  This overrides so the title
       attribute is not set.-->
  <xsl:template name="generate.html.title"/>



  <!-- Param to hold the revision number for inclusion in the favico URL. -->
  <xsl:param name="revision"></xsl:param>

  <!-- Generate the href attribute for the favico -->
  <xsl:template name="favico-href">
    <xsl:attribute name="href">
      <xsl:text>/r/</xsl:text>
      <xsl:value-of select="$revision"/>
      <xsl:text>/static/doc/favicon.ico</xsl:text>
    </xsl:attribute>
  </xsl:template>


  <!-- Override the main Table of Contents to remove the Table of Figures
  and Table of Tables. -->
  <xsl:param name="generate.toc">
      appendix  toc,title
      article/appendix  nop
      article   toc,title
      book      toc,title
      chapter   toc,title
      part      toc,title
      preface   toc,title
      qandadiv  toc
      qandaset  toc
      reference toc,title
      sect1     toc
      sect2     toc
      sect3     toc
      sect4     toc
      sect5     toc
      section   toc
      set       toc,title
  </xsl:param>


  <!-- Replace the label 'Table of Contents' on each page with "Contents" -->
  <xsl:param name="local.l10n.xml" select="document('')"/>
  <l:i18n xmlns:l="http://docbook.sourceforge.net/xmlns/l10n/1.0">
    <l:l10n language="en">
      <l:gentext key="TableofContents" text="Contents"/>
    </l:l10n>
  </l:i18n>

  <!-- ==================================================================== -->
  <xsl:template name="landscape.toc">
    <!--
      Landscape Table of Contents template is the simplified table of contents
      links presented in the left sidebar. It extracts this data by loading all
      chapter titles from the document(landscape.xml).
    -->
    <xsl:param name="titles" select="/foo"/>
    <xsl:param name="current_title" select="/foo"/>

    <h3><xsl:value-of select="$titles"/></h3>
    <strong>Table of Contents</strong>
    <table>
    <xsl:for-each select="$titles">
      <xsl:variable name="count" select="position() - 1"/>
          <xsl:choose>
            <xsl:when test="contains($current_title, .)">
              <tr class="selected">
                <td>
                  <a class="selected"><xsl:value-of select="."/></a>
                </td>
              </tr>
            </xsl:when>
            <xsl:otherwise>
              <tr class="nav">
                <td>
                  <xsl:choose>
                    <xsl:when test="$count = 0">
                      <a href="index.html">
                        <xsl:value-of select="$count"/>. <xsl:value-of select="."/>
                      </a>
                    </xsl:when>
                    <xsl:otherwise>
                      <a href="ch{format-number($count,'00')}.html">
                        <xsl:value-of select="$count"/>. <xsl:value-of select="."/>
                      </a>
                    </xsl:otherwise>
                  </xsl:choose>
                </td>
              </tr>
            </xsl:otherwise>
          </xsl:choose>
      </xsl:for-each>
    </table>
  </xsl:template>

  <!-- ==================================================================== -->
  <xsl:template name="landscape.header">
    <!--
      Landscape Header template gives us the landscape logo in the upper left
      corner.
    -->
    <div id="header">
      <div id="logo-container">
        <a href="/">
          <div id="logo">
            <div id="logo-text">
              LANDSCAPE
            </div>
          </div>
        </a>
      </div>
    </div>
  </xsl:template>

  <!-- ==================================================================== -->
  <xsl:template name="landscape.footer">
    <!--
      Landscape Footer template closes wraps up our page and gives a couple of
      external news and help links to give us the feel of the regular landscape
      UI.
    -->
    <div id="footer-container">
      <div id="footer">
        <div id="footer-logo-container">
          <div id="footer-logo">
            <div id="canonical-logo">
              <a href="http://www.canonical.com/" class="internal">
                <img src="css/canonical.png" alt="Canonical"/>
              </a>
            </div>
          </div>
        </div>
        <div id="footer-menu-container">
          <div id="footer-menu">
            <div id="system-menu">
              <div class="menu-content">
                <ul class="system-menu">
                  <li class="system-help-menu footer-menu-item">
                    <a href="http://help.landscape.canonical.com" title="help">Help</a>
                  </li>
                  <li class="system-latest-news-menu footer-menu-item">
                    <a href="https://insights.ubuntu.com" title="news">Latest News</a>
                  </li>
                  <li class="system-api-documentation-menu footer-menu-item">
                    <a href="/static/doc/api" title="api documentation">API Documentation</a>
                  </li>
                  <li class="system-user-guide-menu footer-menu-item">
                    <a href="/static/doc/user-guide" title="user guide">User Guide</a>
                  </li>
                </ul>
              </div>
            </div>
          </div>
        </div>
        <div id="footer-legal-container">
          <div id="footer-legal">
            <p>© 2005-2018 Canonical Ltd. <a href="https://www.ubuntu.com">Ubuntu</a> and <a href="https://www.canonical.com">Canonical</a> are registered trademarks of Canonical Ltd. <a href="https://www.ubuntu.com/legal">Legal information</a>.
            </p>
          </div>
        </div>
      </div>
    </div>
  </xsl:template>


  <!-- ==================================================================== -->
  <xsl:template name="header.navigation">
    <!--
      Landscape Header Navigation creates the PREV, NEXT and UP links that are
      common to most docbook generated web documentation. These links will be
      presented below the simplified table of contents in the left sidebar of
      the UI.
    -->
    <xsl:param name="prev" select="/foo"/>
    <xsl:param name="next" select="/foo"/>
    <xsl:param name="nav.context"/>

    <xsl:variable name="home" select="/*[1]"/>
    <xsl:variable name="up" select="parent::*"/>

    <xsl:variable name="row1" select="$navig.showtitles != 0"/>
    <xsl:variable name="row2" select="count($prev) &gt; 0 or (count($up) &gt; 0 and generate-id($up) != generate-id($home) and $navig.showtitles != 0) or count($next) &gt; 0"/>

    <xsl:if test="$suppress.navigation = '0' and $suppress.header.navigation = '0'">
      <div id="navigation">
        <div id="navheader">
          <xsl:call-template name="landscape.toc">
            <xsl:with-param name="titles" select="document('landscape.xml')//book/*/title"/>
            <xsl:with-param name="current_title">
                <xsl:apply-templates select="." mode="object.title.markup"/>
            </xsl:with-param>
          </xsl:call-template>
          <br />
          <hr class="nav"/>
          <div id="navhoriz">
            <xsl:if test="$row1 or $row2">
              <xsl:if test="$row2">
                <span id="navprev">
                  <xsl:choose>
                    <xsl:when test="count($prev)&gt;0">
                      <a accesskey="p">
                        <xsl:attribute name="href">
                          <xsl:call-template name="href.target">
                            <xsl:with-param name="object" select="$prev"/>
                          </xsl:call-template>
                        </xsl:attribute>
                        <xsl:call-template name="navig.content">
                          <xsl:with-param name="direction" select="'prev'"/>
                        </xsl:call-template>
                      </a>
                    </xsl:when>
                    <xsl:otherwise>
                      <a class="disabled">Prev</a>
                    </xsl:otherwise>
                  </xsl:choose>
                  <xsl:text>&#160;</xsl:text>
                </span>
                <span id="navindex">
                  <xsl:text>&#160;</xsl:text>
                  <xsl:choose>
                    <xsl:when test="count($up)&gt;0">
                      <a accesskey="u">
                        <xsl:attribute name="href">
                          <xsl:call-template name="href.target">
                            <xsl:with-param name="object" select="$up"/>
                          </xsl:call-template>
                        </xsl:attribute>
                        <xsl:call-template name="navig.content">
                          <xsl:with-param name="direction" select="'up'"/>
                        </xsl:call-template>
                      </a>
                    </xsl:when>
                    <xsl:otherwise>
                      <a class="disabled">Up</a>
                    </xsl:otherwise>
                  </xsl:choose>
                  <xsl:text>&#160;</xsl:text>
                </span>
                <span id="navnext">
                  <xsl:text>&#160;</xsl:text>
                  <xsl:choose>
                    <xsl:when test="count($next)&gt;0">
                      <a accesskey="n">
                        <xsl:attribute name="href">
                          <xsl:call-template name="href.target">
                            <xsl:with-param name="object" select="$next"/>
                          </xsl:call-template>
                        </xsl:attribute>
                        <xsl:call-template name="navig.content">
                          <xsl:with-param name="direction" select="'next'"/>
                        </xsl:call-template>
                      </a>
                    </xsl:when>
                    <xsl:otherwise>
                      <a class="disabled">Next</a>
                    </xsl:otherwise>
                  </xsl:choose>
                </span>
              </xsl:if>
            </xsl:if>
          </div>
        </div>
      </div>
    </xsl:if>
  </xsl:template>

  <!-- ==================================================================== -->
  <xsl:template match="*" mode="process.root">
    <!--
      Effectively our 'main' template. This is the highest-level template. It
      sets up the basic html layout and then calls all the other sub-templates
      defined above to fill in the details.
    -->
    <xsl:variable name="doc" select="self::*"/>

    <xsl:call-template name="user.preroot"/>
    <xsl:call-template name="root.messages"/>

    <html>
      <head>
        <link rel="shortcut icon" type="image/x-icon"
              id="style">
          <xsl:call-template name="favico-href"/>
        </link>

        <xsl:call-template name="system.head.content">
          <xsl:with-param name="node" select="$doc"/>
        </xsl:call-template>
        <xsl:call-template name="head.content">
          <xsl:with-param name="node" select="$doc"/>
        </xsl:call-template>
        <xsl:call-template name="user.head.content">
          <xsl:with-param name="node" select="$doc"/>
        </xsl:call-template>
      </head>
      <body>
        <xsl:call-template name="body.attributes"/>
        <div class="document">
          <div class="content">
            <xsl:call-template name="landscape.header"/>
            <xsl:call-template name="user.header.content">
              <xsl:with-param name="node" select="$doc"/>
            </xsl:call-template>
            <xsl:apply-templates select="."/>
            <xsl:call-template name="user.footer.content">
              <xsl:with-param name="node" select="$doc"/>
            </xsl:call-template>
          </div>
          <div id="push">
            <br>
            </br>
          </div>
        </div>
        <xsl:call-template name="landscape.footer"/>
      </body>
    </html>
    <xsl:value-of select="$html.append"/>

    <!-- Generate any css files only once, not once per chunk -->
    <xsl:call-template name="generate.css.files"/>
  </xsl:template>

  <!-- ==================================================================== -->
  <xsl:template name="chunk-element-content">
    <xsl:param name="prev"/>
    <xsl:param name="next"/>
    <xsl:param name="nav.context"/>
    <xsl:param name="content">
      <xsl:apply-imports/>
    </xsl:param>

    <xsl:call-template name="user.preroot"/>

    <html>



      <xsl:call-template name="html.head">
        <xsl:with-param name="prev" select="$prev"/>
        <xsl:with-param name="next" select="$next"/>
      </xsl:call-template>

      <body>
        <xsl:call-template name="body.attributes"/>
        <div class="document">
          <div class="content">
            <xsl:call-template name="landscape.header"/>
            <xsl:call-template name="user.header.navigation"/>

            <xsl:call-template name="header.navigation">
              <xsl:with-param name="prev" select="$prev"/>
              <xsl:with-param name="next" select="$next"/>
              <xsl:with-param name="nav.context" select="$nav.context"/>
            </xsl:call-template>

            <xsl:call-template name="user.header.content"/>

            <xsl:copy-of select="$content"/>

            <xsl:call-template name="user.footer.content"/>

            <xsl:call-template name="footer.navigation">
              <xsl:with-param name="prev" select="$prev"/>
              <xsl:with-param name="next" select="$next"/>
              <xsl:with-param name="nav.context" select="$nav.context"/>
            </xsl:call-template>

            <xsl:call-template name="user.footer.navigation"/>
          </div>
          <div id="push">
            <br>
            </br>
          </div>
        </div>
        <xsl:call-template name="landscape.footer"/>
      </body>
    </html>
    <xsl:value-of select="$chunk.append"/>
  </xsl:template>

<!-- ==================================================================== -->

  <xsl:template name="html.head">
    <xsl:param name="prev" select="/foo"/>
    <xsl:param name="next" select="/foo"/>
    <xsl:variable name="this" select="."/>
    <xsl:variable name="home" select="/*[1]"/>
    <xsl:variable name="up" select="parent::*"/>

    <head>
      <xsl:call-template name="system.head.content"/>
      <xsl:call-template name="head.content"/>

      <!-- Landscape favicon -->
      <link rel="shortcut icon" type="image/x-icon"
            id="style">
        <xsl:call-template name="favico-href"/>
      </link>


      <!-- home link not valid in HTML5 -->
      <xsl:if test="$home and $div.element != 'section'">
        <link rel="home">
          <xsl:attribute name="href">
            <xsl:call-template name="href.target">
              <xsl:with-param name="object" select="$home"/>
            </xsl:call-template>
          </xsl:attribute>
          <xsl:attribute name="title">
            <xsl:apply-templates select="$home" mode="object.title.markup.textonly"/>
          </xsl:attribute>
        </link>
      </xsl:if>

      <!-- up link not valid in HTML5 -->
      <xsl:if test="$up and $div.element != 'section'">
        <link rel="up">
          <xsl:attribute name="href">
            <xsl:call-template name="href.target">
              <xsl:with-param name="object" select="$up"/>
            </xsl:call-template>
          </xsl:attribute>
          <xsl:attribute name="title">
            <xsl:apply-templates select="$up" mode="object.title.markup.textonly"/>
          </xsl:attribute>
        </link>
      </xsl:if>

      <xsl:if test="$prev">
        <link rel="prev">
          <xsl:attribute name="href">
            <xsl:call-template name="href.target">
              <xsl:with-param name="object" select="$prev"/>
            </xsl:call-template>
          </xsl:attribute>
          <xsl:attribute name="title">
            <xsl:apply-templates select="$prev" mode="object.title.markup.textonly"/>
          </xsl:attribute>
        </link>
      </xsl:if>

      <xsl:if test="$next">
        <link rel="next">
          <xsl:attribute name="href">
            <xsl:call-template name="href.target">
              <xsl:with-param name="object" select="$next"/>
            </xsl:call-template>
          </xsl:attribute>
          <xsl:attribute name="title">
            <xsl:apply-templates select="$next" mode="object.title.markup.textonly"/>
          </xsl:attribute>
        </link>
      </xsl:if>

      <xsl:if test="$html.extra.head.links != 0">
        <xsl:for-each select="//part                             |//reference                             |//preface                             |//chapter                             |//article                             |//refentry                             |//appendix[not(parent::article)]|appendix                             |//glossary[not(parent::article)]|glossary                             |//index[not(parent::article)]|index">
          <link rel="{local-name(.)}">
            <xsl:attribute name="href">
              <xsl:call-template name="href.target">
                <xsl:with-param name="context" select="$this"/>
                <xsl:with-param name="object" select="."/>
              </xsl:call-template>
            </xsl:attribute>
            <xsl:attribute name="title">
              <xsl:apply-templates select="." mode="object.title.markup.textonly"/>
            </xsl:attribute>
          </link>
        </xsl:for-each>

        <xsl:for-each select="section|sect1|refsection|refsect1">
          <link>
            <xsl:attribute name="rel">
              <xsl:choose>
                <xsl:when test="local-name($this) = 'section'                               or local-name($this) = 'refsection'">
                  <xsl:value-of select="'subsection'"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="'section'"/>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:attribute>
            <xsl:attribute name="href">
              <xsl:call-template name="href.target">
                <xsl:with-param name="context" select="$this"/>
                <xsl:with-param name="object" select="."/>
              </xsl:call-template>
            </xsl:attribute>
            <xsl:attribute name="title">
              <xsl:apply-templates select="." mode="object.title.markup.textonly"/>
            </xsl:attribute>
          </link>
        </xsl:for-each>

        <xsl:for-each select="sect2|sect3|sect4|sect5|refsect2|refsect3">
          <link rel="subsection">
            <xsl:attribute name="href">
              <xsl:call-template name="href.target">
                <xsl:with-param name="context" select="$this"/>
                <xsl:with-param name="object" select="."/>
              </xsl:call-template>
            </xsl:attribute>
            <xsl:attribute name="title">
              <xsl:apply-templates select="." mode="object.title.markup.textonly"/>
            </xsl:attribute>
          </link>
        </xsl:for-each>
      </xsl:if>

      <xsl:call-template name="user.head.content"/>
    </head>
  </xsl:template>

</xsl:stylesheet>
