# Copyright 2005-2012 Canonical Limited.  All rights reserved.

from tempfile import mkdtemp
from shutil import rmtree
from os import popen, path

from lxml import etree

from testresources import ResourcedTestCase, TestResourceManager


class XSLTDocsDirResource(TestResourceManager):

    def make(self, dependencies):
        docs_dir = mkdtemp()
        popen(
            "make -C docs html-chunked "
            "LANDSCAPE_XML=docs/docbook-xml/landscape.xml "
            "HTML_PUBLISH_DIR='%s' 2> /dev/null" % docs_dir)
        return docs_dir

    def clean(self, resource):
        rmtree(resource)


class BaseTestCase(ResourcedTestCase):

    resources = [("docs_dir", XSLTDocsDirResource())]

    def test_xsl_chunked_pages(self):
        """
        Validate both index.html and chunked ch01.html are created from
        test.xml.
        """
        for html_file in ["index.html", "ch01.html"]:
            self.assertTrue(
                path.exists("%s/%s" % (self.docs_dir, html_file)),
                msg="Missing expected xslt chunked output file %s/%s" %
                (self.docs_dir, html_file))

    def test_navigation_toc_xsl_processing(self):
        """
        Validate that html-chunked.xsl can properly define the simplified
        table of contents navigation in the sidebar and disable the current
        page link.
        """
        parser = etree.HTMLParser()
        page_titles = {
            "index.html": "Landscape Documentation",
            "ch01.html": "About Landscape and Canonical"
        }

        for chunk_file in ["index.html", "ch01.html"]:
            tree = etree.parse("%s/%s" % (self.docs_dir, chunk_file), parser)
            navigation = tree.xpath("//div[@id='navheader']")[0]
            self.assertEqual(
                "Landscape Documentation",
                navigation.xpath("//h3")[0].text)

            # We should have one link for each book chapter
            self.assertEqual(
                9,
                len(navigation.xpath("//table/tr/td/a[@href]")))

            # The chapter link for the current page is set as selected
            self.assertEqual(
                page_titles[chunk_file],
                navigation.xpath(
                    "//table/tr/td/a[@class='selected']")[0].text)
