#!/bin/bash

. /opt/canonical/landscape/scripts/landscape-env.sh

SCRIPT_NAME=maintenance.sh
LOGGER_NAME=maintenance-script

LOCKFILE=$LOCKDIR/maintenance.lock

exit_if_not_running_cron
exit_if_maintenance_mode $LOGGER_NAME

# get the distributed lock and set a trap to clear it
acquire_lock $SCRIPT_NAME || exit 1
trap "release_lock $SCRIPT_NAME; rm -f $LOCKFILE" EXIT

# 129600s = 1.5d
lockfile -r0 -l 129600 $LOCKFILE
if [ "$?" -ne 0 ]; then
    echo Unable to grab $LOCKFILE lock - aborting
    exit 1
fi

result=0
mark_log "$LOGGER_NAME" "Start"
cd ${ROOTDIR}/landscape

set -o pipefail
./maintenance 2>&1 | pipe_to_syslog $LOGGER_NAME
if [ "$?" -ne 0 ]; then
    alert_admin "$LOGGER_NAME"
    result=1
fi
./schema-maintenance  2>&1 | pipe_to_syslog $LOGGER_NAME
if [ "$?" -ne 0 ]; then
    alert_admin "$LOGGER_NAME"
    result=1
fi
mark_log "$LOGGER_NAME" "End"

exit $result
