#!/bin/bash

. /opt/canonical/landscape/scripts/landscape-env.sh

SCRIPT_NAME=sync_lds_releases.sh
LOGGER_NAME=syncldsreleases

exit_if_not_running_cron
exit_if_maintenance_mode $LOGGER_NAME
load_proxy_config

# not archived, we just use it in case there are errors
OUTPUT_FILE=/var/lib/landscape/lds-releases.json
URL=https://landscape.canonical.com/get-lds-releases
LOCKFILE=$LOCKDIR/sync_lds_releases.lock
# if we can't connect in 60s, abort
CONNECT_TIMEOUT=60
# if speed is lower than 1 bytes/s during 120s, abort. It's stalled.
LOW_SPEED_LIMIT=1
SPEED_TIME=120
CURL_OPTIONS="-f -y $SPEED_TIME -Y $LOW_SPEED_LIMIT -L --max-redirs 10"
CURL_OPTIONS="$CURL_OPTIONS --connect-timeout $CONNECT_TIMEOUT"

# get the distributed lock and set a trap to clear it
acquire_lock $SCRIPT_NAME || exit 1
trap "release_lock $SCRIPT_NAME; rm -f $LOCKFILE" EXIT

# 129600s = 36h
lockfile -r0 -l 129600 $LOCKFILE
if [ "$?" -ne 0 ]; then
    log_to_syslog_and_stdout "$LOGGER_NAME" "Unable to grab $LOCKFILE lock - aborting"
    exit 1
fi

output=$(curl ${CURL_OPTIONS} --output ${OUTPUT_FILE}-new "$URL" 2>&1)
if [ "$?" -ne 0 ]; then
    log_to_syslog_and_stdout "$LOGGER_NAME" "Error downloading LDS releases data from $URL"
    log_to_syslog_and_stdout "$LOGGER_NAME" "$output"
    exit 1
fi
mv -f ${OUTPUT_FILE}-new ${OUTPUT_FILE}

cd ${ROOTDIR}/landscape
set -o pipefail
cat ${OUTPUT_FILE} | ./sync-lds-releases /dev/stdin 2>&1 | pipe_to_syslog $LOGGER_NAME
if [ "$?" -ne 0 ]; then
    alert_admin "$LOGGER_NAME"
    exit 1
fi
exit 0
