#!/bin/bash

# Refresh the list of known USNs by fetching it from the ubuntu website
# and feeding it to the process-usns script.

. /opt/canonical/landscape/scripts/landscape-env.sh

LOGGER_NAME=update-security-db
SCRIPT_NAME=update_security_db.sh

exit_if_not_running_cron
exit_if_maintenance_mode $LOGGER_NAME
load_proxy_config

# not archived, we just use it in case there are errors
OUTPUT_FILE=/var/lib/landscape/usndb.json.bz2
URL=https://usn.ubuntu.com/usn-db/database.json.bz2
LOCKFILE=$LOCKDIR/update_security.lock
# if we can't connect in this amount of time [in seconds], abort
CONNECT_TIMEOUT=60
# if the speed is lower than 1byte/s for 2min, abort. It's stalled.
LOW_SPEED_LIMIT=1
SPEED_TIME=120
CURL_OPTIONS="-f -y $SPEED_TIME -Y $LOW_SPEED_LIMIT -L --max-redirs 10"
CURL_OPTIONS="$CURL_OPTIONS --connect-timeout $CONNECT_TIMEOUT"


# get the distributed lock and set a trap to clear it
acquire_lock $SCRIPT_NAME || exit 1
trap "release_lock $SCRIPT_NAME; rm -f $LOCKFILE" EXIT

# 5400s = 1.5h
lockfile -r0 -l 5400 $LOCKFILE
if [ "$?" -ne 0 ]; then
    log_to_syslog_and_stdout "$LOGGER_NAME" "Unable to grab $LOCKFILE lock - aborting"
    exit 1
fi

# Mitigation for load generated on usn.ubuntu.com (LP: #1754806)
# Spread queries on 15 minutes, and move 5min past the current peak.
sleep $(( 300 + (RANDOM % 900) ))

output=$(curl ${CURL_OPTIONS} --output "${OUTPUT_FILE}"-new "$URL" 2>&1)
if [ "$?" -ne 0 ]; then
    log_to_syslog_and_stdout "$LOGGER_NAME" "Error downloading USN pickle from $URL"
    log_to_syslog_and_stdout "$LOGGER_NAME" "$output"
    exit 1
fi
mv -f ${OUTPUT_FILE}-new ${OUTPUT_FILE}

cd ${ROOTDIR}/landscape
set -o pipefail
bzcat ${OUTPUT_FILE} | ./process-usns /dev/stdin 2>&1 | pipe_to_syslog $LOGGER_NAME
if [ "$?" -ne 0 ]; then
    alert_admin $SCRIPT_NAME
    exit 1
fi
exit 0
