# This is a Source Makefile for Landscape

ROOT_DIR=$(shell pwd)/src/landscape

GO=$(shell which go)
GOPATH=$(ROOT_DIR)/go
GOSRC=$(GOPATH)/src/launchpad.net/landscape/cmd/packagesearch

YUICOMPRESSOR = /usr/bin/yui-compressor

STATIC_DIR=$(ROOT_DIR)/canonical/landscape/static

LANDSCAPE_CSS_EMBED_FILE = $(STATIC_DIR)/skin/manx/embed.css

LANDSCAPE_SCSS_FILES = $(shell find -L $(STATIC_DIR)/skin/hokan -type f -name '*.scss')
LANDSCAPE_CSS_FILES = $(STATIC_DIR)/skin/manx/sprite.css \
                           $(STATIC_DIR)/skin/manx/base.css \
			   $(STATIC_DIR)/skin/manx/tabview.css \
			   $(LANDSCAPE_EMBED_FILE) \
                           $(shell find -L $(STATIC_DIR)/skin/hokan \
                                        -type f -name '*.css' \
                                        -not -name '*-min.css') \
	                   $(LANDSCAPE_SCSS_FILES:.scss=.css)
LANDSCAPE_CSS_MIN_FILES = $(LANDSCAPE_CSS_FILES:.css=-min.css)

JAVASCRIPT_DIR = $(ROOT_DIR)/canonical/landscape/javascript

META_JS_FILES = $(STATIC_DIR)/landscape-yui-meta.js

LANDSCAPE_JS_FILES = $(shell find -L $(JAVASCRIPT_DIR) \
	-type f \
	-name '*.js' \
	| grep -v 'test-config.js' \
	| grep -v '\-min.js' \
	| grep -v '\-debug.js' \
	| grep -v '/test' \
	| sort)

JS_FILES = $(LANDSCAPE_JS_FILES)
JS_FILES += $(META_JS_FILES)

JS_MIN_FILES = $(JS_FILES:.js=-min.js)

META_JS_MIN_FILES = $(META_JS_FILES:.js=-min.js)


%-min.css: %.css
	@$(YUICOMPRESSOR) --type=css $< -o $(<:.css=-min.css)

%.css: %.scss
	sass --style=extended $< $@

css-build: $(LANDSCAPE_CSS_MIN_FILES)


# Minify all JS files that are not minified yet (or that are newer
# than their minified variant) into -min.js.
%-min.js: %.js
	@$(YUICOMPRESSOR) --type=js $< -o $(<:.js=-min.js)

js-build: $(META_JS_MIN_FILES) $(JS_MIN_FILES)

install: css-build js-build
	$(GOSRC)/createversion.sh
	cd $(GOSRC) &&\
		GOPATH=$(GOPATH) GOCACHE=/tmp/ $(GO) build -mod=vendor -o $(GOPATH)/bin/packagesearch
	@mkdir -p $(DESTDIR)/opt/canonical/landscape/go/bin
	install -m 0755 -D $(GOPATH)/bin/packagesearch $(DESTDIR)/opt/canonical/landscape/go/bin
	@cp -pr src/* $(DESTDIR)/opt/canonical
	@rm -rf $(DESTDIR)/opt/canonical/landscape/go-third-party
	@rm -rf $(DESTDIR)/opt/canonical/landscape/go/pkg
	@rm -rf $(DESTDIR)/opt/canonical/landscape/go/src
	@mkdir -p $(DESTDIR)/var/lib/landscape
	@mkdir -p $(DESTDIR)/var/lib/landscape-server
	@cp -pr scripts $(DESTDIR)/opt/canonical/landscape
	@cp -pr apacheroot $(DESTDIR)/opt/canonical/landscape
	@cp -pr gnupg $(DESTDIR)/var/lib/landscape-server/gnupg
	@chmod 0700 $(DESTDIR)/var/lib/landscape-server/gnupg

clean:
	# Nothing todo
