from tests.helpers.pages.page import PageObject

NAVIGATION = "#accounts-menu"

SECONDARY_NAVIGATION = "#toolbar-menu"
NAVIGATION_BILLING = SECONDARY_NAVIGATION + " .account-billing-menu a"

ALERT_MENU = "#account-global-alerts-menu"
ALERT_MENU_ITEMS = ALERT_MENU + " .yui3-menuitem-content"

PERSON_NAME = "#header .link-button.header-user-title"

BUTTON_LOGOUT = "input[value='Logout']"


class AccountBase(PageObject):
    """Base class for all account-related page objects."""

    def navigation_go_to_billing(self):
        """Go to the billing page"""
        self.log("Navigate to Billing")
        self._click(NAVIGATION_BILLING)
        return Billing(self._driver)

    def alerts_menu_wait_item(self, text, seconds):
        """Wait for an alerts menu item with the given text to pop up."""

        # Check if alerts menu item matches the given text
        def condition(driver):
            items = self._all(ALERT_MENU_ITEMS)
            for item in items:
                if item.get_property("innerHTML") == text:
                    return True
            return False

        return self._wait(condition)

    def person_name_is(self, name):
        """Return True if the name of the logged in person is the given one."""
        link = self._one(PERSON_NAME)
        return link.text == name

    def logout(self):
        """Logout from Landscape."""
        self.log("Log out from the Landscape web UI")
        self._click(BUTTON_LOGOUT)


# Avoid circular import errors
from tests.helpers.pages.account.billing import Billing
