from selenium.webdriver.support.expected_conditions import title_contains
from selenium.webdriver.support.ui import WebDriverWait

from tests.helpers.pages.page import PageObject
from tests.helpers.pages.root.signup import Signup
from tests.helpers.pages.account.dashboard import AccountDashboard
from tests.helpers.resources import get_root_url


class Home(PageObject):
    """The home page."""

    _title = "Fake OpenID provider - Decide"

    def login(self, email=None, password=None, identity=None):
        """Login into Landscape.

        This method supports multiple authentication mechanisms, depending
        on the arguments that are passed.

        @param email: In case of password login, the email to use.
        @param password: The password to use.
        @param identity: In case of OpenID login, the identity to use.
        """
        self.log("Log into the Landscape web UI")
        if email and password:
            self._login_password(email, password)
        elif identity:
            self._login_openid(identity)

        condition = title_contains(self._title)
        wait = WebDriverWait(self._driver, 10)
        wait.until_not(condition)

        if self.title == Signup._title:
            return Signup(self._driver)
        else:
            return AccountDashboard(self._driver)

    def _login_password(self, email, password):
        """Login using password authentication."""
        self._fill("#login_form_email", email)
        self._fill("#login_form_password", password)
        self._click("#login_form_submit")

    def _login_openid(self, identity):
        """Login using OpenID."""
        self._driver.get(get_root_url() + "/login/authenticate")
        assert self._driver.title == "Fake OpenID provider - Decide"
        self._fill("#identity", identity)
        self._click("#success-button")

    def _page_wait_yui(self):
        """The new Landscape SaaS home page has no YUI, so short circuit it."""

        # If there's no data-page-key in the body, it means this is the SaaS
        # home page (on-premise Landscape will still have it).
        body = self._one("body")
        if not body.get_attribute("data-page-key"):
            return

        super(Home, self)._page_wait_yui()
