from testtools.content import text_content

from tests.helpers.integration import IntegrationTest
from tests.helpers.resources import get_selenium_driver, get_root_url
from tests.helpers.pages.root.home import Home


class UITest(IntegrationTest):
    """An integration test exercising the web UI.

    In case of test failure a number of logs will be saved under the
    tests/artifacts/ directory, with filenames matching the failed test.

    It's possible to increase available information about Javascript logic by
    adding to the code debug calls like console.log() or Y.log(), which will
    be saved in the '<test-name>.console' artifact.
    """

    with_account = True
    with_person = True

    with_appserver = True
    with_async_frontend = True
    with_job_handler = True

    def setUp(self):
        super(UITest, self).setUp()
        self._driver = get_selenium_driver()
        self.addOnException(self._add_selenium_details)

    def _add_selenium_details(self, exc_info):
        """Save screenshot, source and the console of the current page."""
        screenshot = self._get_artifact_path(".png")
        self._driver.get_screenshot_as_file(screenshot)
        self.addDetail("screenshot", text_content(screenshot))

        source = self._get_artifact_path(".html")
        with open(source, "w") as fd:
            fd.write(self._driver.page_source)
        self.addDetail("source", text_content(source))

        console = self._get_artifact_path(".console")
        with open(console, "w") as fd:
            for entry in self._driver.get_log("browser"):
                fd.write("%(timestamp)d - %(message)s\n" % entry)
        self.addDetail("console", text_content(console))

    def get_home(self):
        """Return the Home page object."""
        self._driver.get(get_root_url())
        return Home(self._driver)

    def login(self, whom=None):
        """Login into Landscape."""
        whom = whom if whom else self.person.identity
        home = self.get_home()
        return home.login(identity=whom)

    @property
    def title(self):
        """Get the title of the current page."""
        return self._driver.title
