import os
import time
from threading import Thread

from twisted.internet import reactor

from canonical.landscape.message.backoff import BackoffStatus
from canonical.testing.unit import UnitTest


def run():
    """A helper function so that reactor can run in a python thread"""
    reactor.run(installSignalHandlers=False)


class ReactorTest(UnitTest):
    """
    A helper class that runs the reactor in the background of a testsuite
    """

    def setUp(self):
        super(ReactorTest, self).setUp()
        thread = Thread(target=run)
        thread.start()

    def tearDown(self):
        super(ReactorTest, self).tearDown()
        reactor.stop()


class BackoffInotifyTest(ReactorTest):
    def test_inotify_triggered(self):
        """
        Test that inotify calls the appropriate function after file changes
        """
        path = self.makeFile("5", basename=BackoffStatus.FILENAME)
        backoff = BackoffStatus(os.path.dirname(path))
        path = self.makeFile("42", path=path)
        time.sleep(0.5)
        self.assertEqual(42, backoff._percent_denied)
