from tests.helpers.ui import UITest

from canonical.landscape.model.configuration import set_stripe_api_keys
from canonical.landscape.sample.sample import (
    SAMPLE_STRIPE_PUBLIC_KEY,
    SAMPLE_STRIPE_SECRET_KEY,
)


class HomeTest(UITest):
    def test_title(self):
        """
        The home page is redirected to login page
        """
        self.get_home()
        self.assertIn("Fake OpenID provider", self.title)

    def test_login(self):
        """
        It's possible to login and get to the account dashboard.
        """
        account_dashboard = self.login()
        self.assertTrue(account_dashboard.person_name_is(self.person.name))

    def test_login_to_signup(self):
        """
        With self-service enabled, from Home, unknown identities go to the
        Signup page.
        """
        set_stripe_api_keys(SAMPLE_STRIPE_PUBLIC_KEY, SAMPLE_STRIPE_SECRET_KEY)
        self.enable_feature_flags("self-service")
        new_identity = self.person.identity + "-integration"
        self.login(new_identity)
        self.assertEqual("Signup - Landscape", self.title)
