# Copyright 2005-2013 Canonical Limited.  All rights reserved.

from zope.schema import Choice

from canonical.content.form import Fields, action
from canonical.url import get_url

from canonical.landscape.model.package.interfaces import IPackageProfile
from canonical.landscape.model.package.profile import PackageProfilesManagement

from canonical.landscape.ui.account.page import AccountPage
from canonical.landscape.ui.form import LandscapeFormProvider
from canonical.landscape.model.main.person import PersonAccessContextsVocabularyFactory


class CopyPackageProfilePage(AccountPage):

    title = "Copy package profile"

    requires = "landscape.CreatePackageProfile"

    def get_computer_ids_with_installed_packages(self):
        """
        We do not allow PackageProfile copy page to specify a computer.
        Return an empty list so as not to allow choosing a computer.
        """
        return list()


class CopyPackageProfileForm(LandscapeFormProvider):

    fields = Fields(IPackageProfile, render_context=True)
    fields = fields.omit("access_context")

    package_error = ""

    def __init__(self, context, request, view):
        super(CopyPackageProfileForm, self).__init__(context, request, view)
        self.summary = "Copy package profile '%s'" % context.name
        self.person = request.principal.person
        self.management = PackageProfilesManagement(
            self.context.account, person=self.person
        )
        access_context = Choice(
            __name__="access_context",
            title="Access group",
            source=PersonAccessContextsVocabularyFactory(
                "CreatePackageProfile", person=self.person
            ),
            default="Global",
            description="The access group the profile should belong to.",
            required=True,
        )
        self.fields += Fields(access_context)
        self.fields = self.fields.hide(
            "creation_time", "modification_time", "version", "package"
        )

    def validate(self, action, data):
        if self.management.get_package_profile_by_name(data.get("name")):
            self.add_error(
                "This name is already used by another profile. "
                "Please use a different one.",
                "name",
            )

    @action("Copy", primary=True)
    def copy(self, action, data):
        profile = self.management.copy_package_profile(
            self.context.name,
            name=data.get("name"),
            title=data.get("title"),
            description=data.get("description"),
            access_context_name=data.get("access_context"),
        )
        profile.on_create(self.person)
        self.request.response.redirect(get_url(profile, self.request))
